<?php
/**
 * 安装向导辅助函数
 */

// 开启会话
session_start();

/**
 * 检查系统环境要求
 * @return array
 */
function checkRequirements() {
    $requirements = array(
        array(
            'name' => 'PHP版本',
            'required' => '5.4.0 或更高',
            'current' => PHP_VERSION,
            'status' => version_compare(PHP_VERSION, '5.4.0', '>=')
        ),
        array(
            'name' => 'MySQL 支持',
            'required' => '开启',
            'current' => extension_loaded('mysqli') ? '开启' : '未开启',
            'status' => extension_loaded('mysqli')
        ),
        array(
            'name' => 'PDO 扩展',
            'required' => '开启',
            'current' => extension_loaded('pdo') ? '开启' : '未开启',
            'status' => extension_loaded('pdo')
        ),
        array(
            'name' => 'GD 库',
            'required' => '开启',
            'current' => extension_loaded('gd') ? '开启' : '未开启',
            'status' => extension_loaded('gd')
        ),
        array(
            'name' => 'JSON 支持',
            'required' => '开启',
            'current' => extension_loaded('json') ? '开启' : '未开启',
            'status' => extension_loaded('json')
        ),
        array(
            'name' => 'CURL 支持',
            'required' => '开启',
            'current' => extension_loaded('curl') ? '开启' : '未开启',
            'status' => extension_loaded('curl')
        )
    );
    
    return $requirements;
}

/**
 * 检查目录权限
 * @return array
 */
function checkDirectories() {
    $dirs = array(
        array(
            'path' => ROOT_PATH . DS . 'Data',
            'writable' => is_writable(ROOT_PATH . DS . 'Data')
        ),
        array(
            'path' => ROOT_PATH . DS . 'uploads',
            'writable' => is_writable(ROOT_PATH . DS . 'uploads')
        ),
        array(
            'path' => ROOT_PATH . DS . 'config',
            'writable' => is_writable(ROOT_PATH . DS . 'config')
        ),
        array(
            'path' => ROOT_PATH . DS . 'Install' . DS . 'key.txt',
            'writable' => is_writable(ROOT_PATH . DS . 'Install' . DS . 'key.txt')
        )
    );
    
    return $dirs;
}

/**
 * 检查必要的函数
 * @return array
 */
function checkFunctions() {
    $functions = array(
        array(
            'name' => 'file_get_contents',
            'available' => function_exists('file_get_contents')
        ),
        array(
            'name' => 'file_put_contents',
            'available' => function_exists('file_put_contents')
        ),
        array(
            'name' => 'mysqli_connect',
            'available' => function_exists('mysqli_connect')
        ),
        array(
            'name' => 'mb_strlen',
            'available' => function_exists('mb_strlen')
        )
    );
    
    return $functions;
}

/**
 * 检查是否可以安装
 * @param array $vars
 * @return bool
 */
function canInstall($vars) {
    // 检查系统要求
    foreach ($vars['requirements'] as $requirement) {
        if (!$requirement['status']) {
            return false;
        }
    }
    
    // 检查目录权限
    foreach ($vars['directories'] as $directory) {
        if (!$directory['writable']) {
            return false;
        }
    }
    
    // 检查函数可用性
    foreach ($vars['functions'] as $function) {
        if (!$function['available']) {
            return false;
        }
    }
    
    return true;
}

/**
 * 从检查结果判断是否可以安装
 * @return bool
 */
function canInstallFromCheck() {
    $requirements = checkRequirements();
    $directories = checkDirectories();
    $functions = checkFunctions();
    
    // 检查系统要求
    foreach ($requirements as $requirement) {
        if (!$requirement['status']) {
            return false;
        }
    }
    
    // 检查目录权限
    foreach ($directories as $directory) {
        if (!$directory['writable']) {
            return false;
        }
    }
    
    // 检查函数可用性
    foreach ($functions as $function) {
        if (!$function['available']) {
            return false;
        }
    }
    
    return true;
}

/**
 * 验证数据库配置
 * @param array $db
 * @return array 错误信息
 */
function validateDatabase($db) {
    $errors = array();
    
    // 检查必填字段
    if (empty($db['host'])) {
        $errors[] = '数据库主机不能为空';
    }
    
    if (empty($db['name'])) {
        $errors[] = '数据库名不能为空';
    }
    
    if (empty($db['user'])) {
        $errors[] = '数据库用户名不能为空';
    }
    
    if (empty($db['prefix'])) {
        $errors[] = '数据库表前缀不能为空';
    } else if (!preg_match('/^[a-zA-Z0-9_]+$/', str_replace('_', '', $db['prefix']))) {
        $errors[] = '数据库表前缀只能包含字母、数字和下划线';
    }
    
    // 确保前缀以下划线结尾
    if (!empty($db['prefix']) && substr($db['prefix'], -1) !== '_') {
        $db['prefix'] .= '_';
    }
    
    // 测试数据库连接
    if (empty($errors)) {
        try {
            $conn = @mysqli_connect($db['host'], $db['user'], $db['password'], '', $db['port']);
            
            if (!$conn) {
                $errors[] = '无法连接到数据库服务器: ' . mysqli_connect_error();
            } else {
                // 检查数据库是否存在
                $dbExists = mysqli_select_db($conn, $db['name']);
                
                if (!$dbExists) {
                    // 尝试创建数据库
                    $sql = "CREATE DATABASE IF NOT EXISTS `" . $db['name'] . "` DEFAULT CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci";
                    if (!mysqli_query($conn, $sql)) {
                        $errors[] = '无法创建数据库: ' . mysqli_error($conn);
                    }
                }
                
                mysqli_close($conn);
            }
        } catch (Exception $e) {
            $errors[] = '数据库连接异常: ' . $e->getMessage();
        }
    }
    
    return $errors;
}

/**
 * 验证网站配置
 * @param array $config
 * @return array 错误信息
 */
function validateConfig($config) {
    $errors = array();
    
    // 检查必填字段
    if (empty($config['site_name'])) {
        $errors[] = '网站名称不能为空';
    }
    
    if (empty($config['site_url'])) {
        $errors[] = '网站URL不能为空';
    }
    
    if (empty($config['admin_user'])) {
        $errors[] = '管理员用户名不能为空';
    }
    
    if (empty($config['admin_password'])) {
        $errors[] = '管理员密码不能为空';
    } else if (strlen($config['admin_password']) < 6) {
        $errors[] = '管理员密码长度不能少于6个字符';
    }
    
    if (empty($config['admin_email'])) {
        $errors[] = '管理员邮箱不能为空';
    } else if (!filter_var($config['admin_email'], FILTER_VALIDATE_EMAIL)) {
        $errors[] = '管理员邮箱格式不正确';
    }
    
    return $errors;
}

/**
 * 重定向
 * @param string $url
 */
function redirect($url) {
    header('Location: ' . $url);
    exit;
}

/**
 * 执行SQL文件
 * @param string $filename
 * @param array $db
 * @return array|bool 错误信息或成功
 */
function executeSqlFile($filename, $db) {
    if (!file_exists($filename)) {
        return array('SQL文件不存在: ' . $filename);
    }
    
    // 读取SQL文件
    $sql = file_get_contents($filename);
    if (!$sql) {
        return array('无法读取SQL文件: ' . $filename);
    }
    
    // 连接数据库
    $conn = @mysqli_connect($db['host'], $db['user'], $db['password'], $db['name'], $db['port']);
    if (!$conn) {
        return array('无法连接到数据库: ' . mysqli_connect_error());
    }
    
    // 设置编码
    mysqli_set_charset($conn, 'utf8mb4');
    
    // 分割SQL语句
    $sql = str_replace("\r", "\n", $sql);
    $queries = explode(";\n", $sql);
    
    // 执行SQL语句
    foreach ($queries as $query) {
        $query = trim($query);
        if (!empty($query)) {
            // 替换表前缀
            $query = str_replace('prefix_', $db['prefix'], $query);
            
            if (!mysqli_query($conn, $query)) {
                return array('SQL执行错误: ' . mysqli_error($conn) . "\nSQL: " . $query);
            }
        }
    }
    
    mysqli_close($conn);
    return true;
}

/**
 * 写入配置文件
 * @param array $db 数据库配置
 * @param array $config 网站配置
 * @return bool
 */
function writeConfig($db, $config) {
    // 确保config目录存在
    $configDir = ROOT_PATH . DS . 'config';
    
    // 检查目录是否存在，如不存在则创建
    if (!file_exists($configDir)) {
        if (!mkdir($configDir, 0755, true)) {
            return false;
        }
    }
    
    // 尝试使目录可写
    if (!is_writable($configDir)) {
        @chmod($configDir, 0755);
        if (!is_writable($configDir)) {
            @chmod($configDir, 0777);
        }
    }
    
    // 创建database.php文件
    $databaseFile = $configDir . DS . 'database.php';
    $databaseContent = "<?php
/**
 * 数据库连接配置文件
 * 
 * 此文件包含数据库连接所需的所有配置信息
 */

// 数据库连接信息
define('DB_HOST', '{$db['host']}');      // 数据库主机地址
define('DB_NAME', '{$db['name']}');      // 数据库名称
define('DB_USER', '{$db['user']}');      // 数据库用户名
define('DB_PASSWORD', '{$db['password']}'); // 数据库密码
define('DB_CHARSET', 'utf8mb4');         // 数据库字符集
define('DB_COLLATE', 'utf8mb4_unicode_ci'); // 数据库排序规则

/**
 * 数据库连接函数
 * 
 * @return PDO 数据库连接对象
 */
function getDbConnection() {
    // 使用已定义的常量
    try {
        \$dsn = \"mysql:host=\" . DB_HOST . \";dbname=\" . DB_NAME . \";charset=\" . DB_CHARSET;
        \$options = [
            PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION,
            PDO::ATTR_DEFAULT_FETCH_MODE => PDO::FETCH_ASSOC,
            PDO::ATTR_EMULATE_PREPARES => false,
        ];
        
        \$pdo = new PDO(\$dsn, DB_USER, DB_PASSWORD, \$options);
        return \$pdo;
    } catch (PDOException \$e) {
        // 生产环境中应该记录错误而不是显示
        die(\"数据库连接失败: \" . \$e->getMessage());
    }
}

/**
 * 使用示例:
 * 
 * // 引入数据库配置文件
 * require_once 'config/database.php';
 * 
 * // 获取数据库连接
 * \$db = getDbConnection();
 * 
 * // 执行查询
 * \$stmt = \$db->query(\"SELECT * FROM users\");
 * \$users = \$stmt->fetchAll();
 */
?>";

    // 创建config.php文件 (可选，如果您的系统需要)
    $configFile = $configDir . DS . 'config.php';
    $configContent = "<?php
/**
 * 站点配置文件
 * 
 * 此文件包含站点基本配置信息
 */

// 站点配置
define('SITE_NAME', '{$config['site_name']}');
define('SITE_URL', '{$config['site_url']}');
define('ADMIN_EMAIL', '{$config['admin_email']}');
define('INSTALL_TIME', '" . date('Y-m-d H:i:s') . "');

?>";

    // 写入两个文件
    $dbResult = file_put_contents($databaseFile, $databaseContent);
    $configResult = file_put_contents($configFile, $configContent);
    
    return ($dbResult !== false && $configResult !== false);
}

/**
 * 创建安装锁定信息
 * @return bool
 */
function createLockFile() {
    $keyFile = ROOT_PATH . DS . 'Install' . DS . 'key.txt';
    // 写入随机数字作为安装标记
    $content = rand(1000, 9999);
    return file_put_contents($keyFile, $content) !== false;
} 