<?php
/**
 * 视频评论添加API
 * 
 * 接收POST请求，添加视频评论
 */

// 设置JSON响应头
header('Content-Type: application/json');

// 引入数据库配置
require_once __DIR__ . '/../config/database.php';

// 检查是否是POST请求
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    echo json_encode([
        'success' => false,
        'message' => '仅接受POST请求'
    ]);
    exit;
}

try {
    // 获取请求体数据
    $inputJSON = file_get_contents('php://input');
    $input = json_decode($inputJSON, true);
    
    // 验证参数
    if (!isset($input['video_id']) || !is_numeric($input['video_id'])) {
        echo json_encode([
            'success' => false,
            'message' => '缺少有效的视频ID参数'
        ]);
        exit;
    }
    
    if (!isset($input['content']) || empty(trim($input['content']))) {
        echo json_encode([
            'success' => false,
            'message' => '评论内容不能为空'
        ]);
        exit;
    }
    
    $videoId = intval($input['video_id']);
    $content = trim($input['content']);
    $parentId = isset($input['parent_id']) ? intval($input['parent_id']) : 0;
    
    // 获取数据库连接
    $db = getDbConnection();
    
    // 检查视频是否存在
    $stmt = $db->prepare("SELECT id FROM videos WHERE id = ? AND status = 1 LIMIT 1");
    $stmt->execute([$videoId]);
    
    if (!$stmt->fetch()) {
        echo json_encode([
            'success' => false,
            'message' => '视频不存在或已禁用'
        ]);
        exit;
    }
    
    // 检查父评论是否存在（如果有）
    if ($parentId > 0) {
        $stmt = $db->prepare("SELECT id FROM video_comments WHERE id = ? AND status = 1 LIMIT 1");
        $stmt->execute([$parentId]);
        
        if (!$stmt->fetch()) {
            echo json_encode([
                'success' => false,
                'message' => '回复的评论不存在或已被删除'
            ]);
            exit;
        }
    }
    
    // 获取用户信息（如果已登录）
    $userId = null;
    $authorName = '匿名用户';
    
    // 如果有会话，尝试获取用户信息
    session_start();
    if (isset($_SESSION['user_id'])) {
        $userId = $_SESSION['user_id'];
        
        // 获取用户名
        $stmt = $db->prepare("SELECT username FROM user WHERE id = ? LIMIT 1");
        $stmt->execute([$userId]);
        $user = $stmt->fetch();
        
        if ($user) {
            $authorName = $user['username'];
        }
    }
    
    // 插入评论
    $stmt = $db->prepare("
        INSERT INTO video_comments (video_id, user_id, author_name, content, parent_id, status, created_at, updated_at)
        VALUES (?, ?, ?, ?, ?, 1, NOW(), NOW())
    ");
    
    $stmt->execute([$videoId, $userId, $authorName, $content, $parentId]);
    $commentId = $db->lastInsertId();
    
    // 返回成功响应及新评论数据
    echo json_encode([
        'success' => true,
        'message' => '评论发表成功',
        'data' => [
            'id' => $commentId,
            'video_id' => $videoId,
            'user_id' => $userId,
            'author_name' => $authorName,
            'content' => $content,
            'parent_id' => $parentId,
            'likes' => 0,
            'created_at' => date('Y-m-d H:i:s')
        ]
    ]);
    
} catch (Exception $e) {
    // 记录错误
    error_log('添加评论错误: ' . $e->getMessage());
    
    // 返回错误响应
    echo json_encode([
        'success' => false,
        'message' => '系统错误，请稍后再试'
    ]);
} 