<?php
/**
 * 视频评论列表API
 * 
 * 接收GET请求，获取视频评论列表
 */

// 设置JSON响应头
header('Content-Type: application/json');

// 引入数据库配置
require_once __DIR__ . '/../config/database.php';

// 检查是否是GET请求
if ($_SERVER['REQUEST_METHOD'] !== 'GET') {
    echo json_encode([
        'success' => false,
        'message' => '仅接受GET请求'
    ]);
    exit;
}

try {
    // 验证参数
    if (!isset($_GET['video_id']) || !is_numeric($_GET['video_id'])) {
        echo json_encode([
            'success' => false,
            'message' => '缺少有效的视频ID参数'
        ]);
        exit;
    }
    
    $videoId = intval($_GET['video_id']);
    $offset = isset($_GET['offset']) ? intval($_GET['offset']) : 0;
    $limit = isset($_GET['limit']) ? intval($_GET['limit']) : 10;
    
    // 限制每页最大数量
    if ($limit > 50) {
        $limit = 50;
    }
    
    // 获取数据库连接
    $db = getDbConnection();
    
    // 获取评论列表
    $stmt = $db->prepare("
        SELECT vc.*, u.username
        FROM video_comments vc
        LEFT JOIN user u ON vc.user_id = u.id
        WHERE vc.video_id = ? AND vc.status = 1 AND vc.parent_id = 0
        ORDER BY vc.created_at DESC
        LIMIT ?, ?
    ");
    $stmt->bindParam(1, $videoId, PDO::PARAM_INT);
    $stmt->bindParam(2, $offset, PDO::PARAM_INT);
    $stmt->bindParam(3, $limit, PDO::PARAM_INT);
    $stmt->execute();
    
    $comments = $stmt->fetchAll();
    
    // 获取评论总数
    $stmt = $db->prepare("
        SELECT COUNT(*) as total 
        FROM video_comments 
        WHERE video_id = ? AND status = 1 AND parent_id = 0
    ");
    $stmt->execute([$videoId]);
    $totalComments = $stmt->fetch()['total'];
    
    // 计算是否有更多评论
    $hasMore = ($offset + $limit) < $totalComments;
    
    // 处理评论数据
    $formattedComments = [];
    foreach ($comments as $comment) {
        // 格式化日期
        $createdAt = new DateTime($comment['created_at']);
        
        $formattedComments[] = [
            'id' => $comment['id'],
            'video_id' => $comment['video_id'],
            'user_id' => $comment['user_id'],
            'author_name' => $comment['author_name'] ?: ($comment['username'] ?: '匿名用户'),
            'content' => $comment['content'],
            'likes' => $comment['likes'],
            'parent_id' => $comment['parent_id'],
            'created_at' => $createdAt->format('Y-m-d'),
            'has_replies' => false // 此处可以扩展为检查是否有回复
        ];
    }
    
    // 返回成功响应
    echo json_encode([
        'success' => true,
        'data' => [
            'comments' => $formattedComments,
            'total' => $totalComments,
            'offset' => $offset,
            'limit' => $limit,
            'has_more' => $hasMore
        ]
    ]);
    
} catch (Exception $e) {
    // 记录错误
    error_log('获取评论列表错误: ' . $e->getMessage());
    
    // 返回错误响应
    echo json_encode([
        'success' => false,
        'message' => '系统错误，请稍后再试'
    ]);
} 