<?php
/**
 * 备份创建处理
 */
// 引入数据库配置文件
require_once '../config/database.php';

// 设置执行时间为无限制（大型网站备份可能需要较长时间）
set_time_limit(0);
ini_set('memory_limit', '512M');

// 确保Data目录存在
$backupDir = '../Data/';
if (!file_exists($backupDir)) {
    mkdir($backupDir, 0777, true);
}

// 检查请求类型
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    header('Location: backup.php?error=无效的请求方法');
    exit;
}

// 获取备份类型
$backupType = isset($_POST['type']) ? $_POST['type'] : '';

if ($backupType === 'database') {
    // 数据库备份
    try {
        $db = getDbConnection();
        
        // 创建备份文件名
        $backupFileName = 'database_backup_' . date('Y-m-d_H-i-s') . '.sql';
        $backupFilePath = $backupDir . $backupFileName;
        
        // 打开文件用于写入
        $file = fopen($backupFilePath, 'w');
        
        if (!$file) {
            throw new Exception('无法创建备份文件');
        }
        
        // 写入SQL文件头信息
        fwrite($file, "-- 数据库备份\n");
        fwrite($file, "-- 生成时间: " . date('Y-m-d H:i:s') . "\n");
        fwrite($file, "-- 服务器版本: " . $db->getAttribute(PDO::ATTR_SERVER_VERSION) . "\n");
        fwrite($file, "-- PHP 版本: " . phpversion() . "\n\n");
        
        // 获取所有表
        $tables = [];
        $stmt = $db->query("SHOW TABLES");
        while ($row = $stmt->fetch(PDO::FETCH_NUM)) {
            $tables[] = $row[0];
        }
        
        // 备份每个表
        foreach ($tables as $table) {
            backupTable($db, $file, $table);
        }
        
        fclose($file);
        
        header('Location: backup.php?success=数据库备份创建成功');
        exit;
    } catch (Exception $e) {
        // 如果出错，删除可能创建的不完整文件
        if (isset($backupFilePath) && file_exists($backupFilePath)) {
            unlink($backupFilePath);
        }
        
        header('Location: backup.php?error=' . urlencode('备份失败: ' . $e->getMessage()));
        exit;
    }
} elseif ($backupType === 'full') {
    // 完整网站备份
    try {
        // 第一步：创建临时目录
        $tempDir = $backupDir . 'temp_' . time() . '/';
        if (!file_exists($tempDir)) {
            mkdir($tempDir, 0777, true);
        }
        
        // 第二步：备份数据库到临时目录
        $db = getDbConnection();
        $dbBackupFile = $tempDir . 'database.sql';
        $file = fopen($dbBackupFile, 'w');
        
        if (!$file) {
            throw new Exception('无法创建数据库备份文件');
        }
        
        // 写入SQL文件头信息
        fwrite($file, "-- 数据库备份\n");
        fwrite($file, "-- 生成时间: " . date('Y-m-d H:i:s') . "\n");
        fwrite($file, "-- 服务器版本: " . $db->getAttribute(PDO::ATTR_SERVER_VERSION) . "\n");
        fwrite($file, "-- PHP 版本: " . phpversion() . "\n\n");
        
        // 获取所有表
        $tables = [];
        $stmt = $db->query("SHOW TABLES");
        while ($row = $stmt->fetch(PDO::FETCH_NUM)) {
            $tables[] = $row[0];
        }
        
        // 备份每个表
        foreach ($tables as $table) {
            backupTable($db, $file, $table);
        }
        
        fclose($file);
        
        // 清空 Install/key.txt 文件
        clearKeyFile();
        
        // 第三步：创建ZIP归档文件
        $zipFileName = 'website_backup_' . date('Y-m-d_H-i-s') . '.zip';
        $zipFilePath = $backupDir . $zipFileName;
        
        $zip = new ZipArchive();
        if ($zip->open($zipFilePath, ZipArchive::CREATE) !== TRUE) {
            throw new Exception('无法创建ZIP文件');
        }
        
        // 递归添加网站文件到ZIP（排除某些目录）
        $rootPath = realpath('../');
        // 先排除Data目录和其他不需要的目录
        $excludeItems = ['Data', 'temp_' . time(), '.git', 'vendor/composer/tmp', 'Install/key.txt'];
        
        // 先添加非Data目录的所有文件
        addDirectoryToZip($zip, $rootPath, '', $excludeItems);
        
        // 手动创建Data目录在ZIP中
        $zip->addEmptyDir('Data');
        
        // 将当前的数据库备份文件也添加到Data目录中
        // 注意：之前我们已经在$tempDir中创建了数据库备份文件dbBackupFile
        $dataBackupFileName = 'database_' . date('Y-m-d_H-i-s') . '.sql';
        $zip->addFile($dbBackupFile, 'Data/' . $dataBackupFileName);
        
        $zip->close();
        
        // 清理临时文件
        unlink($dbBackupFile);
        rmdir($tempDir);
        
        header('Location: backup.php?success=完整网站备份创建成功');
        exit;
    } catch (Exception $e) {
        // 清理临时文件
        if (isset($dbBackupFile) && file_exists($dbBackupFile)) {
            unlink($dbBackupFile);
        }
        
        if (isset($tempDir) && file_exists($tempDir)) {
            rmdir($tempDir);
        }
        
        // 删除不完整的ZIP文件
        if (isset($zipFilePath) && file_exists($zipFilePath)) {
            unlink($zipFilePath);
        }
        
        header('Location: backup.php?error=' . urlencode('备份失败: ' . $e->getMessage()));
        exit;
    }
} else {
    header('Location: backup.php?error=无效的备份类型');
    exit;
}

/**
 * 备份单个表
 */
function backupTable($db, $file, $table) {
    // 写入表删除语句
    fwrite($file, "\n-- 表结构 `$table`\n");
    fwrite($file, "DROP TABLE IF EXISTS `$table`;\n");
    
    // 获取表创建语句
    $stmt = $db->query("SHOW CREATE TABLE `$table`");
    $row = $stmt->fetch(PDO::FETCH_NUM);
    fwrite($file, $row[1] . ";\n\n");
    
    // 获取数据并写入
    $stmt = $db->query("SELECT * FROM `$table`");
    $columnCount = $stmt->columnCount();
    
    // 空表检查
    if ($stmt->rowCount() == 0) {
        fwrite($file, "-- 表 `$table` 中没有数据\n\n");
        return;
    }
    
    fwrite($file, "-- 转存表中的数据 `$table`\n");
    
    // 获取所有列名
    $columnNames = [];
    for ($i = 0; $i < $columnCount; $i++) {
        $meta = $stmt->getColumnMeta($i);
        $columnNames[] = "`" . $meta['name'] . "`";
    }
    
    // 批量插入数据
    $batchSize = 100; // 每批次插入的记录数
    $rowCount = 0;
    $insertPrefix = "INSERT INTO `$table` (" . implode(', ', $columnNames) . ") VALUES\n";
    $insertValues = [];
    
    while ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
        $values = [];
        foreach ($row as $value) {
            if ($value === null) {
                $values[] = 'NULL';
            } else {
                $values[] = $db->quote($value);
            }
        }
        
        $insertValues[] = "(" . implode(", ", $values) . ")";
        $rowCount++;
        
        // 当达到批次大小或处理完所有行时，写入SQL
        if ($rowCount % $batchSize === 0 || $rowCount === $stmt->rowCount()) {
            fwrite($file, $insertPrefix . implode(",\n", $insertValues) . ";\n");
            $insertValues = [];
        }
    }
    
    fwrite($file, "\n");
}

/**
 * 递归将目录添加到ZIP
 */
function addDirectoryToZip($zip, $rootPath, $relativePath, $excludeItems) {
    $dirHandle = opendir($rootPath . '/' . $relativePath);
    while (false !== ($file = readdir($dirHandle))) {
        if ($file === '.' || $file === '..') {
            continue;
        }
        
        $filePath = $rootPath . '/' . $relativePath . '/' . $file;
        $zipPath = $relativePath === '' ? $file : $relativePath . '/' . $file;
        $relativeFilePath = $relativePath === '' ? $file : $relativePath . '/' . $file;
        
        // 检查是否是排除项（目录或文件）
        if (in_array($file, $excludeItems) || in_array($relativeFilePath, $excludeItems)) {
            continue;
        }
        
        // 检查是否是排除目录
        if (is_dir($filePath)) {
            $dirName = basename($filePath);
            if (in_array($dirName, $excludeItems)) {
                continue;
            }
            addDirectoryToZip($zip, $rootPath, $zipPath, $excludeItems);
        } elseif (is_file($filePath)) {
            $zip->addFile($filePath, $zipPath);
        }
    }
    closedir($dirHandle);
}

/**
 * 清空 Install/key.txt 文件
 */
function clearKeyFile() {
    $keyFilePath = '../Install/key.txt';
    
    // 检查文件是否存在
    if (file_exists($keyFilePath)) {
        // 清空文件内容
        if (file_put_contents($keyFilePath, '') === false) {
            // 记录错误，但不中断备份过程
            error_log('无法清空 key.txt 文件。');
        }
    } else {
        error_log('key.txt 文件不存在，无法清空。');
    }
}
?>
