<?php
/**
 * 备份恢复处理
 */
// 引入数据库配置文件
require_once '../config/database.php';

// 设置执行时间为无限制（大型网站恢复可能需要较长时间）
set_time_limit(0);
ini_set('memory_limit', '512M');

// 检查请求类型
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    header('Location: backup.php?error=无效的请求方法');
    exit;
}

// 获取备份文件名
$backupFile = isset($_POST['file']) ? $_POST['file'] : '';
if (empty($backupFile)) {
    header('Location: backup.php?error=未指定备份文件');
    exit;
}

// 构建完整的文件路径
$backupDir = '../Data/';
$backupFilePath = $backupDir . $backupFile;

// 检查文件是否存在
if (!file_exists($backupFilePath)) {
    header('Location: backup.php?error=备份文件不存在');
    exit;
}

// 检查文件类型和执行相应的恢复操作
$fileExtension = pathinfo($backupFile, PATHINFO_EXTENSION);

try {
    if ($fileExtension === 'sql') {
        // 恢复数据库备份
        restoreDatabase($backupFilePath);
        header('Location: backup.php?success=数据库恢复成功');
        exit;
    } elseif ($fileExtension === 'zip') {
        // 恢复完整网站备份
        restoreFullBackup($backupFilePath);
        header('Location: backup.php?success=网站完整恢复成功');
        exit;
    } else {
        header('Location: backup.php?error=不支持的备份文件格式');
        exit;
    }
} catch (Exception $e) {
    header('Location: backup.php?error=' . urlencode('恢复失败: ' . $e->getMessage()));
    exit;
}

/**
 * 恢复数据库
 */
function restoreDatabase($sqlFilePath) {
    $db = getDbConnection();
    
    // 读取SQL文件内容
    $sql = file_get_contents($sqlFilePath);
    if ($sql === false) {
        throw new Exception('无法读取SQL备份文件');
    }
    
    // 将SQL语句拆分为单独的查询
    $queries = parseSQL($sql);
    
    // 开始事务
    $db->beginTransaction();
    
    try {
        // 临时禁用外键约束
        $db->exec('SET FOREIGN_KEY_CHECKS = 0');
        
        // 执行每个查询
        foreach ($queries as $query) {
            if (trim($query) !== '') {
                $db->exec($query);
            }
        }
        
        // 重新启用外键约束
        $db->exec('SET FOREIGN_KEY_CHECKS = 1');
        
        // 提交事务
        $db->commit();
    } catch (PDOException $e) {
        // 出错时回滚事务
        $db->rollBack();
        // 确保重新启用外键约束
        try {
            $db->exec('SET FOREIGN_KEY_CHECKS = 1');
        } catch (Exception $ex) {
            // 忽略重新启用约束时的错误
        }
        throw new Exception('SQL执行错误: ' . $e->getMessage());
    }
}

/**
 * 恢复完整网站备份
 */
function restoreFullBackup($zipFilePath) {
    // 创建临时目录
    $tempDir = '../Data/temp_restore_' . time() . '/';
    if (!file_exists($tempDir)) {
        mkdir($tempDir, 0777, true);
    }
    
    // 解压ZIP文件到临时目录
    $zip = new ZipArchive();
    if ($zip->open($zipFilePath) !== true) {
        throw new Exception('无法打开ZIP文件');
    }
    
    $zip->extractTo($tempDir);
    $zip->close();
    
    // 首先恢复数据库
    $dbFile = $tempDir . 'database.sql';
    if (file_exists($dbFile)) {
        restoreDatabase($dbFile);
    } else {
        throw new Exception('未找到数据库备份文件');
    }
    
    // 然后恢复文件（排除特定目录）
    $excludeDirs = ['Data', 'config']; // 保留Data目录和配置文件
    
    // 递归复制文件（排除Data和config目录）
    $rootPath = realpath('../');
    recursiveCopy($tempDir, $rootPath, $excludeDirs);
    
    // 清理临时目录
    recursiveDelete($tempDir);
}

/**
 * 将SQL文件解析成单独的查询
 */
function parseSQL($sql) {
    // 移除注释
    $sql = preg_replace('/--.*?\\n|#.*?\\n|\/\*.*?\*\//s', '', $sql);
    
    // 按分号分割查询，考虑到引号内的分号
    $queries = [];
    $buffer = '';
    $inString = false;
    $stringChar = '';
    
    for ($i = 0; $i < strlen($sql); $i++) {
        $char = $sql[$i];
        $buffer .= $char;
        
        // 处理字符串引号
        if (($char === "'" || $char === '"') && ($i === 0 || $sql[$i-1] !== '\\')) {
            if (!$inString) {
                $inString = true;
                $stringChar = $char;
            } elseif ($char === $stringChar) {
                $inString = false;
            }
        }
        
        // 如果不在字符串内并且遇到分号，则结束当前查询
        if (!$inString && $char === ';') {
            $queries[] = $buffer;
            $buffer = '';
        }
    }
    
    // 添加最后一个查询，如果有的话
    if (trim($buffer) !== '') {
        $queries[] = $buffer;
    }
    
    return $queries;
}

/**
 * 递归复制文件
 */
function recursiveCopy($source, $destination, $excludeDirs) {
    $dir = opendir($source);
    
    while (false !== ($file = readdir($dir))) {
        if (($file != '.') && ($file != '..')) {
            $sourcePath = $source . '/' . $file;
            $destPath = $destination . '/' . $file;
            
            if (is_dir($sourcePath)) {
                // 排除指定目录
                if (in_array($file, $excludeDirs)) {
                    continue;
                }
                
                if (!file_exists($destPath)) {
                    mkdir($destPath, 0777, true);
                }
                
                recursiveCopy($sourcePath, $destPath, $excludeDirs);
            } else {
                copy($sourcePath, $destPath);
            }
        }
    }
    
    closedir($dir);
}

/**
 * 递归删除目录
 */
function recursiveDelete($dir) {
    if (!file_exists($dir)) {
        return true;
    }
    
    if (!is_dir($dir)) {
        return unlink($dir);
    }
    
    foreach (scandir($dir) as $item) {
        if ($item == '.' || $item == '..') {
            continue;
        }
        
        if (!recursiveDelete($dir . DIRECTORY_SEPARATOR . $item)) {
            return false;
        }
    }
    
    return rmdir($dir);
}
?> 