<?php
/**
 * SitemapManager 类
 * 用于生成和管理网站的站点地图
 */
class SitemapManager {
    /**
     * 数据库连接对象
     * @var PDO
     */
    private $db;
    
    /**
     * 构造函数
     * 
     * @param PDO $db 数据库连接
     */
    public function __construct($db) {
        $this->db = $db;
    }
    
    /**
     * 获取所有页面URL
     * 
     * @return array 所有页面的URL数据
     */
    public function getAllPages() {
        $urls = [];
        
        // 获取网站URL
        $stmt = $this->db->prepare("SELECT value FROM settings WHERE name = 'site_url'");
        $stmt->execute();
        $siteUrl = $stmt->fetchColumn();
        if (!$siteUrl) {
            $siteUrl = 'http://' . $_SERVER['HTTP_HOST'];
        }
        
        // 首页
        $urls[] = [
            'loc' => $siteUrl,
            'lastmod' => date('Y-m-d'),
            'changefreq' => 'daily',
            'priority' => '1.0'
        ];
        
        // 从文章表获取链接
        $stmt = $this->db->prepare("SELECT id, title, updated_at FROM articles WHERE status = 1 ORDER BY id DESC");
        $stmt->execute();
        $articles = $stmt->fetchAll(PDO::FETCH_ASSOC);
        
        foreach ($articles as $article) {
            $urls[] = [
                'loc' => $siteUrl . '/article/' . $article['id'] . '.html',
                'lastmod' => date('Y-m-d', strtotime($article['updated_at'])),
                'changefreq' => 'weekly',
                'priority' => '0.8'
            ];
        }
        
        // 从分类表获取链接
        $stmt = $this->db->prepare("SELECT id, name FROM categories WHERE status = 1");
        $stmt->execute();
        $categories = $stmt->fetchAll(PDO::FETCH_ASSOC);
        
        foreach ($categories as $category) {
            $urls[] = [
                'loc' => $siteUrl . '/category/' . $category['id'] . '.html',
                'lastmod' => date('Y-m-d'),
                'changefreq' => 'weekly',
                'priority' => '0.7'
            ];
        }
        
        // 从标签表获取链接
        $stmt = $this->db->prepare("SELECT id, name FROM tags WHERE status = 1");
        $stmt->execute();
        $tags = $stmt->fetchAll(PDO::FETCH_ASSOC);
        
        foreach ($tags as $tag) {
            $urls[] = [
                'loc' => $siteUrl . '/tag/' . $tag['id'] . '.html',
                'lastmod' => date('Y-m-d'),
                'changefreq' => 'weekly',
                'priority' => '0.6'
            ];
        }
        
        return $urls;
    }
    
    /**
     * 生成XML格式的站点地图
     * 
     * @param array $urls URL数组
     * @return string XML内容
     */
    public function generateXmlSitemap($urls) {
        $xml = '<?xml version="1.0" encoding="UTF-8"?>' . "\n";
        $xml .= '<urlset xmlns="http://www.sitemaps.org/schemas/sitemap/0.9">' . "\n";
        
        foreach ($urls as $url) {
            $xml .= "  <url>\n";
            $xml .= "    <loc>" . htmlspecialchars($url['loc']) . "</loc>\n";
            $xml .= "    <lastmod>" . $url['lastmod'] . "</lastmod>\n";
            $xml .= "    <changefreq>" . $url['changefreq'] . "</changefreq>\n";
            $xml .= "    <priority>" . $url['priority'] . "</priority>\n";
            $xml .= "  </url>\n";
        }
        
        $xml .= '</urlset>';
        
        return $xml;
    }
    
    /**
     * 生成TXT格式的站点地图
     * 
     * @param array $urls URL数组
     * @return string TXT内容
     */
    public function generateTxtSitemap($urls) {
        $txt = '';
        
        foreach ($urls as $url) {
            $txt .= $url['loc'] . "\n";
        }
        
        return $txt;
    }
    
    /**
     * 生成HTML格式的站点地图
     * 
     * @param array $urls URL数组
     * @return string HTML内容
     */
    public function generateHtmlSitemap($urls) {
        // 获取网站URL
        $stmt = $this->db->prepare("SELECT value FROM settings WHERE name = 'site_url'");
        $stmt->execute();
        $siteUrl = $stmt->fetchColumn();
        if (!$siteUrl) {
            $siteUrl = 'http://' . $_SERVER['HTTP_HOST'];
        }
        
        // 获取网站名称
        $stmt = $this->db->prepare("SELECT value FROM settings WHERE name = 'site_name'");
        $stmt->execute();
        $siteName = $stmt->fetchColumn();
        if (!$siteName) {
            $siteName = '网站地图';
        }
        
        $html = '<!DOCTYPE html>' . "\n";
        $html .= '<html lang="zh-CN">' . "\n";
        $html .= '<head>' . "\n";
        $html .= '    <meta charset="UTF-8">' . "\n";
        $html .= '    <meta name="viewport" content="width=device-width, initial-scale=1.0">' . "\n";
        $html .= '    <title>网站地图 - ' . htmlspecialchars($siteName) . '</title>' . "\n";
        $html .= '    <style>' . "\n";
        $html .= '        body { font-family: Arial, sans-serif; margin: 20px; }' . "\n";
        $html .= '        h1 { color: #333; }' . "\n";
        $html .= '        .sitemap-list { margin: 20px 0; }' . "\n";
        $html .= '        .sitemap-item { margin: 10px 0; }' . "\n";
        $html .= '        .sitemap-link { color: #1a0dab; text-decoration: none; }' . "\n";
        $html .= '        .sitemap-link:hover { text-decoration: underline; }' . "\n";
        $html .= '        .sitemap-date { color: #666; font-size: 0.8em; margin-left: 10px; }' . "\n";
        $html .= '        .footer { margin-top: 30px; color: #777; font-size: 0.9em; }' . "\n";
        $html .= '    </style>' . "\n";
        $html .= '</head>' . "\n";
        $html .= '<body>' . "\n";
        $html .= '    <h1>' . htmlspecialchars($siteName) . ' - 网站地图</h1>' . "\n";
        $html .= '    <div class="sitemap-list">' . "\n";
        
        foreach ($urls as $url) {
            $html .= '        <div class="sitemap-item">' . "\n";
            $html .= '            <a href="' . htmlspecialchars($url['loc']) . '" class="sitemap-link">' . htmlspecialchars($url['loc']) . '</a>' . "\n";
            $html .= '            <span class="sitemap-date">更新日期: ' . $url['lastmod'] . '</span>' . "\n";
            $html .= '        </div>' . "\n";
        }
        
        $html .= '    </div>' . "\n";
        $html .= '    <div class="footer">' . "\n";
        $html .= '        <p>最后更新时间: ' . date('Y-m-d H:i:s') . '</p>' . "\n";
        $html .= '        <p>Copyright &copy; ' . date('Y') . ' ' . htmlspecialchars($siteName) . ' - All Rights Reserved</p>' . "\n";
        $html .= '    </div>' . "\n";
        $html .= '</body>' . "\n";
        $html .= '</html>';
        
        return $html;
    }
    
    /**
     * 保存站点地图文件
     * 
     * @param string $content 文件内容
     * @param string $filePath 文件路径
     * @return bool 保存结果
     */
    public function saveSitemapFile($content, $filePath) {
        // 确保目录存在
        $directory = dirname($filePath);
        if (!is_dir($directory)) {
            mkdir($directory, 0755, true);
        }
        
        return file_put_contents($filePath, $content) !== false;
    }
    
    /**
     * 检查站点地图是否存在
     * 
     * @param string $type 站点地图类型
     * @return bool 是否存在
     */
    public function sitemapExists($type) {
        $sitemapDir = __DIR__ . '/../../sitemap';
        
        switch ($type) {
            case 'xml':
                return file_exists($sitemapDir . '/sitemap.xml');
            case 'txt':
                return file_exists($sitemapDir . '/sitemap.txt');
            case 'html':
                return file_exists($sitemapDir . '/sitemap.html');
            default:
                return false;
        }
    }
} 