<?php
namespace Code;

class UserManager {
    private $db;

    public function __construct($db) {
        $this->db = $db;
    }

    /**
     * 获取所有用户列表
     * @return array
     */
    public function getAllUsers() {
        $query = "SELECT * FROM user ORDER BY id DESC";
        $stmt = $this->db->query($query);
        return $stmt->fetchAll(\PDO::FETCH_ASSOC);
    }

    /**
     * 渲染用户列表HTML
     * @param array $users 用户数据数组
     * @return string HTML内容
     */
    public function renderUserList($users) {
        $html = '';
        foreach ($users as $user) {
            $statusBadge = $user['status'] ? '启用' : '禁用';
            $avatarUrl = !empty($user['avatar']) ? '../' . $user['avatar'] : 'public/images/default-avatar.png';
            $groupLink = !empty($user['group_link']) ? 
                '<a href="' . htmlspecialchars($user['group_link']) . '" target="_blank">查看</a>' : 
                '无';
            
            $managedStatus = isset($user['is_managed']) && $user['is_managed'] ? '是' : '否';
            
            $html .= "<tr data-id=\"{$user['id']}\">";
            $html .= "<td>{$user['id']}</td>";
            $html .= "<td>{$user['username']}</td>";
            $html .= "<td>" . (isset($user['email']) ? htmlspecialchars($user['email']) : '-') . "</td>";
            $html .= "<td>" . (isset($user['role']) ? htmlspecialchars($user['role']) : '-') . "</td>";
            $html .= "<td>{$statusBadge}</td>";
            $html .= "<td>" . (isset($user['last_login']) && $user['last_login'] ? date('Y-m-d H:i:s', strtotime($user['last_login'])) : '-') . "</td>";
            $html .= "<td class=\"action-buttons\">";
            $html .= "<button class=\"btn btn-manage\" data-id=\"{$user['id']}\" data-managed=\"" . (isset($user['is_managed']) && $user['is_managed'] ? '1' : '0') . "\">代管</button>";
            $html .= "<button class=\"btn btn-edit\" data-id=\"{$user['id']}\">修改</button>";
            $html .= "<button class=\"btn btn-delete\" data-id=\"{$user['id']}\" data-name=\"{$user['username']}\">删除</button>";
            $html .= "</td>";
            $html .= "</tr>";
        }
        return $html;
    }

    /**
     * 获取并渲染用户列表
     * @return string HTML内容
     */
    public function getAndRenderUserList() {
        $users = $this->getAllUsers();
        return $this->renderUserList($users);
    }

    /**
     * 删除用户
     * @param int $userId
     * @return array
     */
    public function deleteUser($userId) {
        try {
            // 获取用户信息（用于删除头像文件）
            $query = "SELECT avatar FROM user WHERE id = :id";
            $stmt = $this->db->prepare($query);
            $stmt->execute(['id' => $userId]);
            $user = $stmt->fetch(\PDO::FETCH_ASSOC);

            // 删除用户
            $deleteQuery = "DELETE FROM user WHERE id = :id";
            $deleteStmt = $this->db->prepare($deleteQuery);
            $deleteStmt->execute(['id' => $userId]);
            
            if ($deleteStmt->rowCount() > 0) {
                // 如果有头像，删除头像文件
                if (!empty($user['avatar'])) {
                    $avatarPath = $_SERVER['DOCUMENT_ROOT'] . '/' . $user['avatar'];
                    if (file_exists($avatarPath)) {
                        unlink($avatarPath);
                    }
                }
                
                return [
                    'success' => true,
                    'message' => '用户删除成功'
                ];
            }
            
            return [
                'success' => false,
                'message' => '用户不存在或删除失败'
            ];
        } catch (\PDOException $e) {
            return [
                'success' => false,
                'message' => '删除失败：' . $e->getMessage()
            ];
        }
    }

    /**
     * 更新用户代管状态
     * @param int $userId
     * @param bool $isManaged
     * @return array
     */
    public function updateUserManageStatus($userId, $isManaged) {
        try {
            $query = "UPDATE user SET is_managed = :is_managed WHERE id = :id";
            $stmt = $this->db->prepare($query);
            $stmt->execute([
                'id' => $userId,
                'is_managed' => $isManaged
            ]);
            
            if ($stmt->rowCount() > 0) {
                return [
                    'success' => true,
                    'message' => $isManaged ? '已开启代管状态' : '已取消代管状态'
                ];
            }
            
            return [
                'success' => false,
                'message' => '用户不存在或更新失败'
            ];
        } catch (\PDOException $e) {
            return [
                'success' => false,
                'message' => '更新失败：' . $e->getMessage()
            ];
        }
    }

    /**
     * 搜索用户
     * @param string $searchTerm
     * @return array
     */
    public function searchUsers($searchTerm) {
        try {
            $query = "SELECT * FROM user WHERE username LIKE :search OR email LIKE :search ORDER BY id DESC";
            $stmt = $this->db->prepare($query);
            $stmt->execute(['search' => "%$searchTerm%"]);
            return [
                'success' => true,
                'data' => $stmt->fetchAll(\PDO::FETCH_ASSOC)
            ];
        } catch (\PDOException $e) {
            return [
                'success' => false,
                'message' => '搜索失败：' . $e->getMessage()
            ];
        }
    }
} 