<?php
/**
 * 配置管理类
 * 用于获取和管理系统配置信息
 */

// 使用正确的路径引入数据库配置文件
require_once dirname(dirname(__DIR__)) . '/config/database.php';

class Config {
    private static $instance = null;
    private $db = null;
    private $configs = [];
    private $cacheExpiry = 300; // 缓存过期时间（秒）
    private $lastLoadTime = 0;

    private function __construct() {
        $this->db = getDbConnection();
        $this->loadConfigs();
    }

    /**
     * 获取配置管理类实例（单例模式）
     */
    public static function getInstance() {
        if (self::$instance === null) {
            self::$instance = new self();
        }
        return self::$instance;
    }

    /**
     * 加载所有配置
     * @return bool
     */
    private function loadConfigs() {
        // 检查缓存是否有效
        if ($this->isCacheValid()) {
            return true;
        }

        try {
            $query = "SELECT * FROM config ORDER BY sort_order ASC";
            $stmt = $this->db->query($query);
            
            if (!$stmt) {
                throw new PDOException("查询执行失败");
            }

            $this->configs = [];
            while ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
                $this->configs[$row['name']] = [
                    'id' => $row['id'] ?? 0,
                    'name' => $row['name'],
                    'cn_name' => $row['cn_name'],
                    'content' => $row['content'],
                    'sort_order' => $row['sort_order'] ?? 0
                ];
            }

            // 更新缓存时间
            $this->lastLoadTime = time();
            return true;

        } catch (PDOException $e) {
            error_log("配置加载错误: " . $e->getMessage());
            // 如果加载失败但有缓存数据，继续使用缓存
            if (!empty($this->configs)) {
                return true;
            }
            return false;
        }
    }

    /**
     * 检查缓存是否有效
     * @return bool
     */
    private function isCacheValid() {
        return !empty($this->configs) && (time() - $this->lastLoadTime) < $this->cacheExpiry;
    }

    /**
     * 获取配置值
     * @param string $name 配置名称
     * @param mixed $default 默认值
     * @return mixed
     */
    public function get($name, $default = null) {
        $this->refreshIfNeeded();
        return isset($this->configs[$name]) ? $this->configs[$name]['content'] : $default;
    }

    /**
     * 获取配置的完整信息
     * @param string $name 配置名称
     * @return array|null
     */
    public function getConfig($name) {
        $this->refreshIfNeeded();
        return isset($this->configs[$name]) ? $this->configs[$name] : null;
    }

    /**
     * 获取所有配置
     * @return array
     */
    public function getAllConfigs() {
        $this->refreshIfNeeded();
        return $this->configs;
    }

    /**
     * 更新配置
     * @param string $name 配置名称
     * @param string $content 配置内容
     * @return boolean
     */
    public function update($name, $content) {
        if (!isset($this->configs[$name])) {
            error_log("尝试更新不存在的配置: {$name}");
            return false;
        }

        try {
            $query = "UPDATE config SET content = :content WHERE name = :name";
            $stmt = $this->db->prepare($query);
            
            if (!$stmt) {
                throw new PDOException("预处理语句创建失败");
            }

            $result = $stmt->execute([
                'content' => $content,
                'name' => $name
            ]);

            if ($result) {
                // 更新本地缓存
                $this->configs[$name]['content'] = $content;
                return true;
            }

            error_log("配置更新失败: {$name}");
            return false;

        } catch (PDOException $e) {
            error_log("配置更新错误: " . $e->getMessage());
            return false;
        }
    }

    /**
     * 检查并刷新配置
     */
    private function refreshIfNeeded() {
        if (!$this->isCacheValid()) {
            $this->loadConfigs();
        }
    }

    /**
     * 清除配置缓存
     */
    public function clearCache() {
        $this->configs = [];
        $this->lastLoadTime = 0;
        return $this->loadConfigs();
    }

    /**
     * 获取配置更新时间
     * @param string $name 配置名称
     * @return string|null
     */
    public function getLastUpdateTime($name) {
        return isset($this->configs[$name]) ? $this->configs[$name]['updated_at'] : null;
    }

    /**
     * 检查配置是否存在
     * @param string $name 配置名称
     * @return bool
     */
    public function exists($name) {
        $this->refreshIfNeeded();
        return isset($this->configs[$name]);
    }

    /**
     * 更新配置排序
     * @param string $name 配置名称
     * @param int $sort_order 排序值
     * @return boolean
     */
    public function updateSort($name, $sort_order) {
        if (!isset($this->configs[$name])) {
            error_log("尝试更新不存在的配置排序: {$name}");
            return false;
        }

        try {
            $query = "UPDATE config SET sort_order = :sort_order WHERE name = :name";
            $stmt = $this->db->prepare($query);
            
            if (!$stmt) {
                throw new PDOException("预处理语句创建失败");
            }

            $result = $stmt->execute([
                'sort_order' => (int)$sort_order,
                'name' => $name
            ]);

            if ($result) {
                // 更新本地缓存
                $this->configs[$name]['sort_order'] = (int)$sort_order;
                return true;
            }

            error_log("配置排序更新失败: {$name}");
            return false;

        } catch (PDOException $e) {
            error_log("配置排序更新错误: " . $e->getMessage());
            return false;
        }
    }

    /**
     * 处理AJAX配置更新请求
     * @return array 处理结果
     */
    public function handleAjaxRequest() {
        if ($_SERVER['REQUEST_METHOD'] !== 'POST' || !isset($_POST['action'])) {
            return ['success' => false];
        }

        $name = $_POST['name'] ?? '';
        $content = $_POST['content'] ?? '';
        
        if (empty($name) || $content === '') {
            return ['success' => false];
        }
        
        $result = false;
        
        if ($_POST['action'] === 'update') {
            $result = $this->update($name, $content);
        } elseif ($_POST['action'] === 'update_sort') {
            $result = $this->updateSort($name, (int)$content);
        }
        
        return ['success' => $result];
    }
}

