<?php
/**
 * 登录逻辑处理文件
 * 处理管理员登录验证和会话管理
 */

// 启动会话（如果尚未启动）
if (session_status() == PHP_SESSION_NONE) {
    session_start();
}

/**
 * 检查管理员是否已登录
 * @return bool 如果已登录返回true，否则返回false
 */
function isAdminLoggedIn() {
    return isset($_SESSION['admin_id']) && !empty($_SESSION['admin_id']);
}

/**
 * 重定向到指定页面
 * @param string $url 重定向的URL
 */
function redirectTo($url) {
    header("Location: $url");
    exit;
}

/**
 * 处理管理员登录请求
 * @param string $username 用户名
 * @param string $password 密码
 * @return array 包含处理结果的数组，成功时status=success，失败时status=error且包含错误信息
 */
function processLogin($username, $password) {
    // 验证输入
    if (empty($username) || empty($password)) {
        return ['status' => 'error', 'message' => '用户名和密码不能为空'];
    }
    
    try {
        // 引入数据库配置
        require_once '../config/database.php';
        
        // 获取数据库连接
        $db = getDbConnection();
        
        // 查询管理员信息
        $query = "SELECT * FROM `admin` WHERE `username` = :username AND `status` = 1 LIMIT 1";
        $stmt = $db->prepare($query);
        $stmt->execute(['username' => $username]);
        
        if ($stmt->rowCount() === 0) {
            return ['status' => 'error', 'message' => '用户名不存在或账号已禁用'];
        }
        
        $admin = $stmt->fetch(PDO::FETCH_ASSOC);
        
        // 验证密码
        if (!password_verify($password, $admin['password'])) {
            return ['status' => 'error', 'message' => '密码错误'];
        }
        
        // 更新登录信息
        $updateQuery = "UPDATE `admin` SET 
                       `last_login` = NOW(),
                       `login_ip` = :ip,
                       `updated_at` = NOW()
                       WHERE `id` = :id";
                       
        $updateStmt = $db->prepare($updateQuery);
        $updateStmt->execute([
            'ip' => $_SERVER['REMOTE_ADDR'],
            'id' => $admin['id']
        ]);
        
        // 存储会话信息
        $_SESSION['admin_id'] = $admin['id'];
        $_SESSION['admin_username'] = $admin['username'];
        $_SESSION['admin_role'] = $admin['role'];
        $_SESSION['admin_login_time'] = time();
        
        return ['status' => 'success'];
        
    } catch (PDOException $e) {
        return ['status' => 'error', 'message' => '系统错误：' . $e->getMessage()];
    }
} 