<?php
/**
 * 订单管理页面逻辑处理文件
 * 包含：状态筛选、搜索功能、分页逻辑和数据获取
 */

// 引入数据库配置文件
require_once '../config/database.php';

/**
 * 获取订单状态名称映射
 * @return array 状态ID => 状态名称
 */
function getOrderStatusNames() {
    return [
        1 => '有效',
        2 => '审核中',
        3 => '已暂停',
        4 => '已终止',
        5 => '已取消'
    ];
}

/**
 * 处理查询条件和参数
 * @param int|null $statusFilter 状态筛选，null表示不筛选
 * @param string $searchTerm 搜索关键词
 * @return array [whereClause, params] 查询条件和参数
 */
function buildQueryConditions($statusFilter, $searchTerm) {
    $whereClause = "";
    $params = [];

    // 如果状态筛选有效（大于0），则添加状态筛选条件
    if ($statusFilter > 0) {
        $whereClause = "WHERE status = :status";
        $params['status'] = $statusFilter;
    } else {
        $whereClause = "WHERE 1=1"; // 默认条件，查询所有记录
    }

    if (!empty($searchTerm)) {
        $whereClause .= " AND (hostname LIKE :search OR ip_address LIKE :search OR product_type LIKE :search)";
        $params['search'] = "%{$searchTerm}%";
    }
    
    return [$whereClause, $params];
}

/**
 * 获取订单总数和总页数
 * @param PDO $db 数据库连接
 * @param string $whereClause 查询条件
 * @param array $params 查询参数
 * @param int $perPage 每页记录数
 * @return array [totalRecords, totalPages] 总记录数和总页数
 */
function getOrderPagination($db, $whereClause, $params, $perPage) {
    $countQuery = "SELECT COUNT(*) FROM orders {$whereClause}";
    $countStmt = $db->prepare($countQuery);
    $countStmt->execute($params);
    $totalRecords = $countStmt->fetchColumn();
    $totalPages = ceil($totalRecords / $perPage);
    
    return [$totalRecords, $totalPages];
}

/**
 * 获取订单列表
 * @param PDO $db 数据库连接
 * @param string $whereClause 查询条件
 * @param array $params 查询参数
 * @param int $offset 偏移量
 * @param int $perPage 每页记录数
 * @return array 订单数据列表
 */
function getOrders($db, $whereClause, $params, $offset, $perPage) {
    $orderQuery = "SELECT * FROM orders {$whereClause} ORDER BY created_at DESC LIMIT :offset, :limit";
    $orderStmt = $db->prepare($orderQuery);
    $orderStmt->bindValue(':offset', $offset, PDO::PARAM_INT);
    $orderStmt->bindValue(':limit', $perPage, PDO::PARAM_INT);
    
    foreach ($params as $key => $value) {
        $orderStmt->bindValue(":{$key}", $value);
    }
    
    $orderStmt->execute();
    return $orderStmt->fetchAll();
}

/**
 * 生成分页HTML
 * @param int $page 当前页码
 * @param int $totalPages 总页数
 * @param int $statusFilter 状态筛选
 * @param int $perPage 每页记录数
 * @param string $searchTerm 搜索关键词
 * @return string 分页HTML
 */
function generatePaginationHtml($page, $totalPages, $statusFilter, $perPage, $searchTerm) {
    if ($totalPages <= 1) {
        return '';
    }
    
    $html = '<div class="pagination">';
    
    // 上一页链接
    if ($page > 1) {
        $html .= '<a href="orders.php?status=' . $statusFilter . '&page=' . ($page - 1) . '&per_page=' . $perPage . '&search=' . urlencode($searchTerm) . '" class="page-link">';
        $html .= '<i class="fas fa-chevron-left"></i> 上一页</a>';
    }
    
    // 页码链接
    $pageLimit = 5; // 最多显示多少个页码
    $startPage = max(1, min($page - floor($pageLimit / 2), $totalPages - $pageLimit + 1));
    $endPage = min($startPage + $pageLimit - 1, $totalPages);
    
    if ($startPage > 1) {
        $html .= '<a href="orders.php?status=' . $statusFilter . '&page=1&per_page=' . $perPage . '&search=' . urlencode($searchTerm) . '" class="page-link">1</a>';
        if ($startPage > 2) {
            $html .= '<span class="page-ellipsis">...</span>';
        }
    }
    
    for ($i = $startPage; $i <= $endPage; $i++) {
        $activeClass = $i === $page ? 'active' : '';
        $html .= '<a href="orders.php?status=' . $statusFilter . '&page=' . $i . '&per_page=' . $perPage . '&search=' . urlencode($searchTerm) . '" class="page-link ' . $activeClass . '">';
        $html .= $i . '</a>';
    }
    
    if ($endPage < $totalPages) {
        if ($endPage < $totalPages - 1) {
            $html .= '<span class="page-ellipsis">...</span>';
        }
        $html .= '<a href="orders.php?status=' . $statusFilter . '&page=' . $totalPages . '&per_page=' . $perPage . '&search=' . urlencode($searchTerm) . '" class="page-link">' . $totalPages . '</a>';
    }
    
    // 下一页链接
    if ($page < $totalPages) {
        $html .= '<a href="orders.php?status=' . $statusFilter . '&page=' . ($page + 1) . '&per_page=' . $perPage . '&search=' . urlencode($searchTerm) . '" class="page-link">';
        $html .= '下一页 <i class="fas fa-chevron-right"></i></a>';
    }
    
    $html .= '</div>';
    
    return $html;
}

// 处理订单页面请求
function processOrdersRequest() {
    // 获取数据库连接
    $db = getDbConnection();
    
    // 获取当前状态筛选，0表示全部
    $statusFilter = isset($_GET['status']) ? intval($_GET['status']) : 0; // 默认显示所有订单
    $statusNames = getOrderStatusNames();
    
    // 添加"全部"选项到状态名称数组
    $allStatusNames = [0 => '全部'] + $statusNames;
    
    // 搜索功能
    $searchTerm = isset($_GET['search']) ? $_GET['search'] : '';
    list($whereClause, $params) = buildQueryConditions($statusFilter, $searchTerm);
    
    // 分页设置
    $page = isset($_GET['page']) ? intval($_GET['page']) : 1;
    $perPage = isset($_GET['per_page']) ? intval($_GET['per_page']) : 10;
    $offset = ($page - 1) * $perPage;
    
    // 获取分页信息
    list($totalRecords, $totalPages) = getOrderPagination($db, $whereClause, $params, $perPage);
    
    // 获取订单列表
    $orders = getOrders($db, $whereClause, $params, $offset, $perPage);
    
    // 检查是否有成功消息
    $hasSuccessMessage = isset($_GET['success']) && $_GET['success'] == 1;
    
    // 返回数据
    return [
        'statusFilter' => $statusFilter,
        'statusNames' => $allStatusNames, // 带"全部"选项的状态名称（用于标签显示）
        'originalStatusNames' => $statusNames, // 原始状态名称（用于订单状态显示）
        'searchTerm' => $searchTerm,
        'page' => $page,
        'perPage' => $perPage,
        'totalPages' => $totalPages,
        'orders' => $orders,
        'hasSuccessMessage' => $hasSuccessMessage,
        'paginationHtml' => generatePaginationHtml($page, $totalPages, $statusFilter, $perPage, $searchTerm)
    ];
}
