<?php
require_once '../config/database.php';

// 设置自定义日志路径
$logFile = __DIR__ . '/../../logs/debug.log';

// 自定义日志函数
function writeLog($message) {
    global $logFile;
    $timestamp = date('Y-m-d H:i:s');
    $logMessage = "[{$timestamp}] [Sitemap] {$message}" . PHP_EOL;
    
    // 写入日志文件
    file_put_contents($logFile, $logMessage, FILE_APPEND);
    
    // 同时记录到服务器错误日志
    error_log('[Sitemap] ' . $message);
}

// 获取数据库连接
$db = getDbConnection();

// 创建sitemap_generation表（如果不存在）
createSitemapGenerationTable($db);

// 获取当前日期时间
$currentDateTime = date('Y-m-d H:i:s');
$formattedDateTime = date('今天H:i');

// 处理站点地图请求
if (!empty($_POST)) {
    // 记录POST数据到日志
    writeLog('收到POST请求: ' . json_encode($_POST));
    
    $action = isset($_POST['action']) ? $_POST['action'] : '';
    writeLog('Action: ' . $action);
    
    // 处理生成站点地图请求
    if (strpos($action, 'generate_') === 0) {
        $type = str_replace('generate_', '', $action);
        writeLog('生成站点地图类型: ' . $type);
        
        $result = generateSitemap($type);
        if ($result) {
            $message = $type === 'all' ? '所有类型站点地图生成成功' : strtoupper($type) . '站点地图生成成功';
            writeLog('生成成功: ' . $message);
            echo json_encode(['success' => true, 'message' => $message]);
        } else {
            $message = '站点地图生成失败，请检查服务器权限和日志';
            writeLog('生成失败: ' . $message);
            echo json_encode(['success' => false, 'message' => $message]);
        }
        exit;
    } elseif ($action === 'delete_all') {
        writeLog('删除所有站点地图');
        $result = deleteSitemaps();
        if ($result) {
            writeLog('删除成功');
            echo json_encode(['success' => true, 'message' => '站点地图删除成功']);
        } else {
            writeLog('删除失败');
            echo json_encode(['success' => false, 'message' => '站点地图删除失败，请检查文件权限']);
        }
        exit;
    }
}

// 如果直接从命令行运行此脚本，处理生成站点地图的请求
if (php_sapi_name() === 'cli') {
    echo "[Sitemap] 从命令行启动站点地图生成\n";
    
    // 设置默认参数
    $action = 'generate_sitemap';
    $type = 'all';
    
    // 处理命令行参数
    $options = getopt('', ['action:', 'type:']);
    if (isset($options['action'])) {
        $action = $options['action'];
    }
    if (isset($options['type'])) {
        $type = $options['type'];
    }
    
    echo "[Sitemap] 执行操作: $action, 类型: $type\n";
    
    // 执行相应的操作
    if ($action === 'generate_sitemap') {
        $result = generateSitemap($type);
        echo "[Sitemap] 生成" . ($result ? "成功" : "失败") . "\n";
    } else {
        echo "[Sitemap] 未知操作: $action\n";
    }
    
    exit;
}

/**
 * 创建sitemap_generation表
 * 
 * @param PDO $db 数据库连接
 * @return void
 */
function createSitemapGenerationTable($db) {
    try {
        $sql = "CREATE TABLE IF NOT EXISTS `sitemap_generation` (
            `id` int(11) NOT NULL AUTO_INCREMENT,
            `type` varchar(20) NOT NULL COMMENT '地图类型: xml, txt, html, all',
            `generated_at` datetime NOT NULL COMMENT '生成时间',
            PRIMARY KEY (`id`),
            UNIQUE KEY `type` (`type`)
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='站点地图生成记录';";
        
        $db->exec($sql);
        writeLog('创建或验证sitemap_generation表');
    } catch (PDOException $e) {
        // 如果创建表失败，记录错误但继续执行
        writeLog('创建sitemap_generation表失败: ' . $e->getMessage());
    }
}

/**
 * 生成站点地图
 * 
 * @param string $type 站点地图类型 (xml, txt, html, all)
 * @return bool 是否成功生成
 */
function generateSitemap($type) {
    global $db, $currentDateTime;
    
    try {
        writeLog('开始生成站点地图: ' . $type);
        
        // 获取网站URL
        $siteUrl = 'http://www.rrrpt.com';
        try {
            $stmt = $db->prepare("SELECT value FROM settings WHERE name = 'site_url'");
            $stmt->execute();
            $url = $stmt->fetchColumn();
            if ($url) {
                $siteUrl = $url;
            }
        } catch (Exception $e) {
            writeLog('获取网站URL失败: ' . $e->getMessage() . '，使用默认URL: ' . $siteUrl);
        }
        
        writeLog('使用网站URL: ' . $siteUrl);
        
        // 确保sitemap目录存在且可写
        $sitemapDir = __DIR__ . '/../../sitemap';
        if (!is_dir($sitemapDir)) {
            writeLog('创建站点地图目录: ' . $sitemapDir);
            if (!mkdir($sitemapDir, 0777, true)) {
                writeLog('无法创建站点地图目录: ' . $sitemapDir);
                return false;
            }
        }
        
        // 确保目录有写入权限
        if (!is_writable($sitemapDir)) {
            writeLog('站点地图目录没有写入权限，尝试修改权限: ' . $sitemapDir);
            chmod($sitemapDir, 0777);
            if (!is_writable($sitemapDir)) {
                writeLog('修改权限后仍然无法写入: ' . $sitemapDir);
                return false;
            }
        }
        
        // 获取所有页面链接
        $urls = getPageUrls($db, $siteUrl);
        writeLog('获取到 ' . count($urls) . ' 个URL');
        
        $success = true;
        
        // 根据类型生成相应的站点地图
        if ($type === 'xml' || $type === 'all') {
            $xmlContent = generateXmlSitemap($urls);
            $xmlPath = $sitemapDir . '/sitemap.xml';
            writeLog('保存XML站点地图到: ' . $xmlPath);
            
            $writeResult = file_put_contents($xmlPath, $xmlContent);
            if ($writeResult === false) {
                writeLog('无法写入XML站点地图文件: ' . $xmlPath);
                $success = false;
            } else {
                writeLog('成功写入 ' . $writeResult . ' 字节到XML站点地图');
                // 设置文件权限确保可读
                chmod($xmlPath, 0666);
                // 记录生成时间
                updateGenerationTime('xml', $currentDateTime);
            }
        }
        
        if ($type === 'txt' || $type === 'all') {
            $txtContent = generateTxtSitemap($urls);
            $txtPath = $sitemapDir . '/sitemap.txt';
            writeLog('保存TXT站点地图到: ' . $txtPath);
            
            $writeResult = file_put_contents($txtPath, $txtContent);
            if ($writeResult === false) {
                writeLog('无法写入TXT站点地图文件: ' . $txtPath);
                $success = false;
            } else {
                writeLog('成功写入 ' . $writeResult . ' 字节到TXT站点地图');
                // 设置文件权限确保可读
                chmod($txtPath, 0666);
                // 记录生成时间
                updateGenerationTime('txt', $currentDateTime);
            }
        }
        
        if ($type === 'html' || $type === 'all') {
            $htmlContent = generateHtmlSitemap($urls, $siteUrl);
            $htmlPath = $sitemapDir . '/sitemap.html';
            writeLog('保存HTML站点地图到: ' . $htmlPath);
            
            $writeResult = file_put_contents($htmlPath, $htmlContent);
            if ($writeResult === false) {
                writeLog('无法写入HTML站点地图文件: ' . $htmlPath);
                $success = false;
            } else {
                writeLog('成功写入 ' . $writeResult . ' 字节到HTML站点地图');
                // 设置文件权限确保可读
                chmod($htmlPath, 0666);
                // 记录生成时间
                updateGenerationTime('html', $currentDateTime);
            }
        }
        
        // 如果是生成所有类型，记录最后一次全部生成的时间
        if ($type === 'all' && $success) {
            updateGenerationTime('all', $currentDateTime);
        }
        
        writeLog('站点地图生成' . ($success ? '成功' : '失败'));
        return $success;
    } catch (Exception $e) {
        writeLog('生成站点地图时发生异常: ' . $e->getMessage());
        return false;
    }
}

/**
 * 获取页面URL列表
 * 
 * @param PDO $db 数据库连接
 * @param string $siteUrl 网站URL
 * @return array URL数组
 */
function getPageUrls($db, $siteUrl) {
    $urls = [];
    writeLog('开始收集URL');
    
    // 首页
    $urls[] = [
        'loc' => $siteUrl,
        'lastmod' => date('Y-m-d'),
        'changefreq' => 'daily',
        'priority' => '1.0'
    ];
    
    // 扫描网站根目录下的PHP文件
    $rootDir = __DIR__ . '/../../';
    $excludeDirs = ['bot', 'backend', 'user', 'sitemap', 'config', 'logs', 'Install'];
    
    writeLog('扫描网站根目录PHP文件');
    
    try {
        // 扫描根目录PHP文件
        $phpFiles = glob($rootDir . '*.php');
        $phpFilesCount = count($phpFiles);
        writeLog("找到{$phpFilesCount}个根目录PHP文件");
        
        foreach ($phpFiles as $file) {
            $filename = basename($file);
            // 排除index.php
            if ($filename === 'index.php') {
                continue; // index.php是首页，已经添加过了
            }
            
            // 排除某些特殊文件
            if (in_array($filename, ['config.php', 'check_db.php', 'debug-config.php', 'fix.php', 'show-all-configs.php', 'SpecialController.php', 'webhook.php'])) {
                continue;
            }
            
            $pageName = str_replace('.php', '', $filename);
            // 根据需求，根目录php文件转为.html格式
            $pageUrl = $siteUrl . '/' . $pageName . '.html';
            
            $urls[] = [
                'loc' => $pageUrl,
                'lastmod' => date('Y-m-d', filemtime($file)),
                'changefreq' => 'weekly',
                'priority' => '0.7'
            ];
        }
        
        // 扫描根目录HTML文件
        $htmlFiles = glob($rootDir . '*.html');
        $htmlFilesCount = count($htmlFiles);
        writeLog("找到{$htmlFilesCount}个根目录HTML文件");
        
        foreach ($htmlFiles as $file) {
            $filename = basename($file);
            // 排除某些特殊HTML文件
            if (in_array($filename, ['404.html', 'error.html'])) {
                continue;
            }
            
            $pageUrl = $siteUrl . '/' . $filename;
            
            $urls[] = [
                'loc' => $pageUrl,
                'lastmod' => date('Y-m-d', filemtime($file)),
                'changefreq' => 'weekly',
                'priority' => '0.7'
            ];
        }
        
        // 添加product页面
        $urls[] = [
            'loc' => $siteUrl . '/product',
            'lastmod' => date('Y-m-d'),
            'changefreq' => 'daily',
            'priority' => '0.9'
        ];
        
        // 从products表获取产品链接
        try {
            // 获取所有产品ID
            $stmt = $db->prepare("SELECT id, updated_at FROM products WHERE status = 1 ORDER BY id");
            $stmt->execute();
            $products = $stmt->fetchAll(PDO::FETCH_ASSOC);
            
            foreach ($products as $product) {
                $urls[] = [
                    'loc' => $siteUrl . '/product/' . $product['id'] . '.html',
                    'lastmod' => isset($product['updated_at']) ? date('Y-m-d', strtotime($product['updated_at'])) : date('Y-m-d'),
                    'changefreq' => 'weekly',
                    'priority' => '0.8'
                ];
            }
            writeLog('获取到 ' . count($products) . ' 个产品URL');
        } catch (PDOException $e) {
            // 表可能不存在，忽略错误
            writeLog('获取产品表数据失败: ' . $e->getMessage());
        }
        
        // 处理视频目录
        try {
            // 添加视频主页
            $urls[] = [
                'loc' => $siteUrl . '/video',
                'lastmod' => date('Y-m-d'),
                'changefreq' => 'daily',
                'priority' => '0.9'
            ];
            
            // 从videos表获取视频链接
            try {
                $stmt = $db->prepare("SELECT id, updated_at FROM videos WHERE status = 1 ORDER BY id");
                $stmt->execute();
                $videos = $stmt->fetchAll(PDO::FETCH_ASSOC);
                
                foreach ($videos as $video) {
                    $urls[] = [
                        'loc' => $siteUrl . '/video/' . $video['id'] . '.html',
                        'lastmod' => isset($video['updated_at']) ? date('Y-m-d', strtotime($video['updated_at'])) : date('Y-m-d'),
                        'changefreq' => 'weekly',
                        'priority' => '0.8'
                    ];
                }
                writeLog('获取到 ' . count($videos) . ' 个视频URL');
            } catch (PDOException $e) {
                // 表可能不存在，忽略错误
                writeLog('获取视频表数据失败: ' . $e->getMessage());
            }
        } catch (Exception $e) {
            writeLog('处理视频目录失败: ' . $e->getMessage());
        }
        
        // 处理新闻目录
        try {
            // 添加新闻主页
            $urls[] = [
                'loc' => $siteUrl . '/news',
                'lastmod' => date('Y-m-d'),
                'changefreq' => 'daily',
                'priority' => '0.9'
            ];
            
            // 从news表获取新闻链接
            try {
                $stmt = $db->prepare("SELECT id, updated_at FROM news WHERE status = 1 ORDER BY id");
                $stmt->execute();
                $newsItems = $stmt->fetchAll(PDO::FETCH_ASSOC);
                
                foreach ($newsItems as $newsItem) {
                    $urls[] = [
                        'loc' => $siteUrl . '/news/' . $newsItem['id'] . '.html',
                        'lastmod' => isset($newsItem['updated_at']) ? date('Y-m-d', strtotime($newsItem['updated_at'])) : date('Y-m-d'),
                        'changefreq' => 'weekly',
                        'priority' => '0.8'
                    ];
                }
                writeLog('获取到 ' . count($newsItems) . ' 个新闻URL');
            } catch (PDOException $e) {
                // 表可能不存在，忽略错误
                writeLog('获取新闻表数据失败: ' . $e->getMessage());
            }
        } catch (Exception $e) {
            writeLog('处理新闻目录失败: ' . $e->getMessage());
        }
        
        writeLog('收集URL完成，共有 ' . count($urls) . ' 个URL');
    } catch (Exception $e) {
        writeLog('扫描文件失败: ' . $e->getMessage());
    }
    
    return $urls;
}

/**
 * 生成XML站点地图
 * 
 * @param array $urls URL数组
 * @return string XML内容
 */
function generateXmlSitemap($urls) {
    $xml = '<?xml version="1.0" encoding="UTF-8"?>' . "\n";
$xml .= '<urlset xmlns="http://www.sitemaps.org/schemas/sitemap/0.9">' . "\n";

  foreach ($urls as $url) {
  $xml .= " <url>\n";
    $xml .= " <loc>" . htmlspecialchars($url['loc']) . "</loc>\n";
    $xml .= " <lastmod>" . $url['lastmod'] . "</lastmod>\n";
    $xml .= " <changefreq>" . $url['changefreq'] . "</changefreq>\n";
    $xml .= " <priority>" . $url['priority'] . "</priority>\n";
    $xml .= " </url>\n";
  }

  $xml .= '</urlset>';

return $xml;
}

/**
* 生成TXT站点地图
*
* @param array $urls URL数组
* @return string TXT内容
*/
function generateTxtSitemap($urls) {
$txt = '';

foreach ($urls as $url) {
$txt .= $url['loc'] . "\n";
}

return $txt;
}

/**
* 生成HTML站点地图
*
* @param array $urls URL数组
* @param string $siteUrl 网站URL
* @return string HTML内容
*/
function generateHtmlSitemap($urls, $siteUrl) {
$html = '
<!DOCTYPE html>' . "\n";
$html .= '<html lang="zh-CN">' . "\n";
  $html .= '<head>' . "\n";
    $html .= '
    <meta charset="UTF-8">' . "\n";
    $html .= '
    <meta name="viewport" content="width=device-width, initial-scale=1.0">' . "\n";
    $html .= ' <title>网站地图 - ' . htmlspecialchars($siteUrl) . '</title>' . "\n";
    $html .= ' <style>
    ' . "\n";
$html .='        body { font-family: Arial, sans-serif; margin: 20px; }'. "\n";
    $html .='        h1 { color: #333; }'. "\n";
    $html .='        .sitemap-list { margin: 20px 0; }'. "\n";
    $html .='        .sitemap-item { margin: 10px 0; }'. "\n";
    $html .='        .sitemap-link { color: #1a0dab; text-decoration: none; }'. "\n";
    $html .='        .sitemap-link:hover { text-decoration: underline; }'. "\n";
    $html .='        .sitemap-date { color: #666; font-size: 0.8em; margin-left: 10px; }'. "\n";
    $html .='    

    </style>' . "\n";
    $html .= '
  </head>' . "\n";
  $html .= '<body>' . "\n";
    $html .= ' <h1>网站地图</h1>' . "\n";
    $html .= ' <div class="sitemap-list">' . "\n";

      foreach ($urls as $url) {
      $html .= ' <div class="sitemap-item">' . "\n";
        $html .= ' <a href="' . htmlspecialchars($url['loc']) . '" class="sitemap-link">' . htmlspecialchars($url['loc']) . '</a>' . "\n";
        $html .= ' <span class="sitemap-date">更新日期: ' . $url['lastmod'] . '</span>' . "\n";
        $html .= ' </div>' . "\n";
      }

      $html .= ' </div>' . "\n";
    $html .= '</body>' . "\n";
  $html .= '</html>';

return $html;
}

/**
* 更新站点地图生成时间
*
* @param string $type 站点地图类型
* @param string $datetime 生成时间
* @return void
*/
function updateGenerationTime($type, $datetime) {
global $db;

try {
// 检查是否存在记录
$stmt = $db->prepare("SELECT COUNT(*) FROM sitemap_generation WHERE type = ?");
$stmt->execute([$type]);
$exists = $stmt->fetchColumn() > 0;

if ($exists) {
// 更新现有记录
$stmt = $db->prepare("UPDATE sitemap_generation SET generated_at = ? WHERE type = ?");
$stmt->execute([$datetime, $type]);
writeLog("更新{$type}站点地图生成时间记录");
} else {
// 创建新记录
$stmt = $db->prepare("INSERT INTO sitemap_generation (type, generated_at) VALUES (?, ?)");
$stmt->execute([$type, $datetime]);
writeLog("创建{$type}站点地图生成时间记录");
}
} catch (PDOException $e) {
writeLog('更新站点地图生成时间失败: ' . $e->getMessage());
}
}

/**
* 删除所有站点地图文件
*
* @return bool 是否成功删除
*/
function deleteSitemaps() {
try {
$sitemapDir = __DIR__ . '/../../sitemap';

$files = [
$sitemapDir . '/sitemap.xml',
$sitemapDir . '/sitemap.txt',
$sitemapDir . '/sitemap.html'
];

$success = true;

foreach ($files as $file) {
if (file_exists($file)) {
if (!unlink($file)) {
writeLog('无法删除文件: ' . $file);
$success = false;
}
}
}

return $success;
} catch (Exception $e) {
writeLog('删除站点地图时发生错误: ' . $e->getMessage());
return false;
}
}

// 获取各类型站点地图的生成时间
try {
$stmt = $db->prepare("SELECT type, generated_at FROM sitemap_generation");
$stmt->execute();
$generations = $stmt->fetchAll(PDO::FETCH_KEY_PAIR);

$xmlGeneratedAt = isset($generations['xml']) ? $generations['xml'] : null;
$txtGeneratedAt = isset($generations['txt']) ? $generations['txt'] : null;
$htmlGeneratedAt = isset($generations['html']) ? $generations['html'] : null;
$allGeneratedAt = isset($generations['all']) ? $generations['all'] : null;
} catch (PDOException $e) {
// 表可能刚创建，还没有数据
$xmlGeneratedAt = null;
$txtGeneratedAt = null;
$htmlGeneratedAt = null;
$allGeneratedAt = null;
}

// 检查站点地图文件是否存在
$xmlExists = file_exists(__DIR__ . '/../../sitemap/sitemap.xml');
$txtExists = file_exists(__DIR__ . '/../../sitemap/sitemap.txt');
$htmlExists = file_exists(__DIR__ . '/../../sitemap/sitemap.html');
