<?php
// 引入必要的配置文件和函数库
require_once '../config/database.php';
require_once '../config/config.php';

// 添加检查权限的函数,如果它没有在其他地方定义
if (!function_exists('checkPermission')) {
    function checkPermission() {
        // 检查用户是否已登录
        if (!isAdminLoggedIn()) {
            // 未登录,重定向到登录页
            header("Location: login.php");
            exit;
        }
    }
}

// 检查是否已定义isAdminLoggedIn函数
if (!function_exists('isAdminLoggedIn')) {
    function isAdminLoggedIn() {
        // 简单的会话检查,您可能需要根据实际情况调整
        return isset($_SESSION['admin_id']) && !empty($_SESSION['admin_id']);
    }
}

// 启动会话(如果尚未启动)
if (session_status() == PHP_SESSION_NONE) {
    session_start();
}

// 检查用户权限
checkPermission();

// 初始化变量
$id = isset($_GET['id']) ? intval($_GET['id']) : 0;
$video = [
    'id' => 0,
    'title' => '',
    'description' => '',
    'category_id' => 0,
    'status' => 1,
    'featured' => 0,
    'thumbnail' => '',
    'video_url' => '',
    'duration' => '',
    'views' => 0,
    'likes' => 0,
    'created_at' => date('Y-m-d H:i:s'),
    'updated_at' => date('Y-m-d H:i:s')
];
$pageTitle = '添加视频';
$submitButtonText = '保存视频';
$success = false;
$error = '';

try {
    // 获取数据库连接
    $db = getDbConnection();
    
    if (!$db) {
        throw new PDOException("数据库连接失败，无法获取连接对象");
    }
    
    // 获取所有视频分类
    $categoriesSql = "SELECT id, name FROM video_categories WHERE status = 1 ORDER BY sort_order ASC";
    try {
        $categoriesStmt = $db->query($categoriesSql);
        $categories = $categoriesStmt->fetchAll(PDO::FETCH_ASSOC);
    } catch (PDOException $e) {
        error_log("查询视频分类失败: " . $e->getMessage());
        $categories = []; // 如果查询失败，使用空数组
        $error = '获取视频分类失败，请检查数据库连接或联系管理员';
    }
    
    // 如果是编辑操作，获取视频数据
    if ($id > 0) {
        $sql = "SELECT * FROM videos WHERE id = :id";
        try {
            $stmt = $db->prepare($sql);
            $stmt->bindParam(':id', $id, PDO::PARAM_INT);
            $stmt->execute();
            $result = $stmt->fetch(PDO::FETCH_ASSOC);
            
            if ($result) {
                $video = $result;
                $pageTitle = '编辑视频';
                $submitButtonText = '更新视频';
            } else {
                $error = '视频不存在或已被删除';
            }
        } catch (PDOException $e) {
            error_log("获取视频数据失败: " . $e->getMessage());
            $error = '获取视频数据失败，请检查数据库连接';
        }
    }
    
    // 处理表单提交
    if ($_SERVER['REQUEST_METHOD'] == 'POST') {
        // 获取表单数据
        $video['title'] = trim($_POST['title'] ?? '');
        $video['description'] = trim($_POST['description'] ?? '');
        $video['category_id'] = intval($_POST['category_id'] ?? 0);
        $video['status'] = isset($_POST['status']) ? 1 : 0;
        $video['featured'] = isset($_POST['featured']) ? 1 : 0;
        $video['video_url'] = trim($_POST['video_url'] ?? '');
        $video['thumbnail'] = trim($_POST['thumbnail'] ?? '');
        $video['duration'] = trim($_POST['duration'] ?? '');
        $video['updated_at'] = date('Y-m-d H:i:s');
        
        // 验证必填字段
        if (empty($video['title'])) {
            $error = '视频标题不能为空';
        } elseif ($video['category_id'] <= 0) {
            $error = '请选择视频分类';
        } elseif (empty($video['video_url'])) {
            $error = '视频链接不能为空';
        } else {
            try {
                // 保存数据
                if ($id > 0) {
                    // 更新视频
                    $sql = "UPDATE videos SET 
                            title = :title, 
                            description = :description, 
                            category_id = :category_id, 
                            status = :status, 
                            featured = :featured,
                            thumbnail = :thumbnail, 
                            video_url = :video_url, 
                            duration = :duration, 
                            updated_at = :updated_at 
                            WHERE id = :id";
                    $stmt = $db->prepare($sql);
                    if (!$stmt) {
                        throw new PDOException("准备更新SQL语句失败: " . print_r($db->errorInfo(), true));
                    }
                    $stmt->bindParam(':id', $id, PDO::PARAM_INT);
                } else {
                    // 插入新视频
                    $sql = "INSERT INTO videos (
                            title, description, category_id, status, featured,
                            thumbnail, video_url, duration, views, likes,
                            created_at, updated_at
                        ) VALUES (
                            :title, :description, :category_id, :status, :featured,
                            :thumbnail, :video_url, :duration, 0, 0,
                            :created_at, :updated_at
                        )";
                    $stmt = $db->prepare($sql);
                    if (!$stmt) {
                        throw new PDOException("准备插入SQL语句失败: " . print_r($db->errorInfo(), true));
                    }
                    $stmt->bindParam(':created_at', $video['created_at']);
                }
                
                // 绑定参数
                $stmt->bindParam(':title', $video['title']);
                $stmt->bindParam(':description', $video['description']);
                $stmt->bindParam(':category_id', $video['category_id'], PDO::PARAM_INT);
                $stmt->bindParam(':status', $video['status'], PDO::PARAM_INT);
                $stmt->bindParam(':featured', $video['featured'], PDO::PARAM_INT);
                $stmt->bindParam(':thumbnail', $video['thumbnail']);
                $stmt->bindParam(':video_url', $video['video_url']);
                $stmt->bindParam(':duration', $video['duration']);
                $stmt->bindParam(':updated_at', $video['updated_at']);
                
                // 执行SQL并检查结果
                if (!$stmt->execute()) {
                    throw new PDOException("SQL执行失败: " . print_r($stmt->errorInfo(), true));
                }
                
                if ($id == 0) {
                    // 获取新插入的ID
                    $id = $db->lastInsertId();
                    if (!$id) {
                        throw new PDOException("获取新插入ID失败");
                    }
                    $video['id'] = $id;
                }
                $success = true;
                $pageTitle = '编辑视频';
                $submitButtonText = '更新视频';
            } catch (PDOException $e) {
                error_log("保存视频数据失败: " . $e->getMessage());
                $error = '保存视频失败: ' . $e->getMessage();
            }
        }
    }
} catch (PDOException $e) {
    // 记录详细错误日志
    error_log("数据库操作出错: " . $e->getMessage() . "\n" . 
              "SQL状态: " . (isset($stmt) ? print_r($stmt->errorInfo(), true) : "无可用语句") . "\n" .
              "数据库信息: " . (isset($db) ? print_r($db->errorInfo(), true) : "无数据库连接"));
    
    // 调试模式下可以显示详细错误
    $isDebug = true; // 可根据配置文件设置
    if ($isDebug) {
        $error = '数据库操作出错: ' . $e->getMessage();
    } else {
        $error = '数据库操作出错，请稍后再试或联系管理员';
    }
}
