<?php
// 开始会话和数据库连接
session_start();
require_once '../config/database.php';

// 检查是否有产品ID
if (!isset($_GET['id'])) {
    header('Location: product.html');
    exit;
}

$product_id = $_GET['id'];
$db = getDbConnection();

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    try {
        // 处理流量字段
        $traffic = $_POST['traffic'];
        if ($traffic === '不限' || $traffic === '' || $traffic === '0') {
            $traffic = null;
        }

        // 处理标签 - 将数组转换为逗号分隔的字符串
        $tags = isset($_POST['tags']) ? implode(',', $_POST['tags']) : null;

        // 更新产品信息
        $sql = "UPDATE products SET 
                cpu = :cpu,
                memory = :memory,
                disk = :disk,
                bandwidth = :bandwidth,
                traffic = :traffic,
                defense = :defense,
                ip_count = :ip_count,
                gpu = :gpu,
                price = :price,
                region_id = :region_id,
                tags = :tags,
                line_id = :line_id
                WHERE id = :id";

        $stmt = $db->prepare($sql);
        $stmt->execute([
            ':cpu' => $_POST['cpu'],
            ':memory' => $_POST['memory'],
            ':disk' => $_POST['disk'],
            ':bandwidth' => $_POST['bandwidth'],
            ':traffic' => $traffic,
            ':defense' => $_POST['defense'],
            ':ip_count' => $_POST['ip_count'],
            ':gpu' => $_POST['gpu'],
            ':price' => $_POST['price'],
            ':region_id' => $_POST['region_id'],
            ':tags' => $tags,
            ':line_id' => $_POST['line_id'],
            ':id' => $product_id
        ]);

        $_SESSION['success'] = '产品更新成功！';
        header('Location: product.html');
        exit;
    } catch (Exception $e) {
        $_SESSION['error'] = '更新失败：' . $e->getMessage();
    }
}

// 获取产品信息
$stmt = $db->prepare("SELECT * FROM products WHERE id = ?");
$stmt->execute([$product_id]);
$product = $stmt->fetch(PDO::FETCH_ASSOC);

// 如果产品不存在，返回列表页
if (!$product) {
    header('Location: product.html');
    exit;
}

// 获取所有地区数据
$regions = $db->query("SELECT * FROM area ORDER BY sort_order ASC")->fetchAll();

// 获取所有标签数据
$tags = $db->query("SELECT * FROM tags ORDER BY sort_order ASC")->fetchAll();

// 获取所有线路数据
$lines = $db->query("SELECT l.*, s.name as supplier_name 
                     FROM line l 
                     JOIN suppliers s ON l.supplier_id = s.id 
                     ORDER BY l.supplier_id ASC, l.sort_order ASC")->fetchAll();
?>

<!DOCTYPE html>
<html lang="zh-CN">
  <head>
    <meta charset="UTF-8">
    <title>编辑产品</title>
    <link rel="stylesheet" href="public/css/style.css">
    <link rel="stylesheet" href="public/css/product-edit.css">
  </head>
  <body>
    <?php include 'public/header.php'; ?>
    <div class="container">
      <div class="sidebar">
        <?php include 'public/letf.php'; ?>
      </div>
      <div class="main-content">
        <h2>编辑产品</h2>

        <?php if (isset($_SESSION['error'])): ?>
        <div class="alert alert-danger">
          <?php 
                    echo $_SESSION['error'];
                    unset($_SESSION['error']);
                    ?>
        </div>
        <?php endif; ?>

        <form method="POST" class="edit-form">
          <div class="form-group">
            <label for="cpu" class="label1">cpu</label>
            <input type="text" name="cpu" id="cpu" class="form-control" value="<?= htmlspecialchars($product['cpu']) ?>" required>
          </div>

          <div class="form-group">
            <label for="memory" class="label1">内存</label>
            <input type="text" name="memory" id="memory" class="form-control" value="<?= htmlspecialchars($product['memory']) ?>" required>
          </div>

          <div class="form-group">
            <label for="disk" class="label1">硬盘</label>
            <input type="text" name="disk" id="disk" class="form-control" value="<?= htmlspecialchars($product['disk']) ?>" required>
          </div>

          <div class="form-group">
            <label for="bandwidth" class="label1">带宽</label>
            <input type="text" name="bandwidth" id="bandwidth" class="form-control" value="<?= htmlspecialchars($product['bandwidth']) ?>" required>
          </div>

          <div class="form-group">
            <label for="traffic" class="label1">流量</label>
            <input type="text" name="traffic" id="traffic" class="form-control" value="<?= $product['traffic'] === null ? '不限' : htmlspecialchars($product['traffic']) ?>">
          </div>

          <div class="form-group">
            <label for="defense" class="label1">防御</label>
            <input type="text" name="defense" id="defense" class="form-control" value="<?= htmlspecialchars($product['defense'] ?? '') ?>">
          </div>

          <div class="form-group">
            <label for="ip_count" class="label1">IP数量</label>
            <input type="number" name="ip_count" id="ip_count" class="form-control" value="<?= htmlspecialchars($product['ip_count']) ?>" required min="1">
          </div>

          <div class="form-group">
            <label for="gpu" class="label1">GPU</label>
            <input type="text" name="gpu" id="gpu" class="form-control" value="<?= htmlspecialchars($product['gpu'] ?? '') ?>">
          </div>

          <div class="form-group">
            <label for="price" class="label1">价格</label>
            <input type="number" name="price" id="price" class="form-control" value="<?= htmlspecialchars($product['price']) ?>" step="0.01" min="0">
          </div>

          <div class="form-group">
            <label for="region_id" class="label1">地区</label>
            <select name="region_id" id="region_id" class="form-control" required>
              <option value="">请选择地区</option>
              <?php foreach ($regions as $region): ?>
              <option value="<?= $region['id'] ?>" <?= $region['id'] == $product['region_id'] ? 'selected' : '' ?>>
                <?= htmlspecialchars($region['name']) ?>
              </option>
              <?php endforeach; ?>
            </select>
          </div>

          <div class="form-group">
            <div class="tag-list">
              <?php 
                            $selectedTags = !empty($product['tags']) ? explode(',', $product['tags']) : [];
                            // 获取所有标签数据并按父子关系组织
                            $query = "SELECT t1.*, t2.name as parent_name 
                                    FROM tags t1 
                                    LEFT JOIN tags t2 ON t1.parent_id = t2.id 
                                    ORDER BY t1.parent_id = 0 DESC, t1.parent_id ASC, t1.sort_order ASC";
                            $stmt = $db->query($query);
                            $allTags = $stmt->fetchAll();
                            
                            // 组织父子关系
                            $parentTags = [];
                            $childTags = [];
                            foreach ($allTags as $tag) {
                                if ($tag['parent_id'] == 0) {
                                    $parentTags[] = $tag;
                                } else {
                                    $childTags[$tag['parent_id']][] = $tag;
                                }
                            }
                            
                            // 显示标签
                            foreach ($parentTags as $parent): 
                            ?>
              <div class="tag-group">
                <div class="tag-parent">
                  <div class="parent-title"><?= htmlspecialchars($parent['name']) ?></div>
                </div>
                <?php if (isset($childTags[$parent['id']])): ?>
                <div class="tag-children">
                  <?php foreach ($childTags[$parent['id']] as $child): ?>
                  <label class="tag-checkbox">
                    <input type="checkbox" name="tags[]" value="<?= $child['id'] ?>" <?= in_array($child['id'], $selectedTags) ? 'checked' : '' ?>>
                    <span><?= htmlspecialchars($child['name']) ?></span>
                  </label>
                  <?php endforeach; ?>
                </div>
                <?php endif; ?>
              </div>
              <?php endforeach; ?>
            </div>
          </div>

          <div class="form-group">
            <label for="line_id">线路</label>
            <select name="line_id" id="line_id" class="form-control" required>
              <option value="">请选择线路</option>
              <?php 
                            $currentSupplierId = null;
                            foreach ($lines as $line):
                                if ($currentSupplierId !== $line['supplier_id']):
                                    if ($currentSupplierId !== null) echo '</optgroup>';
                                    $currentSupplierId = $line['supplier_id'];
                            ?>
              <optgroup label="<?= htmlspecialchars($line['supplier_name']) ?>">
                <?php endif; ?>
                <option value="<?= $line['id'] ?>" <?= $line['id'] == $product['line_id'] ? 'selected' : '' ?>>
                  <?= htmlspecialchars($line['name']) ?>
                </option>
                <?php endforeach; ?>
              </optgroup>
            </select>
          </div>

          <div class="form-buttons" style="padding-right: 50px;">
            <button type="submit" class="btn btn-primary">保存修改</button>
            <a href="product.html" class="btn btn-secondary btn-primary" style="padding: 0; ">返回</a>
          </div>
        </form>
      </div>
    </div>
  </body>
</html>
