<?php
require_once '../config/database.php';
header('Content-Type: application/json');

// 检查请求方法
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    echo json_encode(['success' => false, 'message' => '无效的请求方法']);
    exit;
}

// 获取POST数据 - 从JSON请求体中读取
$json_data = file_get_contents('php://input');
$data = json_decode($json_data, true);

// 检查必要参数
if (!isset($data['product_id']) || !isset($data['field_name']) || !isset($data['field_value'])) {
    echo json_encode(['success' => false, 'message' => '缺少必要参数']);
    exit;
}

$id = intval($data['product_id']);
$field = $data['field_name'];
$value = trim($data['field_value']);

// 验证字段名称（防止SQL注入）
$allowedFields = ['cpu', 'memory', 'disk', 'bandwidth', 'traffic', 'defense', 'ip_count', 'gpu', 'price', 'region_id', 'line_id', 'tags'];
if (!in_array($field, $allowedFields)) {
    echo json_encode(['success' => false, 'message' => '无效的字段名称']);
    exit;
}

// 如果流量字段为"不限"或为空或为"0"，设置为NULL
if ($field === 'traffic' && ($value === '不限' || $value === '' || $value === '0')) {
    $value = null;
}

try {
    $db = getDbConnection();
    // 准备更新语句
    $sql = "UPDATE products SET $field = :value WHERE id = :id";
    $stmt = $db->prepare($sql);
    // 绑定参数
    $stmt->bindParam(':value', $value);
    $stmt->bindParam(':id', $id, PDO::PARAM_INT);
    // 执行更新
    $result = $stmt->execute();
    if ($result) {
        // 如果更新的是关联字段，返回显示名称
        $displayValue = $value;
        if ($field === 'traffic' && $value === null) {
            $displayValue = '不限';
        } else if ($field === 'region_id' && !empty($value)) {
            $regionQuery = "SELECT name FROM area WHERE id = :id";
            $regionStmt = $db->prepare($regionQuery);
            $regionStmt->bindParam(':id', $value, PDO::PARAM_INT);
            $regionStmt->execute();
            $region = $regionStmt->fetch();
            if ($region) {
                $displayValue = $region['name'];
            }
        } else if ($field === 'line_id' && !empty($value)) {
            $lineQuery = "SELECT l.name, s.name as supplier_name FROM line l 
                         JOIN suppliers s ON l.supplier_id = s.id 
                         WHERE l.id = :id";
            $lineStmt = $db->prepare($lineQuery);
            $lineStmt->bindParam(':id', $value, PDO::PARAM_INT);
            $lineStmt->execute();
            $line = $lineStmt->fetch();
            if ($line) {
                $displayValue = $line['name'] . " (" . $line['supplier_name'] . ")";
            }
        } else if ($field === 'tags' && !empty($value)) {
            // 对于标签，我们需要获取标签名称
            $tagIds = explode(',', $value);
            $tagNames = [];
            foreach ($tagIds as $tagId) {
                $tagQuery = "SELECT name FROM tags WHERE id = :id";
                $tagStmt = $db->prepare($tagQuery);
                $tagStmt->bindParam(':id', $tagId, PDO::PARAM_INT);
                $tagStmt->execute();
                $tag = $tagStmt->fetch();
                if ($tag) {
                    $tagNames[] = $tag['name'];
                }
            }
            $displayValue = $tagNames;
        } else if ($field === 'price' && !empty($value)) {
            // 格式化价格显示
            $displayValue = number_format((float)$value, 2);
        }
        echo json_encode([
            'success' => true, 
            'message' => '产品信息已更新',
            'displayValue' => $displayValue
        ]);
    } else {
        echo json_encode([
            'success' => false, 
            'message' => '更新失败，请重试'
        ]);
    }
} catch (PDOException $e) {
    echo json_encode([
        'success' => false, 
        'message' => '数据库错误: ' . $e->getMessage()
    ]);
}
?>
