document.addEventListener('DOMContentLoaded', function() {
    // 自动调整文本框高度
    function adjustTextareaHeight(textarea) {
        textarea.style.height = 'auto';
        textarea.style.height = textarea.scrollHeight + 'px';
    }
    
    // 防抖函数
    function debounce(func, wait) {
        let timeout;
        return function executedFunction(...args) {
            const later = () => {
                clearTimeout(timeout);
                func(...args);
            };
            clearTimeout(timeout);
            timeout = setTimeout(later, wait);
        };
    }
    
    // 保存配置
    function saveConfig(element, isSort = false) {
        const name = element.dataset.name;
        const content = element.value;
        const action = isSort ? 'update_sort' : 'update';
        
        // 显示保存中的状态
        const row = element.closest('tr');
        if (row) {
            row.classList.add('saving');
        }
        
        fetch('config_list.php', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/x-www-form-urlencoded',
            },
            body: `action=${action}&name=${encodeURIComponent(name)}&content=${encodeURIComponent(content)}`
        })
        .then(response => response.json())
        .then(data => {
            // 保存成功的反馈
            if (row) {
                row.classList.remove('saving');
                row.classList.add('saved');
                
                // 2秒后移除保存成功的状态
                setTimeout(() => {
                    row.classList.remove('saved');
                }, 2000);
            }
        })
        .catch(error => {
            console.error('保存失败:', error);
            if (row) {
                row.classList.remove('saving');
                row.classList.add('save-error');
                
                // 2秒后移除保存失败的状态
                setTimeout(() => {
                    row.classList.remove('save-error');
                }, 2000);
            }
        });
    }
    
    // 创建防抖保存函数
    const debouncedSave = debounce((element, isSort) => {
        saveConfig(element, isSort);
    }, 500);
    
    // 为所有文本框添加事件监听
    document.querySelectorAll('.config-value').forEach(textarea => {
        // 初始化高度
        adjustTextareaHeight(textarea);
        
        // 输入时自动调整高度和保存
        textarea.addEventListener('input', function() {
            adjustTextareaHeight(this);
            debouncedSave(this, false);
        });
        
        // 按下回车键时失去焦点
        textarea.addEventListener('keydown', function(e) {
            if (e.key === 'Enter' && !e.shiftKey) {
                e.preventDefault();
                this.blur();
            }
        });
        
        // 添加焦点样式
        textarea.addEventListener('focus', function() {
            this.closest('tr')?.classList.add('active-row');
        });
        
        textarea.addEventListener('blur', function() {
            this.closest('tr')?.classList.remove('active-row');
        });
    });
    
    // 为所有排序输入框添加事件监听
    document.querySelectorAll('.sort-value').forEach(input => {
        // 输入时自动保存
        input.addEventListener('input', function() {
            // 确保输入的是非负整数
            let value = parseInt(this.value);
            if (isNaN(value) || value < 0) {
                value = 0;
            }
            this.value = value;
            debouncedSave(this, true);
        });
        
        // 按下回车键时失去焦点
        input.addEventListener('keydown', function(e) {
            if (e.key === 'Enter') {
                e.preventDefault();
                this.blur();
            }
        });
        
        // 添加焦点样式
        input.addEventListener('focus', function() {
            this.closest('tr')?.classList.add('active-row');
        });
        
        input.addEventListener('blur', function() {
            this.closest('tr')?.classList.remove('active-row');
        });
    });
    
    // 添加一键复制配置值功能
    function addCopyButtons() {
        document.querySelectorAll('.config-key').forEach(configKey => {
            // 创建复制按钮
            const copyBtn = document.createElement('button');
            copyBtn.className = 'copy-btn';
            copyBtn.innerHTML = '<i class="fas fa-copy"></i>';
            copyBtn.title = '复制配置键';
            
            // 添加到DOM
            configKey.appendChild(copyBtn);
            
            // 添加点击事件
            copyBtn.addEventListener('click', function(e) {
                e.preventDefault();
                e.stopPropagation();
                
                // 复制配置键到剪贴板
                const textToCopy = configKey.textContent.trim();
                navigator.clipboard.writeText(textToCopy)
                    .then(() => {
                        // 显示复制成功的提示
                        copyBtn.innerHTML = '<i class="fas fa-check"></i>';
                        setTimeout(() => {
                            copyBtn.innerHTML = '<i class="fas fa-copy"></i>';
                        }, 1500);
                    })
                    .catch(err => {
                        console.error('复制失败: ', err);
                        copyBtn.innerHTML = '<i class="fas fa-times"></i>';
                        setTimeout(() => {
                            copyBtn.innerHTML = '<i class="fas fa-copy"></i>';
                        }, 1500);
                    });
            });
        });
    }
    
    // 初始化复制按钮
    addCopyButtons();
    
    // 添加表格行悬停效果
    document.querySelectorAll('.config-table tbody tr').forEach(row => {
        row.addEventListener('mouseenter', function() {
            this.classList.add('hover-row');
        });
        
        row.addEventListener('mouseleave', function() {
            this.classList.remove('hover-row');
        });
    });
});
