<?php
require_once '../config/database.php';
require_once 'common/check_login.php';

// 获取数据库连接
$db = getDbConnection();

// 检查ID参数
if (!isset($_GET['id']) || !is_numeric($_GET['id'])) {
    header("Location: script.php");
    exit;
}

$id = intval($_GET['id']);

// 获取脚本信息
$stmt = $db->prepare("SELECT * FROM scripts WHERE id = ?");
$stmt->execute([$id]);
$script = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$script) {
    header("Location: script.php");
    exit;
}

// 获取分类列表
$categories = $db->query("SELECT id, name FROM script_categories WHERE status = 1 ORDER BY sort_order ASC, id DESC")->fetchAll(PDO::FETCH_ASSOC);

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $name = trim($_POST['name']);
    $category_id = intval($_POST['category_id']);
    $description = trim($_POST['description']);
    $source_type = $_POST['source_type'];
    $sort_order = intval($_POST['sort_order']);
    
    // 验证分类是否存在
    $stmt = $db->prepare("SELECT id FROM script_categories WHERE id = ? AND status = 1");
    $stmt->execute([$category_id]);
    if (!$stmt->fetch()) {
        $error = "选择的分类不存在或已禁用！";
    } else {
        try {
            // 处理脚本文件上传
            $url = $script['url']; // 默认保持原有URL
            if (isset($_FILES['script_file']) && $_FILES['script_file']['error'] === UPLOAD_ERR_OK) {
                $uploadDir = '../uploads/scripts/';
                if (!is_dir($uploadDir)) {
                    mkdir($uploadDir, 0755, true);
                }
                
                $fileInfo = pathinfo($_FILES['script_file']['name']);
                $extension = strtolower($fileInfo['extension']);
                
                // 检查文件类型
                $allowedTypes = ['sh', 'bash', 'py', 'php', 'pl', 'rb', 'js'];
                if (!in_array($extension, $allowedTypes)) {
                    throw new Exception('不支持的文件类型！');
                }
                
                // 生成唯一文件名
                $filename = uniqid() . '_' . date('Ymd') . '.' . $extension;
                $targetFile = $uploadDir . $filename;
                
                if (move_uploaded_file($_FILES['script_file']['tmp_name'], $targetFile)) {
                    // 如果原文件是上传的文件，则删除
                    if (strpos($script['url'], 'uploads/scripts/') === 0) {
                        $oldFile = '../' . $script['url'];
                        if (file_exists($oldFile)) {
                            unlink($oldFile);
                        }
                    }
                    $url = 'uploads/scripts/' . $filename;
                } else {
                    throw new Exception('文件上传失败！');
                }
            } elseif (!empty($_POST['script_url']) && $_POST['script_url'] !== $script['url']) {
                // 如果提供了新的URL
                $url = trim($_POST['script_url']);
                if (!filter_var($url, FILTER_VALIDATE_URL)) {
                    throw new Exception('无效的URL地址！');
                }
                
                // 如果原文件是上传的文件，则删除
                if (strpos($script['url'], 'uploads/scripts/') === 0) {
                    $oldFile = '../' . $script['url'];
                    if (file_exists($oldFile)) {
                        unlink($oldFile);
                    }
                }
            }
            
            // 更新数据库
            $stmt = $db->prepare("UPDATE scripts SET category_id = ?, name = ?, url = ?, description = ?, source_type = ?, sort_order = ? WHERE id = ?");
            $stmt->execute([$category_id, $name, $url, $description, $source_type, $sort_order, $id]);
            
            header("Location: script.php?msg=update_success");
            exit;
            
        } catch (Exception $e) {
            $error = $e->getMessage();
        }
    }
}
?>
<!DOCTYPE html>
<html lang="zh-CN">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>编辑脚本 - 管理后台</title>
    <link rel="stylesheet" href="assets/css/bootstrap.min.css">
    <link rel="stylesheet" href="assets/css/font-awesome.min.css">
    <link rel="stylesheet" href="assets/css/admin.css">
</head>
<body>
    <?php include 'common/header.php'; ?>
    <div class="container-fluid">
        <div class="row">
            <?php include 'common/sidebar.php'; ?>
            <main class="col-md-9 ms-sm-auto col-lg-10 px-md-4">
                <div class="d-flex justify-content-between flex-wrap flex-md-nowrap align-items-center pt-3 pb-2 mb-3 border-bottom">
                    <h1 class="h2">编辑脚本</h1>
                    <div class="btn-toolbar mb-2 mb-md-0">
                        <a href="script.php" class="btn btn-sm btn-secondary">
                            <i class="fa fa-arrow-left"></i> 返回列表
                        </a>
                    </div>
                </div>

                <?php if (isset($error)): ?>
                <div class="alert alert-danger alert-dismissible fade show" role="alert">
                    <?= $error ?>
                    <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
                </div>
                <?php endif; ?>

                <div class="card">
                    <div class="card-body">
                        <form method="post" enctype="multipart/form-data">
                            <div class="mb-3">
                                <label for="name" class="form-label">脚本名称</label>
                                <input type="text" class="form-control" id="name" name="name" required value="<?= htmlspecialchars($script['name']) ?>">
                            </div>
                            
                            <div class="mb-3">
                                <label for="category_id" class="form-label">所属分类</label>
                                <select class="form-select" id="category_id" name="category_id" required>
                                    <option value="">请选择分类</option>
                                    <?php foreach ($categories as $category): ?>
                                    <option value="<?= $category['id'] ?>" <?= $script['category_id'] == $category['id'] ? 'selected' : '' ?>>
                                        <?= htmlspecialchars($category['name']) ?>
                                    </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                            
                            <div class="mb-3">
                                <label for="description" class="form-label">脚本描述</label>
                                <textarea class="form-control" id="description" name="description" rows="3"><?= htmlspecialchars($script['description']) ?></textarea>
                            </div>
                            
                            <div class="mb-3">
                                <label class="form-label">脚本来源</label>
                                <div class="form-check">
                                    <input class="form-check-input" type="radio" name="source_type" id="source_original" value="original" <?= $script['source_type'] === 'original' ? 'checked' : '' ?>>
                                    <label class="form-check-label" for="source_original">
                                        原创
                                    </label>
                                </div>
                                <div class="form-check">
                                    <input class="form-check-input" type="radio" name="source_type" id="source_network" value="network" <?= $script['source_type'] === 'network' ? 'checked' : '' ?>>
                                    <label class="form-check-label" for="source_network">
                                        网络
                                    </label>
                                </div>
                            </div>
                            
                            <div class="mb-3">
                                <label class="form-label">脚本文件</label>
                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="mb-3">
                                            <label for="script_file" class="form-label">上传新文件</label>
                                            <input type="file" class="form-control" id="script_file" name="script_file">
                                            <div class="form-text">支持的文件类型：.sh, .bash, .py, .php, .pl, .rb, .js</div>
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="mb-3">
                                            <label for="script_url" class="form-label">或输入URL</label>
                                            <input type="url" class="form-control" id="script_url" name="script_url" value="<?= htmlspecialchars($script['url']) ?>">
                                        </div>
                                    </div>
                                </div>
                                <?php if (strpos($script['url'], 'uploads/scripts/') === 0): ?>
                                <div class="alert alert-info">
                                    <i class="fa fa-info-circle"></i> 当前文件：<?= htmlspecialchars(basename($script['url'])) ?>
                                </div>
                                <?php endif; ?>
                            </div>
                            
                            <div class="mb-3">
                                <label for="sort_order" class="form-label">排序顺序</label>
                                <input type="number" class="form-control" id="sort_order" name="sort_order" value="<?= $script['sort_order'] ?>">
                            </div>
                            
                            <div class="text-end">
                                <button type="button" class="btn btn-secondary" onclick="history.back()">取消</button>
                                <button type="submit" class="btn btn-primary">保存更改</button>
                            </div>
                        </form>
                    </div>
                </div>
            </main>
        </div>
    </div>

    <script src="assets/js/bootstrap.bundle.min.js"></script>
    <script src="assets/js/jquery.min.js"></script>
    <script>
    $(document).ready(function() {
        // 自动隐藏提示消息
        setTimeout(function() {
            $('.alert').alert('close');
        }, 3000);
        
        // 文件上传和URL输入互斥
        $('#script_file').on('change', function() {
            if ($(this).val()) {
                $('#script_url').val('').prop('disabled', true);
            } else {
                $('#script_url').prop('disabled', false);
                $('#script_url').val('<?= htmlspecialchars($script['url']) ?>');
            }
        });
        
        $('#script_url').on('input', function() {
            if ($(this).val() && $(this).val() !== '<?= htmlspecialchars($script['url']) ?>') {
                $('#script_file').val('').prop('disabled', true);
            } else {
                $('#script_file').prop('disabled', false);
            }
        });
    });
    </script>
</body>
</html> 