<?php
/**
 * 后台管理员数据库表创建脚本
 * 用于初始化后台管理系统所需的管理员账号数据库表结构
 */

// 引入数据库配置文件
require_once '../../config/database.php';

// 设置页面内容类型
header('Content-Type: text/html; charset=utf-8');

try {
    // 获取数据库连接
    $db = getDbConnection();
    
    // 检查admin表是否已存在
    $tableExistsQuery = "SHOW TABLES LIKE 'admin'";
    $tableExists = $db->query($tableExistsQuery)->rowCount() > 0;
    
    // 开始事务
    $db->beginTransaction();
    
    if ($tableExists) {
        // 检查是否需要添加密码字段
        $checkPasswordField = "SHOW COLUMNS FROM `admin` LIKE 'password'";
        $passwordFieldExists = $db->query($checkPasswordField)->rowCount() > 0;
        
        if (!$passwordFieldExists) {
            // 添加密码字段
            $addPasswordField = "ALTER TABLE `admin` ADD COLUMN `password` varchar(255) NOT NULL COMMENT '密码(加密)' AFTER `username`";
            $db->exec($addPasswordField);
            echo "<p>已向管理员表添加密码字段。</p>";
            
            // 为现有管理员设置默认密码 (a1b2c3d4.s)
            $defaultPassword = password_hash('a1b2c3d4.s', PASSWORD_DEFAULT);
            $updatePasswordQuery = "UPDATE `admin` SET `password` = :password WHERE `password` IS NULL OR `password` = ''";
            $updateStmt = $db->prepare($updatePasswordQuery);
            $updateStmt->execute(['password' => $defaultPassword]);
            echo "<p>已为现有管理员设置默认密码(a1b2c3d4.s)。</p>";
        } else {
            echo "<p>管理员表(admin)已存在且包含密码字段，跳过创建。</p>";
        }
    } else {
        // 创建admin表
        $createTableQuery = "
        CREATE TABLE `admin` (
          `id` int(11) NOT NULL AUTO_INCREMENT,
          `username` varchar(50) NOT NULL COMMENT '管理员账号',
          `password` varchar(255) NOT NULL COMMENT '密码(加密)',
          `real_name` varchar(100) DEFAULT NULL COMMENT '真实姓名',
          `email` varchar(100) DEFAULT NULL COMMENT '邮箱',
          `phone` varchar(20) DEFAULT NULL COMMENT '手机号',
          `role` varchar(20) NOT NULL DEFAULT 'editor' COMMENT '角色：admin-超级管理员，editor-编辑',
          `last_login` datetime DEFAULT NULL COMMENT '最后登录时间',
          `login_ip` varchar(50) DEFAULT NULL COMMENT '最后登录IP',
          `status` tinyint(1) NOT NULL DEFAULT '1' COMMENT '状态：1启用，0禁用',
          `created_at` datetime NOT NULL COMMENT '创建时间',
          `updated_at` datetime DEFAULT NULL COMMENT '更新时间',
          PRIMARY KEY (`id`),
          UNIQUE KEY `username` (`username`)
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='后台管理员表';
        ";
        
        $db->exec($createTableQuery);
        echo "<p>管理员表(admin)创建成功！</p>";
        
        // 创建超级管理员账号 (使用加密密码)
        $adminPassword = password_hash('a1b2c3d4.s', PASSWORD_DEFAULT);
        $editorPassword = password_hash('a1b2c3d4.s', PASSWORD_DEFAULT);
        $insertAdminDataQuery = "
        INSERT INTO `admin` (`username`, `password`, `real_name`, `email`, `role`, `status`, `created_at`) VALUES
        ('adminmy', :password1, '系统管理员', 'admin@example.com', 'admin', 1, NOW()),
        ('editor', :password2, '内容编辑', 'editor@example.com', 'editor', 1, NOW());
        ";
        
        $insertStmt = $db->prepare($insertAdminDataQuery);
        $insertStmt->execute([
            'password1' => $adminPassword,
            'password2' => $editorPassword
        ]);
        echo "<p>管理员账号创建成功！默认超级管理员：adminmy/a1b2c3d4.s，编辑账号：editor/a1b2c3d4.s</p>";
    }
    
    // 提交事务
    $db->commit();
    
    echo "<div style='margin-top: 20px; padding: 10px; background-color: #dff0d8; color: #3c763d; border-radius: 4px;'>";
    echo "后台管理员系统初始化完成！<br>";
    echo "<a href='../login.php' style='color: #3c763d; text-decoration: underline;'>点击这里</a> 进入后台登录页面。";
    echo "</div>";
    
} catch (PDOException $e) {
    // 回滚事务
    if (isset($db) && $db->inTransaction()) {
        $db->rollBack();
    }
    
    echo "<div style='margin-top: 20px; padding: 10px; background-color: #f2dede; color: #a94442; border-radius: 4px;'>";
    echo "初始化失败：" . $e->getMessage();
    echo "</div>";
}
?>
<!DOCTYPE html>
<html lang="zh-CN">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>后台管理员系统初始化</title>
        <style>
        body {
            font-family: Arial, sans-serif;
            line-height: 1.6;
            margin: 0;
            padding: 20px;
            background-color: #f5f5f5;
        }

        .container {
            max-width: 800px;
            margin: 0 auto;
            background-color: #fff;
            padding: 20px;
            border-radius: 5px;
            box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        }

        h1 {
            color: #333;
            border-bottom: 1px solid #eee;
            padding-bottom: 10px;
        }

        p {
            margin: 10px 0;
        }

        .success {
            color: #3c763d;
        }

        .error {
            color: #a94442;
        }

        </style>
    </head>
    <body>
        <div class="container">
            <h1>后台管理员系统初始化</h1>
            <!-- PHP脚本输出的内容会显示在这里 -->
        </div>
    </body>
</html>
