<?php
/**
 * 合作伙伴管理表设置脚本
 * 
 * 此脚本用于创建合作伙伴分类表和联盟链接表并插入初始数据
 */
// 定义根目录路径
$rootDir = dirname(dirname(__DIR__));

// 引入数据库配置文件
require_once $rootDir . '/config/database.php';
// 获取数据库连接
$db = getDbConnection();

// 创建合作伙伴分类表
$createAllianceCategoryTableSQL = "
CREATE TABLE IF NOT EXISTS `alliance_category` (
  `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '分类ID，主键',
  `name` varchar(100) NOT NULL COMMENT '分类名称',
  `code` varchar(50) NOT NULL COMMENT '分类代码，用于标识',
  `subtitle` varchar(200) DEFAULT NULL COMMENT '副标题/描述',
  `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '状态：1-启用，0-禁用',
  `sort_order` int(11) NOT NULL DEFAULT 0 COMMENT '排序，数值越小排序越靠前',
  `created_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `updated_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  PRIMARY KEY (`id`),
  UNIQUE KEY `code_unique` (`code`),
  KEY `sort_order_index` (`sort_order`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='合作伙伴分类表';
";

// 创建合作伙伴链接表
$createAllianceLinkTableSQL = "
CREATE TABLE IF NOT EXISTS `alliance_link` (
  `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '链接ID，主键',
  `category_id` int(11) NOT NULL COMMENT '分类ID，关联alliance_category表',
  `name` varchar(200) NOT NULL COMMENT '链接名称',
  `url` varchar(500) DEFAULT NULL COMMENT '链接URL',
  `logo` varchar(255) DEFAULT NULL COMMENT 'LOGO图片路径',
  `description` varchar(500) DEFAULT NULL COMMENT '链接描述',
  `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '状态：1-启用，0-禁用',
  `sort_order` int(11) NOT NULL DEFAULT 0 COMMENT '排序，数值越小排序越靠前',
  `created_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `updated_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  PRIMARY KEY (`id`),
  KEY `category_id_index` (`category_id`),
  KEY `sort_order_index` (`sort_order`),
  CONSTRAINT `fk_alliance_category` FOREIGN KEY (`category_id`) REFERENCES `alliance_category` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='合作伙伴链接表';
";

try {
    // 创建合作伙伴分类表
    $db->exec($createAllianceCategoryTableSQL);
    echo "合作伙伴分类表创建成功！<br>";
    
    // 创建合作伙伴链接表
    $db->exec($createAllianceLinkTableSQL);
    echo "合作伙伴链接表创建成功！<br>";
    
    // 检查联盟分类表是否已有数据
    $checkCategoryData = $db->query("SELECT COUNT(*) as count FROM alliance_category");
    $categoryRowCount = $checkCategoryData->fetch()['count'];
    
    if ($categoryRowCount > 0) {
        echo "合作伙伴分类表已有数据，检查是否需要补充分类代码...<br>";
        
        // 检查是否有所需的所有分类
        $requiredCodes = [
            'recommended', 'high_defense', 'physical_server', 'site_cluster', 
            'cloud_server', 'tech_blog', 'industry_tools', 'services', 'original_software'
        ];
        
        $missingCodes = [];
        foreach ($requiredCodes as $code) {
            $checkCodeSQL = "SELECT COUNT(*) FROM alliance_category WHERE code = :code";
            $checkStmt = $db->prepare($checkCodeSQL);
            $checkStmt->execute(['code' => $code]);
            
            if ($checkStmt->fetchColumn() == 0) {
                $missingCodes[] = $code;
            }
        }
        
        if (count($missingCodes) > 0) {
            echo "发现缺少的分类代码: " . implode(", ", $missingCodes) . "<br>";
            echo "将添加缺少的分类...<br>";
            
            // 添加缺少的分类
            $categoryMap = [
                'recommended' => ['name' => '推荐商家', 'subtitle' => '免费测试!可换退~', 'sort_order' => 10],
                'high_defense' => ['name' => '高防服务器', 'subtitle' => '先测试(不收费),扛不住全退!', 'sort_order' => 20],
                'physical_server' => ['name' => '物理服务器', 'subtitle' => '独享资源,提供真机测试!', 'sort_order' => 30],
                'site_cluster' => ['name' => '站群服务器', 'subtitle' => '原生很贵,根据业务选择!', 'sort_order' => 40],
                'cloud_server' => ['name' => '云服务器', 'subtitle' => '不提供测试，建议者勿扰!', 'sort_order' => 50],
                'tech_blog' => ['name' => '技术博客', 'subtitle' => '没事看看,万一学到嘞~', 'sort_order' => 60],
                'industry_tools' => ['name' => '行业工具', 'subtitle' => '第三方网络检测网站~', 'sort_order' => 70],
                'services' => ['name' => '服务项目', 'subtitle' => '量身定制,满意为止~', 'sort_order' => 80],
                'original_software' => ['name' => '原创软件', 'subtitle' => '轻量级行业实用工具~', 'sort_order' => 90]
            ];
            
            $insertCategorySQL = "INSERT INTO alliance_category (name, code, subtitle, sort_order) VALUES (:name, :code, :subtitle, :sort_order)";
            $categoryStmt = $db->prepare($insertCategorySQL);
            
            foreach ($missingCodes as $code) {
                $data = $categoryMap[$code];
                $data['code'] = $code;
                $categoryStmt->execute($data);
                echo "已添加缺少的分类: {$data['name']} (代码: {$code})<br>";
            }
        }
        
        // 获取分类ID映射，用于后续链接数据
        $categories = $db->query("SELECT id, code FROM alliance_category")->fetchAll(PDO::FETCH_KEY_PAIR);
    } else {
        // 插入初始分类数据
        $initialCategoryData = [
            ['name' => '推荐商家', 'code' => 'recommended', 'subtitle' => '免费测试!可换退~', 'sort_order' => 10],
            ['name' => '高防服务器', 'code' => 'high_defense', 'subtitle' => '先测试(不收费),扛不住全退!', 'sort_order' => 20],
            ['name' => '物理服务器', 'code' => 'physical_server', 'subtitle' => '独享资源,提供真机测试!', 'sort_order' => 30],
            ['name' => '站群服务器', 'code' => 'site_cluster', 'subtitle' => '原生很贵,根据业务选择!', 'sort_order' => 40],
            ['name' => '云服务器', 'code' => 'cloud_server', 'subtitle' => '不提供测试，建议者勿扰!', 'sort_order' => 50],
            ['name' => '技术博客', 'code' => 'tech_blog', 'subtitle' => '没事看看,万一学到嘞~', 'sort_order' => 60],
            ['name' => '行业工具', 'code' => 'industry_tools', 'subtitle' => '第三方网络检测网站~', 'sort_order' => 70],
            ['name' => '服务项目', 'code' => 'services', 'subtitle' => '量身定制,满意为止~', 'sort_order' => 80],
            ['name' => '原创软件', 'code' => 'original_software', 'subtitle' => '轻量级行业实用工具~', 'sort_order' => 90]
        ];
        
        $insertCategorySQL = "INSERT INTO alliance_category (name, code, subtitle, sort_order) VALUES (:name, :code, :subtitle, :sort_order)";
        $categoryStmt = $db->prepare($insertCategorySQL);
        
        foreach ($initialCategoryData as $data) {
            $categoryStmt->execute($data);
        }
        
        echo "初始合作伙伴分类数据插入成功！<br>";
        
        // 获取分类ID映射，用于后续链接数据
        $categories = $db->query("SELECT id, code FROM alliance_category")->fetchAll(PDO::FETCH_KEY_PAIR);
    }
    
    // 检查联盟链接表是否已有数据
    $checkLinkData = $db->query("SELECT COUNT(*) as count FROM alliance_link");
    $linkRowCount = $checkLinkData->fetch()['count'];
    
    if ($linkRowCount > 0) {
        echo "合作伙伴链接表已有数据，跳过初始数据插入。<br>";
    } else {
        // 插入初始链接数据
        $initialLinkData = [
            // 推荐商家
            ['category_id' => $categories['recommended'], 'name' => '秀米云', 'url' => '#', 'sort_order' => 10],
            ['category_id' => $categories['recommended'], 'name' => 'Taudb', 'url' => '#', 'sort_order' => 20],
            ['category_id' => $categories['recommended'], 'name' => 'cuexw', 'url' => '#', 'sort_order' => 30],
            ['category_id' => $categories['recommended'], 'name' => '乐酷君', 'url' => '#', 'sort_order' => 40],
            ['category_id' => $categories['recommended'], 'name' => '一点云', 'url' => '#', 'sort_order' => 50],
            ['category_id' => $categories['recommended'], 'name' => 'hnnlb', 'url' => '#', 'sort_order' => 60],
            ['category_id' => $categories['recommended'], 'name' => 'CZSN', 'url' => '#', 'sort_order' => 70],
            ['category_id' => $categories['recommended'], 'name' => 'CQTTO', 'url' => '#', 'sort_order' => 80],
            ['category_id' => $categories['recommended'], 'name' => 'MEZDN', 'url' => '#', 'sort_order' => 90],
            ['category_id' => $categories['recommended'], 'name' => '创诚网络', 'url' => '#', 'sort_order' => 100],
            ['category_id' => $categories['recommended'], 'name' => '房丫头', 'url' => '#', 'sort_order' => 110],
            ['category_id' => $categories['recommended'], 'name' => '瑞斯云', 'url' => '#', 'sort_order' => 120],
            ['category_id' => $categories['recommended'], 'name' => 'RZXNM', 'url' => '#', 'sort_order' => 130],
            ['category_id' => $categories['recommended'], 'name' => '米修云', 'url' => '#', 'sort_order' => 140],
            ['category_id' => $categories['recommended'], 'name' => '王牌服务器', 'url' => '#', 'sort_order' => 150],
            ['category_id' => $categories['recommended'], 'name' => '居启网络', 'url' => '#', 'sort_order' => 160],
            ['category_id' => $categories['recommended'], 'name' => '蜜蜂网络', 'url' => '#', 'sort_order' => 170],
            ['category_id' => $categories['recommended'], 'name' => 'AMZLI', 'url' => '#', 'sort_order' => 180],
            ['category_id' => $categories['recommended'], 'name' => '狄咔云', 'url' => '#', 'sort_order' => 190],
            ['category_id' => $categories['recommended'], 'name' => 'RRRPT', 'url' => '#', 'sort_order' => 200],
            ['category_id' => $categories['recommended'], 'name' => '景天云', 'url' => '#', 'sort_order' => 210],
            ['category_id' => $categories['recommended'], 'name' => 'GOVIV', 'url' => '#', 'sort_order' => 220],
            ['category_id' => $categories['recommended'], 'name' => 'Efsue', 'url' => '#', 'sort_order' => 230],
            ['category_id' => $categories['recommended'], 'name' => 'Deguobach', 'url' => '#', 'sort_order' => 240],
            ['category_id' => $categories['recommended'], 'name' => '恒天科技', 'url' => '#', 'sort_order' => 250],
            ['category_id' => $categories['recommended'], 'name' => 'hayec', 'url' => '#', 'sort_order' => 260],
            ['category_id' => $categories['recommended'], 'name' => '创速服务器', 'url' => '#', 'sort_order' => 270],
            
            // 高防服务器
            ['category_id' => $categories['high_defense'], 'name' => '香港高防服务器', 'url' => '#', 'sort_order' => 10],
            ['category_id' => $categories['high_defense'], 'name' => '美国高防服务器', 'url' => '#', 'sort_order' => 20],
            ['category_id' => $categories['high_defense'], 'name' => '韩国高防服务器', 'url' => '#', 'sort_order' => 30],
            ['category_id' => $categories['high_defense'], 'name' => '日本高防服务器', 'url' => '#', 'sort_order' => 40],
            ['category_id' => $categories['high_defense'], 'name' => '香港CDN加速', 'url' => '#', 'sort_order' => 50],
            ['category_id' => $categories['high_defense'], 'name' => '新加坡高防服务器', 'url' => '#', 'sort_order' => 60],
            
            // 物理服务器
            ['category_id' => $categories['physical_server'], 'name' => '香港服务器', 'url' => '#', 'sort_order' => 10],
            ['category_id' => $categories['physical_server'], 'name' => '美国服务器', 'url' => '#', 'sort_order' => 20],
            ['category_id' => $categories['physical_server'], 'name' => '日本服务器', 'url' => '#', 'sort_order' => 30],
            ['category_id' => $categories['physical_server'], 'name' => '新加坡服务器', 'url' => '#', 'sort_order' => 40],
            ['category_id' => $categories['physical_server'], 'name' => '韩国服务器', 'url' => '#', 'sort_order' => 50],
            ['category_id' => $categories['physical_server'], 'name' => '台湾服务器', 'url' => '#', 'sort_order' => 60],
            ['category_id' => $categories['physical_server'], 'name' => '荷兰服务器', 'url' => '#', 'sort_order' => 70],
            ['category_id' => $categories['physical_server'], 'name' => '德国服务器', 'url' => '#', 'sort_order' => 80],
            ['category_id' => $categories['physical_server'], 'name' => '菲律宾服务器', 'url' => '#', 'sort_order' => 90],
            ['category_id' => $categories['physical_server'], 'name' => '越南服务器', 'url' => '#', 'sort_order' => 100],
            ['category_id' => $categories['physical_server'], 'name' => '柬埔寨服务器', 'url' => '#', 'sort_order' => 110],
            
            // 站群服务器
            ['category_id' => $categories['site_cluster'], 'name' => '香港站群', 'url' => '#', 'sort_order' => 10],
            ['category_id' => $categories['site_cluster'], 'name' => '美国站群', 'url' => '#', 'sort_order' => 20],
            ['category_id' => $categories['site_cluster'], 'name' => '韩国站群', 'url' => '#', 'sort_order' => 30],
            ['category_id' => $categories['site_cluster'], 'name' => '日本站群', 'url' => '#', 'sort_order' => 40],
            ['category_id' => $categories['site_cluster'], 'name' => '新加坡站群', 'url' => '#', 'sort_order' => 50],
            ['category_id' => $categories['site_cluster'], 'name' => 'TikTok专线', 'url' => '#', 'sort_order' => 60],
            ['category_id' => $categories['site_cluster'], 'name' => '原生站群服务器', 'url' => '#', 'sort_order' => 70],
            
            // 云服务器
            ['category_id' => $categories['cloud_server'], 'name' => '香港云服务器', 'url' => '#', 'sort_order' => 10],
            ['category_id' => $categories['cloud_server'], 'name' => '美国云服务器', 'url' => '#', 'sort_order' => 20],
            ['category_id' => $categories['cloud_server'], 'name' => '日本云服务器', 'url' => '#', 'sort_order' => 30],
            ['category_id' => $categories['cloud_server'], 'name' => '英国云服务器', 'url' => '#', 'sort_order' => 40],
            ['category_id' => $categories['cloud_server'], 'name' => '新加坡云服务器', 'url' => '#', 'sort_order' => 50],
            ['category_id' => $categories['cloud_server'], 'name' => '韩国云服务器', 'url' => '#', 'sort_order' => 60],
            ['category_id' => $categories['cloud_server'], 'name' => '台湾云服务器', 'url' => '#', 'sort_order' => 70],
            ['category_id' => $categories['cloud_server'], 'name' => '美国原生住宅IP服务器', 'url' => '#', 'sort_order' => 80],
            ['category_id' => $categories['cloud_server'], 'name' => '德国云服务器', 'url' => '#', 'sort_order' => 90],
            
            // 技术博客
            ['category_id' => $categories['tech_blog'], 'name' => 'IRQM', 'url' => '#', 'sort_order' => 10],
            ['category_id' => $categories['tech_blog'], 'name' => '服务器运维视频', 'url' => '#', 'sort_order' => 20],
            ['category_id' => $categories['tech_blog'], 'name' => 'ZLLAA', 'url' => '#', 'sort_order' => 30],
            ['category_id' => $categories['tech_blog'], 'name' => 'OX2X', 'url' => '#', 'sort_order' => 40],
            ['category_id' => $categories['tech_blog'], 'name' => 'efsue', 'url' => '#', 'sort_order' => 50],
            ['category_id' => $categories['tech_blog'], 'name' => 'ZABCU', 'url' => '#', 'sort_order' => 60],
            ['category_id' => $categories['tech_blog'], 'name' => 'cpazy', 'url' => '#', 'sort_order' => 70],
            ['category_id' => $categories['tech_blog'], 'name' => 'FEDBD', 'url' => '#', 'sort_order' => 80],
            
            // 行业工具
            ['category_id' => $categories['industry_tools'], 'name' => 'IP测试', 'url' => '#', 'sort_order' => 10],
            ['category_id' => $categories['industry_tools'], 'name' => '行业工具', 'url' => '#', 'sort_order' => 20],
            
            // 服务项目
            ['category_id' => $categories['services'], 'name' => '网站建设(仿站)', 'url' => '#', 'sort_order' => 10],
            ['category_id' => $categories['services'], 'name' => '软件开发(全平台)', 'url' => '#', 'sort_order' => 20],
            ['category_id' => $categories['services'], 'name' => '脚本定制(Shell)', 'url' => '#', 'sort_order' => 30],
            
            // 原创软件
            ['category_id' => $categories['original_software'], 'name' => '小白SSH工具', 'url' => '#', 'sort_order' => 10],
            ['category_id' => $categories['original_software'], 'name' => '小蓝鸟排版', 'url' => '#', 'sort_order' => 20],
            ['category_id' => $categories['original_software'], 'name' => 'Windows服务器管理', 'url' => '#', 'sort_order' => 30],
            ['category_id' => $categories['original_software'], 'name' => '仿站小工具', 'url' => '#', 'sort_order' => 40],
            ['category_id' => $categories['original_software'], 'name' => '图片批量处理', 'url' => '#', 'sort_order' => 50]
        ];
        
        $insertLinkSQL = "INSERT INTO alliance_link (category_id, name, url, sort_order) VALUES (:category_id, :name, :url, :sort_order)";
        $linkStmt = $db->prepare($insertLinkSQL);
        
        foreach ($initialLinkData as $data) {
            $linkStmt->execute($data);
        }
        
        echo "初始合作伙伴链接数据插入成功！<br>";
    }
    
    echo "合作伙伴表设置完成！";
} catch (PDOException $e) {
    die("错误: " . $e->getMessage());
}
?>
