<?php
/**
 * 合作伙伴数据库修复脚本
 * 
 * 此脚本用于彻底修复合作伙伴分类表和联盟链接表的问题
 */
// 定义根目录路径
$rootDir = dirname(dirname(__DIR__));

// 引入数据库配置文件
require_once $rootDir . '/config/database.php';
// 获取数据库连接
$db = getDbConnection();

try {
    echo "开始修复合作伙伴数据库问题...<br>";
    
    // 先检查并删除链接表，因为它依赖于分类表
    $checkLinkTableSQL = "SHOW TABLES LIKE 'alliance_link'";
    $linkTableExists = $db->query($checkLinkTableSQL)->rowCount() > 0;
    
    if ($linkTableExists) {
        // 删除链接表
        $db->exec("DROP TABLE alliance_link");
        echo "已删除旧的链接表<br>";
    }
    
    // 检查分类表是否存在
    $checkTableSQL = "SHOW TABLES LIKE 'alliance_category'";
    $tableExists = $db->query($checkTableSQL)->rowCount() > 0;
    
    if ($tableExists) {
        // 删除分类表
        $db->exec("DROP TABLE alliance_category");
        echo "已删除旧的分类表<br>";
    }
    
    // 创建合作伙伴分类表
    $createAllianceCategoryTableSQL = "
    CREATE TABLE IF NOT EXISTS `alliance_category` (
      `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '分类ID，主键',
      `name` varchar(100) NOT NULL COMMENT '分类名称',
      `code` varchar(50) NOT NULL COMMENT '分类代码，用于标识',
      `subtitle` varchar(200) DEFAULT NULL COMMENT '副标题/描述',
      `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '状态：1-启用，0-禁用',
      `sort_order` int(11) NOT NULL DEFAULT 0 COMMENT '排序，数值越小排序越靠前',
      `created_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
      `updated_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
      PRIMARY KEY (`id`),
      UNIQUE KEY `code_unique` (`code`),
      KEY `sort_order_index` (`sort_order`)
    ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='合作伙伴分类表';
    ";
    
    $db->exec($createAllianceCategoryTableSQL);
    echo "合作伙伴分类表创建成功！<br>";
    
    // 创建合作伙伴链接表
    $createAllianceLinkTableSQL = "
    CREATE TABLE IF NOT EXISTS `alliance_link` (
      `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '链接ID，主键',
      `category_id` int(11) NOT NULL COMMENT '分类ID，关联alliance_category表',
      `name` varchar(200) NOT NULL COMMENT '链接名称',
      `url` varchar(500) DEFAULT NULL COMMENT '链接URL',
      `logo` varchar(255) DEFAULT NULL COMMENT 'LOGO图片路径',
      `description` varchar(500) DEFAULT NULL COMMENT '链接描述',
      `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '状态：1-启用，0-禁用',
      `sort_order` int(11) NOT NULL DEFAULT 0 COMMENT '排序，数值越小排序越靠前',
      `created_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
      `updated_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
      PRIMARY KEY (`id`),
      KEY `category_id_index` (`category_id`),
      KEY `sort_order_index` (`sort_order`),
      CONSTRAINT `fk_alliance_category` FOREIGN KEY (`category_id`) REFERENCES `alliance_category` (`id`) ON DELETE CASCADE
    ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='合作伙伴链接表';
    ";
    
    $db->exec($createAllianceLinkTableSQL);
    echo "合作伙伴链接表创建成功！<br>";
    
    // 插入分类数据
    echo "开始插入分类数据...<br>";
    
    // 插入固定的分类数据
    $categoriesData = [
        ['name' => '推荐商家', 'code' => 'recommended', 'subtitle' => '免费测试!可换退~', 'sort_order' => 10],
        ['name' => '高防服务器', 'code' => 'high_defense', 'subtitle' => '先测试(不收费),扛不住全退!', 'sort_order' => 20],
        ['name' => '物理服务器', 'code' => 'physical_server', 'subtitle' => '独享资源,提供真机测试!', 'sort_order' => 30],
        ['name' => '站群服务器', 'code' => 'site_cluster', 'subtitle' => '原生很贵,根据业务选择!', 'sort_order' => 40],
        ['name' => '云服务器', 'code' => 'cloud_server', 'subtitle' => '不提供测试，建议者勿扰!', 'sort_order' => 50],
        ['name' => '技术博客', 'code' => 'tech_blog', 'subtitle' => '没事看看,万一学到嘞~', 'sort_order' => 60],
        ['name' => '行业工具', 'code' => 'industry_tools', 'subtitle' => '第三方网络检测网站~', 'sort_order' => 70],
        ['name' => '服务项目', 'code' => 'services', 'subtitle' => '量身定制,满意为止~', 'sort_order' => 80],
        ['name' => '原创软件', 'code' => 'original_software', 'subtitle' => '轻量级行业实用工具~', 'sort_order' => 90]
    ];
    
    $insertCategorySQL = "INSERT INTO alliance_category (name, code, subtitle, sort_order) VALUES (:name, :code, :subtitle, :sort_order)";
    $categoryStmt = $db->prepare($insertCategorySQL);
    
    foreach ($categoriesData as $data) {
        $categoryStmt->execute($data);
        echo "插入分类: {$data['name']} (代码: {$data['code']})<br>";
    }
    
    // 获取并显示所有分类及其ID
    $categories = $db->query("SELECT id, code, name FROM alliance_category ORDER BY sort_order")->fetchAll(PDO::FETCH_ASSOC);
    echo "<br>已插入的分类信息:<br>";
    echo "<pre>";
    foreach ($categories as $cat) {
        echo "ID: {$cat['id']}, 代码: {$cat['code']}, 名称: {$cat['name']}<br>";
    }
    echo "</pre><br>";
    
    // 获取分类ID映射
    $categoryMap = [];
    foreach ($categories as $cat) {
        $categoryMap[$cat['code']] = $cat['id'];
    }
    
    // 插入初始链接数据
    echo "开始插入链接数据...<br>";
    
    $initialLinkData = [
        // 推荐商家
        ['category_id' => $categoryMap['recommended'], 'name' => '秀米云', 'url' => 'https://www.xiumi.com', 'description' => '提供高稳定性云服务器和云存储解决方案，适合企业级应用', 'logo' => '/assets/images/alliance/xiumi.png', 'sort_order' => 10],
        ['category_id' => $categoryMap['recommended'], 'name' => 'Taudb', 'url' => 'https://www.taudb.com', 'description' => '专业数据库托管服务，提供高可用性和容灾解决方案', 'logo' => '/assets/images/alliance/taudb.png', 'sort_order' => 20],
        ['category_id' => $categoryMap['recommended'], 'name' => 'cuexw', 'url' => 'https://www.cuexw.com', 'description' => '定制化网络加速服务，提升全球访问速度', 'logo' => '/assets/images/alliance/cuexw.png', 'sort_order' => 30],
        ['category_id' => $categoryMap['recommended'], 'name' => '乐酷君', 'url' => 'https://www.lekuidc.com', 'description' => '专业IDC服务商，提供各类服务器和网络解决方案', 'logo' => '/assets/images/alliance/lekuidc.png', 'sort_order' => 40],
        ['category_id' => $categoryMap['recommended'], 'name' => '一点云', 'url' => 'https://www.yidianyun.com', 'description' => '一站式云服务平台，提供云主机、域名注册等多种服务', 'logo' => '/assets/images/alliance/yidianyun.png', 'sort_order' => 50],
        ['category_id' => $categoryMap['recommended'], 'name' => 'hnnlb', 'url' => 'https://www.hnnlb.com', 'description' => '企业级负载均衡服务，保障业务高可用和均衡分发', 'logo' => '/assets/images/alliance/hnnlb.png', 'sort_order' => 60],
        ['category_id' => $categoryMap['recommended'], 'name' => 'Efsue', 'url' => 'https://www.efsue.com', 'description' => '专注于高性能网站托管和云服务解决方案', 'logo' => '/assets/images/alliance/efsue.png', 'sort_order' => 70],
        
        // 高防服务器
        ['category_id' => $categoryMap['high_defense'], 'name' => '香港高防服务器', 'url' => 'https://www.lekuidc.com/hkgf', 'description' => '香港机房高防服务器，防御200G+，延迟低，适合对网络安全要求高的业务', 'logo' => '/assets/images/alliance/hk_defense.png', 'sort_order' => 10],
        ['category_id' => $categoryMap['high_defense'], 'name' => '美国高防服务器', 'url' => 'https://www.lekuidc.com/usgf', 'description' => '美国机房高防服务器，防御500G+，适合海外业务和大型网站', 'logo' => '/assets/images/alliance/us_defense.png', 'sort_order' => 20],
        ['category_id' => $categoryMap['high_defense'], 'name' => '香港CDN加速', 'url' => 'https://www.lekuidc.com/hkcdn', 'description' => '香港CDN加速服务，提高网站访问速度，分散DDoS攻击风险', 'logo' => '/assets/images/alliance/hk_cdn.png', 'sort_order' => 30],
        
        // 物理服务器
        ['category_id' => $categoryMap['physical_server'], 'name' => '香港服务器', 'url' => 'https://www.lekuidc.com/hk', 'description' => '香港机房物理服务器，提供独享资源，支持定制配置', 'logo' => '/assets/images/alliance/hk_server.png', 'sort_order' => 10],
        ['category_id' => $categoryMap['physical_server'], 'name' => '美国服务器', 'url' => 'https://www.lekuidc.com/us', 'description' => '美国机房物理服务器，高性能配置，适合海外业务', 'logo' => '/assets/images/alliance/us_server.png', 'sort_order' => 20],
        ['category_id' => $categoryMap['physical_server'], 'name' => '日本服务器', 'url' => 'https://www.lekuidc.com/jp', 'description' => '日本机房物理服务器，高稳定性，低延迟，适合亚太地区业务', 'logo' => '/assets/images/alliance/jp_server.png', 'sort_order' => 30],
        
        // 站群服务器
        ['category_id' => $categoryMap['site_cluster'], 'name' => '香港站群', 'url' => 'https://www.lekuidc.com/hkcluster', 'description' => '香港站群服务器，支持多IP配置，适合SEO优化和多站点部署', 'logo' => '/assets/images/alliance/hk_cluster.png', 'sort_order' => 10],
        ['category_id' => $categoryMap['site_cluster'], 'name' => 'TikTok专线', 'url' => 'https://www.lekuidc.com/tiktok', 'description' => 'TikTok专用服务器和网络，优化TikTok平台访问和运营', 'logo' => '/assets/images/alliance/tiktok.png', 'sort_order' => 20],
        
        // 云服务器
        ['category_id' => $categoryMap['cloud_server'], 'name' => '香港云服务器', 'url' => 'https://www.lekuidc.com/hkcloud', 'description' => '香港云服务器，高性价比，即开即用，弹性扩展', 'logo' => '/assets/images/alliance/hk_cloud.png', 'sort_order' => 10],
        ['category_id' => $categoryMap['cloud_server'], 'name' => '美国云服务器', 'url' => 'https://www.lekuidc.com/uscloud', 'description' => '美国云服务器，稳定高效，支持多种操作系统，适合海外业务', 'logo' => '/assets/images/alliance/us_cloud.png', 'sort_order' => 20],
        ['category_id' => $categoryMap['cloud_server'], 'name' => '美国原生住宅IP服务器', 'url' => 'https://www.lekuidc.com/usip', 'description' => '美国原生住宅IP服务器，提供真实住宅IP资源，适合特殊业务需求', 'logo' => '/assets/images/alliance/us_native_ip.png', 'sort_order' => 30],
        
        // 技术博客
        ['category_id' => $categoryMap['tech_blog'], 'name' => '服务器运维视频', 'url' => 'https://space.bilibili.com/serverops', 'description' => '专业服务器运维视频教程，涵盖Linux、Windows服务器配置和优化', 'logo' => '/assets/images/alliance/server_ops.png', 'sort_order' => 10],
        ['category_id' => $categoryMap['tech_blog'], 'name' => 'efsue', 'url' => 'https://www.efsue.com/blog', 'description' => '提供服务器技术、网络安全、云计算等领域的专业技术博客', 'logo' => '/assets/images/alliance/efsue_blog.png', 'sort_order' => 20],
        
        // 行业工具
        ['category_id' => $categoryMap['industry_tools'], 'name' => 'IP测试', 'url' => 'https://ip.tool.lu', 'description' => '在线IP查询工具，提供IP地址归属地、运营商等信息查询', 'logo' => '/assets/images/alliance/ip_test.png', 'sort_order' => 10],
        ['category_id' => $categoryMap['industry_tools'], 'name' => '行业工具', 'url' => 'https://tool.chinaz.com', 'description' => '站长工具集，提供域名查询、网站测速、关键词排名等多种检测工具', 'logo' => '/assets/images/alliance/chinaz.png', 'sort_order' => 20],
        
        // 服务项目
        ['category_id' => $categoryMap['services'], 'name' => '网站建设(仿站)', 'url' => 'https://www.lekuidc.com/website', 'description' => '专业网站建设和仿站服务，高度还原目标网站，提供定制开发', 'logo' => '/assets/images/alliance/website.png', 'sort_order' => 10],
        ['category_id' => $categoryMap['services'], 'name' => '软件开发(全平台)', 'url' => 'https://www.lekuidc.com/software', 'description' => '全平台软件开发服务，支持Windows、MacOS、Linux、Android、iOS等系统', 'logo' => '/assets/images/alliance/software.png', 'sort_order' => 20],
        
        // 原创软件
        ['category_id' => $categoryMap['original_software'], 'name' => '小白SSH工具', 'url' => 'https://www.lekuidc.com/ssh-tool', 'description' => '简易SSH客户端工具，适合服务器远程管理，支持Windows系统', 'logo' => '/assets/images/alliance/ssh_tool.png', 'sort_order' => 10],
        ['category_id' => $categoryMap['original_software'], 'name' => '小蓝鸟排版', 'url' => 'https://www.lekuidc.com/twitter-format', 'description' => 'Twitter内容排版工具，支持多种排版样式，提高发布效率', 'logo' => '/assets/images/alliance/twitter_tool.png', 'sort_order' => 20]
    ];
    
    $insertLinkSQL = "INSERT INTO alliance_link (category_id, name, url, description, logo, sort_order) VALUES (:category_id, :name, :url, :description, :logo, :sort_order)";
    $linkStmt = $db->prepare($insertLinkSQL);
    $insertedLinks = 0;
    
    foreach ($initialLinkData as $data) {
        $linkStmt->execute($data);
        $insertedLinks++;
    }
    
    echo "成功插入 {$insertedLinks} 条链接数据！<br>";
    echo "合作伙伴数据库修复完成！<br><br>";
    echo "现在您可以运行 alliance_update.php 来添加更多数据了。";
    
} catch (PDOException $e) {
    die("错误: " . $e->getMessage());
}
?> 