<?php
/**
 * 新闻管理表设置脚本
 * 
 * 此脚本用于创建新闻分类表和新闻表并插入初始数据
 */
// 引入数据库配置文件
require_once '../config/database.php';
// 获取数据库连接
$db = getDbConnection();

// 创建新闻分类表
$createNewsCategoryTableSQL = "
CREATE TABLE IF NOT EXISTS `news_category` (
  `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '分类ID，主键',
  `name` varchar(100) NOT NULL COMMENT '分类名称',
  `code` varchar(50) NOT NULL COMMENT '分类代码，用于标识',
  `description` text DEFAULT NULL COMMENT '分类描述',
  `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '状态：1-启用，0-禁用',
  `sort_order` int(11) NOT NULL DEFAULT 0 COMMENT '排序，数值越小排序越靠前',
  `created_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `updated_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  PRIMARY KEY (`id`),
  UNIQUE KEY `code_unique` (`code`),
  KEY `sort_order_index` (`sort_order`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='新闻分类表';
";

// 创建新闻表
$createNewsTableSQL = "
CREATE TABLE IF NOT EXISTS `news` (
  `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '新闻ID，主键',
  `category_id` int(11) NOT NULL COMMENT '分类ID，关联news_category表',
  `title` varchar(200) NOT NULL COMMENT '新闻标题',
  `summary` varchar(500) DEFAULT NULL COMMENT '新闻简介',
  `keywords` varchar(200) DEFAULT NULL COMMENT '关键词，多个关键词用逗号分隔',
  `content` text NOT NULL COMMENT '新闻详细内容',
  `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '状态：1-发布，0-草稿',
  `views` int(11) NOT NULL DEFAULT 0 COMMENT '浏览次数',
  `sort_order` int(11) NOT NULL DEFAULT 0 COMMENT '排序，数值越小排序越靠前',
  `created_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `updated_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  PRIMARY KEY (`id`),
  KEY `category_id_index` (`category_id`),
  KEY `sort_order_index` (`sort_order`),
  CONSTRAINT `fk_news_category` FOREIGN KEY (`category_id`) REFERENCES `news_category` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='新闻表';
";

try {
    // 创建新闻分类表
    $db->exec($createNewsCategoryTableSQL);
    echo "新闻分类表创建成功！<br>";
    
    // 创建新闻表
    $db->exec($createNewsTableSQL);
    echo "新闻表创建成功！<br>";
    
    // 检查新闻分类表是否已有数据
    $checkCategoryData = $db->query("SELECT COUNT(*) as count FROM news_category");
    $categoryRowCount = $checkCategoryData->fetch()['count'];
    
    if ($categoryRowCount > 0) {
        echo "新闻分类表已有数据，跳过初始数据插入。<br>";
    } else {
        // 插入初始分类数据
        $initialCategoryData = [
            ['name' => '公司新闻', 'code' => 'company', 'description' => '公司相关新闻和公告', 'sort_order' => -10],
            ['name' => '行业动态', 'code' => 'industry', 'description' => '行业相关新闻和趋势', 'sort_order' => -9],
            ['name' => '技术资讯', 'code' => 'technology', 'description' => '技术相关新闻和教程', 'sort_order' => -8]
        ];
        
        $insertCategorySQL = "INSERT INTO news_category (name, code, description, sort_order) VALUES (:name, :code, :description, :sort_order)";
        $categoryStmt = $db->prepare($insertCategorySQL);
        
        foreach ($initialCategoryData as $data) {
            $categoryStmt->execute($data);
        }
        
        echo "初始新闻分类数据插入成功！<br>";
        
        // 插入初始新闻数据
        $initialNewsData = [
            [
                'category_id' => 1, 
                'title' => '公司成立五周年庆典活动圆满结束', 
                'summary' => '我公司于上周举办了盛大的五周年庆典活动，众多合作伙伴和客户到场祝贺。', 
                'keywords' => '公司,周年庆,活动', 
                'content' => '<p>我公司于上周举办了盛大的五周年庆典活动，众多合作伙伴和客户到场祝贺。活动中，公司总结了过去五年的发展历程，并展望了未来的发展方向。</p><p>在庆典上，公司宣布了多项新的业务计划和服务升级方案，得到了与会嘉宾的一致好评。</p>', 
                'sort_order' => -10
            ],
            [
                'category_id' => 2, 
                'title' => '行业最新发展趋势分析', 
                'summary' => '近期行业呈现出新的发展趋势，本文对此进行了详细分析。', 
                'keywords' => '行业,趋势,分析', 
                'content' => '<p>近期行业呈现出新的发展趋势，本文对此进行了详细分析。随着技术的不断进步和市场需求的变化，行业正在经历深刻的转型。</p><p>数据显示，未来几年内，行业将迎来新一轮的增长机遇，企业需要及时调整战略以适应这一变化。</p>', 
                'sort_order' => -9
            ]
        ];
        
        $insertNewsSQL = "INSERT INTO news (category_id, title, summary, keywords, content, sort_order) VALUES (:category_id, :title, :summary, :keywords, :content, :sort_order)";
        $newsStmt = $db->prepare($insertNewsSQL);
        
        foreach ($initialNewsData as $data) {
            $newsStmt->execute($data);
        }
        
        echo "初始新闻数据插入成功！<br>";
    }
    
    // 导入lk_info.sql文件中的数据
    $sqlFile = __DIR__ . '/lk_info.sql';
    
    if (file_exists($sqlFile)) {
        echo "开始导入lk_info.sql数据...<br>";
        
        // 读取SQL文件内容
        $sqlContent = file_get_contents($sqlFile);
        
        if ($sqlContent) {
            // 分割SQL语句
            $sqlStatements = explode(';', $sqlContent);
            
            // 执行每个SQL语句
            $successCount = 0;
            $errorCount = 0;
            
            foreach ($sqlStatements as $statement) {
                $statement = trim($statement);
                
                if (!empty($statement)) {
                    try {
                        $db->exec($statement);
                        $successCount++;
                    } catch (PDOException $e) {
                        echo "SQL执行错误: " . $e->getMessage() . "<br>";
                        $errorCount++;
                    }
                }
            }
            
            echo "SQL导入完成！成功执行 {$successCount} 条语句，失败 {$errorCount} 条。<br>";
        } else {
            echo "无法读取SQL文件内容。<br>";
        }
    } else {
        echo "lk_info.sql文件不存在，跳过数据导入。<br>";
    }
    
    echo "新闻管理表设置完成！";
} catch (PDOException $e) {
    die("错误: " . $e->getMessage());
}
?>
<!DOCTYPE html>
<html>
    <head>
        <!-- 头部内容 -->
    </head>
    <body>
        <?php include 'public/header.php'; ?>
        <!-- 其他内容 -->
    </body>
</html>
