<?php
/**
 * 会员数据库表创建脚本
 * 用于初始化会员管理系统所需的数据库表结构
 */

// 引入数据库配置文件
require_once '../config/database.php';

// 设置页面内容类型
header('Content-Type: text/html; charset=utf-8');

try {
    // 获取数据库连接
    $db = getDbConnection();
    
    // 开始事务
    $db->beginTransaction();
    
    // 检查user表是否已存在
    $tableExistsQuery = "SHOW TABLES LIKE 'user'";
    $tableExists = $db->query($tableExistsQuery)->rowCount() > 0;
    
    if ($tableExists) {
        // 检查是否需要添加密码字段
        $checkPasswordField = "SHOW COLUMNS FROM `user` LIKE 'password'";
        $passwordFieldExists = $db->query($checkPasswordField)->rowCount() > 0;
        
        if (!$passwordFieldExists) {
            // 添加密码字段
            $addPasswordField = "ALTER TABLE `user` ADD COLUMN `password` varchar(255) NOT NULL COMMENT '密码(加密)' AFTER `username`";
            $db->exec($addPasswordField);
            echo "<p>已向会员表添加密码字段。</p>";
            
            // 为现有用户设置默认密码 (123456)
            $defaultPassword = password_hash('123456', PASSWORD_DEFAULT);
            $updatePasswordQuery = "UPDATE `user` SET `password` = :password WHERE `password` IS NULL OR `password` = ''";
            $updateStmt = $db->prepare($updatePasswordQuery);
            $updateStmt->execute(['password' => $defaultPassword]);
            echo "<p>已为现有会员设置默认密码(123456)。</p>";
        } else {
            echo "<p>会员表(user)已存在且包含密码字段，跳过创建。</p>";
        }
    } else {
        // 创建user表
        $createTableQuery = "
        CREATE TABLE `user` (
          `id` int(11) NOT NULL AUTO_INCREMENT,
          `username` varchar(100) NOT NULL COMMENT '会员名',
          `password` varchar(255) NOT NULL COMMENT '密码(加密)',
          `avatar` varchar(255) DEFAULT NULL COMMENT '头像路径',
          `group_id` varchar(100) DEFAULT NULL COMMENT '群ID',
          `group_link` varchar(255) DEFAULT NULL COMMENT '群连接',
          `status` tinyint(1) NOT NULL DEFAULT '1' COMMENT '状态：1启用，0禁用',
          `created_at` datetime NOT NULL COMMENT '创建时间',
          `updated_at` datetime DEFAULT NULL COMMENT '更新时间',
          PRIMARY KEY (`id`),
          UNIQUE KEY `username` (`username`)
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='会员表';
        ";
        
        $db->exec($createTableQuery);
        echo "<p>会员表(user)创建成功！</p>";
        
        // 创建示例数据 (使用加密密码)
        $defaultPassword = password_hash('123456', PASSWORD_DEFAULT);
        $insertDemoDataQuery = "
        INSERT INTO `user` (`username`, `password`, `avatar`, `group_id`, `group_link`, `status`, `created_at`) VALUES
        ('测试会员1', :password1, NULL, 'group123', 'https://example.com/group1', 1, NOW()),
        ('测试会员2', :password2, NULL, 'group456', 'https://example.com/group2', 1, NOW());
        ";
        
        $insertStmt = $db->prepare($insertDemoDataQuery);
        $insertStmt->execute([
            'password1' => $defaultPassword,
            'password2' => $defaultPassword
        ]);
        echo "<p>示例会员数据添加成功！</p>";
    }
    
    // 检查上传目录是否存在
    $uploadDir = '../uploads/avatars/';
    if (!file_exists($uploadDir)) {
        if (mkdir($uploadDir, 0777, true)) {
            echo "<p>头像上传目录创建成功！</p>";
        } else {
            echo "<p>警告：无法创建头像上传目录，请手动创建 {$uploadDir} 并设置适当的权限。</p>";
        }
    } else {
        echo "<p>头像上传目录已存在。</p>";
    }
    
    // 提交事务
    $db->commit();
    
    echo "<div style='margin-top: 20px; padding: 10px; background-color: #dff0d8; color: #3c763d; border-radius: 4px;'>";
    echo "会员管理系统初始化完成！<br>";
    echo "<a href='user.php' style='color: #3c763d; text-decoration: underline;'>点击这里</a> 进入会员管理页面。";
    echo "</div>";
    
} catch (PDOException $e) {
    // 回滚事务
    if ($db->inTransaction()) {
        $db->rollBack();
    }
    
    echo "<div style='margin-top: 20px; padding: 10px; background-color: #f2dede; color: #a94442; border-radius: 4px;'>";
    echo "初始化失败：" . $e->getMessage();
    echo "</div>";
}
?>

<!DOCTYPE html>
<html lang="zh-CN">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>会员管理系统初始化</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            line-height: 1.6;
            margin: 0;
            padding: 20px;
            background-color: #f5f5f5;
        }
        .container {
            max-width: 800px;
            margin: 0 auto;
            background-color: #fff;
            padding: 20px;
            border-radius: 5px;
            box-shadow: 0 2px 5px rgba(0,0,0,0.1);
        }
        h1 {
            color: #333;
            border-bottom: 1px solid #eee;
            padding-bottom: 10px;
        }
        p {
            margin: 10px 0;
        }
        .success {
            color: #3c763d;
        }
        .error {
            color: #a94442;
        }
    </style>
</head>
<body>
    <div class="container">
        <h1>会员管理系统初始化</h1>
        <!-- PHP脚本输出的内容会显示在这里 -->
    </div>
</body>
</html> 