<?php
/**
 * 后台工单管理页面
 * 展示所有用户提交的工单，管理员可以查看和回复工单
 */

// 引入数据库配置文件
require_once '../config/database.php';

// 设置页面内容类型
header('Content-Type: text/html; charset=utf-8');

// 每页显示的工单数量
$perPage = isset($_GET['per_page']) ? intval($_GET['per_page']) : 10;
// 当前页码
$page = isset($_GET['page']) ? intval($_GET['page']) : 1;
// 确保页码不小于1
$page = max(1, $page);
// 计算偏移量
$offset = ($page - 1) * $perPage;

// 排序方式
$sortBy = isset($_GET['sort_by']) ? $_GET['sort_by'] : 'created_at';
$order = isset($_GET['order']) ? $_GET['order'] : 'DESC';

// 工单状态过滤
$statusFilter = isset($_GET['status']) ? $_GET['status'] : '';

try {
    // 获取数据库连接
    $db = getDbConnection();
    
    // 构建WHERE子句
    $whereClause = "";
    $params = [];
    
    if (!empty($statusFilter)) {
        $whereClause = "WHERE status = :status";
        $params['status'] = $statusFilter;
    }
    
    // 获取工单总数
    $countQuery = "SELECT COUNT(*) FROM tickets $whereClause";
    $stmt = $db->prepare($countQuery);
    
    foreach ($params as $key => $value) {
        $stmt->bindValue($key, $value);
    }
    
    $stmt->execute();
    $totalTickets = $stmt->fetchColumn();
    
    // 计算总页数
    $totalPages = ceil($totalTickets / $perPage);
    
    // 获取工单列表
    $validSortColumns = ['id', 'subject', 'status', 'priority', 'created_at', 'last_reply'];
    $sortBy = in_array($sortBy, $validSortColumns) ? $sortBy : 'created_at';
    $order = strtoupper($order) === 'ASC' ? 'ASC' : 'DESC';
    
    $ticketsQuery = "SELECT t.*,
                    DATE_FORMAT(t.created_at, '%Y-%m-%d %H:%i:%s') as formatted_created_at,
                    DATE_FORMAT(t.last_reply, '%Y-%m-%d %H:%i:%s') as formatted_last_reply
                    FROM tickets t 
                    $whereClause
                    ORDER BY t.$sortBy $order
                    LIMIT :offset, :limit";
    
    $stmt = $db->prepare($ticketsQuery);
    
    foreach ($params as $key => $value) {
        $stmt->bindValue($key, $value);
    }
    
    $stmt->bindValue(':offset', $offset, PDO::PARAM_INT);
    $stmt->bindValue(':limit', $perPage, PDO::PARAM_INT);
    $stmt->execute();
    $tickets = $stmt->fetchAll(PDO::FETCH_ASSOC);
    
} catch (PDOException $e) {
    $error = "获取工单数据时出错：" . $e->getMessage();
    $tickets = [];
    $totalPages = 0;
    $totalTickets = 0;
}

// 状态映射
$statusMap = [
    'open' => '未处理',
    'pending' => '处理中',
    'answered' => '已回复',
    'replied' => '已回复',
    'closed' => '已关闭',
];

// 优先级映射
$priorityMap = [
    'low' => '低',
    'medium' => '中',
    'high' => '高',
];
?>

<!DOCTYPE html>
<html lang="zh-CN">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>工单管理</title>
    <link rel="stylesheet" href="public/css/style.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">
    <style>
        /* 工单页面特定样式 */
        .page-title {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 20px;
        }
        
        .ticket-filters {
            display: flex;
            justify-content: space-between;
            margin-bottom: 15px;
            background-color: #f5f7fa;
            padding: 15px;
            border-radius: 5px;
            box-shadow: 0 1px 3px rgba(0, 0, 0, 0.05);
        }
        
        .filter-group {
            display: flex;
            align-items: center;
            gap: 10px;
        }
        
        .filter-group select {
            padding: 8px 12px;
            border-radius: 4px;
            border: 1px solid #dee2e6;
            background-color: #fff;
        }
        
        .filter-group button {
            padding: 8px 15px;
            background-color: var(--primary-color);
            color: white;
            border: none;
            border-radius: 4px;
            cursor: pointer;
        }
        
        .ticket-table {
            width: 100%;
            border-collapse: collapse;
            margin-bottom: 20px;
            background-color: #fff;
            box-shadow: 0 1px 3px rgba(0, 0, 0, 0.05);
            border-radius: 5px;
            overflow: hidden;
        }
        
        .ticket-table th {
            background-color: #f8f9fa;
            padding: 12px 15px;
            text-align: left;
            font-weight: 600;
            color: #495057;
            border-bottom: 2px solid #dee2e6;
            cursor: pointer;
        }
        
        .ticket-table th:hover {
            background-color: #e9ecef;
        }
        
        .ticket-table td {
            padding: 12px 15px;
            border-bottom: 1px solid #dee2e6;
            color: #495057;
        }
        
        .ticket-table tr:hover {
            background-color: #f8f9fa;
        }
        
        .ticket-table tr:last-child td {
            border-bottom: none;
        }
        
        .status-badge {
            display: inline-block;
            padding: 5px 10px;
            border-radius: 20px;
            font-size: 12px;
            font-weight: 500;
        }
        
        .status-open {
            background-color: #e3f2fd;
            color: #1976d2;
        }
        
        .status-pending {
            background-color: #fff8e1;
            color: #f57f17;
        }
        
        .status-answered {
            background-color: #e8f5e9;
            color: #388e3c;
        }
        
        .status-closed {
            background-color: #f5f5f5;
            color: #616161;
        }
        
        .priority-badge {
            display: inline-block;
            padding: 3px 8px;
            border-radius: 3px;
            font-size: 12px;
            font-weight: 500;
        }
        
        .priority-high {
            background-color: #ffebee;
            color: #c62828;
        }
        
        .priority-medium {
            background-color: #fff8e1;
            color: #f57f17;
        }
        
        .priority-low {
            background-color: #e8f5e9;
            color: #388e3c;
        }
        
        .action-buttons {
            display: flex;
            gap: 5px;
        }
        
        .action-buttons a {
            padding: 5px 10px;
            text-decoration: none;
            border-radius: 4px;
            color: white;
            font-size: 13px;
        }
        
        .view-btn {
            background-color: #4285f4;
        }
        
        .view-btn:hover {
            background-color: #2a75f3;
        }
        
        .pagination {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-top: 20px;
        }
        
        .pagination-pages {
            display: flex;
            gap: 5px;
        }
        
        .pagination-pages a, .pagination-pages span {
            padding: 8px 12px;
            border: 1px solid #dee2e6;
            border-radius: 4px;
            text-decoration: none;
            color: #495057;
            background-color: #fff;
        }
        
        .pagination-pages a:hover {
            background-color: #e9ecef;
        }
        
        .pagination-pages span.current {
            background-color: var(--primary-color);
            color: white;
            border-color: var(--primary-color);
        }
        
        .per-page {
            display: flex;
            align-items: center;
            gap: 10px;
        }
        
        .no-results {
            text-align: center;
            padding: 40px 20px;
            background-color: #f8f9fa;
            border-radius: 5px;
            color: #6c757d;
            font-size: 16px;
            margin-top: 20px;
        }
        
        .sorting-icon {
            margin-left: 5px;
            font-size: 12px;
        }
    </style>
</head>
<body>
    <?php include 'public/header.php'; ?>
    <div class="sidebar">
        <?php include 'public/letf.php'; ?>
    </div>
    <div class="main-content">
        <div class="page-title">
            <h1>工单管理</h1>
        </div>
        
        <?php if (isset($error)): ?>
            <div class="alert alert-danger">
                <i class="fas fa-exclamation-circle"></i> <?php echo $error; ?>
            </div>
        <?php endif; ?>
        
        <div class="ticket-filters">
            <div class="filter-group">
                <label for="status-filter">状态:</label>
                <select id="status-filter" name="status">
                    <option value="">全部</option>
                    <?php foreach ($statusMap as $key => $value): ?>
                        <option value="<?php echo $key; ?>" <?php echo $statusFilter === $key ? 'selected' : ''; ?>>
                            <?php echo $value; ?>
                        </option>
                    <?php endforeach; ?>
                </select>
                <button id="filter-btn">筛选</button>
            </div>
        </div>
        
        <?php if (empty($tickets)): ?>
            <div class="no-results">
                <i class="fas fa-ticket-alt" style="font-size: 24px; margin-bottom: 10px; display: block;"></i>
                没有找到匹配的工单记录
            </div>
        <?php else: ?>
            <table class="ticket-table">
                <thead>
                    <tr>
                        <th data-sort="id">ID <?php echo getSortIcon('id', $sortBy, $order); ?></th>
                        <th data-sort="subject">主题 <?php echo getSortIcon('subject', $sortBy, $order); ?></th>
                        <th>提交用户</th>
                        <th data-sort="status">状态 <?php echo getSortIcon('status', $sortBy, $order); ?></th>
                        <th data-sort="priority">优先级 <?php echo getSortIcon('priority', $sortBy, $order); ?></th>
                        <th data-sort="created_at">创建时间 <?php echo getSortIcon('created_at', $sortBy, $order); ?></th>
                        <th data-sort="last_reply">最后回复 <?php echo getSortIcon('last_reply', $sortBy, $order); ?></th>
                        <th>操作</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($tickets as $ticket): ?>
                        <tr>
                            <td>#<?php echo $ticket['id']; ?></td>
                            <td><?php echo htmlspecialchars($ticket['subject']); ?></td>
                            <td><?php echo $ticket['user_id']; ?></td>
                            <td>
                                <span class="status-badge status-<?php echo $ticket['status']; ?>">
                                    <?php echo $statusMap[$ticket['status']]; ?>
                                </span>
                            </td>
                            <td>
                                <span class="priority-badge priority-<?php echo $ticket['priority']; ?>">
                                    <?php echo $priorityMap[$ticket['priority']]; ?>
                                </span>
                            </td>
                            <td><?php echo $ticket['formatted_created_at']; ?></td>
                            <td><?php echo $ticket['formatted_last_reply'] ?? '-'; ?></td>
                            <td>
                                <div class="action-buttons">
                                    <a href="ticket_detail.php?id=<?php echo $ticket['id']; ?>" class="view-btn">
                                        <i class="fas fa-eye"></i> 查看
                                    </a>
                                </div>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
            
            <!-- 分页 -->
            <div class="pagination">
                <div class="pagination-info">
                    显示 <?php echo count($tickets); ?> 条，共 <?php echo $totalTickets; ?> 条记录
                </div>
                <div class="pagination-pages">
                    <?php if ($page > 1): ?>
                        <a href="?page=1&per_page=<?php echo $perPage; ?>&sort_by=<?php echo $sortBy; ?>&order=<?php echo $order; ?>&status=<?php echo $statusFilter; ?>">
                            <i class="fas fa-angle-double-left"></i>
                        </a>
                        <a href="?page=<?php echo $page - 1; ?>&per_page=<?php echo $perPage; ?>&sort_by=<?php echo $sortBy; ?>&order=<?php echo $order; ?>&status=<?php echo $statusFilter; ?>">
                            <i class="fas fa-angle-left"></i>
                        </a>
                    <?php endif; ?>
                    
                    <?php
                    // 显示页码链接
                    $start = max(1, $page - 2);
                    $end = min($start + 4, $totalPages);
                    $start = max(1, $end - 4);
                    
                    for ($i = $start; $i <= $end; $i++) {
                        if ($i == $page) {
                            echo '<span class="current">' . $i . '</span>';
                        } else {
                            echo '<a href="?page=' . $i . '&per_page=' . $perPage . '&sort_by=' . $sortBy . '&order=' . $order . '&status=' . $statusFilter . '">' . $i . '</a>';
                        }
                    }
                    ?>
                    
                    <?php if ($page < $totalPages): ?>
                        <a href="?page=<?php echo $page + 1; ?>&per_page=<?php echo $perPage; ?>&sort_by=<?php echo $sortBy; ?>&order=<?php echo $order; ?>&status=<?php echo $statusFilter; ?>">
                            <i class="fas fa-angle-right"></i>
                        </a>
                        <a href="?page=<?php echo $totalPages; ?>&per_page=<?php echo $perPage; ?>&sort_by=<?php echo $sortBy; ?>&order=<?php echo $order; ?>&status=<?php echo $statusFilter; ?>">
                            <i class="fas fa-angle-double-right"></i>
                        </a>
                    <?php endif; ?>
                </div>
                <div class="per-page">
                    <label for="per-page-select">每页显示:</label>
                    <select id="per-page-select">
                        <option value="10" <?php echo $perPage == 10 ? 'selected' : ''; ?>>10</option>
                        <option value="20" <?php echo $perPage == 20 ? 'selected' : ''; ?>>20</option>
                        <option value="50" <?php echo $perPage == 50 ? 'selected' : ''; ?>>50</option>
                        <option value="100" <?php echo $perPage == 100 ? 'selected' : ''; ?>>100</option>
                    </select>
                </div>
            </div>
        <?php endif; ?>
    </div>
    
    <script>
    document.addEventListener('DOMContentLoaded', function() {
        // 状态筛选功能
        const filterBtn = document.getElementById('filter-btn');
        const statusFilter = document.getElementById('status-filter');
        
        filterBtn.addEventListener('click', function() {
            const status = statusFilter.value;
            window.location.href = `?status=${status}&sort_by=<?php echo $sortBy; ?>&order=<?php echo $order; ?>&per_page=<?php echo $perPage; ?>`;
        });
        
        // 排序功能
        const sortableHeaders = document.querySelectorAll('th[data-sort]');
        sortableHeaders.forEach(header => {
            header.addEventListener('click', function() {
                const sortBy = this.dataset.sort;
                let order = '<?php echo $order; ?>' === 'ASC' ? 'DESC' : 'ASC';
                if (sortBy !== '<?php echo $sortBy; ?>') {
                    order = 'ASC';
                }
                window.location.href = `?sort_by=${sortBy}&order=${order}&status=<?php echo $statusFilter; ?>&per_page=<?php echo $perPage; ?>&page=<?php echo $page; ?>`;
            });
        });
        
        // 每页显示数量
        const perPageSelect = document.getElementById('per-page-select');
        perPageSelect.addEventListener('change', function() {
            const perPage = this.value;
            window.location.href = `?per_page=${perPage}&sort_by=<?php echo $sortBy; ?>&order=<?php echo $order; ?>&status=<?php echo $statusFilter; ?>&page=1`;
        });
    });
    </script>
</body>
</html>

<?php
// 辅助函数：显示排序图标
function getSortIcon($column, $currentSortBy, $currentOrder) {
    $icon = '<span class="sorting-icon">';
    
    if ($column === $currentSortBy) {
        $icon .= $currentOrder === 'ASC' 
                ? '<i class="fas fa-sort-up"></i>' 
                : '<i class="fas fa-sort-down"></i>';
    } else {
        $icon .= '<i class="fas fa-sort"></i>';
    }
    
    $icon .= '</span>';
    
    return $icon;
}
?>
