<?php
// 引入必要的配置文件和函数库
require_once '../config/database.php';
require_once '../config/config.php';
include 'public/header.php';
include_once '../common/functions.php';

// 添加检查权限的函数，如果它没有在其他地方定义
if (!function_exists('checkPermission')) {
    function checkPermission() {
        // 检查用户是否已登录
        if (!isAdminLoggedIn()) {
            // 未登录，重定向到登录页
            header("Location: login.php");
            exit;
        }
    }
}

// 检查是否已定义isAdminLoggedIn函数
if (!function_exists('isAdminLoggedIn')) {
    function isAdminLoggedIn() {
        // 简单的会话检查，您可能需要根据实际情况调整
        return isset($_SESSION['admin_id']) && !empty($_SESSION['admin_id']);
    }
}

// 启动会话（如果尚未启动）
if (session_status() == PHP_SESSION_NONE) {
    session_start();
}

// 检查用户权限
checkPermission();

// 获取分页参数
$page = isset($_GET['page']) ? intval($_GET['page']) : 1;
$limit = 15; // 每页显示15条记录
$offset = ($page - 1) * $limit;

// 获取搜索参数
$search = isset($_GET['search']) ? trim($_GET['search']) : '';
$video_id = isset($_GET['video_id']) ? intval($_GET['video_id']) : 0;
$status = isset($_GET['status']) ? intval($_GET['status']) : -1; // -1表示全部

// 处理批量操作
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['action'])) {
    try {
        $db = getDbConnection();
        $action = $_POST['action'];
        $selected = isset($_POST['selected']) ? $_POST['selected'] : [];
        
        if (empty($selected)) {
            throw new Exception('请至少选择一条评论');
        }
        
        // 安全处理选中的评论ID数组
        $placeholders = implode(',', array_fill(0, count($selected), '?'));
        $params = $selected;
        
        // 执行批量操作
        switch ($action) {
            case 'approve':
                $sql = "UPDATE video_comments SET status = 1 WHERE id IN ({$placeholders})";
                $stmt = $db->prepare($sql);
                $stmt->execute($params);
                $message = '已批准选中的评论';
                break;
                
            case 'reject':
                $sql = "UPDATE video_comments SET status = 0 WHERE id IN ({$placeholders})";
                $stmt = $db->prepare($sql);
                $stmt->execute($params);
                $message = '已驳回选中的评论';
                break;
                
            case 'delete':
                $sql = "DELETE FROM video_comments WHERE id IN ({$placeholders})";
                $stmt = $db->prepare($sql);
                $stmt->execute($params);
                $message = '已删除选中的评论';
                break;
                
            default:
                throw new Exception('未知操作');
        }
        
    } catch (Exception $e) {
        $error = $e->getMessage();
    }
}

// 处理单个评论操作
if (isset($_GET['action']) && isset($_GET['id'])) {
    try {
        $db = getDbConnection();
        $action = $_GET['action'];
        $id = intval($_GET['id']);
        
        switch ($action) {
            case 'approve':
                $sql = "UPDATE video_comments SET status = 1 WHERE id = ?";
                $stmt = $db->prepare($sql);
                $stmt->execute([$id]);
                $message = '评论已批准';
                break;
                
            case 'reject':
                $sql = "UPDATE video_comments SET status = 0 WHERE id = ?";
                $stmt = $db->prepare($sql);
                $stmt->execute([$id]);
                $message = '评论已驳回';
                break;
                
            case 'delete':
                $sql = "DELETE FROM video_comments WHERE id = ?";
                $stmt = $db->prepare($sql);
                $stmt->execute([$id]);
                $message = '评论已删除';
                break;
                
            default:
                throw new Exception('未知操作');
        }
        
        // 重定向以防止刷新页面时重复操作
        header("Location: video_comment.php?message=" . urlencode($message));
        exit;
        
    } catch (Exception $e) {
        $error = $e->getMessage();
    }
}

// 构建查询条件
$where = '1=1';
$params = [];

if (!empty($search)) {
    $where .= ' AND (c.content LIKE ? OR c.author_name LIKE ?)';
    $params[] = "%{$search}%";
    $params[] = "%{$search}%";
}

if ($video_id > 0) {
    $where .= ' AND c.video_id = ?';
    $params[] = $video_id;
}

if ($status != -1) {
    $where .= ' AND c.status = ?';
    $params[] = $status;
}

try {
    // 获取数据库连接
    $db = getDbConnection();

    // 查询评论总数
    $countSql = "SELECT COUNT(*) FROM video_comments c WHERE {$where}";
    $stmt = $db->prepare($countSql);
    $stmt->execute($params);
    $total = $stmt->fetchColumn();

    // 计算总页数
    $totalPages = ceil($total / $limit);
    
    // 确保当前页面在有效范围内
    if ($page < 1) $page = 1;
    if ($page > $totalPages && $totalPages > 0) $page = $totalPages;

    // 查询评论数据，包含视频标题
    $sql = "SELECT c.*, v.title as video_title 
            FROM video_comments c 
            LEFT JOIN videos v ON c.video_id = v.id 
            WHERE {$where} 
            ORDER BY c.created_at DESC 
            LIMIT {$offset}, {$limit}";
    
    $stmt = $db->prepare($sql);
    $stmt->execute($params);
    $comments = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // 获取所有视频供筛选使用
    $videosSql = "SELECT id, title FROM videos ORDER BY title ASC";
    $videosStmt = $db->query($videosSql);
    $videos = $videosStmt->fetchAll(PDO::FETCH_ASSOC);

} catch (PDOException $e) {
    // 记录错误日志
    error_log($e->getMessage());
    $error = '数据库查询出错，请稍后再试或联系管理员';
}

// 获取消息提示
$message = isset($_GET['message']) ? $_GET['message'] : '';
?>
<!DOCTYPE html>
<html lang="zh-CN">
    <head>
        <meta charset="utf-8">
        <meta name="viewport" content="width=device-width, initial-scale=1">
        <title>视频评论管理 - 后台管理系统</title>
        <!-- 引入样式文件 -->
        <link rel="stylesheet" href="public/css/style.css">
        <link rel="stylesheet" href="css/bootstrap.min.css">
        <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.4/css/all.min.css">
        <link rel="stylesheet" href="public/css/video_comment.css">
    </head>
    <body>
        <?php include 'public/letf.php'; ?>
        <div class="main-content">
            <div class="container-fluid">
                <?php if (!empty($message)): ?>
                <div class="alert alert-success">
                    <i class="fas fa-check-circle"></i> <?php echo htmlspecialchars($message); ?>
                </div>
                <?php endif; ?>
                <?php if (isset($error)): ?>
                <div class="alert alert-danger">
                    <i class="fas fa-exclamation-circle"></i> <?php echo htmlspecialchars($error); ?>
                </div>
                <?php endif; ?>
                <!-- 评论列表 -->
                <form method="POST" action="">
                    <div class="panel panel-default">
                        <div class="panel-heading">
                            <h3 class="panel-title"><i class="fas fa-list"></i> 评论列表 (总计: <?php echo $total; ?>)</h3>
                            <div class="btn-group">
                                <a href="video_comment_add.php" class="btn btn-primary btn-sm">
                                    <i class="fas fa-plus"></i> 添加评论
                                </a>
                                <button type="submit" name="action" value="approve" class="btn btn-success btn-sm" onclick="return confirm('确定要批准选中的评论吗？')">
                                    <i class="fas fa-check"></i> 批准
                                </button>
                                <button type="submit" name="action" value="reject" class="btn btn-warning btn-sm" onclick="return confirm('确定要驳回选中的评论吗？')">
                                    <i class="fas fa-ban"></i> 驳回
                                </button>
                                <button type="submit" name="action" value="delete" class="btn btn-danger btn-sm" onclick="return confirm('确定要删除选中的评论吗？此操作不可恢复！')">
                                    <i class="fas fa-trash"></i> 删除
                                </button>
                            </div>
                        </div>
                        <div class="table-responsive">
                            <table class="table table-striped table-hover">
                                <thead>
                                    <tr>
                                        <th width="30"><input type="checkbox" id="select-all"></th>
                                        <th width="50">ID</th>
                                        <th>评论内容</th>
                                        <th>视频</th>
                                        <th>点赞</th>
                                        <th>状态</th>
                                        <th>发布时间</th>
                                        <th width="180">操作</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php if (empty($comments)): ?>
                                    <tr>
                                        <td colspan="8" class="text-center">暂无评论数据</td>
                                    </tr>
                                    <?php else: ?>
                                    <?php foreach ($comments as $comment): ?>
                                    <tr>
                                        <td><input type="checkbox" name="selected[]" value="<?php echo $comment['id']; ?>"></td>
                                        <td><?php echo $comment['id']; ?></td>
                                        <td class="comment-content">
                                            <div class="comment-author">
                                                <?php echo htmlspecialchars($comment['author_name'] ?? '匿名用户'); ?>
                                                <?php if ($comment['parent_id'] > 0): ?>
                                                <span class="badge bg-info text-white">回复</span>
                                                <?php endif; ?>
                                            </div>
                                            <div>
                                                <?php echo htmlspecialchars($comment['content']); ?>
                                            </div>
                                        </td>
                                        <td>
                                            <a href="../cn/video_play.php?id=<?php echo $comment['video_id']; ?>" target="_blank" class="text-primary">
                                                <?php echo htmlspecialchars($comment['video_title']); ?>
                                            </a>
                                        </td>
                                        <td><span class="badge bg-light text-dark"><?php echo number_format($comment['likes']); ?></span></td>
                                        <td>
                                            <?php if ($comment['status'] == 1): ?>
                                            <span class="status-badge bg-success text-white"><i class="fas fa-check-circle"></i> 已审核</span>
                                            <?php else: ?>
                                            <span class="status-badge bg-secondary text-white"><i class="fas fa-clock"></i> 待审核</span>
                                            <?php endif; ?>
                                        </td>
                                        <td><?php echo date('Y-m-d H:i', strtotime($comment['created_at'])); ?></td>
                                        <td class="actions">
                                            <div class="btn-group btn-group-sm">
                                                <?php if ($comment['status'] == 0): ?>
                                                <a href="video_comment.php?action=approve&id=<?php echo $comment['id']; ?>" class="btn btn-primary" title="批准">
                                                    <i class="fas fa-check"></i>
                                                </a>
                                                <?php else: ?>
                                                <a href="video_comment.php?action=reject&id=<?php echo $comment['id']; ?>" class="btn btn-warning" title="驳回">
                                                    <i class="fas fa-ban"></i>
                                                </a>
                                                <?php endif; ?>
                                                <a href="../cn/video_play.php?id=<?php echo $comment['video_id']; ?>#comment-<?php echo $comment['id']; ?>" target="_blank" class="btn btn-info" title="查看">
                                                    <i class="fas fa-eye"></i>
                                                </a>
                                                <a href="javascript:void(0);" onclick="confirmDelete(<?php echo $comment['id']; ?>)" class="btn btn-danger" title="删除">
                                                    <i class="fas fa-trash"></i>
                                                </a>
                                            </div>
                                        </td>
                                    </tr>
                                    <?php endforeach; ?>
                                    <?php endif; ?>
                                </tbody>
                            </table>
                        </div>
                        <!-- 分页 -->
                        <?php if ($totalPages > 1): ?>
                        <div class="panel-footer">
                            <nav aria-label="Page navigation">
                                <ul class="pagination justify-content-center">
                                    <?php if ($page > 1): ?>
                                    <li class="page-item">
                                        <a class="page-link" href="?page=1&search=<?php echo urlencode($search); ?>&video_id=<?php echo $video_id; ?>&status=<?php echo $status; ?>" aria-label="First">
                                            <i class="fas fa-angle-double-left"></i>
                                        </a>
                                    </li>
                                    <li class="page-item">
                                        <a class="page-link" href="?page=<?php echo $page - 1; ?>&search=<?php echo urlencode($search); ?>&video_id=<?php echo $video_id; ?>&status=<?php echo $status; ?>" aria-label="Previous">
                                            <i class="fas fa-angle-left"></i>
                                        </a>
                                    </li>
                                    <?php endif; ?>
                                    <?php
                                    // 显示分页链接
                                    $startPage = max(1, min($page - 2, $totalPages - 4));
                                    $endPage = min($totalPages, max($page + 2, 5));
                                    
                                    for ($i = $startPage; $i <= $endPage; $i++) {
                                        echo '<li class="page-item ' . ($i == $page ? 'active' : '') . '">';
                                        echo '<a class="page-link" href="?page=' . $i . '&search=' . urlencode($search) . '&video_id=' . $video_id . '&status=' . $status . '">' . $i . '</a>';
                                        echo '</li>';
                                    }
                                    ?>
                                    <?php if ($page < $totalPages): ?>
                                    <li class="page-item">
                                        <a class="page-link" href="?page=<?php echo $page + 1; ?>&search=<?php echo urlencode($search); ?>&video_id=<?php echo $video_id; ?>&status=<?php echo $status; ?>" aria-label="Next">
                                            <i class="fas fa-angle-right"></i>
                                        </a>
                                    </li>
                                    <li class="page-item">
                                        <a class="page-link" href="?page=<?php echo $totalPages; ?>&search=<?php echo urlencode($search); ?>&video_id=<?php echo $video_id; ?>&status=<?php echo $status; ?>" aria-label="Last">
                                            <i class="fas fa-angle-double-right"></i>
                                        </a>
                                    </li>
                                    <?php endif; ?>
                                </ul>
                            </nav>
                        </div>
                        <?php endif; ?>
                    </div>
                </form>
            </div>
        </div>
        <!-- JavaScript 脚本 -->
        <script src="js/jquery.min.js"></script>
        <script src="js/bootstrap.min.js"></script>
        <script>
        $(document).ready(function() {
            // 全选/取消全选
            $('#select-all').change(function() {
                $('input[name="selected[]"]').prop('checked', $(this).prop('checked'));
            });

            // 当个别复选框状态改变时，更新全选框状态
            $('input[name="selected[]"]').change(function() {
                if ($('input[name="selected[]"]:checked').length === $('input[name="selected[]"]').length) {
                    $('#select-all').prop('checked', true);
                } else {
                    $('#select-all').prop('checked', false);
                }
            });
        });

        function confirmDelete(id) {
            if (confirm('确定要删除这条评论吗？此操作不可恢复！')) {
                window.location.href = 'video_comment.php?action=delete&id=' + id;
            }
        }
        </script>
    </body>
</html>
