<?php
// 引入必要的配置文件和函数库
require_once '../config/database.php';
require_once '../config/config.php';

// 添加检查权限的函数,如果它没有在其他地方定义
if (!function_exists('checkPermission')) {
    function checkPermission() {
        // 检查用户是否已登录
        if (!isAdminLoggedIn()) {
            // 未登录,重定向到登录页
            header("Location: login.php");
            exit;
        }
    }
}

// 检查是否已定义isAdminLoggedIn函数
if (!function_exists('isAdminLoggedIn')) {
    function isAdminLoggedIn() {
        // 简单的会话检查,您可能需要根据实际情况调整
        return isset($_SESSION['admin_id']) && !empty($_SESSION['admin_id']);
    }
}

// 启动会话(如果尚未启动)
if (session_status() == PHP_SESSION_NONE) {
    session_start();
}

// 检查用户权限
checkPermission();

// 初始化状态变量
$success = false;
$error = '';
$redirect = 'video_list.php';

// 记录操作日志
error_log("开始处理视频删除请求: " . json_encode($_GET));

// 检查是否提供了ID参数
if (!isset($_GET['id']) || empty($_GET['id'])) {
    $error = '未提供有效的视频ID';
    error_log("错误: 未提供有效的视频ID");
} else {
    $id = intval($_GET['id']);
    error_log("准备删除视频ID: $id");
    
    try {
        // 获取数据库连接
        $db = getDbConnection();
        
        // 首先查询视频数据，确保它存在并获取缩略图和视频文件路径
        $checkSql = "SELECT id, title, thumbnail, video_url FROM videos WHERE id = :id";
        $checkStmt = $db->prepare($checkSql);
        $checkStmt->bindParam(':id', $id, PDO::PARAM_INT);
        $checkStmt->execute();
        $video = $checkStmt->fetch(PDO::FETCH_ASSOC);
        
        if (!$video) {
            $error = '视频不存在或已被删除';
            error_log("错误: 视频ID $id 不存在或已被删除");
        } else {
            error_log("找到视频: " . json_encode($video));
            
            // 开始事务
            $db->beginTransaction();
            
            try {
                // 执行删除操作
                $deleteSql = "DELETE FROM videos WHERE id = :id";
                $deleteStmt = $db->prepare($deleteSql);
                $deleteStmt->bindParam(':id', $id, PDO::PARAM_INT);
                
                $deleteResult = $deleteStmt->execute();
                error_log("删除操作执行结果: " . ($deleteResult ? "成功" : "失败") . ", 影响行数: " . $deleteStmt->rowCount());
                
                if ($deleteResult && $deleteStmt->rowCount() > 0) {
                    // 如果有缩略图，尝试删除文件
                    if (!empty($video['thumbnail'])) {
                        $thumbnailPath = '../' . $video['thumbnail'];
                        error_log("尝试删除缩略图: $thumbnailPath");
                        if (file_exists($thumbnailPath)) {
                            $unlinkResult = @unlink($thumbnailPath);
                            error_log("删除缩略图结果: " . ($unlinkResult ? "成功" : "失败"));
                        } else {
                            error_log("缩略图文件不存在: $thumbnailPath");
                        }
                    }
                    
                    // 如果有视频文件，尝试删除
                    if (!empty($video['video_url']) && strpos($video['video_url'], 'http') === false) {
                        $videoPath = '../' . $video['video_url'];
                        error_log("尝试删除视频文件: $videoPath");
                        if (file_exists($videoPath)) {
                            $unlinkResult = @unlink($videoPath);
                            error_log("删除视频文件结果: " . ($unlinkResult ? "成功" : "失败"));
                        } else {
                            error_log("视频文件不存在: $videoPath");
                        }
                    }
                    
                    // 提交事务
                    $db->commit();
                    $success = true;
                    
                    // 记录日志
                    $logMessage = "管理员 {$_SESSION['admin_id']} 删除了视频 ID:{$id}, 标题:{$video['title']}";
                    error_log($logMessage);
                    
                    // 设置成功消息，将通过URL参数传递
                    $redirect .= '?status=deleted&title=' . urlencode($video['title']);
                    error_log("删除成功，准备重定向到: $redirect");
                } else {
                    // 回滚事务
                    $db->rollBack();
                    $error = '删除视频失败，请稍后再试';
                    error_log("删除失败，没有找到匹配的记录或数据库操作失败");
                }
            } catch (PDOException $e) {
                // 回滚事务
                $db->rollBack();
                error_log("删除操作异常: " . $e->getMessage());
                $error = '删除操作出错，请稍后再试或联系管理员: ' . $e->getMessage();
            }
        }
    } catch (PDOException $e) {
        error_log("数据库连接异常: " . $e->getMessage());
        $error = '数据库连接出错，请稍后再试或联系管理员: ' . $e->getMessage();
    }
}

// 根据结果重定向
if ($success) {
    error_log("删除成功，重定向到: $redirect");
    header("Location: $redirect");
    exit;
} else {
    error_log("删除失败，重定向到错误页面，错误信息: $error");
    header("Location: video_list.php?error=" . urlencode($error));
    exit;
}
?> 