<?php
// 引入必要的配置文件和函数库
require_once '../config/database.php';
require_once '../config/config.php';

// 添加检查权限的函数,如果它没有在其他地方定义
if (!function_exists('checkPermission')) {
    function checkPermission() {
        // 检查用户是否已登录
        if (!isAdminLoggedIn()) {
            // 返回未授权错误
            header('Content-Type: application/json');
            echo json_encode(['success' => false, 'error' => '未授权访问']);
            exit;
        }
    }
}

// 检查是否已定义isAdminLoggedIn函数
if (!function_exists('isAdminLoggedIn')) {
    function isAdminLoggedIn() {
        // 简单的会话检查,您可能需要根据实际情况调整
        return isset($_SESSION['admin_id']) && !empty($_SESSION['admin_id']);
    }
}

// 启动会话(如果尚未启动)
if (session_status() == PHP_SESSION_NONE) {
    session_start();
}

// 检查用户权限
checkPermission();

// 设置响应头为JSON
header('Content-Type: application/json');

// 初始化响应数据
$response = [
    'success' => false,
    'message' => '',
    'error' => ''
];

// 记录操作日志
error_log("开始处理AJAX视频删除请求: " . json_encode($_POST));

// 检查是否提供了ID参数
if (!isset($_POST['id']) || empty($_POST['id'])) {
    $response['error'] = '未提供有效的视频ID';
    error_log("错误: 未提供有效的视频ID");
    echo json_encode($response);
    exit;
}

$id = intval($_POST['id']);
error_log("准备删除视频ID: $id");

try {
    // 获取数据库连接
    $db = getDbConnection();
    
    // 首先查询视频数据，确保它存在并获取缩略图和视频文件路径
    $checkSql = "SELECT id, title, thumbnail, video_url FROM videos WHERE id = :id";
    $checkStmt = $db->prepare($checkSql);
    $checkStmt->bindParam(':id', $id, PDO::PARAM_INT);
    $checkStmt->execute();
    $video = $checkStmt->fetch(PDO::FETCH_ASSOC);
    
    if (!$video) {
        $response['error'] = '视频不存在或已被删除';
        error_log("错误: 视频ID $id 不存在或已被删除");
    } else {
        error_log("找到视频: " . json_encode($video));
        
        // 开始事务
        $db->beginTransaction();
        
        try {
            // 执行删除操作
            $deleteSql = "DELETE FROM videos WHERE id = :id";
            $deleteStmt = $db->prepare($deleteSql);
            $deleteStmt->bindParam(':id', $id, PDO::PARAM_INT);
            
            $deleteResult = $deleteStmt->execute();
            $affectedRows = $deleteStmt->rowCount();
            error_log("删除操作执行结果: " . ($deleteResult ? "成功" : "失败") . ", 影响行数: " . $affectedRows);
            
            if ($deleteResult && $affectedRows > 0) {
                // 如果有缩略图，尝试删除文件
                if (!empty($video['thumbnail'])) {
                    $thumbnailPath = '../' . $video['thumbnail'];
                    error_log("尝试删除缩略图: $thumbnailPath");
                    if (file_exists($thumbnailPath)) {
                        $unlinkResult = @unlink($thumbnailPath);
                        error_log("删除缩略图结果: " . ($unlinkResult ? "成功" : "失败"));
                    } else {
                        error_log("缩略图文件不存在: $thumbnailPath");
                    }
                }
                
                // 如果有视频文件，尝试删除
                if (!empty($video['video_url']) && strpos($video['video_url'], 'http') === false) {
                    $videoPath = '../' . $video['video_url'];
                    error_log("尝试删除视频文件: $videoPath");
                    if (file_exists($videoPath)) {
                        $unlinkResult = @unlink($videoPath);
                        error_log("删除视频文件结果: " . ($unlinkResult ? "成功" : "失败"));
                    } else {
                        error_log("视频文件不存在: $videoPath");
                    }
                }
                
                // 提交事务
                $db->commit();
                
                // 记录日志
                $logMessage = "管理员 {$_SESSION['admin_id']} 删除了视频 ID:{$id}, 标题:{$video['title']}";
                error_log($logMessage);
                
                // 设置成功响应
                $response['success'] = true;
                $response['message'] = "视频 \"{$video['title']}\" 已成功删除！";
                $response['id'] = $id;
                error_log("删除成功，返回成功响应");
            } else {
                // 回滚事务
                $db->rollBack();
                $response['error'] = '删除视频失败，请稍后再试';
                error_log("删除失败，没有找到匹配的记录或数据库操作失败");
            }
        } catch (PDOException $e) {
            // 回滚事务
            $db->rollBack();
            error_log("删除操作异常: " . $e->getMessage());
            $response['error'] = '删除操作出错，请稍后再试或联系管理员: ' . $e->getMessage();
        }
    }
} catch (PDOException $e) {
    error_log("数据库连接异常: " . $e->getMessage());
    $response['error'] = '数据库连接出错，请稍后再试或联系管理员: ' . $e->getMessage();
}

// 返回JSON响应
echo json_encode($response);
exit;
?> 