<?php
// 引入必要的配置文件和函数库
require_once 'code/video_edit_code.php';
include 'public/header.php';

// 添加检查权限的函数,如果它没有在其他地方定义
if (!function_exists('checkPermission')) {
    function checkPermission() {
        // 检查用户是否已登录
        if (!isAdminLoggedIn()) {
            // 未登录,重定向到登录页
            header("Location: login.php");
            exit;
        }
    }
}

// 检查是否已定义isAdminLoggedIn函数
if (!function_exists('isAdminLoggedIn')) {
    function isAdminLoggedIn() {
        // 简单的会话检查,您可能需要根据实际情况调整
        return isset($_SESSION['admin_id']) && !empty($_SESSION['admin_id']);
    }
}

// 启动会话(如果尚未启动)
if (session_status() == PHP_SESSION_NONE) {
    session_start();
}

// 检查用户权限
checkPermission();

// 初始化变量
$id = isset($_GET['id']) ? intval($_GET['id']) : 0;
$video = [
    'id' => 0,
    'title' => '',
    'description' => '',
    'category_id' => 0,
    'status' => 1,
    'featured' => 0,
    'thumbnail' => '',
    'video_url' => '',
    'duration' => '',
    'views' => 0,
    'likes' => 0,
    'created_at' => date('Y-m-d H:i:s'),
    'updated_at' => date('Y-m-d H:i:s')
];
$pageTitle = '添加视频';
$submitButtonText = '保存视频';
$success = false;
$error = '';

try {
    // 获取数据库连接
    $db = getDbConnection();
    
    if (!$db) {
        throw new PDOException("数据库连接失败，无法获取连接对象");
    }
    
    // 获取所有视频分类
    $categoriesSql = "SELECT id, name FROM video_categories WHERE status = 1 ORDER BY sort_order ASC";
    try {
        $categoriesStmt = $db->query($categoriesSql);
        $categories = $categoriesStmt->fetchAll(PDO::FETCH_ASSOC);
    } catch (PDOException $e) {
        error_log("查询视频分类失败: " . $e->getMessage());
        $categories = []; // 如果查询失败，使用空数组
        $error = '获取视频分类失败，请检查数据库连接或联系管理员';
    }
    
    // 如果是编辑操作，获取视频数据
    if ($id > 0) {
        $sql = "SELECT * FROM videos WHERE id = :id";
        try {
            $stmt = $db->prepare($sql);
            $stmt->bindParam(':id', $id, PDO::PARAM_INT);
            $stmt->execute();
            $result = $stmt->fetch(PDO::FETCH_ASSOC);
            
            if ($result) {
                $video = $result;
                $pageTitle = '编辑视频';
                $submitButtonText = '更新视频';
            } else {
                $error = '视频不存在或已被删除';
            }
        } catch (PDOException $e) {
            error_log("获取视频数据失败: " . $e->getMessage());
            $error = '获取视频数据失败，请检查数据库连接';
        }
    }
    
    // 处理表单提交
    if ($_SERVER['REQUEST_METHOD'] == 'POST') {
        // 获取表单数据
        $video['title'] = trim($_POST['title'] ?? '');
        $video['description'] = trim($_POST['description'] ?? '');
        $video['category_id'] = intval($_POST['category_id'] ?? 0);
        $video['status'] = isset($_POST['status']) ? 1 : 0;
        $video['featured'] = isset($_POST['featured']) ? 1 : 0;
        $video['video_url'] = trim($_POST['video_url'] ?? '');
        $video['thumbnail'] = trim($_POST['thumbnail'] ?? '');
        $video['duration'] = trim($_POST['duration'] ?? '');
        $video['updated_at'] = date('Y-m-d H:i:s');
        
        // 验证必填字段
        if (empty($video['title'])) {
            $error = '视频标题不能为空';
        } elseif ($video['category_id'] <= 0) {
            $error = '请选择视频分类';
        } elseif (empty($video['video_url'])) {
            $error = '视频链接不能为空';
        } else {
            try {
                // 保存数据
                if ($id > 0) {
                    // 更新视频
                    $sql = "UPDATE videos SET 
                            title = :title, 
                            description = :description, 
                            category_id = :category_id, 
                            status = :status, 
                            featured = :featured,
                            thumbnail = :thumbnail, 
                            video_url = :video_url, 
                            duration = :duration, 
                            updated_at = :updated_at 
                            WHERE id = :id";
                    $stmt = $db->prepare($sql);
                    if (!$stmt) {
                        throw new PDOException("准备更新SQL语句失败: " . print_r($db->errorInfo(), true));
                    }
                    $stmt->bindParam(':id', $id, PDO::PARAM_INT);
                } else {
                    // 插入新视频
                    $sql = "INSERT INTO videos (
                            title, description, category_id, status, featured,
                            thumbnail, video_url, duration, views, likes,
                            created_at, updated_at
                        ) VALUES (
                            :title, :description, :category_id, :status, :featured,
                            :thumbnail, :video_url, :duration, 0, 0,
                            :created_at, :updated_at
                        )";
                    $stmt = $db->prepare($sql);
                    if (!$stmt) {
                        throw new PDOException("准备插入SQL语句失败: " . print_r($db->errorInfo(), true));
                    }
                    $stmt->bindParam(':created_at', $video['created_at']);
                }
                
                // 绑定参数
                $stmt->bindParam(':title', $video['title']);
                $stmt->bindParam(':description', $video['description']);
                $stmt->bindParam(':category_id', $video['category_id'], PDO::PARAM_INT);
                $stmt->bindParam(':status', $video['status'], PDO::PARAM_INT);
                $stmt->bindParam(':featured', $video['featured'], PDO::PARAM_INT);
                $stmt->bindParam(':thumbnail', $video['thumbnail']);
                $stmt->bindParam(':video_url', $video['video_url']);
                $stmt->bindParam(':duration', $video['duration']);
                $stmt->bindParam(':updated_at', $video['updated_at']);
                
                // 执行SQL并检查结果
                if (!$stmt->execute()) {
                    throw new PDOException("SQL执行失败: " . print_r($stmt->errorInfo(), true));
                }
                
                if ($id == 0) {
                    // 获取新插入的ID
                    $id = $db->lastInsertId();
                    if (!$id) {
                        throw new PDOException("获取新插入ID失败");
                    }
                    $video['id'] = $id;
                }
                $success = true;
                $pageTitle = '编辑视频';
                $submitButtonText = '更新视频';
            } catch (PDOException $e) {
                error_log("保存视频数据失败: " . $e->getMessage());
                $error = '保存视频失败: ' . $e->getMessage();
            }
        }
    }
} catch (PDOException $e) {
    // 记录详细错误日志
    error_log("数据库操作出错: " . $e->getMessage() . "\n" . 
              "SQL状态: " . (isset($stmt) ? print_r($stmt->errorInfo(), true) : "无可用语句") . "\n" .
              "数据库信息: " . (isset($db) ? print_r($db->errorInfo(), true) : "无数据库连接"));
    
    // 调试模式下可以显示详细错误
    $isDebug = true; // 可根据配置文件设置
    if ($isDebug) {
        $error = '数据库操作出错: ' . $e->getMessage();
    } else {
        $error = '数据库操作出错，请稍后再试或联系管理员';
    }
}
?>
<!DOCTYPE html>
<html lang="zh-CN">
    <head>
        <meta charset="utf-8">
        <meta name="viewport" content="width=device-width, initial-scale=1">
        <title><?php echo $pageTitle; ?> - 后台管理系统</title>
        <!-- 使用CDN引用替代本地文件 -->
        <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@4.6.2/dist/css/bootstrap.min.css">
        <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
        <link href="https://fonts.googleapis.com/css2?family=Nunito:wght@300;400;600;700&display=swap" rel="stylesheet">
        <link rel="stylesheet" href="public/css/style.css">
        <!-- 视频编辑页面专用样式 -->
        <link rel="stylesheet" href="public/css/video_edit.css">
        <!-- 添加现代化选择框样式 -->
        <link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
        <!-- 添加现代化开关样式 -->
        <link href="https://cdn.jsdelivr.net/npm/sweetalert2@11/dist/sweetalert2.min.css" rel="stylesheet">
    </head>
    <body>
        <?php include 'public/letf.php'; ?>
        <div class="main-content">
            <div class="container-fluid">
                <!-- 页面头部 -->
                <div class="page-header d-flex justify-content-between align-items-center">
                    <h1 style="margin-bottom: 0;"><i class="fas fa-film"></i> 视频信息</h1>
                    <a href="video_list.php" class="btn btn-outline-secondary btn-sm"><i class="fas fa-arrow-left"></i> 返回</a>
                </div>
                <?php if ($success): ?>
                <div class="alert alert-success d-flex align-items-center">
                    <i class="fas fa-check-circle me-2"></i>
                    <div>视频已成功保存</div>
                </div>
                <?php endif; ?>
                <?php if (!empty($error)): ?>
                <div class="alert alert-danger d-flex align-items-center">
                    <i class="fas fa-exclamation-circle me-2"></i>
                    <div><?php echo $error; ?></div>
                </div>
                <?php endif; ?>
                <!-- 视频编辑表单 -->
                <div class="card">
                    <div class="card-header">
                        <div class="d-flex justify-content-between align-items-center">
                            <h5 class="mb-0"><i class="fas fa-edit"></i> 编辑详情</h5>
                        </div>
                    </div>
                    <div class="card-body">
                        <form method="post" enctype="multipart/form-data" id="videoForm" class="needs-validation" novalidate>
                            <!-- 状态设置区域 -->
                            <div class="row mb-4">
                                <div class="col-md-12">
                                    <div class="card settings-card compact-settings-card">
                                        <div class="card-body p-3">
                                            <div class="d-flex justify-content-start">
                                                <div class="custom-control custom-switch mr-4">
                                                    <input type="checkbox" class="custom-control-input" id="status" name="status" <?php echo ($video['status'] == 1) ? 'checked' : ''; ?>>
                                                    <label class="custom-control-label" for="status">发布状态</label>
                                                </div>
                                                <div class="custom-control custom-switch">
                                                    <input type="checkbox" class="custom-control-input" id="featured" name="featured" <?php echo ($video['featured'] == 1) ? 'checked' : ''; ?>>
                                                    <label class="custom-control-label" for="featured">推荐视频</label>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <!-- 视频链接 (独立一行) -->
                            <div class="row mb-3">
                                <div class="col-md-12">
                                    <div class="form-group">
                                        <label for="video_url" class="required">视频链接 <i class="fas fa-link ms-2"></i></label>
                                        <input type="text" class="form-control" id="video_url" name="video_url" value="<?php echo htmlspecialchars($video['video_url']); ?>" required>
                                    </div>
                                </div>
                            </div>
                            <!-- 视频标题和时长 (放在一行) -->
                            <div class="row mb-3">
                                <div class="col-md-8">
                                    <div class="form-group">
                                        <label for="title" class="required">视频标题 <i class="fas fa-heading ms-2"></i></label>
                                        <input type="text" class="form-control" id="title" name="title" value="<?php echo htmlspecialchars($video['title']); ?>" required>
                                    </div>
                                </div>
                                <div class="col-md-4">
                                    <div class="form-group">
                                        <label for="duration">时长 <i class="fas fa-clock ms-2"></i></label>
                                        <input type="text" class="form-control" id="duration" name="duration" value="<?php echo htmlspecialchars($video['duration']); ?>" placeholder="例如: 05:30">
                                    </div>
                                </div>
                            </div>
                            <!-- 视频分类和缩略图 (放在一行) -->
                            <div class="row mb-3">
                                <div class="col-md-4">
                                    <div class="form-group">
                                        <label for="category_id" class="required">视频分类 <i class="fas fa-folder ms-2"></i></label>
                                        <select class="form-control select2" id="category_id" name="category_id" required>
                                            <option value="">-- 请选择分类 --</option>
                                            <?php foreach ($categories as $category): ?>
                                            <option value="<?php echo $category['id']; ?>" <?php echo ($video['category_id'] == $category['id']) ? 'selected' : ''; ?>>
                                                <?php echo htmlspecialchars($category['name']); ?>
                                            </option>
                                            <?php endforeach; ?>
                                        </select>
                                    </div>
                                </div>
                                <div class="col-md-8">
                                    <div class="form-group">
                                        <label for="thumbnail">缩略图 <i class="fas fa-image ms-2"></i></label>
                                        <div class="input-group thumbnail-input-group">
                                            <input type="text" class="form-control" id="thumbnail" name="thumbnail" value="<?php echo htmlspecialchars($video['thumbnail']); ?>" placeholder="图片URL地址">
                                        
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <!-- 视频描述 -->
                            <div class="form-group">
                                <label for="description">视频描述 <i class="fas fa-align-left ms-2"></i></label>
                                <textarea class="form-control" id="description" name="description" rows="4"><?php echo htmlspecialchars($video['description']); ?></textarea>
                            </div>
                            <div class="form-actions">
                                <button type="submit" class="btn btn-primary">
                                    <i class="fas fa-save"></i> <?php echo $submitButtonText; ?>
                                </button>
                                <button type="button" class="btn btn-info" id="previewBtn">
                                    <i class="fas fa-eye"></i> 预览
                                </button>
                                <a href="video_list.php" class="btn btn-secondary">
                                    <i class="fas fa-times"></i> 取消
                                </a>
                            </div>
                        </form>
                    </div>
                </div>
            </div>
        </div>
        <!-- JavaScript 脚本 -->
        <script src="js/jquery.min.js"></script>
        <script src="js/bootstrap.min.js"></script>
        <script src="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/js/all.min.js"></script>
        <!-- Select2 下拉框增强 -->
        <script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>
        <!-- SweetAlert2 美化弹窗 -->
        <script src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>
        <!-- 引入视频编辑页面专用JavaScript -->
        <script src="public/js/video_edit.js"></script>
    </body>
</html>
