<?php
// 引入必要的配置文件和函数库
require_once '../config/database.php';
require_once '../config/config.php';
include 'public/header.php';

// 添加检查权限的函数,如果它没有在其他地方定义
if (!function_exists('checkPermission')) {
    function checkPermission() {
        // 检查用户是否已登录
        if (!isAdminLoggedIn()) {
            // 未登录,重定向到登录页
            header("Location: login.php");
            exit;
        }
    }
}

// 检查是否已定义isAdminLoggedIn函数
if (!function_exists('isAdminLoggedIn')) {
    function isAdminLoggedIn() {
        // 简单的会话检查,您可能需要根据实际情况调整
        return isset($_SESSION['admin_id']) && !empty($_SESSION['admin_id']);
    }
}

// 启动会话(如果尚未启动)
if (session_status() == PHP_SESSION_NONE) {
    session_start();
}

// 检查用户权限
checkPermission();

// 初始化状态消息变量
$statusMessage = '';
$errorMessage = '';
$statusClass = 'alert-success';

// 处理从其他页面传入的消息
if (isset($_GET['status'])) {
    if ($_GET['status'] === 'success') {
        $statusMessage = isset($_GET['message']) ? htmlspecialchars(urldecode($_GET['message'])) : '操作成功！';
        $statusClass = 'alert-success';
    } elseif ($_GET['status'] === 'error') {
        $errorMessage = isset($_GET['message']) ? htmlspecialchars(urldecode($_GET['message'])) : '操作失败！';
        $statusClass = 'alert-danger';
    } elseif ($_GET['status'] === 'deleted' && isset($_GET['title'])) {
        $title = htmlspecialchars(urldecode($_GET['title']));
        $statusMessage = "视频 \"$title\" 已成功删除！";
        $statusClass = 'alert-success';
    }
}

// 处理错误消息
if (isset($_GET['error'])) {
    $errorMessage = htmlspecialchars(urldecode($_GET['error']));
    $statusClass = 'alert-danger';
}

// 处理视频删除请求
if (isset($_GET['delete']) && is_numeric($_GET['delete'])) {
    $videoId = $_GET['delete'];
    
    try {
        // 获取数据库连接
        $db = getDbConnection();
        
        // 首先查询视频数据，确保它存在并获取缩略图路径
        $checkSql = "SELECT id, title, thumbnail FROM videos WHERE id = :id";
        $checkStmt = $db->prepare($checkSql);
        $checkStmt->bindParam(':id', $videoId, PDO::PARAM_INT);
        $checkStmt->execute();
        $video = $checkStmt->fetch(PDO::FETCH_ASSOC);
        
        if (!$video) {
            // 视频不存在
            $errorMessage = '视频不存在或已被删除';
            $statusClass = 'alert-danger';
        } else {
            // 开始事务
            $db->beginTransaction();
            
            try {
                // 执行删除操作
                $deleteSql = "DELETE FROM videos WHERE id = :id";
                $deleteStmt = $db->prepare($deleteSql);
                $deleteStmt->bindParam(':id', $videoId, PDO::PARAM_INT);
                
                if ($deleteStmt->execute()) {
                    // 如果有缩略图，尝试删除文件
                    if (!empty($video['thumbnail'])) {
                        $thumbnailPath = '../' . $video['thumbnail'];
                        if (file_exists($thumbnailPath)) {
                            @unlink($thumbnailPath);
                        }
                    }
                    
                    // 提交事务
                    $db->commit();
                    
                    // 记录日志
                    $logMessage = "管理员 {$_SESSION['admin_id']} 删除了视频 ID:{$videoId}, 标题:{$video['title']}";
                    error_log($logMessage);
                    
                    // 删除成功消息
                    $statusMessage = "视频 \"{$video['title']}\" 删除成功！";
                    $statusClass = 'alert-success';
                } else {
                    // 删除失败，回滚事务
                    $db->rollBack();
                    $errorMessage = '删除视频失败，请稍后再试';
                    $statusClass = 'alert-danger';
                }
            } catch (PDOException $e) {
                // 出现异常，回滚事务
                $db->rollBack();
                error_log($e->getMessage());
                $errorMessage = '删除操作出错，请稍后再试或联系管理员';
                $statusClass = 'alert-danger';
            }
        }
    } catch (PDOException $e) {
        error_log($e->getMessage());
        $errorMessage = '数据库连接出错，请稍后再试或联系管理员';
        $statusClass = 'alert-danger';
    }
}

// 获取分页参数
$page = isset($_GET['page']) ? intval($_GET['page']) : 1;
$limit = 10; // 每页显示10条记录
$offset = ($page - 1) * $limit;

// 设置默认搜索参数
$search = '';
$category_id = 0;
$status = -1; // -1表示全部

// 构建查询条件
$where = '1=1';
$params = [];

try {
    // 获取数据库连接
    $db = getDbConnection();

    // 查询视频总数
    $countSql = "SELECT COUNT(*) FROM videos v WHERE {$where}";
    $stmt = $db->prepare($countSql);
    $stmt->execute($params);
    $total = $stmt->fetchColumn();
    
    // 计算总页数
    $totalPages = ceil($total / $limit);
    
    // 确保当前页面在有效范围内
    if ($page < 1) $page = 1;
    if ($page > $totalPages && $totalPages > 0) $page = $totalPages;

    // 查询视频数据
    $sql = "SELECT v.*, c.name as category_name 
            FROM videos v 
            LEFT JOIN video_categories c ON v.category_id = c.id 
            WHERE {$where} 
            ORDER BY v.created_at DESC 
            LIMIT {$offset}, {$limit}";
    
    $stmt = $db->prepare($sql);
    $stmt->execute($params);
    $videos = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // 获取所有视频分类
    $categoriesSql = "SELECT id, name FROM video_categories WHERE status = 1 ORDER BY sort_order ASC";
    $categoriesStmt = $db->query($categoriesSql);
    $categories = $categoriesStmt->fetchAll(PDO::FETCH_ASSOC);

} catch (PDOException $e) {
    // 记录错误日志
    error_log($e->getMessage());
    $error = '数据库查询出错,请稍后再试或联系管理员';
}
?>
<!DOCTYPE html>
<html lang="zh-CN">
    <head>
        <meta charset="utf-8">
        <meta name="viewport" content="width=device-width, initial-scale=1">
        <title>视频管理 - 后台管理系统</title>
        <link rel="stylesheet" href="public/css/style.css">
        <!-- 使用CDN加载Bootstrap和jQuery -->
        <link rel="stylesheet" href="https://cdn.bootcdn.net/ajax/libs/twitter-bootstrap/4.6.0/css/bootstrap.min.css">
        <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
        <link href="https://fonts.googleapis.com/css2?family=Nunito:wght@300;400;600;700&display=swap" rel="stylesheet">
        <link rel="stylesheet" href="public/css/video_list.css">
        <!-- 添加内联CSS确保模态框正常工作 -->
        <style>
        .modal-backdrop {
            z-index: 1040;
        }

        .modal {
            z-index: 1050;
        }

        </style>
    </head>
    <body>
        <?php include 'public/letf.php'; ?>
        <div class="main-content">
            <div class="container-fluid compact-layout">
                <?php if (!empty($statusMessage)): ?>
                <div class="alert <?php echo $statusClass; ?> alert-dismissible fade show mt-3" role="alert">
                    <i class="fas fa-check-circle mr-2"></i> <?php echo $statusMessage; ?>
                    <button type="button" class="close" data-dismiss="alert" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                </div>
                <?php endif; ?>
                <?php if (!empty($errorMessage)): ?>
                <div class="alert alert-danger alert-dismissible fade show mt-3" role="alert">
                    <i class="fas fa-exclamation-circle mr-2"></i> <?php echo $errorMessage; ?>
                    <button type="button" class="close" data-dismiss="alert" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                </div>
                <?php endif; ?>
                <?php if (isset($error)): ?>
                <div class="alert alert-danger alert-dismissible fade show mt-3" role="alert">
                    <i class="fas fa-exclamation-circle mr-2"></i> <?php echo $error; ?>
                    <button type="button" class="close" data-dismiss="alert" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                </div>
                <?php endif; ?>
                <!-- 视频列表 -->
                <div class="card">
                    <div class="card-header d-flex justify-content-between align-items-center">
                        <h5><i class="fas fa-list"></i> 视频列表 <span class="badge badge-primary total-count-badge">总计: <?php echo $total; ?></span></h5>
                        <div class="header-actions">
                            <a href="video_add.php" class="btn btn-primary btn-add">
                                <i class="fas fa-plus"></i> 添加视频
                            </a>
                        </div>
                    </div>
                    <div class="table-responsive">
                        <table class="table table-hover">
                            <thead>
                                <tr>
                                    <th class="id-column">ID</th>
                                    <th class="thumbnail-column">缩略图</th>
                                    <th class="title-column">标题</th>
                                    <th class="category-column">分类</th>
                                    <th class="stats-column">时长</th>
                                    <th class="stats-column">数据统计</th>
                                    <th class="status-column">状态</th>
                                    <th class="date-column">发布时间</th>
                                    <th class="actions-column">操作</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php if (empty($videos)): ?>
                                <tr>
                                    <td colspan="10">
                                        <div class="empty-state">
                                            <i class="fas fa-video-slash"></i>
                                            <p>暂无视频数据</p>
                                            <a href="video_edit.php" class="btn btn-primary mt-3">
                                                <i class="fas fa-plus"></i> 添加第一个视频
                                            </a>
                                        </div>
                                    </td>
                                </tr>
                                <?php else: ?>
                                <?php foreach ($videos as $video): ?>
                                <tr>
                                    <td class="id-column"><?php echo $video['id']; ?></td>
                                    <td class="thumbnail-column">
                                        <?php if ($video['thumbnail']): ?>
                                        <img src="<?php echo htmlspecialchars($video['thumbnail']); ?>" class="video-thumbnail" alt="缩略图">
                                        <?php else: ?>
                                        <div class="empty-thumbnail">
                                            <i class="fas fa-video"></i>
                                        </div>
                                        <?php endif; ?>
                                    </td>
                                    <td class="title-column">
                                        <div class="title-cell">
                                            <?php echo htmlspecialchars($video['title']); ?>
                                        </div>
                                    </td>
                                    <td class="category-column">
                                        <span class="category-text"><?php echo htmlspecialchars($video['category_name']); ?></span>
                                    </td>
                                    <td class="stats-column">
                                        <i class="fas fa-clock mr-1"></i> <?php echo htmlspecialchars($video['duration']); ?>
                                    </td>
                                    <td class="stats-column">
                                        <i class="fas fa-eye mr-1 views-icon"></i> <?php echo number_format($video['views']); ?>&nbsp;&nbsp;&nbsp;
                                        <i class="fas fa-heart ml-3 mr-1 likes-icon"></i> <?php echo number_format($video['likes']); ?>
                                    </td>
                                    <td class="status-column">
                                        <?php if ($video['status'] == 1): ?>
                                        已发布
                                        <?php else: ?>
                                        草稿
                                        <?php endif; ?>
                                    </td>
                                    <td>
                                        <?php echo date('Y/m/d', strtotime($video['created_at'])); ?>
                                        <?php echo date('H:i', strtotime($video['created_at'])); ?>
                                    </td>
                                    <td class="actions-column">
                                        <div class="btn-group">
                                            <a href="video_edit.php?id=<?php echo $video['id']; ?>" class="btn btn-action btn-edit" data-toggle="tooltip" title="编辑">
                                                <i class="fas fa-edit"></i>
                                            </a>
                                            <a href="../cn/video-detail.html?id=<?php echo $video['id']; ?>" target="_blank" class="btn btn-action btn-preview" data-toggle="tooltip" title="预览">
                                                <i class="fas fa-eye"></i>
                                            </a>
                                            <a href="javascript:void(0);" onclick="confirmDelete(<?php echo $video['id']; ?>)" class="btn btn-action btn-delete" data-toggle="tooltip" title="删除">
                                                <i class="fas fa-trash"></i>
                                            </a>
                                        </div>
                                    </td>
                                </tr>
                                <?php endforeach; ?>
                                <?php endif; ?>
                            </tbody>
                        </table>
                    </div>
                    <!-- 分页 -->
                    <?php if ($totalPages > 1): ?>
                    <div class="card-footer">
                        <nav aria-label="Page navigation">
                            <ul class="pagination justify-content-center">
                                <?php if ($page > 1): ?>
                                <li class="page-item">
                                    <a class="page-link" href="?page=1" aria-label="First">
                                        <i class="fas fa-angle-double-left"></i>
                                    </a>
                                </li>
                                <li class="page-item">
                                    <a class="page-link" href="?page=<?php echo $page - 1; ?>" aria-label="Previous">
                                        <i class="fas fa-angle-left"></i>
                                    </a>
                                </li>
                                <?php endif; ?>
                                <?php
                                // 显示分页链接
                                $startPage = max(1, min($page - 2, $totalPages - 4));
                                $endPage = min($totalPages, max($page + 2, 5));
                                
                                for ($i = $startPage; $i <= $endPage; $i++) {
                                    echo '<li class="page-item ' . ($i == $page ? 'active' : '') . '">';
                                    echo '<a class="page-link" href="?page=' . $i . '">' . $i . '</a>';
                                    echo '</li>';
                                }
                                ?>
                                <?php if ($page < $totalPages): ?>
                                <li class="page-item">
                                    <a class="page-link" href="?page=<?php echo $page + 1; ?>" aria-label="Next">
                                        <i class="fas fa-angle-right"></i>
                                    </a>
                                </li>
                                <li class="page-item">
                                    <a class="page-link" href="?page=<?php echo $totalPages; ?>" aria-label="Last">
                                        <i class="fas fa-angle-double-right"></i>
                                    </a>
                                </li>
                                <?php endif; ?>
                            </ul>
                        </nav>
                    </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>
        <!-- 删除确认模态框 -->
        <div class="modal fade modal-initial" id="deleteModal" tabindex="-1" role="dialog" aria-labelledby="deleteModalLabel" aria-hidden="true">
            <div class="modal-dialog" role="document">
                <div class="modal-content">
                    <div class="modal-header">
                        <h5 class="modal-title" id="deleteModalLabel"><i class="fas fa-trash-alt text-danger mr-2"></i> 确认删除</h5>
                        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                            <span aria-hidden="true">&times;</span>
                        </button>
                    </div>
                    <div class="modal-body">
                        <div class="alert alert-warning">
                            <i class="fas fa-exclamation-triangle mr-2"></i>
                            <strong>警告:</strong> 确定要删除这个视频吗?此操作<strong class="text-danger">不可恢复</strong>!
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-dismiss="modal"><i class="fas fa-times mr-1"></i> 取消</button>
                        <a href="#" id="confirmDeleteBtn" class="btn btn-danger"><i class="fas fa-trash-alt mr-1"></i> 确认删除</a>
                    </div>
                </div>
            </div>
        </div>
        <!-- JavaScript 脚本 -->
        <script src="https://cdn.bootcdn.net/ajax/libs/jquery/3.5.1/jquery.min.js"></script>
        <script src="https://cdn.bootcdn.net/ajax/libs/twitter-bootstrap/4.6.0/js/bootstrap.min.js"></script>
        <script src="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/js/all.min.js"></script>
        <script>
        $(document).ready(function() {
            // 确保模态框初始状态为隐藏
            $('#deleteModal').modal('hide');

            // 初始化工具提示
            $('[data-toggle="tooltip"]').tooltip();

            // 表格行悬停效果
            $('.table tbody tr').hover(
                function() {
                    $(this).addClass('bg-light');
                },
                function() {
                    $(this).removeClass('bg-light');
                }
            );

            // 刷新按钮点击事件
            $('.refresh-btn').click(function() {
                location.reload();
            });

            // 为表格行添加点击效果
            $('.table tbody tr').click(function(e) {
                if (!$(e.target).closest('a').length && !$(e.target).closest('button').length) {
                    var id = $(this).find('.id-column').text();
                    window.location.href = 'video_edit.php?id=' + id;
                }
            });

            // 添加表格行点击视觉反馈
            $('.table tbody tr').css('cursor', 'pointer');

            // 显示状态消息自动消失
            setTimeout(function() {
                $('.alert-dismissible').fadeOut('slow');
            }, 5000);
        });

        function confirmDelete(id) {
            if (id) {
                // 设置删除链接
                $('#confirmDeleteBtn').attr('href', 'video_delete_simple.php?id=' + id);
                // 显示模态框
                $('#deleteModal').modal('show');
            } else {
                console.error('无效的视频ID');
            }
        }
        </script>
    </body>
</html>
