<?php
// 引入必要的配置文件和函数库
include 'header.php';
include '../common/functions.php';

// 检查用户权限
checkPermission();

try {
    // 获取数据库连接
    $db = getDbConnection();
    
    // 获取总视频数
    $totalVideosSql = "SELECT COUNT(*) FROM videos";
    $totalVideos = $db->query($totalVideosSql)->fetchColumn();
    
    // 获取总播放量
    $totalViewsSql = "SELECT SUM(views) FROM videos";
    $totalViews = $db->query($totalViewsSql)->fetchColumn();
    
    // 获取总点赞数
    $totalLikesSql = "SELECT SUM(likes) FROM videos";
    $totalLikes = $db->query($totalLikesSql)->fetchColumn();
    
    // 获取评论总数
    $totalCommentsSql = "SELECT COUNT(*) FROM video_comments";
    $totalComments = $db->query($totalCommentsSql)->fetchColumn();
    
    // 获取每个分类的视频数量
    $categoriesStatsSql = "SELECT c.id, c.name, COUNT(v.id) as video_count, SUM(v.views) as total_views 
                           FROM video_categories c 
                           LEFT JOIN videos v ON c.id = v.category_id 
                           GROUP BY c.id 
                           ORDER BY total_views DESC, video_count DESC";
    $categoriesStatsStmt = $db->query($categoriesStatsSql);
    $categoriesStats = $categoriesStatsStmt->fetchAll(PDO::FETCH_ASSOC);
    
    // 获取最受欢迎的视频（按观看次数）
    $popularVideosSql = "SELECT id, title, views, likes, created_at 
                         FROM videos 
                         ORDER BY views DESC 
                         LIMIT 10";
    $popularVideosStmt = $db->query($popularVideosSql);
    $popularVideos = $popularVideosStmt->fetchAll(PDO::FETCH_ASSOC);
    
    // 获取最新的评论
    $recentCommentsSql = "SELECT c.id, c.content, c.author_name, c.created_at, v.id as video_id, v.title as video_title 
                          FROM video_comments c 
                          LEFT JOIN videos v ON c.video_id = v.id 
                          ORDER BY c.created_at DESC 
                          LIMIT 5";
    $recentCommentsStmt = $db->query($recentCommentsSql);
    $recentComments = $recentCommentsStmt->fetchAll(PDO::FETCH_ASSOC);
    
    // 获取每月视频上传趋势（最近12个月）
    $monthlyTrendsSql = "SELECT 
                           DATE_FORMAT(created_at, '%Y-%m') as month,
                           COUNT(*) as upload_count,
                           SUM(views) as views_count,
                           SUM(likes) as likes_count
                         FROM videos 
                         WHERE created_at >= DATE_SUB(NOW(), INTERVAL 12 MONTH)
                         GROUP BY DATE_FORMAT(created_at, '%Y-%m')
                         ORDER BY month ASC";
    $monthlyTrendsStmt = $db->query($monthlyTrendsSql);
    $monthlyTrends = $monthlyTrendsStmt->fetchAll(PDO::FETCH_ASSOC);
    
    // 准备图表数据
    $chartMonths = [];
    $chartUploads = [];
    $chartViews = [];
    $chartLikes = [];
    
    foreach ($monthlyTrends as $trend) {
        $chartMonths[] = $trend['month'];
        $chartUploads[] = $trend['upload_count'];
        $chartViews[] = $trend['views_count'];
        $chartLikes[] = $trend['likes_count'];
    }
    
    // 准备分类统计图表数据
    $categoryNames = [];
    $categoryVideoCounts = [];
    $categoryViewCounts = [];
    
    foreach ($categoriesStats as $category) {
        $categoryNames[] = $category['name'];
        $categoryVideoCounts[] = $category['video_count'];
        $categoryViewCounts[] = $category['total_views'] ?: 0; // 处理NULL值
    }
    
} catch (PDOException $e) {
    // 记录错误日志
    error_log($e->getMessage());
    $error = '数据库查询出错，请稍后再试或联系管理员';
}
?>

<!DOCTYPE html>
<html lang="zh-CN">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>视频数据统计 - 后台管理系统</title>
    <!-- 引入样式文件 -->
    <link rel="stylesheet" href="css/bootstrap.min.css">
    <link rel="stylesheet" href="css/admin.css">
    <!-- 引入Chart.js图表库 -->
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
    <style>
        .stats-card {
            background-color: #fff;
            border-radius: 4px;
            box-shadow: 0 1px 3px rgba(0,0,0,0.1);
            padding: 15px;
            margin-bottom: 20px;
            transition: transform 0.3s;
        }
        .stats-card:hover {
            transform: translateY(-5px);
            box-shadow: 0 5px 15px rgba(0,0,0,0.1);
        }
        .stats-card .card-icon {
            font-size: 36px;
            margin-bottom: 10px;
            color: #3498db;
        }
        .stats-card .card-title {
            font-size: 14px;
            color: #777;
            margin-bottom: 5px;
        }
        .stats-card .card-value {
            font-size: 24px;
            font-weight: bold;
            color: #34495e;
        }
        .chart-container {
            background-color: #fff;
            border-radius: 4px;
            box-shadow: 0 1px 3px rgba(0,0,0,0.1);
            padding: 15px;
            margin-bottom: 20px;
        }
        .popular-video {
            display: flex;
            align-items: center;
            margin-bottom: 10px;
            padding: 10px;
            background-color: #f9f9f9;
            border-radius: 4px;
        }
        .popular-video .number {
            width: 24px;
            height: 24px;
            background-color: #3498db;
            color: #fff;
            border-radius: 50%;
            text-align: center;
            line-height: 24px;
            margin-right: 10px;
            font-weight: bold;
        }
        .popular-video .info {
            flex-grow: 1;
        }
        .popular-video .title {
            font-weight: bold;
            margin-bottom: 5px;
        }
        .popular-video .meta {
            font-size: 12px;
            color: #777;
        }
        .comment-item {
            padding: 10px;
            border-bottom: 1px solid #eee;
        }
        .comment-item:last-child {
            border-bottom: none;
        }
        .comment-author {
            font-weight: bold;
        }
        .comment-time {
            font-size: 12px;
            color: #777;
        }
        .comment-content {
            margin-top: 5px;
        }
    </style>
</head>
<body>
    <?php include 'letf.php'; ?>
    
    <div class="main-content">
        <div class="container-fluid">
            <div class="page-header">
                <h1><i class="fas fa-chart-bar"></i> 视频数据统计</h1>
            </div>
            
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>
            
            <!-- 统计卡片 -->
            <div class="row">
                <div class="col-md-3">
                    <div class="stats-card">
                        <div class="card-icon">
                            <i class="fas fa-video"></i>
                        </div>
                        <div class="card-title">总视频数</div>
                        <div class="card-value"><?php echo number_format($totalVideos); ?></div>
                    </div>
                </div>
                <div class="col-md-3">
                    <div class="stats-card">
                        <div class="card-icon">
                            <i class="fas fa-eye"></i>
                        </div>
                        <div class="card-title">总播放量</div>
                        <div class="card-value"><?php echo number_format($totalViews); ?></div>
                    </div>
                </div>
                <div class="col-md-3">
                    <div class="stats-card">
                        <div class="card-icon">
                            <i class="fas fa-thumbs-up"></i>
                        </div>
                        <div class="card-title">总点赞数</div>
                        <div class="card-value"><?php echo number_format($totalLikes); ?></div>
                    </div>
                </div>
                <div class="col-md-3">
                    <div class="stats-card">
                        <div class="card-icon">
                            <i class="fas fa-comments"></i>
                        </div>
                        <div class="card-title">总评论数</div>
                        <div class="card-value"><?php echo number_format($totalComments); ?></div>
                    </div>
                </div>
            </div>
            
            <!-- 图表 -->
            <div class="row">
                <!-- 月度趋势图 -->
                <div class="col-md-8">
                    <div class="chart-container">
                        <h4>月度视频趋势</h4>
                        <canvas id="monthlyTrendsChart"></canvas>
                    </div>
                </div>
                
                <!-- 分类统计图 -->
                <div class="col-md-4">
                    <div class="chart-container">
                        <h4>分类统计</h4>
                        <canvas id="categoriesChart"></canvas>
                    </div>
                </div>
            </div>
            
            <div class="row">
                <!-- 最受欢迎的视频 -->
                <div class="col-md-8">
                    <div class="panel panel-default">
                        <div class="panel-heading">
                            <h3 class="panel-title">最受欢迎的视频</h3>
                        </div>
                        <div class="panel-body">
                            <?php if (empty($popularVideos)): ?>
                                <p class="text-center">暂无数据</p>
                            <?php else: ?>
                                <?php foreach ($popularVideos as $index => $video): ?>
                                    <div class="popular-video">
                                        <div class="number"><?php echo $index + 1; ?></div>
                                        <div class="info">
                                            <div class="title">
                                                <a href="../cn/video_play.php?id=<?php echo $video['id']; ?>" target="_blank">
                                                    <?php echo htmlspecialchars($video['title']); ?>
                                                </a>
                                            </div>
                                            <div class="meta">
                                                <span><i class="fas fa-eye"></i> <?php echo number_format($video['views']); ?> 次观看</span>
                                                <span class="ml-2"><i class="fas fa-thumbs-up"></i> <?php echo number_format($video['likes']); ?> 次点赞</span>
                                                <span class="ml-2"><i class="fas fa-clock"></i> <?php echo date('Y-m-d', strtotime($video['created_at'])); ?></span>
                                            </div>
                                        </div>
                                    </div>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
                
                <!-- 最新评论 -->
                <div class="col-md-4">
                    <div class="panel panel-default">
                        <div class="panel-heading">
                            <h3 class="panel-title">最新评论</h3>
                        </div>
                        <div class="panel-body">
                            <?php if (empty($recentComments)): ?>
                                <p class="text-center">暂无评论</p>
                            <?php else: ?>
                                <?php foreach ($recentComments as $comment): ?>
                                    <div class="comment-item">
                                        <div>
                                            <span class="comment-author"><?php echo htmlspecialchars($comment['author_name'] ?? '匿名用户'); ?></span>
                                            <span class="comment-time pull-right"><?php echo date('m-d H:i', strtotime($comment['created_at'])); ?></span>
                                        </div>
                                        <div class="comment-content">
                                            <?php echo htmlspecialchars(mb_substr($comment['content'], 0, 50)) . (mb_strlen($comment['content']) > 50 ? '...' : ''); ?>
                                        </div>
                                        <div class="mt-1">
                                            <small>评论视频：<a href="../cn/video_play.php?id=<?php echo $comment['video_id']; ?>" target="_blank"><?php echo htmlspecialchars($comment['video_title']); ?></a></small>
                                        </div>
                                    </div>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    
    <!-- JavaScript 脚本 -->
    <script src="js/jquery.min.js"></script>
    <script src="js/bootstrap.min.js"></script>
    <script>
    // 月度趋势图
    var monthlyCtx = document.getElementById('monthlyTrendsChart').getContext('2d');
    var monthlyChart = new Chart(monthlyCtx, {
        type: 'line',
        data: {
            labels: <?php echo json_encode($chartMonths); ?>,
            datasets: [
                {
                    label: '视频上传数',
                    data: <?php echo json_encode($chartUploads); ?>,
                    backgroundColor: 'rgba(52, 152, 219, 0.2)',
                    borderColor: 'rgba(52, 152, 219, 1)',
                    borderWidth: 2,
                    tension: 0.3
                },
                {
                    label: '播放量',
                    data: <?php echo json_encode($chartViews); ?>,
                    backgroundColor: 'rgba(46, 204, 113, 0.2)',
                    borderColor: 'rgba(46, 204, 113, 1)',
                    borderWidth: 2,
                    tension: 0.3
                },
                {
                    label: '点赞数',
                    data: <?php echo json_encode($chartLikes); ?>,
                    backgroundColor: 'rgba(231, 76, 60, 0.2)',
                    borderColor: 'rgba(231, 76, 60, 1)',
                    borderWidth: 2,
                    tension: 0.3
                }
            ]
        },
        options: {
            responsive: true,
            scales: {
                y: {
                    beginAtZero: true
                }
            }
        }
    });
    
    // 分类统计图
    var categoriesCtx = document.getElementById('categoriesChart').getContext('2d');
    var categoriesChart = new Chart(categoriesCtx, {
        type: 'doughnut',
        data: {
            labels: <?php echo json_encode($categoryNames); ?>,
            datasets: [{
                label: '视频数量',
                data: <?php echo json_encode($categoryVideoCounts); ?>,
                backgroundColor: [
                    'rgba(52, 152, 219, 0.7)',
                    'rgba(46, 204, 113, 0.7)',
                    'rgba(231, 76, 60, 0.7)',
                    'rgba(241, 196, 15, 0.7)',
                    'rgba(155, 89, 182, 0.7)',
                    'rgba(26, 188, 156, 0.7)',
                    'rgba(230, 126, 34, 0.7)'
                ],
                borderWidth: 1
            }]
        },
        options: {
            responsive: true,
            plugins: {
                legend: {
                    position: 'right',
                }
            }
        }
    });
    </script>
</body>
</html> 