<?php
/**
 * Telegram机器人API封装类
 */
class TelegramBot {
    private $token;
    private $apiUrl = 'https://api.telegram.org/bot';
    
    /**
     * 构造函数
     * 
     * @param string $token API令牌
     */
    public function __construct($token) {
        $this->token = $token;
        $this->apiUrl .= $token . '/';
    }
    
    /**
     * 发送HTTP请求到Telegram API
     * 
     * @param string $method API方法
     * @param array $params 参数
     * @return array 请求结果
     */
    private function request($method, $params = []) {
        $url = $this->apiUrl . $method;
        
        // 记录API请求
        if (function_exists('logTelegramActivity')) {
            logTelegramActivity("API请求: $method, 参数: " . json_encode($params));
        }
        
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_POST, true);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $params);
        
        // 添加错误处理
        curl_setopt($ch, CURLOPT_FAILONERROR, true);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
        curl_setopt($ch, CURLOPT_TIMEOUT, 30);
        
        $response = curl_exec($ch);
        $error = curl_error($ch);
        $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        curl_close($ch);
        
        if ($error) {
            if (function_exists('logTelegramActivity')) {
                logTelegramActivity("API错误: $error, HTTP状态码: $httpCode");
            }
            return ['ok' => false, 'error' => $error, 'http_code' => $httpCode];
        }
        
        // 解析响应
        $decoded = json_decode($response, true);
        
        // 记录API响应
        if (function_exists('logTelegramActivity')) {
            logTelegramActivity("API响应: " . (is_array($decoded) ? json_encode($decoded) : $response));
        }
        
        return $decoded ?: ['ok' => false, 'error' => 'Invalid response'];
    }
    
    /**
     * 发送消息
     * 
     * @param int|string $chatId 聊天ID
     * @param string $text 消息文本
     * @param string $parseMode 解析模式 (HTML, Markdown)
     * @return array 请求结果
     */
    public function sendMessage($chatId, $text, $parseMode = 'HTML') {
        $params = [
            'chat_id' => $chatId,
            'text' => $text,
            'parse_mode' => $parseMode
        ];
        
        return $this->request('sendMessage', $params);
    }
    
    /**
     * 发送图片
     * 
     * @param int|string $chatId 聊天ID
     * @param string $photo 图片URL或文件ID
     * @param string $caption 图片说明文字
     * @param string $parseMode 解析模式 (HTML, Markdown)
     * @return array 请求结果
     */
    public function sendPhoto($chatId, $photo, $caption = null, $parseMode = 'HTML') {
        $params = [
            'chat_id' => $chatId,
            'photo' => $photo
        ];
        
        if (!empty($caption)) {
            $params['caption'] = $caption;
            $params['parse_mode'] = $parseMode;
        }
        
        return $this->request('sendPhoto', $params);
    }
    
    /**
     * 获取机器人信息
     * 
     * @return array 机器人信息
     */
    public function getMe() {
        return $this->request('getMe');
    }
} 
