<?php
// 设置详细错误报告
ini_set('display_errors', 1);
error_reporting(E_ALL);

// 记录日志
$log_prefix = "[DB-CHECK] - " . date('Y-m-d H:i:s') . ": ";
error_log($log_prefix . "开始检查数据库");

// 安全验证 - 请在生产环境中设置更强的验证机制
$admin_ip = ['127.0.0.1', '::1']; // 本地IP
$client_ip = $_SERVER['REMOTE_ADDR'];

// 只允许管理员IP或本地访问
if (!in_array($client_ip, $admin_ip) && !isset($_GET['confirm']) && $client_ip != '127.0.0.1') {
    echo "访问受限。如确认执行，请添加confirm参数";
    error_log($log_prefix . "未授权访问尝试，IP: " . $client_ip);
    exit;
}

// 尝试获取数据库连接
$db = null;
try {
    // 1. 尝试使用getDbConnection函数
    if (function_exists('getDbConnection')) {
        $db = getDbConnection();
        echo "<p>✅ 使用getDbConnection函数连接数据库成功</p>";
        error_log($log_prefix . "通过getDbConnection函数连接成功");
    } else {
        echo "<p>❌ getDbConnection函数不存在</p>";
        error_log($log_prefix . "getDbConnection函数不存在");
        
        // 2. 尝试加载配置
        if (file_exists('../config.php')) {
            include_once '../config.php';
            echo "<p>✅ 找到config.php</p>";
            error_log($log_prefix . "找到config.php");
            
            // 3. 尝试手动连接数据库
            if (defined('DB_HOST') && defined('DB_USER') && defined('DB_PASSWORD') && defined('DB_NAME')) {
                echo "<p>✅ 找到数据库配置</p>";
                error_log($log_prefix . "找到数据库配置");
                
                try {
                    $db = new PDO('mysql:host='.DB_HOST.';dbname='.DB_NAME, DB_USER, DB_PASSWORD);
                    $db->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
                    echo "<p>✅ 手动连接数据库成功</p>";
                    error_log($log_prefix . "手动连接数据库成功");
                } catch (PDOException $e) {
                    echo "<p>❌ 手动连接数据库失败: " . $e->getMessage() . "</p>";
                    error_log($log_prefix . "手动连接数据库失败: " . $e->getMessage());
                }
            } else {
                echo "<p>❌ 未找到数据库配置常量</p>";
                error_log($log_prefix . "未找到数据库配置常量");
            }
        } else {
            echo "<p>❌ 未找到config.php文件</p>";
            error_log($log_prefix . "未找到config.php文件");
        }
    }
    
    // 如果连接成功，继续检查
    if ($db) {
        // 检查chat_messages表是否存在
        $check_table_sql = "SHOW TABLES LIKE 'chat_messages'";
        $table_result = $db->query($check_table_sql);
        
        if ($table_result && $table_result->rowCount() > 0) {
            echo "<p>✅ chat_messages表存在</p>";
            error_log($log_prefix . "chat_messages表存在");
            
            // 检查表结构
            $check_structure_sql = "DESCRIBE chat_messages";
            $structure_result = $db->query($check_structure_sql);
            
            if ($structure_result) {
                echo "<p>✅ 表结构检查成功</p>";
                echo "<table border='1'><tr><th>字段</th><th>类型</th><th>Null</th><th>键</th><th>默认值</th><th>额外</th></tr>";
                
                $columns = [];
                while ($row = $structure_result->fetch(PDO::FETCH_ASSOC)) {
                    $columns[] = $row['Field'];
                    echo "<tr>";
                    echo "<td>" . $row['Field'] . "</td>";
                    echo "<td>" . $row['Type'] . "</td>";
                    echo "<td>" . $row['Null'] . "</td>";
                    echo "<td>" . $row['Key'] . "</td>";
                    echo "<td>" . $row['Default'] . "</td>";
                    echo "<td>" . $row['Extra'] . "</td>";
                    echo "</tr>";
                }
                echo "</table>";
                
                // 检查必须字段
                $required_columns = ['id', 'user_id', 'admin_id', 'message', 'is_read', 'created_at'];
                $missing_columns = array_diff($required_columns, $columns);
                
                if (empty($missing_columns)) {
                    echo "<p>✅ 所有必须字段都存在</p>";
                    error_log($log_prefix . "所有必须字段都存在");
                } else {
                    echo "<p>❌ 缺少字段: " . implode(', ', $missing_columns) . "</p>";
                    error_log($log_prefix . "缺少字段: " . implode(', ', $missing_columns));
                    
                    // 尝试添加缺失字段
                    echo "<p>是否要添加缺失字段? <a href='?fix=1&confirm=1'>是</a></p>";
                    
                    if (isset($_GET['fix']) && $_GET['fix'] == 1) {
                        foreach ($missing_columns as $col) {
                            $alter_sql = "";
                            switch ($col) {
                                case 'id':
                                    $alter_sql = "ALTER TABLE chat_messages ADD id INT NOT NULL AUTO_INCREMENT PRIMARY KEY FIRST";
                                    break;
                                case 'user_id':
                                    $alter_sql = "ALTER TABLE chat_messages ADD user_id INT NOT NULL AFTER id";
                                    break;
                                case 'admin_id':
                                    $alter_sql = "ALTER TABLE chat_messages ADD admin_id INT NULL AFTER user_id";
                                    break;
                                case 'message':
                                    $alter_sql = "ALTER TABLE chat_messages ADD message TEXT NOT NULL AFTER admin_id";
                                    break;
                                case 'is_read':
                                    $alter_sql = "ALTER TABLE chat_messages ADD is_read TINYINT(1) NOT NULL DEFAULT 0 AFTER message";
                                    break;
                                case 'created_at':
                                    $alter_sql = "ALTER TABLE chat_messages ADD created_at DATETIME NOT NULL AFTER is_read";
                                    break;
                            }
                            
                            if (!empty($alter_sql)) {
                                try {
                                    $db->exec($alter_sql);
                                    echo "<p>✅ 成功添加字段: $col</p>";
                                    error_log($log_prefix . "成功添加字段: $col");
                                } catch (Exception $e) {
                                    echo "<p>❌ 添加字段失败: $col - " . $e->getMessage() . "</p>";
                                    error_log($log_prefix . "添加字段失败: $col - " . $e->getMessage());
                                }
                            }
                        }
                    }
                }
                
                // 检查权限
                echo "<h3>权限测试</h3>";
                
                // 1. 测试SELECT权限
                try {
                    $select_test = $db->query("SELECT * FROM chat_messages LIMIT 1");
                    echo "<p>✅ SELECT权限正常</p>";
                    error_log($log_prefix . "SELECT权限正常");
                } catch (Exception $e) {
                    echo "<p>❌ SELECT权限异常: " . $e->getMessage() . "</p>";
                    error_log($log_prefix . "SELECT权限异常: " . $e->getMessage());
                }
                
                // 2. 测试INSERT权限
                try {
                    $db->beginTransaction();
                    $insert_test = $db->exec("INSERT INTO chat_messages (user_id, message, is_read, created_at) VALUES (1, '测试消息 - 请忽略', 1, NOW())");
                    $last_id = $db->lastInsertId();
                    echo "<p>✅ INSERT权限正常，插入ID: $last_id</p>";
                    error_log($log_prefix . "INSERT权限正常，插入ID: $last_id");
                    
                    // 3. 测试UPDATE权限
                    $update_test = $db->exec("UPDATE chat_messages SET message = '测试消息已更新 - 请忽略' WHERE id = $last_id");
                    echo "<p>✅ UPDATE权限正常</p>";
                    error_log($log_prefix . "UPDATE权限正常");
                    
                    // 4. 测试DELETE权限
                    $delete_test = $db->exec("DELETE FROM chat_messages WHERE id = $last_id");
                    echo "<p>✅ DELETE权限正常</p>";
                    error_log($log_prefix . "DELETE权限正常");
                    
                    $db->commit();
                } catch (Exception $e) {
                    $db->rollBack();
                    echo "<p>❌ 写入权限测试失败: " . $e->getMessage() . "</p>";
                    error_log($log_prefix . "写入权限测试失败: " . $e->getMessage());
                }
                
                // 显示最近的消息
                echo "<h3>最近10条消息</h3>";
                try {
                    $recent_msgs = $db->query("SELECT * FROM chat_messages ORDER BY id DESC LIMIT 10");
                    if ($recent_msgs && $recent_msgs->rowCount() > 0) {
                        echo "<table border='1'><tr><th>ID</th><th>用户ID</th><th>管理员ID</th><th>消息</th><th>已读</th><th>时间</th></tr>";
                        while ($msg = $recent_msgs->fetch(PDO::FETCH_ASSOC)) {
                            echo "<tr>";
                            echo "<td>" . $msg['id'] . "</td>";
                            echo "<td>" . $msg['user_id'] . "</td>";
                            echo "<td>" . ($msg['admin_id'] ?: 'NULL') . "</td>";
                            echo "<td>" . htmlspecialchars(substr($msg['message'], 0, 50)) . "</td>";
                            echo "<td>" . ($msg['is_read'] ? '是' : '否') . "</td>";
                            echo "<td>" . $msg['created_at'] . "</td>";
                            echo "</tr>";
                        }
                        echo "</table>";
                    } else {
                        echo "<p>没有找到消息记录</p>";
                    }
                } catch (Exception $e) {
                    echo "<p>❌ 获取最近消息失败: " . $e->getMessage() . "</p>";
                }
                
            } else {
                echo "<p>❌ 无法获取表结构</p>";
                error_log($log_prefix . "无法获取表结构: " . print_r($db->errorInfo(), true));
            }
        } else {
            echo "<p>❌ chat_messages表不存在</p>";
            error_log($log_prefix . "chat_messages表不存在");
            
            // 提供创建表的选项
            echo "<p>是否要创建chat_messages表? <a href='?create=1&confirm=1'>是</a></p>";
            
            if (isset($_GET['create']) && $_GET['create'] == 1) {
                $create_table_sql = "
                CREATE TABLE chat_messages (
                    id INT NOT NULL AUTO_INCREMENT PRIMARY KEY,
                    user_id INT NOT NULL,
                    admin_id INT NULL,
                    message TEXT NOT NULL,
                    is_read TINYINT(1) NOT NULL DEFAULT 0,
                    created_at DATETIME NOT NULL
                )
                ";
                
                try {
                    $db->exec($create_table_sql);
                    echo "<p>✅ chat_messages表创建成功</p>";
                    error_log($log_prefix . "chat_messages表创建成功");
                } catch (Exception $e) {
                    echo "<p>❌ 表创建失败: " . $e->getMessage() . "</p>";
                    error_log($log_prefix . "表创建失败: " . $e->getMessage());
                }
            }
        }
    } else {
        echo "<p>❌ 无法连接数据库</p>";
        error_log($log_prefix . "无法连接数据库");
    }
    
} catch (Exception $e) {
    echo "<p>❌ 发生异常: " . $e->getMessage() . "</p>";
    error_log($log_prefix . "检查过程中发生异常: " . $e->getMessage());
}

// 附加信息
echo "<h3>PHP环境信息</h3>";
echo "<p>PHP版本: " . phpversion() . "</p>";
echo "<p>PDO驱动: " . implode(", ", PDO::getAvailableDrivers()) . "</p>";
echo "<p>服务器软件: " . $_SERVER['SERVER_SOFTWARE'] . "</p>";
?> 