<?php
// 修正配置文件路径
include_once __DIR__ . '/../public/config.php';

class CartProduct {
    private $id;
    private $title;
    private $specs;
    private $pricing;
    private $db;
    
    public function __construct($id) {
        global $db;
        $this->db = $db;
        $this->id = $id;
        $this->loadProductData();
    }
    
    private function loadProductData() {
        try {
            // 从数据库获取产品信息
            $sql = "SELECT * FROM products WHERE id = ?";
            $stmt = $this->db->prepare($sql);
            $stmt->execute([$this->id]);
            $product = $stmt->fetch(PDO::FETCH_ASSOC);
            
            if ($product) {
                // 获取地区信息
                $locationText = '高速';
                if (isset($product['region_id'])) {
                    $areaStmt = $this->db->query("SELECT name FROM area WHERE id = " . $product['region_id']);
                    if ($area = $areaStmt->fetch()) {
                        $locationText = $area['name'];
                    }
                }
                
                // 获取线路信息
                $lineName = 'CN2线路';
                if (isset($product['line_id'])) {
                    $lineStmt = $this->db->query("SELECT name FROM line WHERE id = " . $product['line_id']);
                    if ($line = $lineStmt->fetch()) {
                        $lineName = $line['name'];
                    }
                }
                
                $this->title = $locationText . "服务器 - " . ($product['type'] ?? '基础型');
                $this->specs = [
                    'cpu' => $product['upc'] ?? '',
                    'memory' => $product['memory'] ?? '',
                    'disk' => $product['disk'] ?? '',
                    'bandwidth' => $product['bandwidth'] ?? '',
                    'ip_count' => $product['ip_count'] ?? '',
                    'traffic' => $product['traffic'] ?? '',
                    'defense' => $product['defense'] ?? '',
                    'line' => $lineName,
                    'location' => $locationText
                ];
                
                // 设置价格
                $basePrice = floatval($product['price']);
                $this->pricing = [
                    'monthly' => $basePrice,
                    'quarterly' => $basePrice * 3 * 0.95,
                    'half-year' => $basePrice * 6 * 0.98,
                    'yearly' => $basePrice * 12 * 0.9
                ];
            }
        } catch (Exception $e) {
            error_log("Error loading product data: " . $e->getMessage());
        }
    }
    
    public function getTitle() {
        return $this->title;
    }
    
    public function getSpecs() {
        return $this->specs;
    }
    
    public function getPricing() {
        return $this->pricing;
    }
    
    public function calculatePrice($period = 'monthly', $quantity = 1) {
        if (isset($this->pricing[$period])) {
            return $this->pricing[$period] * $quantity;
        }
        return 0;
    }
}

class Cart {
    private $items = [];
    
    public function addProduct($productId, $quantity = 1, $config = []) {
        $product = new CartProduct($productId);
        $this->items[] = [
            'product' => $product,
            'quantity' => $quantity,
            'config' => $config
        ];
    }
    
    public function getItems() {
        return $this->items;
    }
    
    public function getTotalPrice($period = 'monthly') {
        $total = 0;
        foreach ($this->items as $item) {
            $total += $item['product']->calculatePrice($period, $item['quantity']);
        }
        return $total;
    }
}

// 处理AJAX请求
if (isset($_GET['action'])) {
    switch ($_GET['action']) {
        case 'generate_password':
            header('Content-Type: text/plain');
            echo generateRandomPassword();
            exit;
            
        case 'get_os_versions':
            header('Content-Type: application/json');
            if (isset($_GET['brand_id']) && is_numeric($_GET['brand_id'])) {
                $brandId = intval($_GET['brand_id']);
                try {
                    $conn = getDbConnection();
                    $sql = "SELECT id, name FROM systems WHERE parent_id = ? ORDER BY sort_order, name";
                    $stmt = $conn->prepare($sql);
                    $stmt->execute([$brandId]);
                    
                    $versions = [];
                    while ($version = $stmt->fetch(PDO::FETCH_ASSOC)) {
                        $versions[] = [
                            'id' => $version['id'],
                            'name' => $version['name']
                        ];
                    }
                    
                    echo json_encode($versions);
                } catch (Exception $e) {
                    // 返回空数组和错误状态
                    http_response_code(500);
                    echo json_encode(['error' => '获取版本失败: ' . $e->getMessage()]);
                }
            } else {
                // 返回错误信息
                http_response_code(400);
                echo json_encode(['error' => '无效的品牌ID']);
            }
            exit;
    }
}

// 随机密码生成函数
function generateRandomPassword() {
    $uppercase = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ';
    $lowercase = 'abcdefghijklmnopqrstuvwxyz';
    $numbers = '0123456789';
    $special = '!@#$%^&*';  // 减少特殊字符的种类
    
    $password = '';
    
    // 确保至少包含2个大写字母
    for ($i = 0; $i < 2; $i++) {
        $password .= $uppercase[random_int(0, strlen($uppercase) - 1)];
    }
    
    // 确保至少包含2个小写字母
    for ($i = 0; $i < 2; $i++) {
        $password .= $lowercase[random_int(0, strlen($lowercase) - 1)];
    }
    
    // 确保至少包含2个数字
    for ($i = 0; $i < 2; $i++) {
        $password .= $numbers[random_int(0, strlen($numbers) - 1)];
    }
    
    // 添加1-2个特殊字符
    $special_count = random_int(1, 2);
    for ($i = 0; $i < $special_count; $i++) {
        $password .= $special[random_int(0, strlen($special) - 1)];
    }
    
    // 生成剩余字符（字母和数字）直到达到16位
    $alphanum = $uppercase . $lowercase . $numbers;
    while (strlen($password) < 16) {
        $password .= $alphanum[random_int(0, strlen($alphanum) - 1)];
    }
    
    // 打乱密码字符顺序
    $password = str_shuffle($password);
    
    return $password;
}

// 获取产品ID
$product_id = isset($_GET['id']) ? intval($_GET['id']) : 0;

// 获取用户余额
$balance = 0;
if (isset($_SESSION['member_id'])) {
    $balance = calculateUserBalance($_SESSION['member_id']);
}

// 如果提供了产品ID，获取产品信息
if ($product_id > 0) {
    try {
        $conn = getDbConnection();
        $sql = "SELECT * FROM products WHERE id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bindParam(1, $product_id, PDO::PARAM_INT);
        $stmt->execute();
        
        if ($stmt->rowCount() > 0) {
            $product = $stmt->fetch(PDO::FETCH_ASSOC);
            
            // 获取地区信息
            $regionData = [
                'regionName' => '',
                'countryName' => '',
                'locationText' => '高速',
                'parentRegions' => [],
                'allRegions' => [],
                'areaNames' => []
            ];
            
            // 构建位置文本
            $locationText = '高速';
            if (isset($product['region_id'])) {
                $areaStmt = $conn->query("SELECT name FROM area WHERE id = " . $product['region_id']);
                if ($area = $areaStmt->fetch()) {
                    $locationText = $area['name'];
                }
            }
            
            // 获取线路信息
            $lineName = 'CN2线路';
            if (isset($product['line_id'])) {
                $lineStmt = $conn->query("SELECT name FROM line WHERE id = " . $product['line_id']);
                if ($line = $lineStmt->fetch()) {
                    $lineName = $line['name'];
                }
            }
            
            // 计算价格
            $original_price = $product['price'];
            $prices = calculatePrice($original_price);
        } else {
            // 如果产品不存在，重定向到产品列表页
            header("Location: /product");
            exit;
        }
    } catch (Exception $e) {
        // 记录错误日志
        error_log("Error in cart.html: " . $e->getMessage());
        // 重定向到产品列表页
        header("Location: /product");
        exit;
    }
}

// 获取操作系统数据
$osBrands = [];
$osVersions = [];
$allOsVersionsJson = '{}'; // 用于存储所有版本的JSON数据
$debug = []; // 用于调试

try {
    $conn = getDbConnection();
    
    // 获取顶级操作系统（parent_id = 0 表示顶级分类）
    $brandSql = "SELECT id, name, sort_order FROM systems WHERE parent_id = 0 ORDER BY sort_order, name";
    $debug['brand_sql'] = $brandSql;
    $brandStmt = $conn->query($brandSql);
    
    while ($brand = $brandStmt->fetch(PDO::FETCH_ASSOC)) {
        $brandId = $brand['id'];
        $brandName = $brand['name'];
        $osBrands[$brandId] = $brandName;
        $debug['brands'][] = $brand;
        
        // 获取该操作系统下的所有版本
        $versionSql = "SELECT id, name, sort_order FROM systems WHERE parent_id = ? ORDER BY sort_order, name";
        $versionStmt = $conn->prepare($versionSql);
        $versionStmt->execute([$brandId]);
        
        $versions = [];
        while ($version = $versionStmt->fetch(PDO::FETCH_ASSOC)) {
            $versions[] = [
                'id' => $version['id'],
                'name' => $version['name']
            ];
            $debug['versions'][$brandId][] = $version;
        }
        
        $osVersions[$brandId] = $versions;
    }
    
    // 将所有版本数据编码为JSON字符串
    $allOsVersionsJson = json_encode($osVersions);
    $debugJson = json_encode($debug); // 调试信息
    
} catch (Exception $e) {
    // 记录错误日志
    error_log("Error loading operating systems: " . $e->getMessage());
    // 设置默认值，以防数据库查询失败
    $osBrands = [1 => 'Windows', 2 => 'CentOS', 3 => 'Ubuntu', 4 => 'Debian'];
    $osVersions = [
        1 => [
            ['id' => 5, 'name' => 'Windows - 2012R2 - Datacenter'],
            ['id' => 6, 'name' => 'Windows - 2016 - Datacenter']
        ],
        2 => [
            ['id' => 16, 'name' => 'CentOS - 7.0.1406 - x64']
        ],
        3 => [
            ['id' => 23, 'name' => 'Ubuntu - 16.04 - x64']
        ],
        4 => [
            ['id' => 28, 'name' => 'Debian - 10.3.3 - x64']
        ]
    ];
    $allOsVersionsJson = json_encode($osVersions);
    $debugJson = json_encode(['error' => $e->getMessage()]);
}

/**
 * 格式化金额显示
 * @param float $amount 金额
 * @return string 格式化后的金额字符串
 */
function formatAmount($amount) {
    return '$' . number_format($amount, 2);
}

/**
 * 从URL和GET参数中获取产品ID
 * @return int 产品ID，如果未找到则返回0
 */
function getProductIdFromRequest() {
    // 从GET参数获取
    if (isset($_GET['id'])) {
        return intval($_GET['id']);
    }
    
    // 从伪静态URL获取
    $request_uri = $_SERVER['REQUEST_URI'];
    if (preg_match('#/cart/([0-9]+)\.html#', $request_uri, $matches)) {
        return intval($matches[1]);
    }
    
    return 0; // 默认值
}

/**
 * 获取产品详细信息
 * @param int $product_id 产品ID
 * @return array|null 产品信息数组，如果未找到或发生错误则返回null
 */
function getProductDetails($product_id) {
    if ($product_id <= 0) {
        return null;
    }
    
    try {
        $db = getDbConnection();
        
        // 使用参数化查询安全地查询数据库
        $query = "SELECT * FROM products WHERE id = :product_id LIMIT 1";
        $stmt = $db->prepare($query);
        $stmt->bindParam(':product_id', $product_id, PDO::PARAM_INT);
        $stmt->execute();
        
        if ($stmt->rowCount() > 0) {
            $product = $stmt->fetch(PDO::FETCH_ASSOC);
            
            // 获取地区信息
            $locationText = '高速';
            if (isset($product['region_id'])) {
                $areaStmt = $db->query("SELECT name FROM area WHERE id = " . $product['region_id']);
                if ($area = $areaStmt->fetch()) {
                    $locationText = $area['name'];
                }
            }
            
            // 获取线路信息
            $lineName = 'CN2线路';
            if (isset($product['line_id'])) {
                $lineStmt = $db->query("SELECT name FROM line WHERE id = " . $product['line_id']);
                if ($line = $lineStmt->fetch()) {
                    $lineName = $line['name'];
                }
            }
            
            // 添加额外信息到产品数组
            $product['locationText'] = $locationText;
            $product['lineName'] = $lineName;
            
            return $product;
        }
    } catch (PDOException $e) {
        error_log("获取产品详情错误: " . $e->getMessage());
    }
    
    return null;
}

/**
 * 获取购物车页面所需的所有数据
 * @return array 包含购物车页面所需所有数据的关联数组
 */
function getCartPageData() {
    // 获取产品ID
    $product_id = getProductIdFromRequest();
    
    // 获取当前用户ID
    $userId = getCurrentUserId();
    
    // 初始化结果数组
    $pageData = [
        'product_id' => $product_id,
        'product' => null,
        'userId' => $userId,
        'balance' => 0,
        'locationText' => '未知位置',
        'lineName' => 'CN2线路',
        'osBrands' => [],
        'osVersions' => [],
        'allOsVersionsJson' => '{}',
        'debugJson' => '{}'
    ];
    
    // 获取用户余额
    if (isset($_SESSION['member_id'])) {
        $pageData['balance'] = calculateUserBalance($_SESSION['member_id']);
    } else if ($userId) {
        $pageData['balance'] = calculateUserBalance($userId);
    }
    
    // 如果有产品ID，获取产品详情
    if ($product_id > 0) {
        $product = getProductDetails($product_id);
        if ($product) {
            $pageData['product'] = $product;
            $pageData['locationText'] = $product['locationText'];
            $pageData['lineName'] = $product['lineName'];
        }
    }
    
    // 获取操作系统数据
    $osData = getOperatingSystemsData();
    $pageData['osBrands'] = $osData['brands'];
    $pageData['osVersions'] = $osData['versions'];
    $pageData['allOsVersionsJson'] = $osData['json'];
    $pageData['debugJson'] = $osData['debug'];
    
    return $pageData;
}

/**
 * 获取操作系统数据
 * @return array 包含操作系统品牌、版本和调试信息的数组
 */
function getOperatingSystemsData() {
    $result = [
        'brands' => [],
        'versions' => [],
        'json' => '{}',
        'debug' => '{}'
    ];
    
    $debug = []; // 用于调试
    
    try {
        $conn = getDbConnection();
        
        // 获取顶级操作系统（parent_id = 0 表示顶级分类）
        $brandSql = "SELECT id, name, sort_order FROM systems WHERE parent_id = 0 ORDER BY sort_order, name";
        $debug['brand_sql'] = $brandSql;
        $brandStmt = $conn->query($brandSql);
        
        $osBrands = [];
        $osVersions = [];
        
        while ($brand = $brandStmt->fetch(PDO::FETCH_ASSOC)) {
            $brandId = $brand['id'];
            $brandName = $brand['name'];
            $osBrands[$brandId] = $brandName;
            $debug['brands'][] = $brand;
            
            // 获取该操作系统下的所有版本
            $versionSql = "SELECT id, name, sort_order FROM systems WHERE parent_id = ? ORDER BY sort_order, name";
            $versionStmt = $conn->prepare($versionSql);
            $versionStmt->execute([$brandId]);
            
            $versions = [];
            while ($version = $versionStmt->fetch(PDO::FETCH_ASSOC)) {
                $versions[] = [
                    'id' => $version['id'],
                    'name' => $version['name']
                ];
                $debug['versions'][$brandId][] = $version;
            }
            
            $osVersions[$brandId] = $versions;
        }
        
        $result['brands'] = $osBrands;
        $result['versions'] = $osVersions;
        $result['json'] = json_encode($osVersions);
        $result['debug'] = json_encode($debug);
        
    } catch (Exception $e) {
        // 记录错误日志
        error_log("Error loading operating systems: " . $e->getMessage());
        // 设置默认值，以防数据库查询失败
        $result['brands'] = [1 => 'Windows', 2 => 'CentOS', 3 => 'Ubuntu', 4 => 'Debian'];
        $result['versions'] = [
            1 => [
                ['id' => 5, 'name' => 'Windows - 2012R2 - Datacenter'],
                ['id' => 6, 'name' => 'Windows - 2016 - Datacenter']
            ],
            2 => [
                ['id' => 16, 'name' => 'CentOS - 7.0.1406 - x64']
            ],
            3 => [
                ['id' => 23, 'name' => 'Ubuntu - 16.04 - x64']
            ],
            4 => [
                ['id' => 28, 'name' => 'Debian - 10.3.3 - x64']
            ]
        ];
        $result['json'] = json_encode($result['versions']);
        $result['debug'] = json_encode(['error' => $e->getMessage()]);
    }
    
    return $result;
}
?>
