<?php
/**
 * de_cloud_code.php - 德国云服务器数据处理逻辑
 * 用于获取德国云服务器相关数据
 */

// 防止直接访问
if (!defined('INCLUDED_FROM_VIEW')) {
    header('HTTP/1.0 403 Forbidden');
    exit;
}

// 引入数据库配置（如果需要）
if (!function_exists('getDbConnection')) {
    require_once dirname(dirname(__FILE__)) . '/config/database.php';
}

/**
 * 获取价格显示的倍率
 * 用于根据不同情况调整价格显示
 * 
 * @return float 价格倍率
 */
// 避免重复声明函数
if (!function_exists('getMultiplier')) {
    function getMultiplier() {
        // 默认倍率为1，可根据业务需求调整
        return 1.0;
    }
}

/**
 * 获取德国云服务器产品数据
 * 查询条件：region_id=24（德国地区）且tags包含7
 * 
 * @param bool $debug 是否开启调试模式
 * @return array 德国云服务器产品数据
 */
function getDeCloudProducts_Main($debug = false) {
    // 获取数据库连接
    $db = getDbConnection();
    $result = [];
    
    try {
        // 构建SQL查询语句 - 筛选德国云服务器(region_id=24，tags包含7的产品)
        $query = "SELECT * FROM products 
                 WHERE region_id = 24 
                 AND FIND_IN_SET(7, tags) 
                 AND status = 1 
                 ORDER BY price ASC";
        
        $stmt = $db->query($query);
        $products = $stmt->fetchAll();
        
        // 计算记录数量
        $count = count($products);
        
        // 如果开启调试模式，打印查询结果
        if ($debug) {
            echo "<div style='background:#f5f5f5; padding:15px; margin:15px; border:1px solid #ddd;'>";
            echo "<h3>查询结果</h3>";
            echo "<p>找到 <strong>{$count}</strong> 条记录</p>";
            
            if ($count > 0) {
                echo "<p>第一条记录:</p>";
                echo "<pre>";
                print_r($products[0]);
                echo "</pre>";
            }
            
            echo "<p>SQL查询:</p>";
            echo "<pre>{$query}</pre>";
            echo "</div>";
        }
        
        // 返回结果
        return $products;
        
    } catch (PDOException $e) {
        // 错误处理
        if ($debug) {
            echo "<div style='background:#f5f5f5; padding:15px; margin:15px; border:1px solid #ddd;'>";
            echo "<h3>查询错误</h3>";
            echo "<p>错误信息: " . $e->getMessage() . "</p>";
            echo "<p>SQL查询: {$query}</p>";
            echo "</div>";
        }
        
        // 记录错误日志
        error_log("德国云服务器数据查询错误: " . $e->getMessage());
        
        // 返回空数组
        return [];
    }
}

/**
 * 获取德国云服务器详细产品信息
 * 
 * @param int $productId 产品ID
 * @param bool $debug 是否开启调试模式
 * @return array|bool 产品详细信息或false
 */
function getDeCloudProductDetails($productId, $debug = false) {
    // 获取数据库连接
    $db = getDbConnection();
    
    try {
        // 构建SQL查询语句 - 获取指定ID的产品详情
        $query = "SELECT * FROM products WHERE id = :id AND region_id = 24 AND status = 1";
        $stmt = $db->prepare($query);
        $stmt->bindParam(':id', $productId, PDO::PARAM_INT);
        $stmt->execute();
        
        $product = $stmt->fetch(PDO::FETCH_ASSOC);
        
        // 如果调试模式开启，输出查询结果
        if ($debug) {
            echo "<div style='background:#f5f5f5; padding:15px; margin:15px; border:1px solid #ddd;'>";
            echo "<h3>产品详情查询</h3>";
            echo "<p>产品ID: {$productId}</p>";
            
            if ($product) {
                echo "<p>查询成功</p>";
                echo "<pre>";
                print_r($product);
                echo "</pre>";
            } else {
                echo "<p>未找到产品</p>";
            }
            
            echo "<p>SQL查询: {$query}</p>";
            echo "</div>";
        }
        
        return $product ? $product : false;
        
    } catch (PDOException $e) {
        // 错误处理
        if ($debug) {
            echo "<div style='background:#f5f5f5; padding:15px; margin:15px; border:1px solid #ddd;'>";
            echo "<h3>产品详情查询错误</h3>";
            echo "<p>错误信息: " . $e->getMessage() . "</p>";
            echo "</div>";
        }
        
        // 记录错误日志
        error_log("德国云服务器产品详情查询错误: " . $e->getMessage());
        
        return false;
    }
} 