<?php
/**
 * 德国服务器页面数据处理文件
 * 提供德国服务器的不同类型产品数据获取函数
 */

// 确保文件被包含而非直接访问
defined('INCLUDED_FROM_VIEW') or define('INCLUDED_FROM_VIEW', true);

// 引入数据库配置
require_once dirname(dirname(__FILE__)) . '/config/database.php';

/**
 * 获取德国云服务器产品数据
 * 
 * @param bool $debug 是否开启调试模式打印数据
 * @return array 查询结果数组
 */
function getGermanyCloudProducts($debug = false) {
    $db = getDbConnection();
    $result = [];
    
    try {
        // 构建SQL查询语句 - 德国云服务器(region_id=24, tag=7)
        // 使用FIND_IN_SET函数更精确地查找包含标签7的记录
        $query = "SELECT * FROM products 
                 WHERE region_id = 24 
                 AND FIND_IN_SET('7', tags) 
                 AND status = 1 
                 ORDER BY price ASC";
        
        $stmt = $db->query($query);
        $products = $stmt->fetchAll(PDO::FETCH_ASSOC);
        
        // 如果调试模式开启，记录一些信息
        if ($debug) {
            echo "<pre>";
            echo "SQL查询: " . $query . "\n";
            echo "找到记录数: " . count($products) . "\n";
            if (count($products) > 0) {
                echo "第一条记录: \n";
                print_r($products[0]);
            }
            echo "</pre>";
        }
        
        // 处理调试信息和产品数据
        $result = processProductsData($db, $products, $query, $debug);
    } catch (PDOException $e) {
        // 错误处理
        handleDatabaseError($e, $debug);
        $result = [];
    }
    
    return $result;
}

/**
 * 获取德国裸机云服务器产品数据
 * 
 * @param bool $debug 是否开启调试模式打印数据
 * @return array 查询结果数组
 */
function getGermanyBareMetalProducts($debug = false) {
    $db = getDbConnection();
    $result = [];
    
    try {
        // 构建SQL查询语句 - 德国裸机云服务器(region_id=24, tag=9)
        $query = "SELECT * FROM products 
                 WHERE region_id = 24 
                 AND FIND_IN_SET('9', tags) 
                 AND status = 1 
                 ORDER BY price ASC";
        
        $stmt = $db->query($query);
        $products = $stmt->fetchAll(PDO::FETCH_ASSOC);
        
        // 处理调试信息和产品数据
        $result = processProductsData($db, $products, $query, $debug);
    } catch (PDOException $e) {
        // 错误处理
        handleDatabaseError($e, $debug);
        $result = [];
    }
    
    return $result;
}

/**
 * 获取德国站群服务器产品数据
 * 
 * @param bool $debug 是否开启调试模式打印数据
 * @return array 查询结果数组
 */
function getGermanyClusterProducts($debug = false) {
    $db = getDbConnection();
    $result = [];
    
    try {
        // 构建SQL查询语句 - 德国站群服务器(region_id=24, tag=23)
        $query = "SELECT * FROM products 
                 WHERE region_id = 24 
                 AND FIND_IN_SET('23', tags) 
                 AND status = 1 
                 ORDER BY price ASC";
        
        $stmt = $db->query($query);
        $products = $stmt->fetchAll(PDO::FETCH_ASSOC);
        
        // 处理调试信息和产品数据
        $result = processProductsData($db, $products, $query, $debug);
    } catch (PDOException $e) {
        // 错误处理
        handleDatabaseError($e, $debug);
        $result = [];
    }
    
    return $result;
}

/**
 * 处理产品数据和调试信息
 * 
 * @param PDO $db 数据库连接
 * @param array $products 产品数据
 * @param string $query SQL查询语句
 * @param bool $debug 是否开启调试模式
 * @return array 处理后的结果
 */
function processProductsData($db, $products, $query, $debug = false) {
    $count = count($products);
    $result = [
        'products' => $products,
        'count' => $count
    ];
    
    // 如果开启调试模式，打印查询结果
    if ($debug) {
        echo "<div style='background:#f5f5f5; padding:15px; margin:15px; border:1px solid #ddd;'>";
        echo "<h3>查询结果</h3>";
        echo "<p>找到 <strong>{$count}</strong> 条记录</p>";
        
        if ($count > 0) {
            echo "<table border='1' cellpadding='5' cellspacing='0' style='border-collapse:collapse; width:100%;'>";
            echo "<tr style='background:#eee;'>";
            echo "<th>ID</th>";
            echo "<th>产品名称</th>";
            echo "<th>CPU</th>";
            echo "<th>内存</th>";
            echo "<th>硬盘</th>";
            echo "<th>带宽</th>";
            echo "<th>IP数量</th>";
            echo "<th>原价</th>";
            echo "<th>显示价格</th>";
            echo "<th>标签</th>";
            echo "</tr>";
            
            foreach ($products as $product) {
                echo "<tr>";
                echo "<td>" . $product['id'] . "</td>";
                echo "<td>" . $product['name'] . "</td>";
                echo "<td>" . $product['cpu'] . "</td>";
                echo "<td>" . $product['memory'] . "</td>";
                echo "<td>" . $product['disk'] . "</td>";
                echo "<td>" . $product['bandwidth'] . "</td>";
                echo "<td>" . $product['ip_count'] . "</td>";
                echo "<td>$" . number_format($product['price'], 2) . "</td>";
                echo "<td>$" . number_format($product['price'] * getMultiplier(), 2) . "</td>";
                echo "<td>" . $product['tags'] . "</td>";
                echo "</tr>";
            }
            
            echo "</table>";
        } else {
            echo "<p>没有找到匹配的记录</p>";
        }
        
        echo "<p>SQL: " . htmlspecialchars($query) . "</p>";
        echo "</div>";
    }
    
    return $result;
}

/**
 * 处理数据库错误
 * 
 * @param PDOException $e 异常对象
 * @param bool $debug 是否开启调试模式
 */
function handleDatabaseError($e, $debug = false) {
    if ($debug) {
        echo "<div style='background:#f8d7da; padding:15px; margin:15px; border:1px solid #f5c6cb;'>";
        echo "<h3>查询错误</h3>";
        echo "<p>错误信息: <strong>{$e->getMessage()}</strong></p>";
        echo "<p>错误代码: <strong>{$e->getCode()}</strong></p>";
        echo "<p>发生在: <strong>{$e->getFile()}</strong> 行 <strong>{$e->getLine()}</strong></p>";
        echo "</div>";
    }
    // 在正式环境中可以记录到日志
    error_log("Database Error: " . $e->getMessage());
} 
