<?php
/**
 * jp_code.php - 日本服务器数据处理逻辑
 * 用于获取日本服务器相关数据
 */

// 防止直接访问
if (!defined('INCLUDED_FROM_VIEW')) {
    header('HTTP/1.0 403 Forbidden');
    exit;
}

// 引入数据库配置（如果需要）
if (!function_exists('getDbConnection')) {
    require_once dirname(dirname(__FILE__)) . '/config/database.php';
}

/**
 * 获取价格显示的倍率
 * 用于根据不同情况调整价格显示
 * 
 * @return float 价格倍率
 */
// 避免重复声明函数
if (!function_exists('getMultiplier')) {
    function getMultiplier() {
        // 默认倍率为1，可根据业务需求调整
        return 1.0;
    }
}

/**
 * 获取日本物理服务器产品数据
 * 查询条件：region_id=8（日本地区）且tags包含8
 * 
 * @param bool $debug 是否开启调试模式
 * @return array 日本物理服务器产品数据
 */
function getJpServerProducts($debug = false) {
    // 获取数据库连接
    $db = getDbConnection();
    $result = [];
    
    try {
        // 构建SQL查询语句
        $query = "SELECT * FROM products 
                 WHERE region_id = 8 
                 AND FIND_IN_SET(8, tags) 
                 AND status = 1 
                 ORDER BY price ASC";
        
        $stmt = $db->query($query);
        $products = $stmt->fetchAll();
        
        // 计算记录数量
        $count = count($products);
        
        // 如果开启调试模式，打印查询结果
        if ($debug) {
            echo "<div style='background:#f5f5f5; padding:15px; margin:15px; border:1px solid #ddd;'>";
            echo "<h3>查询结果</h3>";
            echo "<p>找到 <strong>{$count}</strong> 条记录</p>";
            
            if ($count > 0) {
                echo "<table style='width:100%; border-collapse:collapse; margin-top:10px;'>";
                echo "<tr style='background:#eee;'>";
                echo "<th style='padding:8px; text-align:left; border:1px solid #ddd;'>ID</th>";
                echo "<th style='padding:8px; text-align:left; border:1px solid #ddd;'>产品名称</th>";
                echo "<th style='padding:8px; text-align:left; border:1px solid #ddd;'>CPU</th>";
                echo "<th style='padding:8px; text-align:left; border:1px solid #ddd;'>内存</th>";
                echo "<th style='padding:8px; text-align:left; border:1px solid #ddd;'>硬盘</th>";
                echo "<th style='padding:8px; text-align:left; border:1px solid #ddd;'>带宽</th>";
                echo "<th style='padding:8px; text-align:left; border:1px solid #ddd;'>价格</th>";
                echo "</tr>";
                
                foreach ($products as $product) {
                    echo "<tr>";
                    echo "<td style='padding:8px; text-align:left; border:1px solid #ddd;'>{$product['id']}</td>";
                    echo "<td style='padding:8px; text-align:left; border:1px solid #ddd;'>{$product['name']}</td>";
                    echo "<td style='padding:8px; text-align:left; border:1px solid #ddd;'>{$product['cpu']}</td>";
                    echo "<td style='padding:8px; text-align:left; border:1px solid #ddd;'>{$product['memory']}</td>";
                    echo "<td style='padding:8px; text-align:left; border:1px solid #ddd;'>{$product['disk']}</td>";
                    echo "<td style='padding:8px; text-align:left; border:1px solid #ddd;'>{$product['bandwidth']}</td>";
                    echo "<td style='padding:8px; text-align:left; border:1px solid #ddd;'>\${$product['price']}</td>";
                    echo "</tr>";
                }
                
                echo "</table>";
            }
            
            echo "</div>";
        }
        
        // 处理产品数据（添加额外信息）
        foreach ($products as &$product) {
            // 计算显示价格（应用倍数）
            $product['display_price'] = $product['price'] * getMultiplier();
            
            // 格式化显示价格
            $product['formatted_price'] = number_format($product['display_price'], 2, '.', ',');
            
            // 处理标签
            if (!empty($product['tags'])) {
                $tagIds = explode(',', $product['tags']);
                $product['tag_names'] = getTagNames($db, $tagIds);
            } else {
                $product['tag_names'] = [];
            }
        }
        
        $result = $products;
    } catch (Exception $e) {
        // 错误处理
        if ($debug) {
            echo "<div style='background:#f8d7da; padding:15px; margin:15px; border:1px solid #f5c6cb;'>";
            echo "<h3>数据库错误</h3>";
            echo "<p>" . $e->getMessage() . "</p>";
            echo "</div>";
        }
        error_log("获取日本物理服务器产品错误: " . $e->getMessage());
        $result = [];
    }
    
    return $result;
}

/**
 * 获取日本云服务器产品数据
 * 查询条件：region_id=8（日本地区）且tags包含7
 * 
 * @param bool $debug 是否开启调试模式
 * @return array 日本云服务器产品数据
 */
function getJpCloudProducts($debug = false) {
    // 获取数据库连接
    $db = getDbConnection();
    $result = [];
    
    try {
        // 构建SQL查询语句 - 筛选日本云服务器(tags包含7的产品)
        $query = "SELECT * FROM products 
                 WHERE region_id = 8 
                 AND FIND_IN_SET(7, tags) 
                 AND status = 1 
                 ORDER BY price ASC";
        
        $stmt = $db->query($query);
        $products = $stmt->fetchAll();
        
        // 计算记录数量
        $count = count($products);
        
        // 如果开启调试模式，打印查询结果
        if ($debug) {
            echo "<div style='background:#f5f5f5; padding:15px; margin:15px; border:1px solid #ddd;'>";
            echo "<h3>日本云服务器查询结果</h3>";
            echo "<p>找到 <strong>{$count}</strong> 条记录</p>";
            
            if ($count > 0) {
                echo "<table style='width:100%; border-collapse:collapse; margin-top:10px;'>";
                echo "<tr style='background:#eee;'>";
                echo "<th style='padding:8px; text-align:left; border:1px solid #ddd;'>ID</th>";
                echo "<th style='padding:8px; text-align:left; border:1px solid #ddd;'>产品名称</th>";
                echo "<th style='padding:8px; text-align:left; border:1px solid #ddd;'>CPU</th>";
                echo "<th style='padding:8px; text-align:left; border:1px solid #ddd;'>内存</th>";
                echo "<th style='padding:8px; text-align:left; border:1px solid #ddd;'>硬盘</th>";
                echo "<th style='padding:8px; text-align:left; border:1px solid #ddd;'>带宽</th>";
                echo "<th style='padding:8px; text-align:left; border:1px solid #ddd;'>价格</th>";
                echo "</tr>";
                
                foreach ($products as $product) {
                    echo "<tr>";
                    echo "<td style='padding:8px; text-align:left; border:1px solid #ddd;'>{$product['id']}</td>";
                    echo "<td style='padding:8px; text-align:left; border:1px solid #ddd;'>{$product['name']}</td>";
                    echo "<td style='padding:8px; text-align:left; border:1px solid #ddd;'>{$product['cpu']}</td>";
                    echo "<td style='padding:8px; text-align:left; border:1px solid #ddd;'>{$product['memory']}</td>";
                    echo "<td style='padding:8px; text-align:left; border:1px solid #ddd;'>{$product['disk']}</td>";
                    echo "<td style='padding:8px; text-align:left; border:1px solid #ddd;'>{$product['bandwidth']}</td>";
                    echo "<td style='padding:8px; text-align:left; border:1px solid #ddd;'>\${$product['price']}</td>";
                    echo "</tr>";
                }
                
                echo "</table>";
            }
            
            echo "</div>";
        }
        
        // 处理产品数据（添加额外信息）
        foreach ($products as &$product) {
            // 计算显示价格（应用倍数）
            $product['display_price'] = $product['price'] * getMultiplier();
            
            // 格式化显示价格
            $product['formatted_price'] = number_format($product['display_price'], 2, '.', ',');
            
            // 处理标签
            if (!empty($product['tags'])) {
                $tagIds = explode(',', $product['tags']);
                $product['tag_names'] = getTagNames($db, $tagIds);
            } else {
                $product['tag_names'] = [];
            }
        }
        
        $result = $products;
    } catch (Exception $e) {
        // 错误处理
        if ($debug) {
            echo "<div style='background:#f8d7da; padding:15px; margin:15px; border:1px solid #f5c6cb;'>";
            echo "<h3>数据库错误</h3>";
            echo "<p>" . $e->getMessage() . "</p>";
            echo "</div>";
        }
        error_log("获取日本云服务器产品错误: " . $e->getMessage());
        $result = [];
    }
    
    return $result;
}

/**
 * 获取标签名称
 *
 * @param PDO $db 数据库连接
 * @param array $tagIds 标签ID数组
 * @return array 标签名称数组
 */
function getTagNames($db, $tagIds) {
    $tagNames = [];
    
    if (empty($tagIds)) {
        return $tagNames;
    }
    
    try {
        $placeholders = implode(',', array_fill(0, count($tagIds), '?'));
        $query = "SELECT id, name FROM tags WHERE id IN ($placeholders)";
        
        $stmt = $db->prepare($query);
        
        // 绑定参数
        foreach ($tagIds as $index => $id) {
            $stmt->bindValue($index + 1, $id);
        }
        
        $stmt->execute();
        
        while ($tag = $stmt->fetch()) {
            $tagNames[$tag['id']] = $tag['name'];
        }
    } catch (Exception $e) {
        error_log("获取标签名称错误: " . $e->getMessage());
    }
    
    return $tagNames;
}

/**
 * 主函数：获取日本服务器产品数据
 * 直接从数据库获取数据
 * 
 * @param bool $debug 是否开启调试模式
 * @return array 日本服务器产品数据
 */
function getJpProducts($debug = false) {
    return getJpServerProducts($debug);
} 