<?php
/**
 * kr_code.php - 韩国服务器数据处理逻辑
 * 用于获取韩国服务器相关数据
 */

// 防止直接访问
if (!defined('INCLUDED_FROM_VIEW')) {
    header('HTTP/1.0 403 Forbidden');
    exit;
}

// 引入数据库配置（如果需要）
if (!function_exists('getDbConnection')) {
    require_once dirname(dirname(__FILE__)) . '/config/database.php';
}

/**
 * 获取价格显示的倍率
 * 用于根据不同情况调整价格显示
 * 
 * @return float 价格倍率
 */
// 避免重复声明函数
if (!function_exists('getMultiplier')) {
    function getMultiplier() {
        // 默认倍率为1，可根据业务需求调整
        return 1.0;
    }
}

/**
 * 获取韩国服务器产品数据
 * 查询条件：region_id=19（韩国地区）且tags包含8
 * 
 * @param bool $debug 是否开启调试模式
 * @return array 韩国服务器产品数据
 */
function getKrProducts($debug = false) {
    // 获取数据库连接
    $db = getDbConnection();
    $result = [];
    
    try {
        // 构建SQL查询语句
        $query = "SELECT * FROM products 
                 WHERE region_id = 19 
                 AND FIND_IN_SET(8, tags) 
                 AND status = 1 
                 ORDER BY price ASC";
        
        $stmt = $db->query($query);
        $products = $stmt->fetchAll();
        
        // 计算记录数量
        $count = count($products);
        
        // 如果开启调试模式，打印查询结果
        if ($debug) {
            echo "<div style='background:#f5f5f5; padding:15px; margin:15px; border:1px solid #ddd;'>";
            echo "<h3>查询结果</h3>";
            echo "<p>找到 <strong>{$count}</strong> 条记录</p>";
            
            if ($count > 0) {
                echo "<table style='width:100%; border-collapse:collapse; margin-top:10px;'>";
                echo "<tr style='background:#eee;'>";
                echo "<th style='padding:8px; border:1px solid #ddd;'>ID</th>";
                echo "<th style='padding:8px; border:1px solid #ddd;'>名称</th>";
                echo "<th style='padding:8px; border:1px solid #ddd;'>CPU</th>";
                echo "<th style='padding:8px; border:1px solid #ddd;'>内存</th>";
                echo "<th style='padding:8px; border:1px solid #ddd;'>硬盘</th>";
                echo "<th style='padding:8px; border:1px solid #ddd;'>带宽</th>";
                echo "<th style='padding:8px; border:1px solid #ddd;'>IP数</th>";
                echo "<th style='padding:8px; border:1px solid #ddd;'>价格</th>";
                echo "</tr>";
                
                foreach ($products as $product) {
                    echo "<tr>";
                    echo "<td style='padding:8px; border:1px solid #ddd;'>{$product['id']}</td>";
                    echo "<td style='padding:8px; border:1px solid #ddd;'>{$product['name']}</td>";
                    echo "<td style='padding:8px; border:1px solid #ddd;'>{$product['cpu']}</td>";
                    echo "<td style='padding:8px; border:1px solid #ddd;'>{$product['memory']}</td>";
                    echo "<td style='padding:8px; border:1px solid #ddd;'>{$product['disk']}</td>";
                    echo "<td style='padding:8px; border:1px solid #ddd;'>{$product['bandwidth']}</td>";
                    echo "<td style='padding:8px; border:1px solid #ddd;'>{$product['ip_count']}</td>";
                    echo "<td style='padding:8px; border:1px solid #ddd;'>\${$product['price']}</td>";
                    echo "</tr>";
                }
                
                echo "</table>";
            } else {
                echo "<p>没有找到符合条件的记录</p>";
            }
            
            echo "</div>";
        }
        
        return $products;
    } catch (PDOException $e) {
        if ($debug) {
            echo "<div style='background:#f8d7da; padding:15px; margin:15px; border:1px solid #f5c6cb;'>";
            echo "<h3>数据库错误</h3>";
            echo "<p>" . $e->getMessage() . "</p>";
            echo "</div>";
        }
        
        error_log("获取韩国服务器产品错误: " . $e->getMessage());
        return [];
    }
} 