<?php
/**
 * 新闻列表页面逻辑处理文件
 * 处理新闻列表的查询、分页和分类显示等功能
 */

// 先定义ROOT_PATH（如果不存在）
if (!defined('ROOT_PATH')) {
    define('ROOT_PATH', dirname(__DIR__));
}

// 引入必要的配置文件
include_once ROOT_PATH . '/public/config.php';
require_once ROOT_PATH . '/config/database.php';

/**
 * 获取新闻数据
 * 
 * @return array 包含新闻列表、分类和分页信息的数组
 */
function getNewsData() {
    // 获取数据库连接
    $db = getDbConnection();
    
    // 获取请求参数
    $category_id = isset($_GET['category_id']) ? intval($_GET['category_id']) : 0;
    $page = isset($_GET['page']) ? intval($_GET['page']) : 1;
    $limit = 10; // 每页显示的数量
    $offset = ($page - 1) * $limit;
    
    // 获取所有新闻分类
    $categoryQuery = "SELECT * FROM news_category ORDER BY sort_order ASC";
    $categories = $db->query($categoryQuery)->fetchAll(PDO::FETCH_ASSOC);
    
    // 构建查询条件
    $where = $category_id > 0 ? "WHERE category_id = {$category_id}" : "";
    
    // 查询总数
    $countSql = "SELECT COUNT(*) as total FROM news {$where}";
    $countResult = $db->query($countSql);
    $total = $countResult->fetch(PDO::FETCH_ASSOC)['total'];
    
    // 查询新闻列表
    $sql = "SELECT n.*, c.name as category_name 
            FROM news n 
            LEFT JOIN news_category c ON n.category_id = c.id 
            {$where}
            ORDER BY n.sort_order ASC, n.created_at DESC 
            LIMIT {$offset}, {$limit}";
            
    $newsList = $db->query($sql)->fetchAll(PDO::FETCH_ASSOC);
    
    // 计算分页信息
    $totalPages = ceil($total / $limit);
    
    // 返回数据
    return [
        'newsList' => $newsList,
        'categories' => $categories,
        'pagination' => [
            'page' => $page,
            'limit' => $limit,
            'total' => $total,
            'totalPages' => $totalPages,
            'category_id' => $category_id
        ]
    ];
}

/**
 * 生成分页HTML
 * 
 * @param array $pagination 分页信息数组
 * @return string 分页HTML代码
 */
function generatePaginationHtml($pagination) {
    // 提取分页信息
    $page = $pagination['page'];
    $totalPages = $pagination['totalPages'];
    $category_id = $pagination['category_id'];
    
    // 如果总页数小于等于1，不显示分页
    if ($totalPages <= 1) {
        return '';
    }
    
    $html = '<div class="page-nav">';
    
    // 定义显示的页码范围
    $pageRange = 2; // 当前页前后各显示的页码数
    $startPage = max(1, $page - $pageRange);
    $endPage = min($totalPages, $page + $pageRange);
    
    // 首页
    if ($page > 1) {
        $html .= '<a href="?page=1' . ($category_id ? '&category_id=' . $category_id : '') . '" class="page-nav-item page-first" title="首页"><i class="material-icons">first_page</i></a>';
    } else {
        $html .= '<span class="page-nav-item page-first disabled"><i class="material-icons">first_page</i></span>';
    }
    
    // 上一页
    if ($page > 1) {
        $html .= '<a href="?page=' . ($page - 1) . ($category_id ? '&category_id=' . $category_id : '') . '" class="page-nav-item page-prev" title="上一页"><i class="material-icons">chevron_left</i></a>';
    } else {
        $html .= '<span class="page-nav-item page-prev disabled"><i class="material-icons">chevron_left</i></span>';
    }
    
    // 显示第一页和省略号
    if ($startPage > 1) {
        $html .= '<a href="?page=1' . ($category_id ? '&category_id=' . $category_id : '') . '" class="page-number">1</a>';
        if ($startPage > 2) {
            $html .= '<span class="page-ellipsis">...</span>';
        }
    }
    
    // 页码
    for ($i = $startPage; $i <= $endPage; $i++) {
        if ($i == $page) {
            $html .= '<a href="javascript:void(0);" class="page-number active">' . $i . '</a>';
        } else {
            $html .= '<a href="?page=' . $i . ($category_id ? '&category_id=' . $category_id : '') . '" class="page-number">' . $i . '</a>';
        }
    }
    
    // 显示最后一页和省略号
    if ($endPage < $totalPages) {
        if ($endPage < $totalPages - 1) {
            $html .= '<span class="page-ellipsis">...</span>';
        }
        $html .= '<a href="?page=' . $totalPages . ($category_id ? '&category_id=' . $category_id : '') . '" class="page-number">' . $totalPages . '</a>';
    }
    
    // 下一页
    if ($page < $totalPages) {
        $html .= '<a href="?page=' . ($page + 1) . ($category_id ? '&category_id=' . $category_id : '') . '" class="page-nav-item page-next" title="下一页"><i class="material-icons">chevron_right</i></a>';
    } else {
        $html .= '<span class="page-nav-item page-next disabled"><i class="material-icons">chevron_right</i></span>';
    }
    
    // 末页
    if ($page < $totalPages) {
        $html .= '<a href="?page=' . $totalPages . ($category_id ? '&category_id=' . $category_id : '') . '" class="page-nav-item page-last" title="末页"><i class="material-icons">last_page</i></a>';
    } else {
        $html .= '<span class="page-nav-item page-last disabled"><i class="material-icons">last_page</i></span>';
    }
    
    // 页码信息
    $html .= '<span class="page-info">第 ' . $page . ' 页 / 共 ' . $totalPages . ' 页</span>';
    
    $html .= '</div>';
    
    return $html;
}

/**
 * 获取热门文章列表
 * 
 * @param int $limit 获取的文章数量，默认为10条
 * @return array 热门文章列表
 */
function getHotNews($limit = 10) {
    // 获取数据库连接
    $db = getDbConnection();
    
    // 查询访问量最高的文章
    $sql = "SELECT id, title, views 
            FROM news 
            WHERE status = 1 
            ORDER BY views DESC, created_at DESC 
            LIMIT {$limit}";
            
    $hotNews = $db->query($sql)->fetchAll(PDO::FETCH_ASSOC);
    
    // 如果从数据库获取的文章数量少于请求的限制，添加一些默认文章
    if (count($hotNews) < $limit) {
        $defaultArticles = [
            ['id' => 101, 'title' => '香港服务器和美国服务器哪个更适合中国大陆访问？', 'views' => 9870],
            ['id' => 102, 'title' => '服务器被攻击后如何快速恢复和防御', 'views' => 8760],
            ['id' => 103, 'title' => '2023年云服务器价格趋势分析', 'views' => 7650],
            ['id' => 104, 'title' => '服务器硬件选择指南：CPU、内存与存储', 'views' => 6540],
            ['id' => 105, 'title' => '新手必读：服务器基础知识全解析', 'views' => 5430],
            ['id' => 106, 'title' => '高防服务器如何抵御DDoS攻击', 'views' => 4320],
            ['id' => 107, 'title' => '云服务器与物理服务器的对比分析', 'views' => 3210],
            ['id' => 108, 'title' => '服务器性能优化的十大技巧', 'views' => 2100],
            ['id' => 109, 'title' => '如何选择最适合的服务器操作系统', 'views' => 1980],
            ['id' => 110, 'title' => '服务器安全防护最佳实践指南', 'views' => 1870]
        ];
        
        // 计算需要添加的默认文章数量
        $neededArticles = $limit - count($hotNews);
        
        // 添加默认文章到结果集
        for ($i = 0; $i < $neededArticles && $i < count($defaultArticles); $i++) {
            $hotNews[] = $defaultArticles[$i];
        }
    }
    
    return $hotNews;
}
