<?php
/**
 * 产品详情页逻辑处理文件
 * 处理所有与产品详情相关的数据获取和逻辑运算
 */

// 确保文件被包含而非直接访问
if (!defined('INCLUDED_FROM_VIEW')) {
    header("HTTP/1.0 403 Forbidden");
    exit;
}

// 先定义ROOT_PATH（如果不存在）
if (!defined('ROOT_PATH')) {
    define('ROOT_PATH', dirname(__DIR__));
}

// 引入数据库配置文件
require_once ROOT_PATH . '/config/database.php';

/**
 * 获取产品详情
 * @param int $product_id 产品ID
 * @return array|null 产品信息数组或null
 */
function getProductDetails($product_id) {
    $conn = getDbConnection();
    $sql = "SELECT * FROM products WHERE id = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bindParam(1, $product_id, PDO::PARAM_INT);
    $stmt->execute();
    if ($stmt->rowCount() > 0) {
        return $stmt->fetch(PDO::FETCH_ASSOC);
    }
    return null;
}

/**
 * 获取地区数据
 * @return array 包含区域数据的数组
 */
function getRegionData() {
    $conn = getDbConnection();
    $result = [
        'regionName' => '',
        'countryName' => '',
        'locationText' => '高速',  // 修改默认值，与产品名称保持一致
        'parentRegions' => [],
        'allRegions' => [],
        'areaNames' => []
    ];
    
    try {
        // 获取所有地区数据
        $areaStmt = $conn->query("SELECT id, name FROM area");
        while ($area = $areaStmt->fetch()) {
            $result['areaNames'][$area['id']] = $area['name'];
        }
        
        // 获取一级地区（parent_id为null或0的记录）
        $parentQuery = "SELECT id, name, slug FROM area WHERE (parent_id IS NULL OR parent_id = 0) AND status = 1 ORDER BY sort_order ASC";
        $parentStmt = $conn->query($parentQuery);
        $result['parentRegions'] = $parentStmt->fetchAll();

        // 获取所有地区
        $regionQuery = "SELECT id, name, parent_id, slug FROM area WHERE status = 1 ORDER BY sort_order ASC";
        $regionStmt = $conn->query($regionQuery);
        $result['allRegions'] = $regionStmt->fetchAll();
    } catch (PDOException $e) {
        // 发生错误时使用默认值
    }
    
    return $result;
}

/**
 * 根据产品和区域数据构建位置文本
 * @param array $product 产品信息
 * @param array $regionData 区域数据
 * @return string 构建的位置文本
 */
function buildLocationText($product, $regionData) {
    $regionName = '';
    $countryName = '';
    
    // 获取当前产品的地区和国家信息
    if (isset($product['region_id']) && isset($regionData['areaNames'][$product['region_id']])) {
        $regionName = $regionData['areaNames'][$product['region_id']];
        // 查找该地区的父级地区(国家)
        foreach ($regionData['allRegions'] as $region) {
            if ($region['id'] == $product['region_id'] && !empty($region['parent_id'])) {
                // 找到父级地区(国家)名称
                foreach ($regionData['parentRegions'] as $parent) {
                    if ($parent['id'] == $region['parent_id']) {
                        $countryName = $parent['name'];
                        break;
                    }
                }
                break;
            }
        }
    }
    
    // 构建完整地区显示文本
    $locationText = '';
    if (!empty($regionName)) {
        if (!empty($countryName) && $countryName != '中国') {
            $locationText = $regionName . '(' . $countryName . ')';
        } else {
            $locationText = $regionName;
        }
    } else {
        $locationText = '高速';  // 修改默认值，与产品名称保持一致
    }
    
    return $locationText;
}

/**
 * 获取产品线路信息
 * @param int $line_id 线路ID
 * @return string 线路名称
 */
function getLineInfo($line_id) {
    $lineName = 'CN2线路'; // 默认值
    
    if (!empty($line_id)) {
        try {
            $conn = getDbConnection();
            $lineQuery = "SELECT l.name as line_name FROM line l WHERE l.id = :line_id";
            $lineStmt = $conn->prepare($lineQuery);
            $lineStmt->bindValue(':line_id', $line_id);
            $lineStmt->execute();
            $lineInfo = $lineStmt->fetch();
            
            if ($lineInfo) {
                $lineName = $lineInfo['line_name'];
            }
        } catch (PDOException $e) {
            // 发生错误时使用默认值
        }
    }
    
    return $lineName;
}

/**
 * 获取产品标签
 * @param string $tagIds 标签ID字符串，逗号分隔
 * @return array 标签数组
 */
function getProductTags($tagIds) {
    $tags = [];
    if (!empty($tagIds)) {
        $tagIdsArray = array_filter(array_map('intval', explode(',', $tagIds)));
        if (!empty($tagIdsArray)) {
            $placeholders = implode(',', array_fill(0, count($tagIdsArray), '?'));
            try {
                $conn = getDbConnection();
                $tagQuery = "SELECT id, name, Airbag FROM tags WHERE id IN ($placeholders) AND status = 1 ORDER BY FIELD(id, $placeholders)";
                $tagStmt = $conn->prepare($tagQuery);
                // 绑定参数两次，ORDER BY FIELD 也需要
                $i = 1;
                foreach ($tagIdsArray as $id) {
                    $tagStmt->bindValue($i++, $id, PDO::PARAM_INT);
                }
                foreach ($tagIdsArray as $id) {
                    $tagStmt->bindValue($i++, $id, PDO::PARAM_INT);
                }
                $tagStmt->execute();
                while ($tag = $tagStmt->fetch(PDO::FETCH_ASSOC)) {
                    $tags[] = [
                        'name' => $tag['name'],
                        'description' => $tag['Airbag']
                    ];
                }
            } catch (PDOException $e) {
                // 发生错误时跳过
            }
        }
    }
    return $tags;
}

/**
 * 格式化产品编码
 * @param int $product_id 产品ID
 * @return string 格式化后的产品编码
 */
function formatProductCode($product_id) {
    return '8' . str_pad($product_id, 4, '0', STR_PAD_LEFT);
}

/**
 * 处理产品默认值，确保所有必要字段都有值
 * @param array $product 原始产品数据
 * @return array 处理后的产品数据
 */
function processProductDefaults($product) {
    $defaults = [
        'upc' => 'E3-1230v3',
        'memory' => '32G',
        'disk' => '500GB SSD',
        'bandwidth' => '30M',
        'ip_count' => '1',
        'defense' => '可选',
        'traffic' => '不限流量'
    ];
    
    foreach ($defaults as $key => $value) {
        if (!isset($product[$key]) || empty($product[$key])) {
            $product[$key] = $value;
        }
    }
    
    return $product;
}

/**
 * 获取网络测试数据
 * @param string $locationText 地区文本
 * @return array 测试数据数组
 */
function getNetworkTestData($locationText) {
    // 可以根据不同地区返回不同的测试数据
    // 默认数据
    $defaultData = [
        ['location' => '北京', 'latency' => '约 70 ms'],
        ['location' => '上海', 'latency' => '约 65 ms'],
        ['location' => '广州', 'latency' => '约 45 ms'],
        ['location' => '深圳', 'latency' => '约 38 ms'],
        ['location' => '西安', 'latency' => '约 75 ms'],
        ['location' => '成都', 'latency' => '约 80 ms']
    ];
    
    // 按地区返回不同测试数据
    // TODO: 根据不同地区定义不同的网络测试数据
    
    return $defaultData;
}

/**
 * 获取ISP兼容性数据
 * @param string $locationText 地区文本
 * @return array ISP兼容性数据
 */
function getISPCompatibilityData($locationText) {
    // 默认数据
    $defaultData = [
        ['name' => '电信', 'rating' => 'excellent', 'label' => '优'],
        ['name' => '联通', 'rating' => 'excellent', 'label' => '优'],
        ['name' => '移动', 'rating' => 'good', 'label' => '良'],
        ['name' => '教育网', 'rating' => 'fair', 'label' => '中']
    ];
    
    // TODO: 按地区返回不同ISP兼容性数据
    
    return $defaultData;
}

/**
 * 获取产品特性数据
 * @param array $product 产品数据
 * @param string $lineName 线路名称
 * @return array 产品特性数据
 */
function getProductFeatures($product, $lineName) {
    return [
        [
            'icon' => 'speed',
            'title' => '高速稳定',
            'description' => "采用{$product['bandwidth']} 双向{$lineName}，延迟低，提供稳定高速的网络体验"
        ],
        [
            'icon' => 'security',
            'title' => '安全防护',
            'description' => '标配100G DDoS防御，保障服务器安全稳定运行'
        ],
        [
            'icon' => 'memory',
            'title' => '高性能配置',
            'description' => "E3-1230v3处理器，{$product['memory']}，500GB SSD，满足各类应用需求"
        ],
        [
            'icon' => 'support_agent',
            'title' => '专业支持',
            'description' => '7×24小时技术支持，专业团队随时解决您的问题'
        ],
        [
            'icon' => 'language',
            'title' => '全球加速',
            'description' => '优化的网络路由，为全球用户提供低延迟访问体验'
        ],
        [
            'icon' => 'verified',
            'title' => '服务保障',
            'description' => '支持真机测试，七天无理由退款，确保您的满意度'
        ]
    ];
}

/**
 * 获取FAQ数据
 * @return array FAQ问答数据
 */
function getFAQData() {
    return [
        [
            'question' => '如何申请测试这台服务器？',
            'answer' => '您可以通过点击"申请测机"按钮，填写您的联系信息和需求，我们的客服人员会在24小时内联系您，为您安排测试事宜。'
        ],
        [
            'question' => '这台服务器支持哪些操作系统？',
            'answer' => '我们支持多种操作系统，包括但不限于：CentOS、Ubuntu、Debian、Windows Server等。如需其他操作系统，请联系客服确认。'
        ],
        [
            'question' => '如何升级配置？',
            'answer' => '您可以随时联系我们的客服人员申请升级配置。根据资源可用情况，我们会为您提供合适的升级方案。'
        ],
        [
            'question' => '服务器购买后多长时间可以交付？',
            'answer' => '标准配置服务器通常在支付确认后1-24小时内交付，特殊配置可能需要更长时间，具体交付时间请咨询客服。'
        ],
        [
            'question' => '是否提供技术支持？',
            'answer' => '是的，我们提供7×24小时技术支持。您可以通过工单系统、在线客服或电话获取帮助。'
        ]
    ];
}

/**
 * 获取客户评价数据
 * @param string $lineName 线路名称
 * @return array 客户评价数据
 */
function getCustomerReviews($lineName) {
    return [
        [
            'rating' => 5,
            'content' => "\"服务器性能非常稳定，{$lineName}确实很快，对我们的业务帮助很大。\"",
            'reviewer' => '张先生，电商平台'
        ],
        [
            'rating' => 4.5,
            'content' => '"技术支持响应迅速，服务器性能符合预期，性价比很高。"',
            'reviewer' => '李先生，游戏开发'
        ],
        [
            'rating' => 5,
            'content' => '"我们公司的网站迁移到这台服务器后，访问速度明显提升，客户满意度也随之提高。"',
            'reviewer' => '王先生，企业网站'
        ]
    ];
}

/**
 * 获取推荐产品
 * @param int $current_product_id 当前产品ID，避免推荐相同产品
 * @return array 推荐产品数组
 */
function getRecommendedProducts($current_product_id) {
    $conn = getDbConnection();
    $recommendedProducts = [];
    
    try {
        // 获取相似产品（同一类别或同一地区的产品）
        $query = "SELECT p.*, 
                    CONCAT('8', LPAD(p.id, 4, '0')) as code,
                    a.name as location_name,
                    l.name as line_name 
                  FROM products p 
                  LEFT JOIN area a ON p.region_id = a.id
                  LEFT JOIN line l ON p.line_id = l.id
                  WHERE p.id != :current_id 
                  AND p.status = 1 
                  AND (p.region_id = (SELECT region_id FROM products WHERE id = :current_id) 
                       OR p.category_id = (SELECT category_id FROM products WHERE id = :current_id))
                  ORDER BY p.sort_order ASC 
                  LIMIT 3";
        
        $stmt = $conn->prepare($query);
        $stmt->bindValue(':current_id', $current_product_id, PDO::PARAM_INT);
        $stmt->execute();
        
        while ($product = $stmt->fetch(PDO::FETCH_ASSOC)) {
            // 处理产品默认值
            $product = processProductDefaults($product);
            
            // 格式化价格
            $price = !empty($product['price']) ? number_format($product['price'], 2) : '0.00';
            
            // 构建推荐产品数据
            $recommendedProducts[] = [
                'id' => $product['id'],
                'title' => (!empty($product['location_name']) ? $product['location_name'] : '高速') . ' 服务器',
                'description' => !empty($product['short_description']) ? $product['short_description'] : '优质高速服务器，稳定可靠',
                'price' => $price,
                'link' => '/product_detail.php?id=' . $product['id'],
                'code' => isset($product['code']) ? $product['code'] : '80' . str_pad($product['id'], 3, '0', STR_PAD_LEFT),
                'cpu' => $product['upc'],
                'memory' => $product['memory'],
                'disk' => $product['disk'],
                'bandwidth' => $product['bandwidth'],
                'traffic' => $product['traffic'],
                'defense' => $product['defense'],
                'line' => !empty($product['line_name']) ? $product['line_name'] : '优化带宽',
                'location' => !empty($product['location_name']) ? $product['location_name'] : '香港',
                'ip_count' => $product['ip_count']
            ];
        }
        
        // 如果没有相似产品或不足3个，补充一些热门产品
        if (count($recommendedProducts) < 3) {
            $limit = 3 - count($recommendedProducts);
            $existingIds = array_column($recommendedProducts, 'id');
            $existingIds[] = $current_product_id;
            
            $placeholders = str_repeat('?,', count($existingIds) - 1) . '?';
            $query = "SELECT p.*, 
                        CONCAT('8', LPAD(p.id, 4, '0')) as code,
                        a.name as location_name,
                        l.name as line_name 
                      FROM products p 
                      LEFT JOIN area a ON p.region_id = a.id
                      LEFT JOIN line l ON p.line_id = l.id
                      WHERE p.id NOT IN ($placeholders) 
                      AND p.status = 1 
                      ORDER BY p.views DESC, p.sort_order ASC 
                      LIMIT :limit";
            
            $stmt = $conn->prepare($query);
            foreach ($existingIds as $index => $id) {
                $stmt->bindValue($index + 1, $id, PDO::PARAM_INT);
            }
            $stmt->bindValue(':limit', $limit, PDO::PARAM_INT);
            $stmt->execute();
            
            while ($product = $stmt->fetch(PDO::FETCH_ASSOC)) {
                // 处理产品默认值
                $product = processProductDefaults($product);
                
                // 格式化价格
                $price = !empty($product['price']) ? number_format($product['price'], 2) : '0.00';
                
                // 构建推荐产品数据
                $recommendedProducts[] = [
                    'id' => $product['id'],
                    'title' => (!empty($product['location_name']) ? $product['location_name'] : '高速') . ' 服务器',
                    'description' => !empty($product['short_description']) ? $product['short_description'] : '优质高速服务器，稳定可靠',
                    'price' => $price,
                    'link' => '/product_detail.php?id=' . $product['id'],
                    'code' => isset($product['code']) ? $product['code'] : '80' . str_pad($product['id'], 3, '0', STR_PAD_LEFT),
                    'cpu' => $product['upc'],
                    'memory' => $product['memory'],
                    'disk' => $product['disk'],
                    'bandwidth' => $product['bandwidth'],
                    'traffic' => $product['traffic'],
                    'defense' => $product['defense'],
                    'line' => !empty($product['line_name']) ? $product['line_name'] : '优化带宽',
                    'location' => !empty($product['location_name']) ? $product['location_name'] : '香港',
                    'ip_count' => $product['ip_count']
                ];
            }
        }
    } catch (PDOException $e) {
        // 出错时返回一些静态数据
        $recommendedProducts = [
            [
                'title' => '香港服务器',
                'description' => '高速稳定，低延迟',
                'price' => '397.05',
                'link' => '/product_detail.php?id=1',
                'code' => '80786',
                'cpu' => 'E3-1230',
                'memory' => '8G',
                'disk' => '240G SSD',
                'bandwidth' => '15M',
                'traffic' => '不限',
                'defense' => '可选',
                'line' => '优化带宽',
                'location' => '香港',
                'ip_count' => '232个'
            ],
            [
                'title' => '美国服务器',
                'description' => '大带宽，高防护',
                'price' => '299.99',
                'link' => '/product_detail.php?id=2',
                'code' => '80787',
                'cpu' => 'E3-1231',
                'memory' => '16G',
                'disk' => '500G SSD',
                'bandwidth' => '30M',
                'traffic' => '不限',
                'defense' => '20G',
                'line' => 'CN2 GIA',
                'location' => '美国',
                'ip_count' => '256个'
            ],
            [
                'title' => '日本服务器',
                'description' => '稳定性能，快速响应',
                'price' => '359.99',
                'link' => '/product_detail.php?id=3',
                'code' => '80788',
                'cpu' => 'E5-2650',
                'memory' => '32G',
                'disk' => '1T SSD',
                'bandwidth' => '20M',
                'traffic' => '不限',
                'defense' => '10G',
                'line' => '优化线路',
                'location' => '日本',
                'ip_count' => '128个'
            ]
        ];
    }
    
    return $recommendedProducts;
}

/**
 * 获取产品页面SEO元数据
 * @param array $product 产品数据
 * @param string $locationText 地区文本
 * @param string $lineName 线路名称
 * @param array $prices 价格信息
 * @return array SEO元数据
 */
function getProductSEOMetadata($product, $locationText, $lineName, $prices) {
    // 默认值
    $memory = $product['memory'] ?? '32G';
    $disk = $product['disk'] ?? '500GB SSD';
    $bandwidth = $product['bandwidth'] ?? '30M';
    $ip_count = $product['ip_count'] ?? '1';
    
    return [
        'title' => "{$locationText}高速服务器 - {$memory}内存{$disk}硬盘{$bandwidth}带宽 - " . $GLOBALS['SiteName'],
        'keywords' => "{$locationText}服务器,{$locationText}裸机云,{$locationText}独立服务器,{$memory}内存配置,{$bandwidth}带宽,{$disk}存储,高防服务器,{$lineName},服务器租用",
        'description' => "{$locationText}机房裸机云服务器,配备{$memory}大内存,{$disk}高速存储,{$bandwidth}独享带宽,无限流量,可选DDoS防御,含{$ip_count}个独立IP,{$lineName},月付仅需\${$prices['new_formatted']}",
        'og_title' => "{$locationText}高速服务器 - " . $GLOBALS['SiteName'],
        'og_description' => "高性能{$locationText}数据中心服务器，满足您的各种业务需求"
    ];
}

/**
 * 生成默认产品描述
 * @param array $product 产品数据
 * @param string $locationText 地区文本
 * @param string $lineName 线路名称
 * @return string 默认产品描述
 */
function generateDefaultProductDescription($product, $locationText, $lineName) {
    $upc = $product['upc'] ?? 'E3-1230v3';
    $memory = $product['memory'] ?? '32GB';
    $disk = $product['disk'] ?? '500GB SSD';
    
    return "该服务器位于{$locationText}数据中心，采用{$lineName}，延迟低，高速稳定。适合对网络延迟和稳定性有较高要求的客户使用。配备{$upc}处理器，{$memory}内存，{$disk}高速硬盘，支持1Gbps内网速度，非常适合各类网站、应用和游戏服务部署。";
}

/**
 * 获取服务保障信息
 * @return array 服务保障项目
 */
function getServiceGuarantees() {
    return [
        ['icon' => 'security', 'text' => '免费真机测试'],
        ['icon' => 'verified_user', 'text' => '7天无理由退换'],
        ['icon' => 'computer', 'text' => '免费重装系统'],
        ['icon' => 'support_agent', 'text' => '7×24小时技术支持']
    ];
}

/**
 * 更新产品的UV（页面浏览量）
 * @param int $product_id 产品ID
 * @return bool 是否成功更新
 */
function updateProductUV($product_id) {
    try {
        $conn = getDbConnection();
        $sql = "UPDATE products SET uv = uv + 1 WHERE id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bindParam(1, $product_id, PDO::PARAM_INT);
        return $stmt->execute();
    } catch (PDOException $e) {
        // 更新失败时记录错误，但不影响页面正常显示
        error_log("更新产品UV失败: " . $e->getMessage());
        return false;
    }
}

// 注意：calculatePrice函数已在/public/config.php中定义，不再重复定义

// 主逻辑：获取产品详情并处理
function processProductDetail($product_id) {
    // 获取产品信息
    $product = getProductDetails($product_id);
    if (!$product) {
        return [
            'success' => false,
            'redirect' => '/product'
        ];
    }
    
    // 更新产品UV计数（页面浏览量）
    updateProductUV($product_id);
    
    // 处理产品默认值
    $product = processProductDefaults($product);
    
    // 获取地区信息
    $regionData = getRegionData();
    
    // 构建位置文本
    $locationText = buildLocationText($product, $regionData);
    
    // 获取线路信息
    $lineName = getLineInfo($product['line_id'] ?? null);
    
    // 获取产品标签
    $tags = getProductTags($product['tags'] ?? '');
    
    // 计算价格 - 使用公共配置中的函数
    $original_price = $product['price'];
    $prices = calculatePrice($original_price);
    
    // 格式化产品编码
    $productCode = formatProductCode($product['id']);
    
    // 获取网络测试数据
    $networkTestData = getNetworkTestData($locationText);
    
    // 获取ISP兼容性数据
    $ispData = getISPCompatibilityData($locationText);
    
    // 获取产品特性
    $features = getProductFeatures($product, $lineName);
    
    // 获取FAQ数据
    $faqData = getFAQData();
    
    // 获取客户评价数据
    $reviews = getCustomerReviews($lineName);
    
    // 获取推荐产品
    $recommendedProducts = getRecommendedProducts($product['id']);
    
    // 获取SEO元数据
    $seoMetadata = getProductSEOMetadata($product, $locationText, $lineName, $prices);
    
    // 生成默认产品描述（如果产品没有描述）
    $defaultDescription = generateDefaultProductDescription($product, $locationText, $lineName);
    
    // 获取服务保障信息
    $serviceGuarantees = getServiceGuarantees();
    
    return [
        'success' => true,
        'product' => $product,
        'productCode' => $productCode,
        'locationText' => $locationText,
        'lineName' => $lineName,
        'tags' => $tags,
        'prices' => $prices,
        'regionData' => $regionData,
        'networkTestData' => $networkTestData,
        'ispData' => $ispData,
        'features' => $features,
        'faqData' => $faqData,
        'reviews' => $reviews,
        'recommendedProducts' => $recommendedProducts,
        'seoMetadata' => $seoMetadata,
        'defaultDescription' => $defaultDescription,
        'serviceGuarantees' => $serviceGuarantees
    ];
} 
