<?php
/**
 * sg_code.php - 新加坡服务器数据处理逻辑
 * 用于获取新加坡服务器相关数据
 */

// 防止直接访问
if (!defined('INCLUDED_FROM_VIEW')) {
    header('HTTP/1.0 403 Forbidden');
    exit;
}

// 引入数据库配置（如果需要）
if (!function_exists('getDbConnection')) {
    require_once dirname(dirname(__FILE__)) . '/config/database.php';
}

/**
 * 获取价格显示的倍率
 * 用于根据不同情况调整价格显示
 * 
 * @return float 价格倍率
 */
// 避免重复声明函数
if (!function_exists('getMultiplier')) {
    function getMultiplier() {
        // 默认倍率为1，可根据业务需求调整
        return 1.0;
    }
}

/**
 * 获取新加坡云服务器产品数据
 * 查询条件：region_id=11（新加坡地区）且tags包含7(云服务器)
 * 
 * @param bool $debug 是否开启调试模式
 * @return array 新加坡云服务器产品数据
 */
function getSgCloudProducts($debug = false) {
    // 获取数据库连接
    $db = getDbConnection();
    $result = [];
    
    try {
        // 构建SQL查询语句
        $query = "SELECT * FROM products 
                 WHERE region_id = 11 
                 AND FIND_IN_SET(7, tags) 
                 AND status = 1 
                 ORDER BY price ASC";
        
        $stmt = $db->query($query);
        $products = $stmt->fetchAll();
        
        // 计算记录数量
        $count = count($products);
        
        // 如果开启调试模式，打印查询结果
        if ($debug) {
            echo "<div style='background:#f5f5f5; padding:15px; margin:15px; border:1px solid #ddd;'>";
            echo "<h3>查询结果 - 新加坡云服务器</h3>";
            echo "<p>找到 <strong>{$count}</strong> 条记录</p>";
            
            if ($count > 0) {
                echo "<table border='1' cellpadding='5' cellspacing='0' style='border-collapse:collapse; width:100%;'>";
                echo "<tr style='background:#eee;'>";
                echo "<th>ID</th>";
                echo "<th>产品名称</th>";
                echo "<th>CPU</th>";
                echo "<th>内存</th>";
                echo "<th>硬盘</th>";
                echo "<th>带宽</th>";
                echo "<th>IP数量</th>";
                echo "<th>原价</th>";
                echo "<th>显示价格</th>";
                echo "</tr>";
                
                foreach ($products as $product) {
                    echo "<tr>";
                    echo "<td>" . $product['id'] . "</td>";
                    echo "<td>" . $product['name'] . "</td>";
                    echo "<td>" . $product['cpu'] . "</td>";
                    echo "<td>" . $product['memory'] . "</td>";
                    echo "<td>" . $product['disk'] . "</td>";
                    echo "<td>" . $product['bandwidth'] . "</td>";
                    echo "<td>" . $product['ip_count'] . "</td>";
                    echo "<td>$" . number_format($product['price'], 2) . "</td>";
                    echo "<td>$" . number_format($product['price'] * getMultiplier(), 2) . "</td>";
                    echo "</tr>";
                }
                
                echo "</table>";
            } else {
                echo "<p>没有找到匹配的记录</p>";
            }
            
            echo "<p>SQL: " . htmlspecialchars($query) . "</p>";
            echo "</div>";
        }
        
        return $products;
    } catch (Exception $e) {
        // 错误处理
        if ($debug) {
            echo "<div style='background:#f8d7da; padding:15px; margin:15px; border:1px solid #f5c6cb;'>";
            echo "<h3>数据库错误</h3>";
            echo "<p>" . $e->getMessage() . "</p>";
            echo "</div>";
        }
        error_log("获取新加坡云服务器产品错误: " . $e->getMessage());
        return [];
    }
}

/**
 * 获取新加坡物理服务器产品数据
 * 查询条件：region_id=11（新加坡地区）且tags包含8(物理服务器)
 * 
 * @param bool $debug 是否开启调试模式
 * @return array 新加坡物理服务器产品数据
 */
function getSgPhysicalProducts($debug = false) {
    // 获取数据库连接
    $db = getDbConnection();
    $result = [];
    
    try {
        // 构建SQL查询语句
        $query = "SELECT * FROM products 
                 WHERE region_id = 11 
                 AND FIND_IN_SET(8, tags) 
                 AND status = 1 
                 ORDER BY price ASC";
        
        $stmt = $db->query($query);
        $products = $stmt->fetchAll();
        
        // 计算记录数量
        $count = count($products);
        
        // 如果开启调试模式，打印查询结果
        if ($debug) {
            echo "<div style='background:#f5f5f5; padding:15px; margin:15px; border:1px solid #ddd;'>";
            echo "<h3>查询结果 - 新加坡物理服务器</h3>";
            echo "<p>找到 <strong>{$count}</strong> 条记录</p>";
            
            if ($count > 0) {
                echo "<table border='1' cellpadding='5' cellspacing='0' style='border-collapse:collapse; width:100%;'>";
                echo "<tr style='background:#eee;'>";
                echo "<th>ID</th>";
                echo "<th>产品名称</th>";
                echo "<th>CPU</th>";
                echo "<th>内存</th>";
                echo "<th>硬盘</th>";
                echo "<th>带宽</th>";
                echo "<th>IP数量</th>";
                echo "<th>原价</th>";
                echo "<th>显示价格</th>";
                echo "</tr>";
                
                foreach ($products as $product) {
                    echo "<tr>";
                    echo "<td>" . $product['id'] . "</td>";
                    echo "<td>" . $product['name'] . "</td>";
                    echo "<td>" . $product['cpu'] . "</td>";
                    echo "<td>" . $product['memory'] . "</td>";
                    echo "<td>" . $product['disk'] . "</td>";
                    echo "<td>" . $product['bandwidth'] . "</td>";
                    echo "<td>" . $product['ip_count'] . "</td>";
                    echo "<td>$" . number_format($product['price'], 2) . "</td>";
                    echo "<td>$" . number_format($product['price'] * getMultiplier(), 2) . "</td>";
                    echo "</tr>";
                }
                
                echo "</table>";
            } else {
                echo "<p>没有找到匹配的记录</p>";
            }
            
            echo "<p>SQL: " . htmlspecialchars($query) . "</p>";
            echo "</div>";
        }
        
        return $products;
    } catch (Exception $e) {
        // 错误处理
        if ($debug) {
            echo "<div style='background:#f8d7da; padding:15px; margin:15px; border:1px solid #f5c6cb;'>";
            echo "<h3>数据库错误</h3>";
            echo "<p>" . $e->getMessage() . "</p>";
            echo "</div>";
        }
        error_log("获取新加坡物理服务器产品错误: " . $e->getMessage());
        return [];
    }
}

/**
 * 获取新加坡站群服务器产品数据
 * 查询条件：region_id=11（新加坡地区）且tags包含9(站群服务器)
 * 
 * @param bool $debug 是否开启调试模式
 * @return array 新加坡站群服务器产品数据
 */
function getSgClusterProducts($debug = false) {
    // 获取数据库连接
    $db = getDbConnection();
    $result = [];
    
    try {
        // 构建SQL查询语句
        $query = "SELECT * FROM products 
                 WHERE region_id = 11 
                 AND FIND_IN_SET(9, tags) 
                 AND status = 1 
                 ORDER BY price ASC";
        
        $stmt = $db->query($query);
        $products = $stmt->fetchAll();
        
        // 计算记录数量
        $count = count($products);
        
        // 如果开启调试模式，打印查询结果
        if ($debug) {
            echo "<div style='background:#f5f5f5; padding:15px; margin:15px; border:1px solid #ddd;'>";
            echo "<h3>查询结果 - 新加坡站群服务器</h3>";
            echo "<p>找到 <strong>{$count}</strong> 条记录</p>";
            
            if ($count > 0) {
                echo "<table border='1' cellpadding='5' cellspacing='0' style='border-collapse:collapse; width:100%;'>";
                echo "<tr style='background:#eee;'>";
                echo "<th>ID</th>";
                echo "<th>产品名称</th>";
                echo "<th>CPU</th>";
                echo "<th>内存</th>";
                echo "<th>硬盘</th>";
                echo "<th>带宽</th>";
                echo "<th>IP数量</th>";
                echo "<th>原价</th>";
                echo "<th>显示价格</th>";
                echo "</tr>";
                
                foreach ($products as $product) {
                    echo "<tr>";
                    echo "<td>" . $product['id'] . "</td>";
                    echo "<td>" . $product['name'] . "</td>";
                    echo "<td>" . $product['cpu'] . "</td>";
                    echo "<td>" . $product['memory'] . "</td>";
                    echo "<td>" . $product['disk'] . "</td>";
                    echo "<td>" . $product['bandwidth'] . "</td>";
                    echo "<td>" . $product['ip_count'] . "</td>";
                    echo "<td>$" . number_format($product['price'], 2) . "</td>";
                    echo "<td>$" . number_format($product['price'] * getMultiplier(), 2) . "</td>";
                    echo "</tr>";
                }
                
                echo "</table>";
            } else {
                echo "<p>没有找到匹配的记录</p>";
            }
            
            echo "<p>SQL: " . htmlspecialchars($query) . "</p>";
            echo "</div>";
        }
        
        return $products;
    } catch (Exception $e) {
        // 错误处理
        if ($debug) {
            echo "<div style='background:#f8d7da; padding:15px; margin:15px; border:1px solid #f5c6cb;'>";
            echo "<h3>数据库错误</h3>";
            echo "<p>" . $e->getMessage() . "</p>";
            echo "</div>";
        }
        error_log("获取新加坡站群服务器产品错误: " . $e->getMessage());
        return [];
    }
}

/**
 * 获取新加坡高防服务器产品数据
 * 查询条件：region_id=11（新加坡地区）且tags包含10(高防服务器)
 * 
 * @param bool $debug 是否开启调试模式
 * @return array 新加坡高防服务器产品数据
 */
function getSgHighDefenseProducts($debug = false) {
    // 获取数据库连接
    $db = getDbConnection();
    $result = [];
    
    try {
        // 构建SQL查询语句
        $query = "SELECT * FROM products 
                 WHERE region_id = 11 
                 AND FIND_IN_SET(10, tags) 
                 AND status = 1 
                 ORDER BY price ASC";
        
        $stmt = $db->query($query);
        $products = $stmt->fetchAll();
        
        // 计算记录数量
        $count = count($products);
        
        // 如果开启调试模式，打印查询结果
        if ($debug) {
            echo "<div style='background:#f5f5f5; padding:15px; margin:15px; border:1px solid #ddd;'>";
            echo "<h3>查询结果 - 新加坡高防服务器</h3>";
            echo "<p>找到 <strong>{$count}</strong> 条记录</p>";
            
            if ($count > 0) {
                echo "<table border='1' cellpadding='5' cellspacing='0' style='border-collapse:collapse; width:100%;'>";
                echo "<tr style='background:#eee;'>";
                echo "<th>ID</th>";
                echo "<th>产品名称</th>";
                echo "<th>CPU</th>";
                echo "<th>内存</th>";
                echo "<th>硬盘</th>";
                echo "<th>带宽</th>";
                echo "<th>IP数量</th>";
                echo "<th>原价</th>";
                echo "<th>显示价格</th>";
                echo "</tr>";
                
                foreach ($products as $product) {
                    echo "<tr>";
                    echo "<td>" . $product['id'] . "</td>";
                    echo "<td>" . $product['name'] . "</td>";
                    echo "<td>" . $product['cpu'] . "</td>";
                    echo "<td>" . $product['memory'] . "</td>";
                    echo "<td>" . $product['disk'] . "</td>";
                    echo "<td>" . $product['bandwidth'] . "</td>";
                    echo "<td>" . $product['ip_count'] . "</td>";
                    echo "<td>$" . number_format($product['price'], 2) . "</td>";
                    echo "<td>$" . number_format($product['price'] * getMultiplier(), 2) . "</td>";
                    echo "</tr>";
                }
                
                echo "</table>";
            } else {
                echo "<p>没有找到匹配的记录</p>";
            }
            
            echo "<p>SQL: " . htmlspecialchars($query) . "</p>";
            echo "</div>";
        }
        
        return $products;
    } catch (Exception $e) {
        // 错误处理
        if ($debug) {
            echo "<div style='background:#f8d7da; padding:15px; margin:15px; border:1px solid #f5c6cb;'>";
            echo "<h3>数据库错误</h3>";
            echo "<p>" . $e->getMessage() . "</p>";
            echo "</div>";
        }
        error_log("获取新加坡高防服务器产品错误: " . $e->getMessage());
        return [];
    }
} 