<?php
/**
 * 标签产品页面逻辑处理文件
 * 处理通过tag参数获取特定标签的产品
 */

// 引入数据库配置
require_once dirname(dirname(__FILE__)) . '/config/database.php';
// 引入网站配置
require_once dirname(__FILE__) . '/../public/config.php';
// 引入产品数据处理文件
require_once __DIR__ . '/product_data.php';

// 确保文件被包含而非直接访问
if (!defined('INCLUDED_FROM_VIEW')) {
    header("HTTP/1.0 403 Forbidden");
    exit;
}

/**
 * 获取指定标签的产品列表
 * @param int $tagId 标签ID
 * @return array 处理结果数组，包含产品列表及相关数据
 */
function getProductsByTag($tagId) {
    $db = getDbConnection();
    
    // 获取标签信息
    $tagInfo = getTagInfo($db, $tagId);
    if (!$tagInfo) {
        return [
            'success' => false,
            'redirect' => '/product',
            'message' => '标签不存在'
        ];
    }
    
    // 构建过滤器
    $filters = [
        'tag' => $tagId,
        'page' => isset($_GET['page']) ? intval($_GET['page']) : 1,
        'sort' => isset($_GET['sort']) ? $_GET['sort'] : 'recommended',
        'order' => isset($_GET['order']) ? $_GET['order'] : 'desc'
    ];
    
    // 获取产品列表
    $productsData = getProductsList($db, $filters);
    
    // 获取其他必要数据
    $regionsData = getRegionsData($db);
    $tagsData = getTagsData($db);
    $areaNames = getAreaNames($db);
    
    // 预先获取所有产品所需的线路信息
    $lineData = getLineData($db, $productsData['products']);
    
    // 构建返回结果
    return [
        'success' => true,
        'products' => $productsData['products'],
        'totalItems' => $productsData['totalItems'],
        'totalPages' => $productsData['totalPages'],
        'currentPage' => $productsData['currentPage'],
        'tagInfo' => $tagInfo,
        'regionsData' => $regionsData,
        'tagsData' => $tagsData,
        'areaNames' => $areaNames,
        'lineData' => $lineData,
        'filters' => $filters
    ];
}

/**
 * 获取标签信息
 * @param PDO $db 数据库连接
 * @param int $tagId 标签ID
 * @return array|bool 标签信息数组或false
 */
function getTagInfo($db, $tagId) {
    try {
        $query = "SELECT * FROM tags WHERE id = :tag_id AND status = 1";
        $stmt = $db->prepare($query);
        $stmt->bindValue(':tag_id', $tagId, PDO::PARAM_INT);
        $stmt->execute();
        
        if ($stmt->rowCount() > 0) {
            return $stmt->fetch(PDO::FETCH_ASSOC);
        }
        return false;
    } catch (PDOException $e) {
        error_log("获取标签信息错误: " . $e->getMessage());
        return false;
    }
}

/**
 * 获取线路数据
 * @param PDO $db 数据库连接
 * @param array $products 产品列表
 * @return array 线路数据
 */
function getLineData($db, $products) {
    $lineData = [];
    try {
        // 获取所有产品使用的线路ID
        $lineIds = [];
        foreach ($products as $product) {
            if (!empty($product['line_id']) && !in_array($product['line_id'], $lineIds)) {
                $lineIds[] = $product['line_id'];
            }
        }
        
        // 如果有线路ID，一次性查询所有线路信息
        if (!empty($lineIds)) {
            $placeholders = implode(',', array_fill(0, count($lineIds), '?'));
            $lineQuery = "SELECT id, name FROM line WHERE id IN ($placeholders)";
            $lineStmt = $db->prepare($lineQuery);
            
            // 绑定参数
            foreach ($lineIds as $index => $id) {
                $lineStmt->bindValue($index + 1, $id);
            }
            
            $lineStmt->execute();
            while ($line = $lineStmt->fetch()) {
                $lineData[$line['id']] = $line['name'];
            }
        }
    } catch (PDOException $e) {
        error_log("线路数据查询错误: " . $e->getMessage());
    }
    
    return $lineData;
} 