<?php
// 先定义ROOT_PATH（如果不存在）
if (!defined('ROOT_PATH')) {
    define('ROOT_PATH', dirname(__DIR__));
}

// 引入数据库配置文件
require_once ROOT_PATH . '/config/database.php';

// 获取视频ID
$videoId = isset($_GET['id']) ? intval($_GET['id']) : 0;

// 如果 URL 中没有 id 参数，尝试从 URL 路径中提取
if ($videoId == 0 && isset($_SERVER['REQUEST_URI'])) {
    $patterns = [
        '/\\/video\\/(\\d+)\\.html/',  // 匹配 /video/数字.html
        '/\\/video-detail\\.html\\?id=(\\d+)/'  // 匹配 /video-detail.html?id=数字
    ];
    
    foreach ($patterns as $pattern) {
        if (preg_match($pattern, $_SERVER['REQUEST_URI'], $matches)) {
            $videoId = intval($matches[1]);
            break;
        }
    }
}

$currentVideo = [];
$relatedVideos = [];
$tags = [];
$comments = [];
$commentCount = 0;

// 如果没有视频ID，重定向到视频列表页
if ($videoId <= 0) {
    header('Location: /video.php');
    exit;
}

try {
    // 获取数据库连接
    $db = getDbConnection();
    
    // 更新视频观看次数
    $updateViewsQuery = "UPDATE videos SET views = views + 1 WHERE id = :id";
    $updateStmt = $db->prepare($updateViewsQuery);
    $updateStmt->execute(['id' => $videoId]);
    
    // 获取视频详情
    $videoQuery = "SELECT v.*, vc.name as category_name 
                  FROM videos v 
                  LEFT JOIN video_categories vc ON v.category_id = vc.id 
                  WHERE v.id = :id AND v.status = 1";
    $videoStmt = $db->prepare($videoQuery);
    $videoStmt->execute(['id' => $videoId]);
    $currentVideo = $videoStmt->fetch(PDO::FETCH_ASSOC);
    
    // 如果视频不存在或状态不为1，重定向到视频列表页
    if (!$currentVideo) {
        header('Location: /video.php');
        exit;
    }
    
    // 将观看次数格式化
    $currentVideo['views_formatted'] = number_format($currentVideo['views'], 0, '.', ',');
    
    // 获取视频标签
    if (!empty($currentVideo['id'])) {
        $tagsQuery = "SELECT t.* FROM tags t 
                     JOIN video_tags vt ON t.id = vt.tag_id 
                     WHERE vt.video_id = :video_id";
        $tagsStmt = $db->prepare($tagsQuery);
        $tagsStmt->execute(['video_id' => $currentVideo['id']]);
        $tags = $tagsStmt->fetchAll(PDO::FETCH_ASSOC);
    }
    
    // 同步尝试3种方式获取推荐视频
    
    // 1. 先尝试获取同分类的视频（传统方式）
    if (!empty($currentVideo['category_id'])) {
        $relatedQuery = "SELECT * FROM videos 
                        WHERE category_id = :category_id 
                        AND id != :video_id 
                        AND status = 1 
                        ORDER BY views DESC, created_at DESC 
                        LIMIT 10";
        
        // 调试信息
        error_log("正在查询同分类视频 - 视频ID: {$videoId}, 分类ID: {$currentVideo['category_id']}, SQL: " . $relatedQuery);
        
        $relatedStmt = $db->prepare($relatedQuery);
        $relatedStmt->execute([
            'category_id' => $currentVideo['category_id'],
            'video_id' => $videoId
        ]);
        $relatedVideos = $relatedStmt->fetchAll(PDO::FETCH_ASSOC);
        
        // 调试信息
        error_log("同分类视频查询结果条数: " . count($relatedVideos) . ", 查询参数: category_id = {$currentVideo['category_id']}, video_id = {$videoId}");
        if (!empty($relatedVideos)) {
            error_log("第一个相关视频: ID=" . $relatedVideos[0]['id'] . ", 标题=" . $relatedVideos[0]['title']);
        }
    }
    
    // 2. 如果同分类没有视频，尝试获取相似标签的视频
    if (empty($relatedVideos) && !empty($tags)) {
        $tagIds = array_column($tags, 'id');
        $tagIdsString = implode(',', $tagIds);
        
        if (!empty($tagIdsString)) {
            $tagRelatedQuery = "SELECT DISTINCT v.* FROM videos v 
                            JOIN video_tags vt ON v.id = vt.video_id 
                            WHERE vt.tag_id IN ($tagIdsString) 
                            AND v.id != :video_id 
                            AND v.status = 1 
                            ORDER BY v.views DESC, v.created_at DESC 
                            LIMIT 10";
            $tagRelatedStmt = $db->prepare($tagRelatedQuery);
            $tagRelatedStmt->execute(['video_id' => $videoId]);
            $relatedVideos = $tagRelatedStmt->fetchAll(PDO::FETCH_ASSOC);
        }
    }
    
    // 3. 如果同分类和相似标签都没有视频，获取最新/最热门的视频
    if (empty($relatedVideos)) {
        $popularQuery = "SELECT * FROM videos 
                        WHERE id != :video_id 
                        AND status = 1 
                        ORDER BY views DESC, created_at DESC 
                        LIMIT 10";
        
        // 调试信息
        error_log("尝试查询热门视频 - SQL: " . $popularQuery . ", video_id = {$videoId}");
        
        $popularStmt = $db->prepare($popularQuery);
        $popularStmt->execute(['video_id' => $videoId]);
        $relatedVideos = $popularStmt->fetchAll(PDO::FETCH_ASSOC);
        
        // 调试信息
        error_log("热门视频查询结果条数: " . count($relatedVideos));
        if (!empty($relatedVideos)) {
            error_log("第一个热门视频: ID=" . $relatedVideos[0]['id'] . ", 标题=" . $relatedVideos[0]['title']);
        }
    }
    
    // 4. 最后保底方案：如果所有推荐方式都没找到视频，创建一个虚拟视频列表
    if (empty($relatedVideos)) {
        $relatedVideos = [
            [
                'id' => 0,
                'title' => '暂无推荐视频',
                'thumbnail' => 'http://temp.im/120x68',
                'duration' => '0:00',
                'views' => 0
            ]
        ];
    }
    
    // 获取视频评论
    $commentsQuery = "SELECT c.*, u.username 
                     FROM comments c 
                     LEFT JOIN users u ON c.user_id = u.id 
                     WHERE c.video_id = :video_id AND c.status = 1 
                     ORDER BY c.created_at DESC 
                     LIMIT 10";
    $commentsStmt = $db->prepare($commentsQuery);
    $commentsStmt->execute(['video_id' => $videoId]);
    $comments = $commentsStmt->fetchAll(PDO::FETCH_ASSOC);
    
    // 获取评论总数
    $commentCountQuery = "SELECT COUNT(*) FROM comments WHERE video_id = :video_id AND status = 1";
    $commentCountStmt = $db->prepare($commentCountQuery);
    $commentCountStmt->execute(['video_id' => $videoId]);
    $commentCount = $commentCountStmt->fetchColumn();
    
} catch (PDOException $e) {
    // 记录错误
    error_log("视频详情页错误: " . $e->getMessage());
    // 如果出错，尝试使用默认值，防止页面完全崩溃
    if (empty($currentVideo)) {
        $currentVideo = [
            'id' => $videoId,
            'title' => '视频加载失败',
            'description' => '无法加载视频内容，请稍后再试。',
            'views' => 0,
            'views_formatted' => '0',
            'likes' => 0,
            'duration' => '00:00',
            'created_at' => date('Y-m-d H:i:s'),
            'video_url' => '',
            'thumbnail' => '',
            'category_id' => 0,
            'category_name' => ''
        ];
    }
    
    // 如果出错，提供一个默认的推荐视频
    if (empty($relatedVideos)) {
        $relatedVideos = [
            [
                'id' => 0,
                'title' => '暂无推荐视频',
                'thumbnail' => 'http://temp.im/120x68',
                'duration' => '0:00',
                'views' => 0
            ]
        ];
    }
}

/**
 * 从YouTube URL获取嵌入URL
 */
function getYoutubeEmbedUrl($url) {
    $videoId = '';
    
    // 提取YouTube视频ID
    if (preg_match('/youtube\.com\/watch\?v=([^&]+)/', $url, $matches)) {
        $videoId = $matches[1];
    } elseif (preg_match('/youtu\.be\/([^?]+)/', $url, $matches)) {
        $videoId = $matches[1];
    } elseif (preg_match('/youtube\.com\/embed\/([^?]+)/', $url, $matches)) {
        $videoId = $matches[1];
    }
    
    if (!empty($videoId)) {
        return 'https://www.youtube.com/embed/' . $videoId;
    }
    
    // 如果不是YouTube链接，直接返回原始URL
    return $url;
}
