<?php
// 引入数据库配置
require_once 'database.php';

// 定义全局配置数组
$CONFIG = [];

/**
 * 核心配置管理函数
 */

/**
 * 从数据库获取配置项
 * 
 * @param string $name 配置项名称
 * @param mixed $default 默认值（如果配置不存在）
 * @return mixed 配置项的值
 */
function getConfig($name, $default = null) {
    global $CONFIG;
    
    // 如果全局配置数组已存在且包含该配置项，直接返回
    if (isset($CONFIG) && isset($CONFIG[$name])) {
        return $CONFIG[$name];
    }
    
    try {
        $db = getDbConnection();
        $stmt = $db->prepare("SELECT content FROM config WHERE name = ?");
        $stmt->execute([$name]);
        $result = $stmt->fetch();
        
        if ($result) {
            // 如果全局配置数组存在，更新它
            if (isset($CONFIG)) {
                $CONFIG[$name] = $result['content'];
            }
            
            // 同时设置全局变量
            $GLOBALS[$name] = $result['content'];
            
            return $result['content'];
        }
        
        return $default;
    } catch (PDOException $e) {
        error_log("获取配置项错误: " . $e->getMessage());
        return $default;
    }
}

/**
 * 获取所有配置项
 * 
 * @return array 所有配置项
 */
function getAllConfig() {
    global $CONFIG;
    
    try {
        $db = getDbConnection();
        $stmt = $db->query("SELECT id, cn_name, name, content, sort_order FROM config ORDER BY sort_order ASC");
        $CONFIG = [];
        
        while ($row = $stmt->fetch()) {
            $name = $row['name'];
            $content = $row['content'];
            
            // 记录每个配置项
            error_log("Loading config: {$name} = {$content}");
            
            // 将配置项保存到全局数组中
            $CONFIG[$name] = $content;
            
            // 同时创建一个与数据库字段同名的全局变量
            $GLOBALS[$name] = $content;
            
            // 兼容性处理：对于一些特殊变量，确保它们能被访问到
            if ($name == 'Scriptaddress') {
                // 创建几种可能的变体
                $GLOBALS['scriptaddress'] = $content; // 全小写
                $GLOBALS['ScriptAddress'] = $content; // 驼峰式
                $GLOBALS['Script_address'] = $content; // 下划线分隔
            }
        }
        
        return $CONFIG;
    } catch (PDOException $e) {
        error_log("获取所有配置项错误: " . $e->getMessage());
        return [];
    }
}

/**
 * 配置访问辅助函数
 */

/**
 * 配置变量智能获取函数，支持多种写法
 * @param string $key 配置键名
 * @return mixed 配置值或null
 */
function c($key) {
    global $CONFIG;
    
    // 如果直接匹配，则返回
    if (isset($CONFIG[$key])) {
        return $CONFIG[$key];
    }
    
    // 尝试不同的大小写变体
    $variants = [
        $key,
        strtolower($key),
        strtoupper($key),
        ucfirst(strtolower($key))
    ];
    
    foreach ($variants as $variant) {
        if (isset($CONFIG[$variant])) {
            return $CONFIG[$variant];
        }
    }
    
    return null;
}

/**
 * 兼容函数 e_config 用于获取配置项
 * @param string $key 配置键名
 * @return mixed 配置值或null
 */
function e_config($key) {
    global $CONFIG;
    
    // 直接从全局配置数组中获取
    if (isset($CONFIG[$key])) {
        return $CONFIG[$key];
    }
    
    // 尝试不同的大小写变体
    $variants = [
        $key,
        strtolower($key),
        strtoupper($key),
        ucfirst(strtolower($key))
    ];
    
    foreach ($variants as $variant) {
        if (isset($CONFIG[$variant])) {
            return $CONFIG[$variant];
        }
    }
    
    // 如果都找不到，尝试使用getConfig
    return getConfig($key);
}

/**
 * 显示配置项或获取特定配置项的值
 * @param string|null $key 配置键名，如果为null则显示所有配置
 * @param bool $echo 是否直接输出结果
 * @return mixed 如果$echo为false，则返回配置值或配置数组
 */
function display_config($key = null, $echo = true) {
    global $CONFIG;
    
    // 确保配置已加载
    if (empty($CONFIG)) {
        $CONFIG = getAllConfig();
    }
    
    if ($key !== null) {
        // 获取特定配置项
        $value = isset($CONFIG[$key]) ? $CONFIG[$key] : null;
        
        if ($value === null) {
            // 尝试不同的大小写变体
            $variants = [
                strtolower($key),
                strtoupper($key),
                ucfirst(strtolower($key))
            ];
            
            foreach ($variants as $variant) {
                if (isset($CONFIG[$variant])) {
                    $value = $CONFIG[$variant];
                    break;
                }
            }
        }
        
        if ($echo && $value !== null) {
            echo htmlspecialchars($value);
        }
        
        return $value;
    } else {
        // 显示所有配置项
        if ($echo) {
            echo '<table border="1" cellpadding="5" cellspacing="0">';
            echo '<tr><th>配置名称</th><th>配置值</th></tr>';
            
            foreach ($CONFIG as $name => $content) {
                echo '<tr>';
                echo '<td>' . htmlspecialchars($name) . '</td>';
                echo '<td>' . htmlspecialchars($content) . '</td>';
                echo '</tr>';
            }
            
            echo '</table>';
        }
        
        return $CONFIG;
    }
}

/**
 * 配置初始化和可用性函数
 */

/**
 * 确保所有配置都可用的辅助函数
 * 在每个页面开始时调用此函数可确保所有配置变量都可用
 */
function ensureConfigsAvailable() {
    global $CONFIG;
    
    // 如果配置未加载，则加载
    if (empty($CONFIG)) {
        $CONFIG = getAllConfig();
    }
    
    // 确保所有配置都设置为全局变量
    foreach ($CONFIG as $key => $value) {
        $GLOBALS[$key] = $value;
    }
    
    // 对于某些特殊配置，提供多种访问方式
    foreach (['Scriptaddress', 'SiteName', 'Siteurl', 'Telegram', 'USDTaddress'] as $key) {
        if (isset($CONFIG[$key])) {
            // 注意大小写
            $GLOBALS[strtolower($key)] = $CONFIG[$key];
            $GLOBALS[strtoupper($key)] = $CONFIG[$key];
            
            // 直接定义为全局变量
            if ($key == 'Scriptaddress') {
                global $Scriptaddress, $scriptaddress, $SCRIPTADDRESS;
                $Scriptaddress = $CONFIG[$key];
                $scriptaddress = $CONFIG[$key];
                $SCRIPTADDRESS = $CONFIG[$key];
            }
        }
    }
}

/**
 * 获取配置项并确保所有配置变量都可用
 * 在每个页面顶部调用此函数以确保所有配置正确加载
 */
function load_all_configs() {
    global $CONFIG;
    
    // 加载所有配置
    $CONFIG = getAllConfig();
    
    // 使用extract将配置项设置为全局变量
    extract($CONFIG, EXTR_OVERWRITE);
    
    // 确保配置可用
    ensureConfigsAvailable();
    
    // 特别处理一些常用配置
    foreach (['SiteName', 'Siteurl', 'Telegram', 'Scriptaddress', 'USDTaddress'] as $key) {
        if (isset($CONFIG[$key])) {
            $GLOBALS[$key] = $CONFIG[$key];
        }
    }
}

/**
 * 调试和辅助函数
 */

/**
 * 显示所有配置项（调试用）
 */
function debugShowAllConfig() {
    global $CONFIG;
    
    echo "<pre>";
    echo "全局配置变量内容：\n";
    print_r($CONFIG);
    
    echo "\n\n单独的全局变量：\n";
    
    if (isset($CONFIG) && is_array($CONFIG)) {
        foreach ($CONFIG as $key => $value) {
            echo "$key: " . (isset($GLOBALS[$key]) ? $GLOBALS[$key] : "未设置") . "\n";
        }
    } else {
        echo "CONFIG 数组未正确初始化\n";
    }
    
    echo "</pre>";
}

/**
 * 调试变量的辅助函数
 * @param string $varName 变量名
 * @param bool $echo 是否直接输出结果
 * @return array 变量信息
 */
function debug_variable($varName, $echo = true) {
    global $CONFIG;
    
    $result = [
        'name' => $varName,
        'isset_global' => isset($GLOBALS[$varName]),
        'isset_config' => isset($CONFIG[$varName]),
        'value_global' => isset($GLOBALS[$varName]) ? $GLOBALS[$varName] : null,
        'value_config' => isset($CONFIG[$varName]) ? $CONFIG[$varName] : null
    ];
    
    if ($echo) {
        echo '<pre>';
        echo "变量名: {$varName}\n";
        echo "是否在GLOBALS中: " . ($result['isset_global'] ? '是' : '否') . "\n";
        echo "是否在CONFIG中: " . ($result['isset_config'] ? '是' : '否') . "\n";
        echo "GLOBALS中的值: " . print_r($result['value_global'], true) . "\n";
        echo "CONFIG中的值: " . print_r($result['value_config'], true) . "\n";
        echo '</pre>';
    }
    
    return $result;
}

/**
 * 业务逻辑函数
 */

/**
 * 计算用户余额函数
 * 计算方法：获取finance表中对应用户ID且payment_status为1的所有记录，将amount字段值相加
 * @param int $userId 用户ID
 * @return float 用户余额
 */
function calculateUserBalance($userId) {
    try {
        $db = getDbConnection();    
        $stmt = $db->prepare("
            SELECT SUM(amount) as total_balance 
            FROM finance 
            WHERE member_id = ? AND payment_status = 1
        ");
        $stmt->execute([$userId]);
        $result = $stmt->fetch();
        return $result['total_balance'] ? (float)$result['total_balance'] : 0;
    } catch (PDOException $e) {
        error_log("Error calculating user balance: " . $e->getMessage());
        return 0;
    }
}

/**
 * 初始化配置
 */

// 从数据库加载所有配置项并自动创建全局变量
$CONFIG = getAllConfig();

// 确保所有页面都能访问这些配置
extract($CONFIG, EXTR_SKIP);

// 确保特殊配置变量可用
ensureConfigsAvailable();

// 确保加载所有配置
load_all_configs();

?>
