<?php
include_once __DIR__ . '/../public/config.php';

class CartProduct {
    private $id;
    private $title;
    private $specs;
    private $pricing;
    private $db;
    
    public function __construct($id) {
        global $db;
        $this->db = $db;
        $this->id = $id;
        $this->loadProductData();
    }
    
    private function loadProductData() {
        // 从数据库获取产品信息
        $stmt = $this->db->prepare("SELECT * FROM products WHERE id = ?");
        $stmt->execute([$this->id]);
        $product = $stmt->fetch(PDO::FETCH_ASSOC);
        
        if ($product) {
            // 获取地区信息
            $stmt = $this->db->prepare("
                SELECT r.name as region_name, pr.name as parent_name 
                FROM regions r 
                LEFT JOIN regions pr ON r.parent_id = pr.id 
                WHERE r.id = ?
            ");
            $stmt->execute([$product['region_id']]);
            $region = $stmt->fetch(PDO::FETCH_ASSOC);
            
            // 获取线路信息
            $stmt = $this->db->prepare("SELECT name FROM lines WHERE id = ?");
            $stmt->execute([$product['line_id']]);
            $line = $stmt->fetch(PDO::FETCH_ASSOC);
            
            $locationText = $region ? ($region['parent_name'] . $region['region_name']) : '';
            
            $this->title = $locationText . "服务器 - " . ($product['type'] ?? '基础型');
            $this->specs = [
                'cpu' => $product['upc'] ?? '',
                'memory' => $product['memory'] ?? '',
                'disk' => $product['disk'] ?? '',
                'bandwidth' => $product['bandwidth'] ?? '',
                'ip_count' => $product['ip_count'] ?? '',
                'traffic' => $product['traffic'] ?? '',
                'defense' => $product['defense'] ?? '',
                'line' => $line['name'] ?? '',
                'location' => $locationText
            ];
            
            // 设置价格
            $basePrice = floatval($product['price']);
            $this->pricing = [
                'monthly' => $basePrice,
                'quarterly' => $basePrice * 3 * 0.95, // 季付95折
                'yearly' => $basePrice * 12 * 0.9    // 年付9折
            ];
        }
    }
    
    public function getTitle() {
        return $this->title;
    }
    
    public function getSpecs() {
        return $this->specs;
    }
    
    public function getPricing() {
        return $this->pricing;
    }
    
    public function calculatePrice($period, $quantity = 1, $config = []) {
        if (!isset($this->pricing[$period])) {
            return 0;
        }
        
        $basePrice = $this->pricing[$period];
        $totalPrice = $basePrice;
        
        // 处理额外配置的价格调整
        if (!empty($config)) {
            // 带宽调整
            if (isset($config['bandwidth'])) {
                $bandwidth = intval($config['bandwidth']);
                $defaultBandwidth = 100; // 默认带宽为100M
                
                if ($bandwidth > $defaultBandwidth) {
                    // 超出默认带宽的部分，每多1M带宽增加0.5元
                    $extraBandwidth = $bandwidth - $defaultBandwidth;
                    $totalPrice += $extraBandwidth * 0.5;
                }
            }
            
            // IP数量调整
            if (isset($config['ip_count'])) {
                $ipCount = intval($config['ip_count']);
                $defaultIpCount = 1; // 默认1个IP
                
                if ($ipCount > $defaultIpCount) {
                    // 每多1个IP增加10元
                    $extraIpCount = $ipCount - $defaultIpCount;
                    $totalPrice += $extraIpCount * 10;
                }
            }
            
            // 增值服务
            if (isset($config['addons']) && is_array($config['addons'])) {
                foreach ($config['addons'] as $addon) {
                    // 查询增值服务价格
                    $stmt = $this->db->prepare("SELECT price FROM addons WHERE id = ?");
                    $stmt->execute([intval($addon)]);
                    $addonPrice = $stmt->fetchColumn();
                    
                    if ($addonPrice) {
                        $totalPrice += floatval($addonPrice);
                    }
                }
            }
        }
        
        return $totalPrice * $quantity;
    }
}

class Cart {
    private $items = [];
    
    public function addProduct($productId, $quantity = 1, $config = []) {
        $product = new CartProduct($productId);
        $this->items[] = [
            'product' => $product,
            'quantity' => $quantity,
            'config' => $config
        ];
    }
    
    public function getItems() {
        return $this->items;
    }
    
    public function getTotalPrice($period = 'monthly') {
        $total = 0;
        foreach ($this->items as $item) {
            $total += $item['product']->calculatePrice($period, $item['quantity'], $item['config']);
        }
        return $total;
    }
}

// 处理POST请求
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $response = [];
    
    if (isset($_POST['action'])) {
        $cart = new Cart();
        
        switch ($_POST['action']) {
            case 'add_to_cart':
                if (isset($_POST['product_id'])) {
                    $config = [
                        'hostname' => $_POST['hostname'] ?? '',
                        'password' => $_POST['password'] ?? '',
                        'os_brand' => $_POST['os_brand'] ?? '',
                        'os_version' => $_POST['os_version'] ?? '',
                        'auto_renew' => isset($_POST['auto_renew']),
                        'addons' => $_POST['addons'] ?? []
                    ];
                    
                    $cart->addProduct(
                        $_POST['product_id'],
                        $_POST['quantity'] ?? 1,
                        $config
                    );
                    
                    $response = [
                        'status' => 'success',
                        'message' => '产品已添加到购物车'
                    ];
                }
                break;
                
            case 'get_product_info':
                if (isset($_POST['product_id'])) {
                    $product = new CartProduct($_POST['product_id']);
                    $response = [
                        'status' => 'success',
                        'data' => [
                            'title' => $product->getTitle(),
                            'specs' => $product->getSpecs(),
                            'pricing' => $product->getPricing()
                        ]
                    ];
                }
                break;
                
            case 'calculate_price':
                if (isset($_POST['product_id'])) {
                    $product = new CartProduct($_POST['product_id']);
                    $period = $_POST['period'] ?? 'monthly';
                    $quantity = intval($_POST['quantity'] ?? 1);
                    
                    // 收集额外配置选项
                    $config = [];
                    
                    // 带宽
                    if (isset($_POST['bandwidth'])) {
                        $config['bandwidth'] = intval($_POST['bandwidth']);
                    }
                    
                    // IP数量
                    if (isset($_POST['ip_count'])) {
                        $config['ip_count'] = intval($_POST['ip_count']);
                    }
                    
                    // 增值服务
                    if (isset($_POST['addon']) && is_array($_POST['addon'])) {
                        $config['addons'] = $_POST['addon'];
                    }
                    
                    $price = $product->calculatePrice($period, $quantity, $config);
                    
                    $response = [
                        'status' => 'success',
                        'data' => [
                            'price' => $price,
                            'formatted_price' => '$' . number_format($price, 2)
                        ]
                    ];
                }
                break;
        }
    }
    
    header('Content-Type: application/json');
    echo json_encode($response);
    exit;
}

// 添加一个辅助函数用于前端直接调用
function display_product_price($product_id, $period = 'monthly', $quantity = 1) {
    $product = new CartProduct($product_id);
    $price = $product->calculatePrice($period, $quantity);
    return '$' . number_format($price, 2);
}
