<?php
/**
 * FAQ数据获取函数
 * 用于从数据库中获取FAQ分类和问题数据
 */

// 定义ROOT_PATH常量(如果尚未定义)
if (!defined('ROOT_PATH')) {
    define('ROOT_PATH', dirname(dirname(__DIR__)));
}

// 引入数据库配置
require_once ROOT_PATH . '/config/database.php';

/**
 * 获取所有FAQ分类
 * 
 * @param bool $onlyActive 是否只获取激活状态的分类
 * @return array 分类数组
 */
function getFaqCategories($onlyActive = true) {
    $db = getDbConnection();
    
    $sql = "SELECT * FROM faq_category WHERE 1=1";
    if ($onlyActive) {
        $sql .= " AND status = 1";
    }
    $sql .= " ORDER BY sort_order ASC, id ASC";
    
    $stmt = $db->prepare($sql);
    $stmt->execute();
    
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

/**
 * 获取指定分类下的所有FAQ问题
 * 
 * @param int $categoryId 分类ID
 * @param bool $onlyActive 是否只获取激活状态的问题
 * @return array 问题数组
 */
function getFaqItemsByCategory($categoryId, $onlyActive = true) {
    $db = getDbConnection();
    
    $sql = "SELECT * FROM faq_item WHERE category_id = :category_id";
    if ($onlyActive) {
        $sql .= " AND status = 1";
    }
    $sql .= " ORDER BY sort_order ASC, id ASC";
    
    $stmt = $db->prepare($sql);
    $stmt->bindParam(':category_id', $categoryId, PDO::PARAM_INT);
    $stmt->execute();
    
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

/**
 * 获取所有FAQ分类及其问题
 * 
 * @param bool $onlyActive 是否只获取激活状态的分类和问题
 * @return array 包含分类和问题的嵌套数组
 */
function getAllFaqData($onlyActive = true) {
    $categories = getFaqCategories($onlyActive);
    $result = [];
    
    foreach ($categories as $category) {
        $items = getFaqItemsByCategory($category['id'], $onlyActive);
        $category['items'] = $items;
        $result[] = $category;
    }
    
    return $result;
}

/**
 * 搜索FAQ问题
 * 
 * @param string $keyword 搜索关键词
 * @param bool $onlyActive 是否只搜索激活状态的问题
 * @return array 匹配的问题数组
 */
function searchFaqItems($keyword, $onlyActive = true) {
    if (empty($keyword)) {
        return [];
    }
    
    $db = getDbConnection();
    
    $sql = "SELECT f.*, c.name as category_name, c.slug as category_slug
            FROM faq_item f
            JOIN faq_category c ON f.category_id = c.id
            WHERE (f.question LIKE :keyword OR f.answer LIKE :keyword)";
    
    if ($onlyActive) {
        $sql .= " AND f.status = 1 AND c.status = 1";
    }
    
    $sql .= " ORDER BY c.sort_order ASC, f.sort_order ASC";
    
    $stmt = $db->prepare($sql);
    $searchParam = '%' . $keyword . '%';
    $stmt->bindParam(':keyword', $searchParam, PDO::PARAM_STR);
    $stmt->execute();
    
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

/**
 * 根据分类标识(slug)获取分类信息
 * 
 * @param string $slug 分类标识
 * @return array|null 分类信息数组或null
 */
function getCategoryBySlug($slug) {
    $db = getDbConnection();
    
    $sql = "SELECT * FROM faq_category WHERE slug = :slug AND status = 1";
    $stmt = $db->prepare($sql);
    $stmt->bindParam(':slug', $slug, PDO::PARAM_STR);
    $stmt->execute();
    
    $result = $stmt->fetch(PDO::FETCH_ASSOC);
    return $result ?: null;
} 