// 服务器定制页面的JavaScript功能

document.addEventListener('DOMContentLoaded', function() {
  // FAQ展开/收起功能
  initFaqToggle();
  
  // 表单验证
  initFormValidation();
  
  // 动态更新表单选项
  initDynamicFormOptions();
});

/**
 * 初始化FAQ问答的展开/收起功能
 */
function initFaqToggle() {
  const faqQuestions = document.querySelectorAll('.faq-question');
  
  faqQuestions.forEach(question => {
    question.addEventListener('click', function() {
      const faqItem = this.parentElement;
      const faqAnswer = faqItem.querySelector('.faq-answer');
      
      // 切换当前项的展开状态
      faqItem.classList.toggle('active');
      
      // 设置答案区域的高度动画
      if (faqItem.classList.contains('active')) {
        faqAnswer.style.maxHeight = faqAnswer.scrollHeight + 'px';
      } else {
        faqAnswer.style.maxHeight = '0';
      }
    });
  });
  
  // 默认展开第一个FAQ
  if (faqQuestions.length > 0) {
    faqQuestions[0].click();
  }
}

/**
 * 初始化表单验证
 */
function initFormValidation() {
  const customForm = document.querySelector('.custom-form form');
  
  if (customForm) {
    customForm.addEventListener('submit', function(e) {
      let isValid = true;
      const requiredFields = customForm.querySelectorAll('input[required], select[required], textarea[required]');
      
      requiredFields.forEach(field => {
        if (!field.value.trim()) {
          isValid = false;
          field.classList.add('error');
        } else {
          field.classList.remove('error');
        }
      });
      
      // 验证邮箱格式
      const emailField = customForm.querySelector('#email');
      if (emailField && emailField.value) {
        const emailPattern = /^[^\s@]+@[^\s@]+\.[^\s@]+$/;
        if (!emailPattern.test(emailField.value)) {
          isValid = false;
          emailField.classList.add('error');
        }
      }
      
      if (!isValid) {
        e.preventDefault();
        alert('请填写所有必填字段并确保信息格式正确');
      }
    });
  }
}

/**
 * 初始化动态表单选项
 */
function initDynamicFormOptions() {
  // 服务器类型变更时更新相关选项
  const serverTypeSelect = document.querySelector('#server_type');
  
  if (serverTypeSelect) {
    serverTypeSelect.addEventListener('change', function() {
      updateCpuOptions(this.value);
      updateMemoryOptions(this.value);
    });
  }
  
  // 自定义选项处理
  const selects = document.querySelectorAll('select');
  selects.forEach(select => {
    select.addEventListener('change', function() {
      if (this.value === 'custom') {
        const fieldName = this.id;
        const customValue = prompt(`请输入您需要的${getFieldLabel(fieldName)}:`);
        if (customValue) {
          // 在这里可以处理自定义值，例如添加到隐藏字段或显示在页面上
          console.log(`自定义${getFieldLabel(fieldName)}: ${customValue}`);
        }
      }
    });
  });
}

/**
 * 根据服务器类型更新CPU选项
 */
function updateCpuOptions(serverType) {
  const cpuSelect = document.querySelector('#cpu');
  if (!cpuSelect) return;
  
  // 保存当前选中值
  const currentValue = cpuSelect.value;
  
  // 清空现有选项，保留第一个
  while (cpuSelect.options.length > 1) {
    cpuSelect.remove(1);
  }
  
  // 根据服务器类型添加不同的CPU选项
  let options = [];
  
  switch(serverType) {
    case 'physical':
      options = [
        {value: 'e3_4c', text: 'E3系列 4核'},
        {value: 'e5_8c', text: 'E5系列 8核'},
        {value: 'e5_16c', text: 'E5系列 16核'},
        {value: 'e7_24c', text: 'E7系列 24核'},
        {value: 'amd_8c', text: 'AMD EPYC 8核'},
        {value: 'amd_16c', text: 'AMD EPYC 16核'},
        {value: 'amd_32c', text: 'AMD EPYC 32核'}
      ];
      break;
    case 'cloud':
      options = [
        {value: 'vcpu_2c', text: '2核 vCPU'},
        {value: 'vcpu_4c', text: '4核 vCPU'},
        {value: 'vcpu_8c', text: '8核 vCPU'},
        {value: 'vcpu_16c', text: '16核 vCPU'},
        {value: 'vcpu_32c', text: '32核 vCPU'}
      ];
      break;
    case 'high_performance':
      options = [
        {value: 'e5_16c', text: 'E5系列 16核'},
        {value: 'e7_24c', text: 'E7系列 24核'},
        {value: 'e7_32c', text: 'E7系列 32核'},
        {value: 'amd_32c', text: 'AMD EPYC 32核'},
        {value: 'amd_64c', text: 'AMD EPYC 64核'},
        {value: 'dual_cpu', text: '双路CPU'}
      ];
      break;
    default:
      options = [
        {value: 'e3_4c', text: 'E3系列 4核'},
        {value: 'e5_8c', text: 'E5系列 8核'},
        {value: 'e5_16c', text: 'E5系列 16核'},
        {value: 'amd_8c', text: 'AMD EPYC 8核'}
      ];
  }
  
  // 添加选项
  options.forEach(option => {
    const opt = document.createElement('option');
    opt.value = option.value;
    opt.textContent = option.text;
    cpuSelect.appendChild(opt);
  });
  
  // 添加自定义选项
  const customOpt = document.createElement('option');
  customOpt.value = 'custom';
  customOpt.textContent = '自定义';
  cpuSelect.appendChild(customOpt);
  
  // 尝试恢复之前的选择
  if (currentValue && Array.from(cpuSelect.options).some(opt => opt.value === currentValue)) {
    cpuSelect.value = currentValue;
  }
}

/**
 * 根据服务器类型更新内存选项
 */
function updateMemoryOptions(serverType) {
  const memorySelect = document.querySelector('#memory');
  if (!memorySelect) return;
  
  // 保存当前选中值
  const currentValue = memorySelect.value;
  
  // 清空现有选项，保留第一个
  while (memorySelect.options.length > 1) {
    memorySelect.remove(1);
  }
  
  // 根据服务器类型添加不同的内存选项
  let options = [];
  
  switch(serverType) {
    case 'physical':
      options = [
        {value: '16gb', text: '16GB'},
        {value: '32gb', text: '32GB'},
        {value: '64gb', text: '64GB'},
        {value: '128gb', text: '128GB'},
        {value: '256gb', text: '256GB'}
      ];
      break;
    case 'cloud':
      options = [
        {value: '2gb', text: '2GB'},
        {value: '4gb', text: '4GB'},
        {value: '8gb', text: '8GB'},
        {value: '16gb', text: '16GB'},
        {value: '32gb', text: '32GB'}
      ];
      break;
    case 'high_performance':
      options = [
        {value: '64gb', text: '64GB'},
        {value: '128gb', text: '128GB'},
        {value: '256gb', text: '256GB'},
        {value: '512gb', text: '512GB'},
        {value: '1tb', text: '1TB'}
      ];
      break;
    default:
      options = [
        {value: '8gb', text: '8GB'},
        {value: '16gb', text: '16GB'},
        {value: '32gb', text: '32GB'},
        {value: '64gb', text: '64GB'}
      ];
  }
  
  // 添加选项
  options.forEach(option => {
    const opt = document.createElement('option');
    opt.value = option.value;
    opt.textContent = option.text;
    memorySelect.appendChild(opt);
  });
  
  // 添加自定义选项
  const customOpt = document.createElement('option');
  customOpt.value = 'custom';
  customOpt.textContent = '自定义';
  memorySelect.appendChild(customOpt);
  
  // 尝试恢复之前的选择
  if (currentValue && Array.from(memorySelect.options).some(opt => opt.value === currentValue)) {
    memorySelect.value = currentValue;
  }
}

/**
 * 获取字段的中文标签
 */
function getFieldLabel(fieldName) {
  const labels = {
    'cpu': 'CPU配置',
    'memory': '内存配置',
    'storage': '存储配置',
    'bandwidth': '带宽配置',
    'ip_count': 'IP数量',
    'location': '服务器位置',
    'os': '操作系统'
  };
  
  return labels[fieldName] || fieldName;
}