/**
 * 视频详情页面JavaScript功能
 */
document.addEventListener('DOMContentLoaded', function() {
    // 打印视频播放器元素，确认是否存在
    console.log("查找播放器元素:", document.getElementById('youtubePlayer'));
    
    // 延迟初始化播放器，确保DOM完全加载
    setTimeout(function() {
        // 初始化YouTube播放器
        initYouTubePlayer();
    }, 500);
    
    // 初始化点赞、分享和收藏功能
    initActionButtons();
    
    // 初始化评论系统
    initCommentSystem();
});

/**
 * 初始化YouTube播放器
 */
function initYouTubePlayer() {
    const youtubeIframe = document.getElementById('youtubePlayer');
    console.log("初始化播放器，找到iframe:", youtubeIframe);
    
    // 如果找不到播放器元素，则返回
    if (!youtubeIframe) {
        console.error("未找到YouTube播放器iframe元素");
        return;
    }
    
    // 获取视频ID
    const videoId = youtubeIframe.getAttribute('data-id');
    if (!videoId) {
        console.error("YouTube iframe缺少data-id属性");
        return;
    }
    
    console.log("初始化播放器，视频ID:", videoId);
    
    // 设置播放记录标志，避免重复计数
    let hasRecordedView = false;
    
    // 监听视频加载完成和播放事件
    youtubeIframe.addEventListener('load', function() {
        console.log("YouTube iframe已加载");
    });
    
    // 加载YouTube API
    loadYouTubeAPI(function() {
        try {
            // 确保iframe仍存在
            if (!document.getElementById('youtubePlayer')) {
                console.error("无法找到YouTube iframe");
                return;
            }
            
            // 创建播放器实例
            console.log("创建YT播放器实例");
            new YT.Player('youtubePlayer', {
                events: {
                    'onReady': function(event) {
                        console.log("YouTube播放器准备就绪");
                    },
                    'onStateChange': function(event) {
                        console.log("YouTube播放器状态变化:", event.data);
                        // 状态变化: -1(未开始), 0(结束), 1(播放), 2(暂停), 3(缓冲), 5(已插入视频)
                        switch (event.data) {
                            case YT.PlayerState.ENDED: // 视频结束
                                console.log('视频播放结束');
                                showRelatedVideos();
                                break;
                            case YT.PlayerState.PLAYING: // 开始播放
                                console.log('视频开始播放');
                                // 记录播放次数（只记录一次）
                                if (!hasRecordedView) {
                                    // 延迟几秒再计数，避免快速点击
                                    setTimeout(function() {
                                        incrementViewCount(videoId);
                                        hasRecordedView = true;
                                    }, 5000);
                                }
                                break;
                        }
                    },
                    'onError': function(event) {
                        console.error("YouTube播放器错误:", event.data);
                    }
                }
            });
        } catch (e) {
            console.error("初始化YouTube播放器时出错:", e);
        }
    });
    
    // 备选的消息监听方法（兼容性考虑）
    window.addEventListener('message', function(event) {
        // 检查消息来源
        if (event.origin.indexOf('youtube.com') === -1) return;
        
        try {
            let data;
            // 尝试解析消息数据
            if (typeof event.data === 'string') {
                try {
                    data = JSON.parse(event.data);
                } catch (e) {
                    // 可能是非JSON格式消息，忽略
                    return;
                }
            } else {
                data = event.data;
            }
            
            if (data.event === 'onStateChange' && !hasRecordedView && data.info === 1) {
                console.log("通过消息事件检测到播放");
                // 播放状态
                setTimeout(function() {
                    incrementViewCount(videoId);
                    hasRecordedView = true;
                }, 5000);
            }
        } catch (e) {
            console.warn("处理YouTube消息时出错:", e);
        }
    });
}

/**
 * 加载YouTube iframe API
 */
function loadYouTubeAPI(callback) {
    console.log("开始加载YouTube API");
    
    // 如果API已加载，直接调用回调
    if (window.YT && window.YT.Player) {
        console.log("YouTube API已加载");
        callback();
        return;
    }
    
    // 原有的回调可能被覆盖，将其保存
    const oldCallback = window.onYouTubeIframeAPIReady;
    
    // 设置新的回调
    window.onYouTubeIframeAPIReady = function() {
        console.log("YouTube API准备就绪");
        // 调用原有回调
        if (typeof oldCallback === 'function') {
            oldCallback();
        }
        // 调用我们的回调
        callback();
    };
    
    // 加载API脚本
    if (!document.querySelector('script[src*="youtube.com/iframe_api"]')) {
        const tag = document.createElement('script');
        tag.src = 'https://www.youtube.com/iframe_api';
        console.log("添加YouTube API脚本");
        const firstScriptTag = document.getElementsByTagName('script')[0];
        firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);
    }
}

/**
 * 记录播放次数
 */
function incrementViewCount(videoId) {
    fetch('/api/video/view.php', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json',
        },
        body: JSON.stringify({ videoId: videoId })
    })
    .then(response => response.json())
    .then(data => {
        console.log('观看次数已更新', data);
        // 可以在这里更新页面上的观看次数显示
        updateViewCountDisplay();
    })
    .catch(error => {
        console.error('更新观看次数失败:', error);
    });
}

/**
 * 更新页面上的观看次数显示
 */
function updateViewCountDisplay() {
    const viewsElement = document.querySelector('.video-views');
    if (viewsElement) {
        const currentText = viewsElement.textContent;
        const currentCount = parseInt(currentText.replace(/[^0-9]/g, ''));
        if (!isNaN(currentCount)) {
            const newCount = currentCount + 1;
            const formattedCount = new Intl.NumberFormat('zh-CN').format(newCount);
            viewsElement.innerHTML = `<i class="material-icons">visibility</i> ${formattedCount}次观看`;
        }
    }
}

/**
 * 初始化操作按钮（点赞、分享、收藏）
 */
function initActionButtons() {
    // 点赞按钮
    const likeBtn = document.querySelector('.like-btn');
    if (likeBtn) {
        likeBtn.addEventListener('click', function() {
            const likeCount = this.querySelector('.like-count');
            const likeIcon = this.querySelector('.material-icons');
            
            // 切换点赞状态
            if (this.classList.contains('liked')) {
                this.classList.remove('liked');
                likeIcon.textContent = 'thumb_up_off_alt';
                if (likeCount) {
                    let count = parseInt(likeCount.textContent);
                    likeCount.textContent = Math.max(0, count - 1);
                }
            } else {
                this.classList.add('liked');
                likeIcon.textContent = 'thumb_up_alt';
                if (likeCount) {
                    let count = parseInt(likeCount.textContent);
                    likeCount.textContent = count + 1;
                }
            }
            
            // 向服务器发送点赞请求
            const videoId = this.dataset.id;
            updateLikeStatus(videoId, this.classList.contains('liked'));
        });
    }
    
    // 分享按钮
    const shareBtn = document.querySelector('.share-btn');
    if (shareBtn) {
        shareBtn.addEventListener('click', function() {
            // 如果浏览器支持Web Share API，则使用它
            if (navigator.share) {
                navigator.share({
                    title: document.querySelector('.video-title').textContent,
                    url: window.location.href
                }).then(() => {
                    console.log('分享成功');
                }).catch((error) => {
                    console.log('分享失败：', error);
                    showShareDialog();
                });
            } else {
                // 否则显示自定义分享对话框
                showShareDialog();
            }
        });
    }
    
    // 收藏按钮
    const saveBtn = document.querySelector('.save-btn');
    if (saveBtn) {
        saveBtn.addEventListener('click', function() {
            const saveIcon = this.querySelector('.material-icons');
            
            // 切换收藏状态
            if (this.classList.contains('saved')) {
                this.classList.remove('saved');
                saveIcon.textContent = 'bookmark_border';
                showToast('已取消收藏');
            } else {
                this.classList.add('saved');
                saveIcon.textContent = 'bookmark';
                showToast('已添加到收藏');
            }
            
            // 向服务器发送收藏请求
            const videoId = this.dataset.id;
            updateSaveStatus(videoId, this.classList.contains('saved'));
        });
    }
}

/**
 * 初始化评论系统
 */
function initCommentSystem() {
    const commentForm = document.getElementById('commentForm');
    if (!commentForm) return;
    
    commentForm.addEventListener('submit', function(e) {
        e.preventDefault();
        
        const commentTextarea = this.querySelector('textarea');
        const commentText = commentTextarea.value.trim();
        const videoId = this.querySelector('input[name="video_id"]').value;
        
        if (commentText === '') {
            showToast('请输入评论内容');
            return;
        }
        
        // 显示提交中状态
        const submitBtn = this.querySelector('.comment-submit');
        const originalBtnText = submitBtn.textContent;
        submitBtn.textContent = '提交中...';
        submitBtn.disabled = true;
        
        // 提交评论到服务器
        submitComment(videoId, commentText)
            .then(response => {
                if (response.success) {
                    // 添加新评论到列表
                    addNewComment(response.data);
                    
                    // 重置表单
                    commentTextarea.value = '';
                    showToast('评论发表成功');
                    
                    // 更新评论数量
                    updateCommentCount(1);
                } else {
                    showToast(response.message || '评论提交失败，请重试');
                }
            })
            .catch(error => {
                console.error('评论提交错误:', error);
                showToast('评论提交失败，请重试');
            })
            .finally(() => {
                submitBtn.textContent = originalBtnText;
                submitBtn.disabled = false;
            });
    });
    
    // 初始化评论操作（回复、点赞等）
    initCommentActions();
    
    // 初始化加载更多评论功能
    const viewMoreBtn = document.querySelector('.view-more-comments button');
    if (viewMoreBtn) {
        viewMoreBtn.addEventListener('click', function() {
            loadMoreComments(this);
        });
    }
}

/**
 * 提交评论到服务器
 */
function submitComment(videoId, content, parentId = 0) {
    return fetch('/api/comment/add.php', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json',
        },
        body: JSON.stringify({
            video_id: videoId,
            content: content,
            parent_id: parentId
        })
    })
    .then(response => response.json());
}

/**
 * 添加新评论到DOM
 */
function addNewComment(commentData) {
    const commentsList = document.querySelector('.comments-list');
    
    // 如果是首条评论，清除"暂无评论"提示
    const noComments = commentsList.querySelector('.no-comments');
    if (noComments) {
        noComments.remove();
    }
    
    // 创建新评论元素
    const commentItem = document.createElement('div');
    commentItem.className = 'comment-item';
    commentItem.dataset.id = 'comment-' + commentData.id;
    
    commentItem.innerHTML = `
        <div class="comment-avatar">
            <img src="http://temp.im/40x40" alt="用户头像">
        </div>
        <div class="comment-content">
            <div class="comment-header">
                <span class="comment-author">${commentData.author_name || '匿名用户'}</span>
                <span class="comment-time">${commentData.created_at || new Date().toISOString().split('T')[0]}</span>
            </div>
            <div class="comment-text">
                ${commentData.content}
            </div>
            <div class="comment-actions">
                <a href="#" class="comment-like" data-id="${commentData.id}">
                    <i class="material-icons">thumb_up_off_alt</i> <span>0</span>
                </a>
                <a href="#" class="comment-reply" data-id="${commentData.id}">回复</a>
            </div>
        </div>
    `;
    
    // 添加到列表顶部
    commentsList.insertBefore(commentItem, commentsList.firstChild);
    
    // 绑定新评论的点赞和回复事件
    bindCommentEvents(commentItem);
}

/**
 * 绑定评论的点赞和回复事件
 */
function bindCommentEvents(commentElement) {
    const likeBtn = commentElement.querySelector('.comment-like');
    const replyBtn = commentElement.querySelector('.comment-reply');
    
    if (likeBtn) {
        likeBtn.addEventListener('click', function(e) {
            e.preventDefault();
            
            const likeIcon = this.querySelector('.material-icons');
            const likeCount = this.querySelector('span');
            
            if (this.classList.contains('active')) {
                this.classList.remove('active');
                likeIcon.textContent = 'thumb_up_off_alt';
                if (likeCount) {
                    let count = parseInt(likeCount.textContent);
                    likeCount.textContent = Math.max(0, count - 1);
                }
            } else {
                this.classList.add('active');
                likeIcon.textContent = 'thumb_up_alt';
                if (likeCount) {
                    let count = parseInt(likeCount.textContent);
                    likeCount.textContent = count + 1;
                }
            }
            
            // 向服务器发送评论点赞请求
            const commentId = this.dataset.id;
            updateCommentLike(commentId, this.classList.contains('active'));
        });
    }
    
    if (replyBtn) {
        replyBtn.addEventListener('click', function(e) {
            e.preventDefault();
            
            const commentItem = this.closest('.comment-item');
            const commentAuthor = commentItem.querySelector('.comment-author').textContent;
            
            const commentTextarea = document.querySelector('.comment-form textarea');
            commentTextarea.value = `@${commentAuthor} `;
            commentTextarea.focus();
            
            // 添加隐藏字段存储父评论ID
            let parentIdField = document.querySelector('.comment-form input[name="parent_id"]');
            if (!parentIdField) {
                parentIdField = document.createElement('input');
                parentIdField.type = 'hidden';
                parentIdField.name = 'parent_id';
                document.querySelector('.comment-form').appendChild(parentIdField);
            }
            parentIdField.value = this.dataset.id;
            
            // 滚动到评论表单
            document.querySelector('.comment-form').scrollIntoView({ behavior: 'smooth' });
        });
    }
}

/**
 * 加载更多评论
 */
function loadMoreComments(button) {
    // 显示加载状态
    button.textContent = '加载中...';
    button.disabled = true;
    
    const videoId = button.dataset.videoId;
    const commentsList = document.querySelector('.comments-list');
    const commentsCount = commentsList.querySelectorAll('.comment-item').length;
    
    // 请求加载更多评论
    fetch(`/api/comment/list.php?video_id=${videoId}&offset=${commentsCount}&limit=10`)
        .then(response => response.json())
        .then(data => {
            if (data.success && data.data.comments.length > 0) {
                // 添加新评论到列表
                data.data.comments.forEach(comment => {
                    const commentItem = document.createElement('div');
                    commentItem.className = 'comment-item';
                    commentItem.dataset.id = 'comment-' + comment.id;
                    
                    commentItem.innerHTML = `
                        <div class="comment-avatar">
                            <img src="http://temp.im/40x40" alt="用户头像">
                        </div>
                        <div class="comment-content">
                            <div class="comment-header">
                                <span class="comment-author">${comment.author_name || (comment.username || '匿名用户')}</span>
                                <span class="comment-time">${comment.created_at}</span>
                            </div>
                            <div class="comment-text">
                                ${comment.content}
                            </div>
                            <div class="comment-actions">
                                <a href="#" class="comment-like" data-id="${comment.id}">
                                    <i class="material-icons">thumb_up_off_alt</i> <span>${comment.likes || 0}</span>
                                </a>
                                <a href="#" class="comment-reply" data-id="${comment.id}">回复</a>
                            </div>
                        </div>
                    `;
                    
                    commentsList.appendChild(commentItem);
                    bindCommentEvents(commentItem);
                });
                
                // 如果没有更多评论，隐藏加载更多按钮
                if (!data.data.has_more) {
                    button.closest('.view-more-comments').style.display = 'none';
                }
            } else {
                // 没有更多评论，隐藏按钮
                button.closest('.view-more-comments').style.display = 'none';
            }
        })
        .catch(error => {
            console.error('加载评论失败:', error);
            showToast('加载评论失败，请重试');
        })
        .finally(() => {
            button.textContent = '查看更多评论';
            button.disabled = false;
        });
}

/**
 * 更新评论数量显示
 */
function updateCommentCount(increment) {
    const countElement = document.querySelector('.video-comments h3');
    if (countElement) {
        const countMatch = countElement.textContent.match(/\((\d+)\)/);
        if (countMatch) {
            const currentCount = parseInt(countMatch[1]);
            const newCount = currentCount + increment;
            countElement.textContent = `评论 (${newCount})`;
        }
    }
}

/**
 * 显示分享对话框
 */
function showShareDialog() {
    // 这里可以实现自定义分享对话框
    // 例如弹出一个包含分享链接和社交媒体按钮的模态框
    alert('分享链接：' + window.location.href);
}

/**
 * 显示相关推荐视频
 */
function showRelatedVideos() {
    // 视频结束后的相关推荐逻辑
    console.log('显示相关推荐视频');
    // 可以在这里添加代码来突出显示推荐视频区域
}

/**
 * 显示提示信息
 */
function showToast(message, duration = 3000) {
    let toast = document.querySelector('.toast-message');
    
    if (!toast) {
        toast = document.createElement('div');
        toast.className = 'toast-message';
        document.body.appendChild(toast);
        
        // 添加样式
        toast.style.position = 'fixed';
        toast.style.bottom = '20px';
        toast.style.left = '50%';
        toast.style.transform = 'translateX(-50%)';
        toast.style.padding = '10px 20px';
        toast.style.background = 'rgba(0, 0, 0, 0.7)';
        toast.style.color = '#fff';
        toast.style.borderRadius = '4px';
        toast.style.zIndex = '9999';
        toast.style.transition = 'opacity 0.3s ease-in-out';
    }
    
    // 设置消息内容并显示
    toast.textContent = message;
    toast.style.opacity = '1';
    
    // 定时隐藏
    clearTimeout(toast.hideTimeout);
    toast.hideTimeout = setTimeout(() => {
        toast.style.opacity = '0';
    }, duration);
}

/**
 * 更新视频点赞状态（向服务器发送请求）
 */
function updateLikeStatus(videoId, isLiked) {
    // 实际项目中，这里应该发送AJAX请求到服务器
    console.log('更新视频点赞状态：', { videoId, isLiked });
    // fetch('/api/videos/' + videoId + '/like', {
    //     method: 'POST',
    //     headers: {
    //         'Content-Type': 'application/json',
    //     },
    //     body: JSON.stringify({ isLiked }),
    // })
    // .then(response => response.json())
    // .then(data => console.log('点赞成功：', data))
    // .catch(error => console.error('点赞失败：', error));
}

/**
 * 更新视频收藏状态（向服务器发送请求）
 */
function updateSaveStatus(videoId, isSaved) {
    // 实际项目中，这里应该发送AJAX请求到服务器
    console.log('更新视频收藏状态：', { videoId, isSaved });
    // fetch('/api/videos/' + videoId + '/save', {
    //     method: 'POST',
    //     headers: {
    //         'Content-Type': 'application/json',
    //     },
    //     body: JSON.stringify({ isSaved }),
    // })
    // .then(response => response.json())
    // .then(data => console.log('收藏成功：', data))
    // .catch(error => console.error('收藏失败：', error));
}

/**
 * 更新评论点赞状态（向服务器发送请求）
 */
function updateCommentLike(commentId, isLiked) {
    // 实际项目中，这里应该发送AJAX请求到服务器
    console.log('更新评论点赞状态：', { commentId, isLiked });
    // fetch('/api/comments/' + commentId + '/like', {
    //     method: 'POST',
    //     headers: {
    //         'Content-Type': 'application/json',
    //     },
    //     body: JSON.stringify({ isLiked }),
    // })
    // .then(response => response.json())
    // .then(data => console.log('评论点赞成功：', data))
    // .catch(error => console.error('评论点赞失败：', error));
} 