<?php
/**
 * 聊天API接口
 * 处理聊天消息的发送和接收
 */

// 启用错误报告（生产环境中应当关闭）
ini_set('display_errors', 1);
error_reporting(E_ALL);

// 设置响应头为JSON
header('Content-Type: application/json');

// 引入数据库连接
require_once '../../config/database.php';
session_start();

// 日志记录函数
function logMessage($message) {
    error_log("[聊天API] " . $message);
}

// 当前时间标记，用于调试
$now = date('Y-m-d H:i:s');
logMessage("API请求开始: " . $now);

// 检查用户会话
$user_id = isset($_SESSION['user_id']) ? $_SESSION['user_id'] : 0;

// 如果用户未登录，返回错误
if ($user_id <= 0) {
    $response = [
        'success' => false,
        'message' => '用户未登录',
        'data' => null
    ];
    echo json_encode($response);
    exit;
}

// 获取数据库连接
$db = getDbConnection();

// 定义响应数组
$response = [
    'success' => false,
    'message' => '',
    'data' => null
];

// 处理API请求
$action = '';

// 获取请求方法
$method = $_SERVER['REQUEST_METHOD'];
logMessage("请求方法: " . $method);

if ($method === 'GET') {
    // 处理GET请求
    $action = isset($_GET['action']) ? $_GET['action'] : '';
    logMessage("GET请求操作: " . $action);
    
    // 根据操作执行相应功能
    switch ($action) {
        case 'get_messages':
            getMessages($db, $response, $user_id);
            break;
            
        case 'get_settings':
            getSettings($db, $response);
            break;
            
        default:
            $response['message'] = '未知的操作请求';
    }
} else if ($method === 'POST') {
    // 处理POST请求
    // 获取POST数据
    $json = file_get_contents('php://input');
    logMessage("接收POST数据: " . $json);
    
    $data = json_decode($json, true);
    
    if ($data && isset($data['action'])) {
        $action = $data['action'];
        logMessage("POST请求操作: " . $action);
        
        switch ($action) {
            case 'send_message':
                sendMessage($db, $data, $response, $user_id);
                break;
                
            default:
                $response['message'] = '未知的操作请求';
        }
    } else {
        $response['message'] = '无效的请求数据';
        logMessage("无效的请求数据: " . $json);
    }
} else {
    $response['message'] = '不支持的请求方法';
    logMessage("不支持的请求方法: " . $method);
}

// 输出响应
logMessage("API响应: " . json_encode($response));
echo json_encode($response);

/**
 * 获取消息列表
 */
function getMessages($db, &$response, $user_id) {
    // 获取最近的消息更新时间戳，如果没有则返回所有消息
    $last_check = isset($_GET['last_check']) ? $_GET['last_check'] : 0;
    
    logMessage("获取消息: user_id=" . $user_id . ", last_check=" . $last_check);
    
    try {
        $query = "SELECT * FROM chat_messages WHERE user_id = :user_id ORDER BY created_at ASC";
        $params = [':user_id' => $user_id];
        
        // 如果有last_check参数，则只获取最近的消息
        if ($last_check > 0) {
            // 将时间戳转换为日期时间
            $last_check_date = date('Y-m-d H:i:s', intval($last_check / 1000) - 30); // 减去30秒以确保不会遗漏
            $query = "SELECT * FROM chat_messages WHERE user_id = :user_id AND created_at > :last_check ORDER BY created_at ASC";
            $params[':last_check'] = $last_check_date;
        }
        
        // 查询消息
        $stmt = $db->prepare($query);
        $stmt->execute($params);
        $messages = $stmt->fetchAll(PDO::FETCH_ASSOC);
        
        logMessage("查询到消息数量: " . count($messages));
        
        // 更新管理员发送的消息为已读
        if (!empty($messages)) {
            $updateQuery = "UPDATE chat_messages SET is_read = 1 WHERE user_id = :user_id AND admin_id IS NOT NULL AND is_read = 0";
            $stmt = $db->prepare($updateQuery);
            $stmt->execute([':user_id' => $user_id]);
            logMessage("更新消息为已读");
        }
        
        $response['success'] = true;
        $response['messages'] = $messages;
    } catch (PDOException $e) {
        $response['message'] = '获取消息失败: ' . $e->getMessage();
        logMessage("获取消息数据库错误: " . $e->getMessage());
    }
}

/**
 * 发送消息
 */
function sendMessage($db, $data, &$response, $user_id) {
    // 验证消息内容
    if (!isset($data['message']) || empty($data['message'])) {
        $response['message'] = '消息内容不能为空';
        logMessage("发送消息错误: 消息内容为空");
        return;
    }
    
    $message = $data['message'];
    
    logMessage("发送消息: user_id=" . $user_id . ", message=" . $message);
    
    try {
        // 插入用户消息
        $stmt = $db->prepare("
            INSERT INTO chat_messages 
            (user_id, admin_id, message, is_read, created_at) 
            VALUES 
            (?, NULL, ?, 1, NOW())
        ");
        
        $stmt->execute([$user_id, $message]);
        
        $userMessageId = $db->lastInsertId();
        logMessage("用户消息插入成功，ID: " . $userMessageId);
        
        $response['success'] = true;
        $response['message'] = '消息发送成功';
        $response['message_id'] = $userMessageId;
        
        // 模拟客服回复
        simulateAgentReply($db, $user_id);
        
    } catch (PDOException $e) {
        $response['message'] = '发送消息失败: ' . $e->getMessage();
        logMessage("发送消息数据库错误: " . $e->getMessage());
    }
}

/**
 * 模拟客服回复
 */
function simulateAgentReply($db, $user_id) {
    logMessage("模拟客服回复");
    
    // 随机等待1-3秒，模拟客服回复的延迟
    sleep(rand(1, 3));
    
    try {
        // 预设的客服回复内容
        $replies = [
            "您好，很高兴为您服务！",
            "感谢您的咨询，我会尽快处理您的问题。",
            "您的问题已经收到，我们的专业团队正在处理中。",
            "请问还有其他问题需要帮助吗？",
            "您的满意是我们的追求，如有其他问题请随时咨询。"
        ];
        
        // 随机选择一条回复
        $replyContent = $replies[array_rand($replies)];
        
        // 插入客服回复
        $stmt = $db->prepare("
            INSERT INTO chat_messages 
            (user_id, admin_id, message, is_read, created_at) 
            VALUES 
            (?, 1, ?, 0, NOW())
        ");
        
        $stmt->execute([$user_id, $replyContent]);
        
        logMessage("客服回复已发送: " . $replyContent);
    } catch (PDOException $e) {
        logMessage("模拟客服回复失败: " . $e->getMessage());
    }
}

/**
 * 获取系统设置
 */
function getSettings($db, &$response) {
    try {
        // 查询系统设置
        $stmt = $db->query("SELECT setting_key, setting_value FROM ocs_settings");
        $settings = [];
        
        while ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
            $settings[$row['setting_key']] = $row['setting_value'];
        }
        
        $response['success'] = true;
        $response['settings'] = $settings;
    } catch (PDOException $e) {
        $response['message'] = '获取设置失败: ' . $e->getMessage();
        logMessage("获取设置数据库错误: " . $e->getMessage());
    }
} 