<?php
/**
 * 用户认证处理文件
 * 用于验证用户是否已登录，未登录则重定向到登录页面
 */

// 启动会话
if (session_status() === PHP_SESSION_NONE) {
    session_start();
}

/**
 * 检查用户是否已登录
 * @return bool 返回用户是否已登录
 */
function isLoggedIn() {
    return isset($_SESSION['user_id']) && !empty($_SESSION['user_id']);
}

/**
 * 获取当前登录用户ID
 * @return int|null 返回用户ID，未登录则返回null
 */
function getCurrentUserId() {
    return $_SESSION['user_id'] ?? null;
}

/**
 * 获取当前登录用户名
 * @return string|null 返回用户名，未登录则返回null
 */
function getCurrentUsername() {
    return $_SESSION['username'] ?? null;
}

/**
 * 获取当前用户的完整信息
 * @return array|null 返回用户信息数组，未登录则返回null
 */
function getCurrentUserInfo() {
    if (!isLoggedIn()) {
        return null;
    }
    
    require_once __DIR__ . '/../../config/database.php';
    try {
        $db = getDbConnection();
        $stmt = $db->prepare("SELECT * FROM user WHERE id = ?");
        $stmt->execute([getCurrentUserId()]);
        return $stmt->fetch();
    } catch (PDOException $e) {
        error_log("Error fetching user info: " . $e->getMessage());
        return null;
    }
}

/**
 * 要求用户登录
 * 如果用户未登录，将重定向到登录页面
 */
function requireLogin() {
    if (!isLoggedIn()) {
        // 保存当前URL到会话中，以便登录后返回
        $_SESSION['redirect_after_login'] = $_SERVER['REQUEST_URI'];
        
        // 重定向到登录页面
        header('Location: login.php');
        exit;
    }
}

/**
 * 处理登录后的重定向
 * 如果存在之前保存的URL，则重定向到该URL
 */
function handleLoginRedirect() {
    if (isset($_SESSION['redirect_after_login'])) {
        $redirect_url = $_SESSION['redirect_after_login'];
        unset($_SESSION['redirect_after_login']); // 清除保存的URL
        header('Location: ' . $redirect_url);
        exit;
    }
    
    // 默认重定向到用户中心
    header('Location: index.php');
    exit;
}

/**
 * 处理用户退出登录
 */
function logout() {
    // 清除所有会话变量
    $_SESSION = array();
    
    // 删除会话cookie
    if (isset($_COOKIE[session_name()])) {
        setcookie(session_name(), '', time() - 3600, '/');
    }
    
    // 删除记住我cookie
    setcookie('remember_token', '', time() - 3600, '/');
    
    // 销毁会话
    session_destroy();
    
    // 重定向到网站首页
    header('Location: /');
    exit;
} 
