<?php
// 引入数据库配置
require_once dirname(dirname(__FILE__)) . '/../config/database.php';
// 引入网站配置
require_once dirname(dirname(__FILE__)) . '/../config/config.php';
// 获取数据库连接
$db = getDbConnection();

// 检查数据库连接
if (!$db) {
    die("数据库连接失败，请检查配置");
}
else {
    // 连接成功，输出提示（测试用，正式环境应删除）
    echo "<!-- 数据库连接成功 -->";
}

// 获取所有地区数据
function getRegionsData($db) {
    $result = [
        'parentRegions' => [],
        'allRegions' => [],
        'childRegionsByParent' => []
    ];
    
    try {
        // 获取一级地区（parent_id为null或0的记录）- 修改ORDER BY确保按sort_order升序排序
        $parentQuery = "SELECT id, name, slug FROM area WHERE (parent_id IS NULL OR parent_id = 0) AND status = 1 ORDER BY sort_order ASC";
        $parentStmt = $db->query($parentQuery);
        $result['parentRegions'] = $parentStmt->fetchAll();
        
        // 获取所有地区 - 同样确保按sort_order升序排序
        $regionQuery = "SELECT id, name, parent_id, slug FROM area WHERE status = 1 ORDER BY sort_order ASC";
        $regionStmt = $db->query($regionQuery);
        $result['allRegions'] = $regionStmt->fetchAll();
        
        // 按父级ID组织子地区
        $childRegionsByParent = [];
        foreach ($result['allRegions'] as $region) {
            if (!empty($region['parent_id'])) {
                $parentId = $region['parent_id'];
                if (!isset($childRegionsByParent[$parentId])) {
                    $childRegionsByParent[$parentId] = [];
                }
                $childRegionsByParent[$parentId][] = $region;
            }
        }
        $result['childRegionsByParent'] = $childRegionsByParent;
    } catch (PDOException $e) {
        // 错误处理
        echo "<!-- 地区数据查询错误: " . $e->getMessage() . " -->";
    }
    
    return $result;
}

// 获取所有标签数据
function getTagsData($db) {
    $result = [
        'parentTags' => [],
        'allTags' => [],
        'childTagsByParent' => []
    ];
    
    try {
        // 获取一级标签（parent_id为null或0的记录）
        $parentTagQuery = "SELECT id, name FROM tags WHERE (parent_id IS NULL OR parent_id = 0) AND status = 1 ORDER BY sort_order ASC";
        $parentTagStmt = $db->query($parentTagQuery);
        $result['parentTags'] = $parentTagStmt->fetchAll();
        
        // 获取所有标签
        $allTagsQuery = "SELECT id, name, parent_id FROM tags WHERE status = 1 ORDER BY sort_order ASC";
        $allTagsStmt = $db->query($allTagsQuery);
        $result['allTags'] = $allTagsStmt->fetchAll();
        
        // 按父级ID组织子标签
        $childTagsByParent = [];
        foreach ($result['allTags'] as $tag) {
            if (!empty($tag['parent_id'])) {
                $parentId = $tag['parent_id'];
                if (!isset($childTagsByParent[$parentId])) {
                    $childTagsByParent[$parentId] = [];
                }
                $childTagsByParent[$parentId][] = $tag;
            }
        }
        $result['childTagsByParent'] = $childTagsByParent;
    } catch (PDOException $e) {
        // 错误处理
        echo "<!-- 标签数据查询错误: " . $e->getMessage() . " -->";
    }
    
    return $result;
}

// 获取价格范围
function getPriceRanges() {
    // 价格区间 - 考虑到1.5倍数，调整为更合理的范围
    return [
        ['min' => 0, 'max' => 50, 'label' => '$0-$50'],
        ['min' => 50, 'max' => 100, 'label' => '$50-$100'],
        ['min' => 100, 'max' => 150, 'label' => '$100-$150'],
        ['min' => 150, 'max' => 200, 'label' => '$150-$200'],
        ['min' => 200, 'max' => 250, 'label' => '$200-$250'],
        ['min' => 250, 'max' => 300, 'label' => '$250-$300'],
        ['min' => 300, 'max' => 350, 'label' => '$300-$350'],
        ['min' => 350, 'max' => 400, 'label' => '$350-$400'],
        ['min' => 400, 'max' => 500, 'label' => '$400-$500'],
        ['min' => 500, 'max' => 600, 'label' => '$500-$600'],
        ['min' => 600, 'max' => 999999, 'label' => '$600以上']
    ];
}

// 获取产品列表
function getProductsList($db, $filters) {
    $whereConditions = [];
    $params = [];
    
    // 产品状态筛选 - 只显示激活状态的产品
    $whereConditions[] = "p.status = 1";
    
    // 标签筛选
    if (isset($filters['tag']) && $filters['tag'] != 0) {
        $whereConditions[] = "FIND_IN_SET(:tag_id, p.tags)";
        $params[':tag_id'] = $filters['tag'];
    } elseif (isset($filters['parent_tag']) && $filters['parent_tag'] != 0) {
        // 如果选择的是父级标签，获取该标签及其所有子标签
        $tagIds = [];
        $tagIds[] = $filters['parent_tag']; // 添加父级标签自身ID
        
        // 获取所有标签数据
        $tagsData = getTagsData($db);
        
        // 添加所有子标签ID
        if (isset($tagsData['childTagsByParent'][$filters['parent_tag']])) {
            foreach ($tagsData['childTagsByParent'][$filters['parent_tag']] as $childTag) {
                $tagIds[] = $childTag['id'];
            }
        }
        
        // 构建IN查询，找出tags字段中包含任何一个标签ID的产品
        if (!empty($tagIds)) {
            $tagConditions = [];
            foreach ($tagIds as $index => $id) {
                $paramName = ":tag_id_$index";
                $tagConditions[] = "FIND_IN_SET($paramName, p.tags)";
                $params[$paramName] = $id;
            }
            $whereConditions[] = "(" . implode(' OR ', $tagConditions) . ")";
        }
    }
    if (isset($filters['region']) && $filters['region'] != 0) {
        // 如果选择的是具体地区，直接按地区ID筛选
        $whereConditions[] = "p.region_id = :region_id";
        $params[':region_id'] = $filters['region'];
    } elseif (isset($filters['parent_region']) && $filters['parent_region'] != 0) {
        // 如果选择的是父级地区，获取该地区及其所有子地区
        $regionIds = [];
        $regionIds[] = $filters['parent_region']; // 添加父级地区自身ID
        
        // 获取所有地区数据
        $regionsData = getRegionsData($db);
        
        // 添加所有子地区ID
        if (isset($regionsData['childRegionsByParent'][$filters['parent_region']])) {
            foreach ($regionsData['childRegionsByParent'][$filters['parent_region']] as $childRegion) {
                $regionIds[] = $childRegion['id'];
            }
        }
        
        // 构建IN查询
        if (!empty($regionIds)) {
            $placeholders = implode(',', array_fill(0, count($regionIds), '?'));
            $whereConditions[] = "p.region_id IN ($placeholders)";
            // 添加参数
            foreach ($regionIds as $index => $id) {
                $params[] = $id;
            }
        }
    }
    
    // 价格区间筛选
    if (isset($filters['min_price']) && isset($filters['max_price'])) {
        // 直接使用前端显示的价格值，不需要除以倍数
        // 因为我们已经在筛选条件中直接使用实际显示价格
        $whereConditions[] = "p.price * " . getMultiplier() . " BETWEEN :min_price AND :max_price";
        $params[':min_price'] = $filters['min_price'];
        $params[':max_price'] = $filters['max_price'];
    }
    
    // 构建WHERE子句
    $whereClause = '';
    if (!empty($whereConditions)) {
        $whereClause = "WHERE " . implode(' AND ', $whereConditions);
    }
    
    // 排序
    $orderClause = "ORDER BY p.id DESC"; // 默认按ID倒序排序
    if (isset($filters['sort'])) {
        if ($filters['sort'] == 'price') {
            $orderDir = (isset($filters['order']) && $filters['order'] == 'desc') ? 'DESC' : 'ASC';
            $orderClause = "ORDER BY p.price $orderDir";
        } elseif ($filters['sort'] == 'created') {
            $orderDir = (isset($filters['order']) && $filters['order'] == 'asc') ? 'ASC' : 'DESC';
            $orderClause = "ORDER BY p.created_at $orderDir";
        } elseif ($filters['sort'] == 'sales') {
            $orderClause = "ORDER BY p.sales DESC";
        }
    }
    
    // 分页
    $itemsPerPage = 18; // 每页显示18个产品
    $currentPage = isset($filters['page']) ? (int) $filters['page'] : 1;
    if ($currentPage < 1) $currentPage = 1;
    $offset = ($currentPage - 1) * $itemsPerPage;
    
    // 构建查询语句 - 使用预处理语句来避免SQL注入
    $query = "SELECT * FROM products p $whereClause $orderClause LIMIT $offset, $itemsPerPage";
    
    $result = [
        'products' => [],
        'totalItems' => 0,
        'totalPages' => 0,
        'currentPage' => $currentPage,
        'itemsPerPage' => $itemsPerPage
    ];
    
    try {
        if (!empty($params)) {
            // 使用预处理语句执行查询
            $stmt = $db->prepare($query);
            $stmt->execute($params);
            $products = $stmt->fetchAll();
        } else {
            // 如果没有参数，直接执行查询
            $stmt = $db->query($query);
            $products = $stmt->fetchAll();
        }
        
        // 确保每个产品都有original_price字段，即使为null
        foreach ($products as &$product) {
            if (!isset($product['original_price'])) {
                $product['original_price'] = null;
            }
        }
        
        $result['products'] = $products;
    } catch (PDOException $e) {
        $result['products'] = [];
    }
    
    // 获取总产品数量用于分页
    try {
        $countQuery = "SELECT COUNT(*) as total FROM products p $whereClause";
        if (!empty($params)) {
            $countStmt = $db->prepare($countQuery);
            $countStmt->execute($params);
            $result['totalItems'] = $countStmt->fetch()['total'];
        } else {
            $countStmt = $db->query($countQuery);
            $result['totalItems'] = $countStmt->fetch()['total'];
        }
        $result['totalPages'] = ceil($result['totalItems'] / $itemsPerPage);
    } catch (PDOException $e) {
        $result['totalItems'] = 0;
        $result['totalPages'] = 0;
    }
    
    return $result;
}

// 获取区域名称
function getAreaNames($db) {
    $areaNames = [];
    try {
        $query = "SELECT id, name FROM area WHERE status = 1";
        $stmt = $db->query($query);
        while ($row = $stmt->fetch()) {
            $areaNames[$row['id']] = $row['name'];
        }
    } catch (PDOException $e) {
        // 错误处理
    }
    return $areaNames;
}

// 获取所有标签
function getAllTags($db) {
    $tags = [];
    try {
        $query = "SELECT id, name FROM tags WHERE status = 1";
        $stmt = $db->query($query);
        while ($row = $stmt->fetch()) {
            $tags[$row['id']] = $row['name'];
        }
    } catch (PDOException $e) {
        // 错误处理
    }
    return $tags;
}

// 获取推荐产品
function getRecommendedProducts($db, $limit = 5) {
    $products = [];
    try {
        $query = "SELECT * FROM products WHERE status = 1 AND is_recommended = 1 ORDER BY sort_order ASC LIMIT $limit";
        $stmt = $db->query($query);
        $products = $stmt->fetchAll();
    } catch (PDOException $e) {
        // 错误处理
    }
    return $products;
}

// 标签颜色类
function getTagClasses() {
    return [
        'blue' => 'tag-blue',
        'green' => 'tag-green',
        'orange' => 'tag-orange',
        'red' => 'tag-red',
        'purple' => 'tag-purple',
        'cyan' => 'tag-cyan',
        'magenta' => 'tag-magenta',
        'yellow' => 'tag-yellow',
    ];
}

// 获取当前筛选条件
function getCurrentFilters() {
    // 从GET参数获取筛选条件
    $tag = isset($_GET['tag']) ? (int)$_GET['tag'] : 0;
    $parentTag = isset($_GET['parent_tag']) ? (int)$_GET['parent_tag'] : 0;
    $region = isset($_GET['region']) ? (int)$_GET['region'] : 0;
    $parentRegion = isset($_GET['parent_region']) ? (int)$_GET['parent_region'] : 0;
    $minPrice = isset($_GET['min_price']) ? $_GET['min_price'] : null;
    $maxPrice = isset($_GET['max_price']) ? $_GET['max_price'] : null;
    $sort = isset($_GET['sort']) ? $_GET['sort'] : 'recommended';
    $order = isset($_GET['order']) ? $_GET['order'] : '';
    $page = isset($_GET['page']) ? max(1, (int)$_GET['page']) : 1;
    
    // 返回所有筛选条件
    return [
        'tag' => $tag,
        'parent_tag' => $parentTag,
        'region' => $region,
        'parent_region' => $parentRegion,
        'min_price' => $minPrice,
        'max_price' => $maxPrice,
        'sort' => $sort,
        'order' => $order,
        'page' => $page,
    ];
}

// 获取价格倍数
function getMultiplier() {
    // 实际应用中，这个值可能来自配置文件或数据库
    // 默认使用1.5作为倍数
    return 1.5;
} 