<?php
/**
 * 产品页面辅助函数文件
 * 包含各种与产品显示相关的辅助函数
 */

/**
 * 生成产品标题
 * 
 * @param array $product 产品数据
 * @param array $areaNames 地区名称数组
 * @param array $allRegions 所有地区数据
 * @param array $parentRegions 父级地区数据
 * @return string 格式化后的产品标题
 */
function generateProductTitle($product, $areaNames, $allRegions, $parentRegions) {
    $regionName = '';
    $countryName = '';
    
    if (isset($product['region_id']) && isset($areaNames[$product['region_id']])) {
        $regionName = $areaNames[$product['region_id']];
        
        // 查找该地区的父级地区(国家)
        foreach ($allRegions as $region) {
            if ($region['id'] == $product['region_id'] && !empty($region['parent_id'])) {
                // 找到父级地区(国家)名称
                foreach ($parentRegions as $parent) {
                    if ($parent['id'] == $region['parent_id']) {
                        $countryName = $parent['name'];
                        break;
                    }
                }
                break;
            }
        }
    }
    
    // 显示格式：地区(国家)服务器，如果没有国家信息则只显示地区
    if (!empty($regionName)) {
        if (!empty($countryName) && $countryName != '中国') {
            return htmlspecialchars($regionName . '(' . $countryName . ')服务器');
        } else {
            return htmlspecialchars($regionName . '服务器');
        }
    } else {
        return htmlspecialchars($product['upc'] ?? '未命名产品');
    }
}

/**
 * 获取产品 ID 格式化显示
 * 
 * @param int $id 产品ID
 * @return string 格式化后的产品ID
 */
function formatProductId($id) {
    return '8' . str_pad($id ?? '0', 4, '0', STR_PAD_LEFT);
}

/**
 * 获取产品防御信息显示
 * 
 * @param string $defense 防御信息
 * @return string 格式化后的防御信息
 */
function getDefenseDisplay($defense) {
    if (isset($defense) && !empty($defense)) {
        return htmlspecialchars($defense);
    } else {
        return '可选';
    }
}

/**
 * 获取产品流量信息显示
 * 
 * @param string $traffic 流量信息
 * @return string 格式化后的流量信息
 */
function getTrafficDisplay($traffic) {
    if (isset($traffic) && !empty($traffic)) {
        return htmlspecialchars($traffic);
    } else {
        return '不限';
    }
}

/**
 * 获取产品线路信息显示
 * 
 * @param int $lineId 线路ID
 * @param array $lineData 线路数据
 * @return string 格式化后的线路信息
 */
function getLineDisplay($lineId, $lineData) {
    if (!empty($lineId) && isset($lineData[$lineId])) {
        return htmlspecialchars($lineData[$lineId]);
    } else {
        return '未设置';
    }
}

/**
 * 获取产品价格显示
 * 
 * @param float $price 当前价格
 * @param float $originalPrice 原价
 * @param bool $withHtml 是否包含HTML标签，默认为true
 * @return string 格式化后的价格显示
 */
function getPriceDisplay($price, $originalPrice = null, $withHtml = true) {
    $result = '';
    $multiplier = getMultiplier();
    
    if (isset($originalPrice) && !empty($originalPrice) && $originalPrice > $price) {
        if ($withHtml) {
            $result .= '<del>$' . number_format($originalPrice * $multiplier, 2) . '</del> ';
        } else {
            $result .= '$' . number_format($originalPrice * $multiplier, 2) . ' ';
        }
    }
    
    $result .= '$' . number_format(($price ?? 0) * $multiplier, 2) . '/月';
    
    return $result;
}

/**
 * 获取区域显示
 * 
 * @param int $regionId 区域ID
 * @param array $areaNames 地区名称数组
 * @return string 格式化后的区域显示
 */
function getRegionDisplay($regionId, $areaNames) {
    if (isset($regionId) && isset($areaNames[$regionId])) {
        return htmlspecialchars($areaNames[$regionId]);
    } else {
        return '未设置';
    }
}

/**
 * 处理推荐产品描述
 * 
 * @param array $product 产品数据
 * @param array $areaNames 地区名称数组
 * @return string 格式化后的产品描述
 */
function getRecommendedProductDesc($product, $areaNames) {
    if (!empty($product['short_description'])) {
        return htmlspecialchars($product['short_description']);
    } else if (!empty($product['bandwidth'])) {
        $regionName = isset($product['region_id']) && isset($areaNames[$product['region_id']])
            ? $areaNames[$product['region_id']] : '未知地区';
        return htmlspecialchars($product['bandwidth'] . '，' . $regionName . '优质线路');
    } else {
        return '高性能服务器，稳定可靠';
    }
}

/**
 * 生成分页HTML
 * 
 * @param int $currentPage 当前页码
 * @param int $totalPages 总页数
 * @return string 分页HTML
 */
function generatePagination($currentPage, $totalPages) {
    if ($totalPages <= 1) {
        return '';
    }
    
    $html = '<div class="pagination">';
    
    // 上一页按钮
    $prevDisabled = $currentPage == 1 ? 'disabled' : '';
    $prevPage = max(1, $currentPage - 1);
    $html .= '<a href="javascript:void(0);" class="page-item ' . $prevDisabled . '" data-page="' . $prevPage . '"><i class="fas fa-chevron-left"></i></a>';
    
    // 计算显示的页码范围
    $startPage = max(1, $currentPage - 2);
    $endPage = min($totalPages, $startPage + 4);
    if ($endPage - $startPage < 4 && $startPage > 1) {
        $startPage = max(1, $endPage - 4);
    }
    
    // 页码
    for ($i = $startPage; $i <= $endPage; $i++) {
        $activeClass = $i == $currentPage ? 'active' : '';
        $html .= '<a href="javascript:void(0);" class="page-item ' . $activeClass . '" data-page="' . $i . '">' . $i . '</a>';
    }
    
    // 下一页按钮
    $nextDisabled = $currentPage == $totalPages ? 'disabled' : '';
    $nextPage = min($totalPages, $currentPage + 1);
    $html .= '<a href="javascript:void(0);" class="page-item ' . $nextDisabled . '" data-page="' . $nextPage . '"><i class="fas fa-chevron-right"></i></a>';
    
    $html .= '</div>';
    
    return $html;
}

/**
 * 获取推荐产品价格显示
 * 
 * @param float $price 当前价格
 * @return string 格式化后的价格显示
 */
function getRecommendedProductPrice($price) {
    return number_format(($price ?? 0) * getMultiplier(), 2);
}

/**
 * 获取格式化价格金额（不含货币符号）
 * 
 * @param float $price 当前价格
 * @return string 格式化后的价格金额
 */
function getFormattedPrice($price) {
    return number_format(($price ?? 0) * getMultiplier(), 2);
} 