<?php
require_once 'auth.php';
require_once 'publi.php';
require_once '../config/database.php'; // 引入数据库配置文件

// 检查用户是否已登录
if (!isset($_SESSION['user_id']) || empty($_SESSION['user_id'])) {
    header('Location: login.php');
    exit;
}

// 获取当前用户信息
$userId = $_SESSION['user_id'];

// 检查是否提供了工单ID
if (!isset($_GET['id']) || empty($_GET['id'])) {
    header('Location: ticket.php');
    exit;
}

$ticketId = intval($_GET['id']);
$error = '';
$ticket = null;
$replies = [];

// 设置附件目录路径 - 确保与管理员后台一致
$uploadDir = '../uploads/tickets/';
// 设置显示用的URL路径
$uploadPath = '/uploads/tickets/';

try {
    // 获取数据库连接
    $db = getDbConnection();
    
    // 获取工单信息，修改查询不再使用user_id过滤
    $ticketQuery = "SELECT t.* FROM tickets t
                    WHERE t.id = :id";
    $stmt = $db->prepare($ticketQuery);
    $stmt->bindParam(':id', $ticketId, PDO::PARAM_INT);
    $stmt->execute();
    
    $ticket = $stmt->fetch(PDO::FETCH_ASSOC);
    
    if (!$ticket) {
        // 工单不存在或不属于当前用户
        header('Location: ticket.php');
        exit;
    }
    
    // 获取工单回复，确保按照时间顺序排列
    $repliesQuery = "SELECT r.* FROM ticket_replies r
                     WHERE r.ticket_id = :ticket_id
                     ORDER BY r.created_at ASC, r.id ASC";  // 按创建时间和ID排序
    $stmt = $db->prepare($repliesQuery);
    $stmt->bindParam(':ticket_id', $ticketId, PDO::PARAM_INT);
    $stmt->execute();
    
    $replies = $stmt->fetchAll(PDO::FETCH_ASSOC);
    $replyCount = count($replies); // 统计回复数量
    
    // 如果没有找到回复记录，确保回复数组至少为空数组
    if (!$replies) {
        $replies = [];
    }
    
    // 获取附件信息
    $attachmentsQuery = "SELECT * FROM ticket_attachments 
                        WHERE ticket_id = :ticket_id
                        ORDER BY created_at ASC";
    $stmt = $db->prepare($attachmentsQuery);
    $stmt->bindParam(':ticket_id', $ticketId, PDO::PARAM_INT);
    $stmt->execute();
    
    $attachments = $stmt->fetchAll(PDO::FETCH_ASSOC);
    
    // 整理附件到对应的回复
    $replyAttachments = [];
    foreach ($attachments as $attachment) {
        $replyId = $attachment['reply_id'] ?? 0;
        if (!isset($replyAttachments[$replyId])) {
            $replyAttachments[$replyId] = [];
        }
        $replyAttachments[$replyId][] = $attachment;
    }
    
    // 处理回复提交
    if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['reply_submit'])) {
        $replyMessage = trim($_POST['replyMessage'] ?? '');
        
        if (empty($replyMessage)) {
            $error = '请输入回复内容';
        } else {
            try {
                // 开始事务
                $db->beginTransaction();
                
                // 记录日志，调试用
                error_log("开始提交回复，工单ID: {$ticketId}");
                
                // 获取工单的conversation_id
                $getConversationQuery = "SELECT conversation_id FROM tickets WHERE id = :ticket_id";
                $stmt = $db->prepare($getConversationQuery);
                $stmt->bindParam(':ticket_id', $ticketId, PDO::PARAM_INT);
                $stmt->execute();
                $conversationId = $stmt->fetchColumn();
                
                if (!$conversationId) {
                    // 如果没有conversation_id，创建一个新的
                    $conversationId = 'TKT' . date('YmdHis') . rand(1000, 9999);
                    
                    // 更新工单的conversation_id
                    $updateTicketQuery = "UPDATE tickets SET conversation_id = :conversation_id WHERE id = :ticket_id";
                    $stmt = $db->prepare($updateTicketQuery);
                    $stmt->bindParam(':conversation_id', $conversationId, PDO::PARAM_STR);
                    $stmt->bindParam(':ticket_id', $ticketId, PDO::PARAM_INT);
                    $stmt->execute();
                }
                
                // 插入回复，设置正确的user_id和conversation_id
                $insertReplyQuery = "INSERT INTO ticket_replies (ticket_id, user_id, conversation_id, message, created_at) 
                                    VALUES (:ticket_id, :user_id, :conversation_id, :message, NOW())";
                $stmt = $db->prepare($insertReplyQuery);
                $stmt->bindParam(':ticket_id', $ticketId, PDO::PARAM_INT);
                $stmt->bindParam(':user_id', $userId, PDO::PARAM_INT);
                $stmt->bindParam(':conversation_id', $conversationId, PDO::PARAM_STR);
                $stmt->bindParam(':message', $replyMessage, PDO::PARAM_STR);
                $stmt->execute();
                
                $replyId = $db->lastInsertId();
                error_log("回复已插入，回复ID: {$replyId}");
                
                // 更新工单状态和最后回复时间
                $updateTicketQuery = "UPDATE tickets SET status = 'open', updated_at = NOW(), last_reply = NOW() 
                                    WHERE id = :id";
                $stmt = $db->prepare($updateTicketQuery);
                $stmt->bindParam(':id', $ticketId, PDO::PARAM_INT);
                $stmt->execute();
                
                // 处理附件上传
                if (!empty($_FILES['replyAttachments']['name'][0])) {
                    // 确保上传目录存在
                    if (!file_exists($uploadDir)) {
                        mkdir($uploadDir, 0777, true);
                    }
                    
                    // 允许的文件类型
                    $allowedTypes = ['image/jpeg', 'image/jpg', 'image/png', 'image/gif', 'application/pdf', 'application/zip'];
                    $maxFileSize = 1024 * 1024; // 1MB
                    
                    // 循环处理每个上传的文件
                    foreach ($_FILES['replyAttachments']['name'] as $key => $filename) {
                        if (empty($filename)) continue;
                        
                        $tmpName = $_FILES['replyAttachments']['tmp_name'][$key];
                        $fileSize = $_FILES['replyAttachments']['size'][$key];
                        $fileType = $_FILES['replyAttachments']['type'][$key];
                        
                        // 检查文件类型
                        if (!in_array($fileType, $allowedTypes)) {
                            throw new Exception('文件类型不允许：' . $filename);
                        }
                        
                        // 检查文件大小
                        if ($fileSize > $maxFileSize) {
                            throw new Exception('文件大小超过限制：' . $filename);
                        }
                        
                        // 生成唯一的文件名
                        $newFilename = uniqid() . '_' . preg_replace('/[^a-zA-Z0-9\.]/', '_', $filename);
                        $destination = $uploadDir . $newFilename;
                        
                        // 移动上传的文件
                        if (move_uploaded_file($tmpName, $destination)) {
                            // 保存附件信息到数据库 - 使用与管理员后台一致的路径
                            $filePath = $uploadPath . $newFilename;
                            $insertAttachmentQuery = "INSERT INTO ticket_attachments (ticket_id, reply_id, file_name, file_path, file_type, file_size, created_at) 
                                                    VALUES (:ticket_id, :reply_id, :file_name, :file_path, :file_type, :file_size, NOW())";
                            $stmt = $db->prepare($insertAttachmentQuery);
                            $stmt->bindParam(':ticket_id', $ticketId, PDO::PARAM_INT);
                            $stmt->bindParam(':reply_id', $replyId, PDO::PARAM_INT);
                            $stmt->bindParam(':file_name', $filename, PDO::PARAM_STR);
                            $stmt->bindParam(':file_path', $filePath, PDO::PARAM_STR);
                            $stmt->bindParam(':file_type', $fileType, PDO::PARAM_STR);
                            $stmt->bindParam(':file_size', $fileSize, PDO::PARAM_INT);
                            $stmt->execute();
                            
                            error_log("附件已上传: {$filename}，路径: {$filePath}");
                        } else {
                            throw new Exception('文件上传失败：' . $filename);
                        }
                    }
                }
                
                // 提交事务
                $db->commit();
                error_log("回复提交成功，工单ID: {$ticketId}");
                
                // 重定向到当前页面以刷新数据
                header("Location: ticket_detail.php?id=$ticketId&success=1");
                exit;
                
            } catch (Exception $e) {
                // 回滚事务
                if (isset($db) && $db->inTransaction()) {
                    $db->rollBack();
                }
                error_log("回复提交错误: " . $e->getMessage());
                $error = "提交回复时出错：" . $e->getMessage();
            }
        }
    }
    
    // 处理关闭工单，移除user_id条件
    if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['close_ticket'])) {
        $updateTicketQuery = "UPDATE tickets SET status = 'closed', updated_at = NOW() WHERE id = :id";
        $stmt = $db->prepare($updateTicketQuery);
        $stmt->bindParam(':id', $ticketId, PDO::PARAM_INT);
        $stmt->execute();
        
        header("Location: ticket_detail.php?id=$ticketId&closed=1");
        exit;
    }
    
} catch (Exception $e) {
    error_log("工单详情错误: " . $e->getMessage());
    $error = "获取工单详情时出错：" . $e->getMessage();
}

// 获取状态显示信息
function getStatusBadgeClass($status) {
    switch ($status) {
        case 'open':
            return 'open';
        case 'replied':
        case 'answered':
            return 'answered';
        case 'closed':
            return 'closed';
        default:
            return '';
    }
}

// 获取状态显示文本
function getStatusText($status) {
    switch ($status) {
        case 'open':
            return '未回复';
        case 'replied':
        case 'answered':
            return '已回复';
        case 'closed':
            return '已关闭';
        default:
            return $status;
    }
}

// 格式化日期时间
function formatDateTime($datetime) {
    return date('Y/m/d (H:i)', strtotime($datetime));
}
