<?php
/**
 * 用户订单页面逻辑处理文件
 * 包含：状态筛选、分页逻辑和数据获取
 */

// 引入数据库配置文件
require_once __DIR__ . '/../../config/database.php';
require_once __DIR__ . '/auth.php';

/**
 * 获取订单状态名称映射
 * @return array 状态ID => 状态名称
 */
function getUserOrderStatusNames() {
    return [
        1 => '有效的',
        2 => '审核中',
        3 => '已暂停',
        4 => '已终止',
        5 => '已取消'
    ];
}

/**
 * 处理查询条件和参数
 * @param int|null $statusFilter 状态筛选，null表示不筛选
 * @param int $userId 用户ID
 * @return array [whereClause, params] 查询条件和参数
 */
function buildUserOrderQueryConditions($statusFilter, $userId) {
    $whereClause = "WHERE MemberID = :user_id";
    $params = ['user_id' => $userId];

    // 如果状态筛选有效（大于0），添加状态筛选条件
    // 根据实际数据库字段调整
    if ($statusFilter > 0) {
        // 注意：此处假设数据库中实际有status字段，如果没有请根据实际情况调整
        $whereClause .= " AND status = :status";
        $params['status'] = $statusFilter;
    }
    
    return [$whereClause, $params];
}

/**
 * 获取订单总数和总页数
 * @param PDO $db 数据库连接
 * @param string $whereClause 查询条件
 * @param array $params 查询参数
 * @param int $perPage 每页记录数
 * @return array [totalRecords, totalPages] 总记录数和总页数
 */
function getUserOrderPagination($db, $whereClause, $params, $perPage) {
    $countQuery = "SELECT COUNT(*) FROM orders {$whereClause}";
    $countStmt = $db->prepare($countQuery);
    $countStmt->execute($params);
    $totalRecords = $countStmt->fetchColumn();
    $totalPages = ceil($totalRecords / $perPage);
    
    return [$totalRecords, $totalPages];
}

/**
 * 获取用户订单列表
 * @param PDO $db 数据库连接
 * @param string $whereClause 查询条件
 * @param array $params 查询参数
 * @param int $offset 偏移量
 * @param int $perPage 每页记录数
 * @return array 订单数据列表
 */
function getUserOrders($db, $whereClause, $params, $offset, $perPage) {
    // 如果存在status字段，则按status升序（有效的优先）
    // 否则只按ID降序排列
    $orderQuery = "SELECT * FROM orders {$whereClause} ORDER BY id DESC LIMIT :offset, :limit";
    $orderStmt = $db->prepare($orderQuery);
    $orderStmt->bindValue(':offset', $offset, PDO::PARAM_INT);
    $orderStmt->bindValue(':limit', $perPage, PDO::PARAM_INT);
    
    foreach ($params as $key => $value) {
        $orderStmt->bindValue(":{$key}", $value);
    }
    
    $orderStmt->execute();
    return $orderStmt->fetchAll();
}

/**
 * 生成分页HTML
 * @param int $page 当前页码
 * @param int $totalPages 总页数
 * @param int $statusFilter 状态筛选
 * @param int $perPage 每页记录数
 * @return string 分页HTML
 */
function generateUserPaginationHtml($page, $totalPages, $statusFilter, $perPage) {
    if ($totalPages <= 1) {
        return '';
    }
    
    $html = '<div class="pagination"><div class="pagination-controls">';
    
    // 上一页链接
    if ($page > 1) {
        $html .= '<a href="orders.php?status=' . $statusFilter . '&page=' . ($page - 1) . '&per_page=' . $perPage . '">上一页</a>';
    } else {
        $html .= '<a href="#" class="disabled">上一页</a>';
    }
    
    // 页码链接
    $pageLimit = 5; // 最多显示多少个页码
    $startPage = max(1, min($page - floor($pageLimit / 2), $totalPages - $pageLimit + 1));
    $endPage = min($startPage + $pageLimit - 1, $totalPages);
    
    for ($i = $startPage; $i <= $endPage; $i++) {
        $activeClass = $i === $page ? 'active' : '';
        $html .= '<a href="orders.php?status=' . $statusFilter . '&page=' . $i . '&per_page=' . $perPage . '" class="' . $activeClass . '">' . $i . '</a>';
    }
    
    // 下一页链接
    if ($page < $totalPages) {
        $html .= '<a href="orders.php?status=' . $statusFilter . '&page=' . ($page + 1) . '&per_page=' . $perPage . '">下一页</a>';
    } else {
        $html .= '<a href="#" class="disabled">下一页</a>';
    }
    
    $html .= '</div></div>';
    
    return $html;
}

/**
 * 处理用户订单页面请求
 * @return array 包含页面需要的所有数据
 */
function processUserOrdersRequest() {
    // 获取数据库连接
    $db = getDbConnection();
    
    // 验证用户是否登录
    requireLogin();
    $userId = getCurrentUserId();
    
    // 获取当前状态筛选，默认为0(全部)，而不是1(有效的)
    $statusFilter = isset($_GET['status']) ? intval($_GET['status']) : 0;
    $statusNames = getUserOrderStatusNames();
    
    // 添加"全部"选项到状态名称数组
    $allStatusNames = [0 => '全部'] + $statusNames;
    
    // 构建查询条件
    list($whereClause, $params) = buildUserOrderQueryConditions($statusFilter, $userId);
    
    // 分页设置
    $page = isset($_GET['page']) ? intval($_GET['page']) : 1;
    $perPage = isset($_GET['per_page']) ? intval($_GET['per_page']) : 10;
    $offset = ($page - 1) * $perPage;
    
    // 获取分页信息
    list($totalRecords, $totalPages) = getUserOrderPagination($db, $whereClause, $params, $perPage);
    
    // 获取订单列表
    $orders = getUserOrders($db, $whereClause, $params, $offset, $perPage);
    
    // 返回数据
    return [
        'statusFilter' => $statusFilter,
        'statusNames' => $allStatusNames, // 使用包含"全部"选项的状态名称
        'page' => $page,
        'perPage' => $perPage,
        'totalPages' => $totalPages,
        'totalRecords' => $totalRecords,
        'orders' => $orders,
        'paginationHtml' => generateUserPaginationHtml($page, $totalPages, $statusFilter, $perPage)
    ];
} 