/**
 * chat-functions.js - 优化版聊天功能
 * 确保消息正确显示和加载
 */

document.addEventListener('DOMContentLoaded', function() {
    const chatInput = document.querySelector('.chat-input');
    const sendButton = document.querySelector('.send-btn');
    const chatMessages = document.querySelector('.chat-messages');
    
    if (!chatInput || !sendButton || !chatMessages) {
        console.error('聊天界面元素未找到');
        return;
    }
    
    // 初始化聊天界面
    initChatInterface();
    
    // 发送消息
    function sendMessage() {
        const message = chatInput.value.trim();
        if (message === '') return;
        
        // 添加用户消息
        addMessage(message, true);
        
        // 清空输入框
        chatInput.value = '';
        chatInput.focus();
        
        // 模拟客服回复
        setTimeout(() => {
            const reply = "感谢您的咨询，我们的客服人员会尽快回复您的问题。";
            addMessage(reply, false);
        }, 800);
    }
    
    // 添加消息到聊天界面
    function addMessage(text, isUser) {
        if (!text || text.trim() === '') return;
        
        const messageDiv = document.createElement('div');
        messageDiv.className = isUser ? 'user-message' : 'agent-message';
        messageDiv.innerHTML = `
            <div class="message-content">
                <p>${text}</p>
            </div>
        `;
        
        // 确保消息被添加到聊天界面
        try {
            chatMessages.appendChild(messageDiv);
            
            // 确保滚动到底部
            scrollToBottom();
        } catch (error) {
            console.error('添加消息时出错:', error);
        }
    }
    
    // 滚动到底部函数
    function scrollToBottom() {
        try {
            // 使用两种方法确保滚动到底部
            if (window.scrollChatToBottom) {
                window.scrollChatToBottom();
            }
            
            // 直接滚动方法
            setTimeout(() => {
                chatMessages.scrollTop = chatMessages.scrollHeight;
            }, 100);
        } catch (error) {
            console.error('滚动时出错:', error);
        }
    }
    
    // 初始化聊天界面
    function initChatInterface() {
        // 确保初始化时滚动到底部
        scrollToBottom();
        
        // 检查聊天消息区域是否为空
        if (chatMessages.children.length === 0) {
            // 添加欢迎消息
            addMessage("您好！我是在线客服，有什么可以帮您？", false);
        }
        
        // 观察聊天消息区域尺寸变化，确保始终滚动到底部
        try {
            if (window.ResizeObserver) {
                const resizeObserver = new ResizeObserver(() => {
                    scrollToBottom();
                });
                resizeObserver.observe(chatMessages);
            }
        } catch (error) {
            console.error('设置ResizeObserver时出错:', error);
        }
    }
    
    // 绑定发送按钮点击事件
    sendButton.addEventListener('click', sendMessage);
    
    // 绑定回车键发送
    chatInput.addEventListener('keypress', function(e) {
        if (e.key === 'Enter') {
            e.preventDefault();
            sendMessage();
        }
    });
    
    // 绑定窗口大小变化事件
    window.addEventListener('resize', scrollToBottom);
}); 