/**
 * chat-scroll.js - 聊天界面滚动功能专用脚本
 * 专门负责在消息较多时自动滚动到最新消息
 */

(function() {
    // 在DOM加载完成后执行
    document.addEventListener('DOMContentLoaded', function() {
        // 滚动到底部函数 - 使用requestAnimationFrame确保滚动更加平滑
        function scrollToBottom() {
            const chatMessages = document.querySelector('.chat-messages');
            if (chatMessages) {
                requestAnimationFrame(() => {
                    chatMessages.scrollTop = chatMessages.scrollHeight;
                });
            }
        }

        // 调整聊天容器高度和滚动位置
        function adjustChatContainerHeight() {
            const chatContainer = document.querySelector('.chat-container');
            const chatMessages = document.querySelector('.chat-messages');
            const inputContainer = document.querySelector('.input-container');
            
            if (chatContainer && chatMessages && inputContainer) {
                // 计算并设置聊天区域高度
                const containerHeight = chatContainer.offsetHeight;
                const inputHeight = inputContainer.offsetHeight;
                chatMessages.style.height = `${containerHeight - inputHeight}px`;
                
                // 滚动到底部
                scrollToBottom();
            }
        }

        // 初始化：确保页面加载后滚动到最新消息
        adjustChatContainerHeight();
        
        // 页面加载完成后再次确保滚动到底部
        // 延迟时间更长，确保所有内容都已加载
        setTimeout(scrollToBottom, 500);

        // 窗口大小变化时自动调整
        window.addEventListener('resize', adjustChatContainerHeight);

        // 监听消息区域的变化，确保新消息自动滚动
        const chatMessages = document.querySelector('.chat-messages');
        if (chatMessages) {
            const observer = new MutationObserver(function(mutations) {
                // 检查是否真的有新元素添加
                if (mutations.some(mutation => mutation.addedNodes.length > 0)) {
                    scrollToBottom();
                }
            });
            
            observer.observe(chatMessages, {
                childList: true,  // 监听子节点变化
                subtree: true     // 监听所有后代节点变化
            });
        }

        // 监听发送按钮点击事件
        const sendButton = document.querySelector('.send-btn');
        if (sendButton) {
            sendButton.addEventListener('click', function() {
                // 点击发送后使用多个时间点确保滚动到底部
                scrollToBottom(); // 立即滚动
                setTimeout(scrollToBottom, 50); // 短暂延迟
                setTimeout(scrollToBottom, 300); // 长延迟确保动画完成
            });
        }

        // 监听输入框的回车事件
        const chatInput = document.querySelector('.chat-input');
        if (chatInput) {
            chatInput.addEventListener('keypress', function(e) {
                if (e.key === 'Enter') {
                    // 回车发送后确保滚动到底部
                    scrollToBottom(); // 立即滚动
                    setTimeout(scrollToBottom, 50); // 短暂延迟
                    setTimeout(scrollToBottom, 300); // 长延迟确保动画完成
                }
            });
        }

        // 添加测试功能：生成多条测试消息
        // 这个函数可以用来测试滚动效果，您可以在控制台调用 addTestMessages(10) 生成10条测试消息
        window.addTestMessages = function(count) {
            const chatMessages = document.querySelector('.chat-messages');
            if (!chatMessages) return;
            
            for (let i = 0; i < count; i++) {
                // 创建用户消息
                const userMessageDiv = document.createElement('div');
                userMessageDiv.className = 'user-message';
                
                const messageContent = document.createElement('div');
                messageContent.className = 'message-content';
                
                const messagePara = document.createElement('p');
                messagePara.textContent = `这是测试消息 #${i+1}`;
                
                messageContent.appendChild(messagePara);
                userMessageDiv.appendChild(messageContent);
                chatMessages.appendChild(userMessageDiv);
                
                // 每添加一条消息后滚动到底部
                scrollToBottom();
                
                // 创建客服回复
                const agentMessageDiv = document.createElement('div');
                agentMessageDiv.className = 'agent-message';
                
                const agentMessageContent = document.createElement('div');
                agentMessageContent.className = 'message-content';
                
                const agentMessagePara = document.createElement('p');
                agentMessagePara.textContent = `这是客服回复测试消息 #${i+1}`;
                
                agentMessageContent.appendChild(agentMessagePara);
                agentMessageDiv.appendChild(agentMessageContent);
                chatMessages.appendChild(agentMessageDiv);
                
                // 每添加一条消息后滚动到底部
                scrollToBottom();
            }
            
            // 最后再次确保滚动到底部
            setTimeout(scrollToBottom, 100);
            setTimeout(scrollToBottom, 300);
        };
        
        // 在控制台提示测试方法
        console.log('聊天测试功能已加载，您可以在控制台使用 addTestMessages(数量) 来添加测试消息');
    });
})(); 