/**
 * main.js - 会员中心交互功能
 */

document.addEventListener('DOMContentLoaded', function() {
    // 页面加载成功消息处理
    const urlParams = new URLSearchParams(window.location.search);
    if (urlParams.has('success')) {
        const successMessage = document.getElementById('success-message');
        successMessage.textContent = urlParams.get('message') || '操作成功！';
        successMessage.style.display = 'block';
        setTimeout(() => {
            successMessage.style.display = 'none';
        }, 3000);
    }

    // 聊天界面高度管理
    function adjustChatContainerHeight() {
        const chatContainer = document.querySelector('.chat-container');
        const chatMessages = document.querySelector('.chat-messages');
        const inputContainer = document.querySelector('.input-container');
        
        if (chatContainer && chatMessages && inputContainer) {
            // 确保聊天消息区域自适应高度，防止不必要的滚动
            const containerHeight = chatContainer.offsetHeight;
            const inputHeight = inputContainer.offsetHeight;
            
            // 设置聊天区域高度
            chatMessages.style.height = `${containerHeight - inputHeight}px`;
            
            // 滚动到底部显示最新消息
            scrollToBottom();
        }
    }
    
    // 滚动到底部函数，用于显示最新消息
    function scrollToBottom() {
        const chatMessages = document.querySelector('.chat-messages');
        if (chatMessages) {
            chatMessages.scrollTop = chatMessages.scrollHeight;
        }
    }
    
    // 初始化时调整聊天容器高度
    adjustChatContainerHeight();
    
    // 页面加载后确保滚动到最新消息
    setTimeout(scrollToBottom, 100);
    
    // 窗口大小变化时重新调整并滚动到底部
    window.addEventListener('resize', adjustChatContainerHeight);
    
    // MutationObserver监听聊天区域内容变化，确保新消息出现时自动滚动
    const chatMessages = document.querySelector('.chat-messages');
    if (chatMessages) {
        const observer = new MutationObserver(function(mutations) {
            scrollToBottom();
        });
        
        observer.observe(chatMessages, {
            childList: true,  // 监听子节点变化
            subtree: true     // 监听所有后代节点变化
        });
    }

    // 新闻标签切换
    const navItems = document.querySelectorAll('.nav-item');
    const contentSections = document.querySelectorAll('.content-section');

    navItems.forEach(item => {
        item.addEventListener('click', function() {
            // 移除所有激活状态
            navItems.forEach(nav => nav.classList.remove('active'));
            contentSections.forEach(section => section.style.display = 'none');
            
            // 添加当前项目的激活状态
            this.classList.add('active');
            const targetId = this.getAttribute('data-target');
            document.getElementById(targetId).style.display = 'block';
        });
    });

    // 卡片悬停效果增强
    const resourceCards = document.querySelectorAll('.resource-card');
    resourceCards.forEach(card => {
        card.addEventListener('mouseenter', function() {
            this.style.transform = 'translateY(-5px)';
            this.style.boxShadow = '0 10px 20px rgba(0, 0, 0, 0.12)';
        });
        
        card.addEventListener('mouseleave', function() {
            this.style.transform = 'translateY(0)';
            this.style.boxShadow = '0 6px 16px rgba(0, 0, 0, 0.08)';
        });
    });

    // 菜单切换功能
    const menuToggle = document.getElementById('menuToggle');
    const sidebar = document.querySelector('.sidebar');
    const main = document.querySelector('.main');
    
    // 创建遮罩层用于移动端
    const overlay = document.createElement('div');
    overlay.classList.add('overlay');
    document.body.appendChild(overlay);
    
    // 显示/隐藏菜单按钮，仅在移动端显示
    function handleResponsiveMenu() {
        const menuToggle = document.getElementById('menuToggle');
        const sidebar = document.querySelector('.sidebar');
        const main = document.querySelector('.main');
        const overlay = document.querySelector('.overlay');
        
        function updateMenuVisibility() {
            if (window.innerWidth <= 768) {
                // 移动端逻辑
                menuToggle.style.display = 'block';
                sidebar.classList.remove('active');
                main.style.marginLeft = '0';
                if (overlay) overlay.classList.remove('active');
            } else {
                // 桌面端逻辑
                menuToggle.style.display = 'none';
                sidebar.classList.add('active');
                main.style.marginLeft = '250px';
                if (overlay) overlay.classList.remove('active');
            }
            
            // 重置body滚动状态
            document.body.style.overflow = '';
        }
        
        // 页面加载和窗口大小改变时执行
        updateMenuVisibility();
        
        // 窗口大小改变时重新计算
        window.addEventListener('resize', function() {
            updateMenuVisibility();
            // 如果是桌面模式，确保侧边栏可见
            if (window.innerWidth > 768) {
                sidebar.classList.add('active');
                main.style.marginLeft = '250px';
            }
        });
        
        // 菜单按钮点击事件
        if (menuToggle) {
            menuToggle.addEventListener('click', function() {
                sidebar.classList.toggle('active');
                if (overlay) overlay.classList.toggle('active');
                
                // 更新主内容区域的边距
                if (window.innerWidth <= 768) {
                    if (sidebar.classList.contains('active')) {
                        document.body.style.overflow = 'hidden';
                    } else {
                        document.body.style.overflow = '';
                    }
                }
                
                // 更新无障碍属性
                menuToggle.setAttribute('aria-expanded', sidebar.classList.contains('active'));
            });
        }
        
        // 点击遮罩层关闭菜单
        if (overlay) {
            overlay.addEventListener('click', function() {
                sidebar.classList.remove('active');
                overlay.classList.remove('active');
                document.body.style.overflow = '';
                if (menuToggle) {
                    menuToggle.setAttribute('aria-expanded', 'false');
                }
            });
        }
    }

    // 初始化响应式菜单
    handleResponsiveMenu();
    
    // 处理聊天功能
    function initChatFunctionality() {
        const chatInput = document.querySelector('.chat-input');
        const sendButton = document.querySelector('.send-btn');
        const chatMessages = document.querySelector('.chat-messages');
        
        if (chatInput && sendButton && chatMessages) {
            // 发送消息函数
            function sendMessage() {
                const message = chatInput.value.trim();
                if (message !== '') {
                    // 创建用户消息
                    const userMessageDiv = document.createElement('div');
                    userMessageDiv.className = 'user-message';
                    
                    const messageContent = document.createElement('div');
                    messageContent.className = 'message-content';
                    
                    const messagePara = document.createElement('p');
                    messagePara.textContent = message;
                    
                    messageContent.appendChild(messagePara);
                    userMessageDiv.appendChild(messageContent);
                    
                    // 添加时间戳
                    const timestamp = document.createElement('div');
                    timestamp.className = 'message-time';
                    
                    const now = new Date();
                    timestamp.textContent = `${now.getHours().toString().padStart(2, '0')}:${now.getMinutes().toString().padStart(2, '0')}`;
                    
                    userMessageDiv.appendChild(timestamp);
                    
                    // 添加到聊天区域
                    chatMessages.appendChild(userMessageDiv);
                    
                    // 清空输入框
                    chatInput.value = '';
                    
                    // 滚动到底部
                    scrollToBottom();
                    
                    // 这里可以添加发送到后端的逻辑
                    // fetchAPI('path/to/api', { message: message })
                    //   .then(response => {
                    //     // 处理回应
                    //   });
                }
            }
            
            // 绑定发送按钮点击事件
            sendButton.addEventListener('click', sendMessage);
            
            // 绑定回车键发送
            chatInput.addEventListener('keypress', function(e) {
                if (e.key === 'Enter' && !e.shiftKey) {
                    e.preventDefault();
                    sendMessage();
                }
            });
        }
    }
    
    // 如果在聊天页面，初始化聊天功能
    if (document.querySelector('.chat-container')) {
        initChatFunctionality();
    }
    
    // 调整侧边栏和内容区域高度
    function adjustContentHeight() {
        const contentWrapper = document.querySelector('.content-wrapper');
        const rightSidebar = document.querySelector('.right-sidebar');
        
        // 确保内容区域至少和视口一样高
        if (contentWrapper) {
            contentWrapper.style.minHeight = `calc(100vh - 60px)`;
        }
        
        // 如果存在右侧栏，调整其高度
        if (rightSidebar && window.innerWidth > 992) {
            const contentHeight = document.querySelector('.content').offsetHeight;
            rightSidebar.style.minHeight = `${contentHeight}px`;
        }
    }
    
    // 页面加载和窗口大小变化时调整高度
    window.addEventListener('load', adjustContentHeight);
    window.addEventListener('resize', adjustContentHeight);
    
    // 创建MutationObserver监听内容变化以重新调整高度
    const contentWrapper = document.querySelector('.content-wrapper');
    if (contentWrapper) {
        const observer = new MutationObserver(adjustContentHeight);
        observer.observe(contentWrapper, {
            childList: true,
            subtree: true,
            attributes: true
        });
    }
}); 