/**
 * 菜单交互处理脚本
 * 用于统一处理左侧菜单的行为和高亮当前页面的菜单项
 */

document.addEventListener('DOMContentLoaded', function() {
    // 切换菜单项的展开/收起状态
    const menuTitles = document.querySelectorAll('.menu-title');
    const submenuItems = document.querySelectorAll('.submenu');
    
    // 初始化子菜单状态
    submenuItems.forEach(submenu => {
        submenu.style.display = 'none';
    });
    
    // 为每个菜单标题添加点击事件
    menuTitles.forEach(title => {
        title.addEventListener('click', function(e) {
            e.preventDefault();
            e.stopPropagation();
            
            const menuItem = this.parentElement;
            const submenu = menuItem.querySelector('.submenu');
            
            // 关闭其他打开的菜单项
            document.querySelectorAll('.menu-item.active').forEach(item => {
                if (item !== menuItem) {
                    item.classList.remove('active');
                    const otherSubmenu = item.querySelector('.submenu');
                    if (otherSubmenu) {
                        otherSubmenu.style.display = 'none';
                    }
                    
                    // 更新其他菜单的箭头
                    const otherArrow = item.querySelector('.menu-title .arrow-container i');
                    if (otherArrow) {
                        otherArrow.classList.remove('fa-chevron-up');
                        otherArrow.classList.add('fa-chevron-down');
                    }
                }
            });
            
            // 切换当前菜单项的状态
            menuItem.classList.toggle('active');
            if (submenu) {
                submenu.style.display = submenu.style.display === 'none' ? 'block' : 'none';
            }
            
            // 更新箭头方向
            const arrow = this.querySelector('.arrow-container i');
            if (arrow) {
                if (menuItem.classList.contains('active')) {
                    arrow.classList.remove('fa-chevron-down');
                    arrow.classList.add('fa-chevron-up');
                } else {
                    arrow.classList.remove('fa-chevron-up');
                    arrow.classList.add('fa-chevron-down');
                }
            }
        });
    });
    
    // 获取当前页面URL
    const currentUrl = window.location.pathname;
    const pageName = currentUrl.split('/').pop();
    
    // 页面与菜单项映射
    const menuMapping = {
        // PHP文件映射
        'index.php': { menu: 'dashboard', page: 'dashboard' },
        'product.php': { menu: 'purchase', page: 'products' },
        'orders.php': { menu: 'orders', page: 'order-list' },
        'finance.php': { menu: 'finance', page: 'transactions' },
        'recharge.php': { menu: 'finance', page: 'wallet' },
        'pay.php': { menu: 'finance', page: 'wallet' },
        'ticket.php': { menu: 'tickets', page: 'ticket-list' },
        'ticket_add.php': { menu: 'tickets', page: 'create-ticket' },
        'ticket_detail.php': { menu: 'tickets', page: 'ticket-list' },
        'ocs.php': { menu: 'tickets', page: 'ticket-list' },
        'machine.php': { menu: 'orders', page: 'order-list' },
        
        // HTML文件映射
        'index.html': { menu: 'dashboard', page: 'dashboard' },
        'product.html': { menu: 'purchase', page: 'products' },
        'orders.html': { menu: 'orders', page: 'order-list' },
        'finance.html': { menu: 'finance', page: 'transactions' },
        'recharge.html': { menu: 'finance', page: 'wallet' },
        'pay.html': { menu: 'finance', page: 'wallet' },
        'ticket.html': { menu: 'tickets', page: 'ticket-list' },
        'ticket_add.html': { menu: 'tickets', page: 'create-ticket' },
        'ticket_detail.html': { menu: 'tickets', page: 'ticket-list' },
        'ocs.html': { menu: 'tickets', page: 'ticket-list' },
        'machine.html': { menu: 'orders', page: 'order-list' }
    };
    
    // 根据当前页面设置激活状态
    if (menuMapping[pageName]) {
        const { menu, page } = menuMapping[pageName];
        
        // 激活对应的主菜单
        const menuItem = document.querySelector(`.menu-title[data-target="${menu}"]`);
        if (menuItem) {
            const parentItem = menuItem.parentElement;
            parentItem.classList.add('active');
            
            // 显示子菜单
            const submenu = parentItem.querySelector('.submenu');
            if (submenu) {
                submenu.style.display = 'block';
            }
            
            // 更新箭头
            const arrow = menuItem.querySelector('.arrow-container i');
            if (arrow) {
                arrow.classList.remove('fa-chevron-down');
                arrow.classList.add('fa-chevron-up');
            }
            
            // 激活对应的子菜单项
            const submenuItem = document.querySelector(`.submenu a[data-page="${page}"]`);
            if (submenuItem) {
                submenuItem.classList.add('active');
            }
        }
    } else {
        // 当前页面没有映射关系，尝试使用来源页面(referrer)
        if (document.referrer) {
            // 提取来源页面的URL
            const referrerUrl = new URL(document.referrer);
            const referrerPath = referrerUrl.pathname;
            const referrerPage = referrerPath.split('/').pop();
            
            // 检查来源页面是否有映射
            if (menuMapping[referrerPage]) {
                const { menu, page } = menuMapping[referrerPage];
                
                // 激活对应的主菜单
                const menuItem = document.querySelector(`.menu-title[data-target="${menu}"]`);
                if (menuItem) {
                    const parentItem = menuItem.parentElement;
                    parentItem.classList.add('active');
                    
                    // 显示子菜单
                    const submenu = parentItem.querySelector('.submenu');
                    if (submenu) {
                        submenu.style.display = 'block';
                    }
                    
                    // 更新箭头
                    const arrow = menuItem.querySelector('.arrow-container i');
                    if (arrow) {
                        arrow.classList.remove('fa-chevron-down');
                        arrow.classList.add('fa-chevron-up');
                    }
                    
                    // 激活对应的子菜单项
                    const submenuItem = document.querySelector(`.submenu a[data-page="${page}"]`);
                    if (submenuItem) {
                        submenuItem.classList.add('active');
                    }
                }
            }
        }
    }
    
    // 处理移动端菜单切换
    const menuToggle = document.getElementById('menuToggle');
    const sidebar = document.querySelector('.sidebar');
    
    if (menuToggle && sidebar) {
        menuToggle.addEventListener('click', function() {
            sidebar.classList.toggle('active');
            
            // 添加遮罩层
            let overlay = document.querySelector('.sidebar-overlay');
            
            if (!overlay) {
                overlay = document.createElement('div');
                overlay.className = 'sidebar-overlay';
                document.body.appendChild(overlay);
                
                // 点击遮罩层关闭菜单
                overlay.addEventListener('click', function() {
                    sidebar.classList.remove('active');
                    this.classList.remove('active');
                });
            }
            
            overlay.classList.toggle('active');
        });
    }
    
    // 窗口调整大小时适应布局
    window.addEventListener('resize', function() {
        if (window.innerWidth > 768) {
            // 移除移动端菜单相关类
            if (sidebar) {
                sidebar.classList.remove('active');
            }
            
            const overlay = document.querySelector('.sidebar-overlay');
            if (overlay) {
                overlay.classList.remove('active');
            }
        }
    });
}); 