/**
 * Payment page JavaScript functionality
 */

// 立即执行函数，确保不污染全局作用域
(function() {
  // 将所有函数直接绑定到全局 window 对象，确保内联 onclick 事件可以正常调用
  window.showPaymentModal = showPaymentModal;
  window.closePaymentModal = closePaymentModal;
  window.copyAddress = copyAddress;
  
  // 在脚本加载后立即执行初始化
  initPaymentPage();
  
  // 页面加载完成后执行的初始化函数
  function initPaymentPage() {
    console.log('[支付页面] 初始化开始');
    
    // 设置支付按钮点击事件
    setupPaymentButton();
    
    // 设置模态框外部点击关闭事件
    setupModalOutsideClick();
    
    console.log('[支付页面] 初始化完成');
  }
  
  // 设置支付按钮点击事件
  function setupPaymentButton() {
    const payButton = document.getElementById('payButton');
    if (payButton) {
      console.log('[支付页面] 找到支付按钮，绑定点击事件');
      
      // 删除可能已存在的事件监听器
      payButton.removeEventListener('click', showPaymentModal);
      
      // 添加新的事件监听器
      payButton.addEventListener('click', showPaymentModal);
      
      // 确保内联事件也能正常工作
      payButton.onclick = showPaymentModal;
      
      console.log('[支付页面] 支付按钮点击事件已绑定');
    } else {
      console.error('[支付页面] 找不到支付按钮元素');
    }
  }
  
  // 设置模态框外部点击关闭事件
  function setupModalOutsideClick() {
    const modal = document.getElementById('paymentModal');
    if (modal) {
      window.onclick = function(event) {
        if (event.target === modal) {
          closePaymentModal();
        }
      };
    }
  }
  
  // 显示支付模态框
  function showPaymentModal() {
    console.log('[支付页面] 显示支付模态框被触发');
    
    const modal = document.getElementById('paymentModal');
    if (!modal) {
      console.error('[支付页面] 找不到支付模态框元素');
      return;
    }
    
    // 显示模态框
    modal.style.display = 'block';
    document.body.style.overflow = 'hidden'; // 防止背景滚动
    
    // 处理支付请求
    processPaymentRequest();
  }
  
  // 处理支付请求
  function processPaymentRequest() {
    try {
      // 获取支付金额和订单号
      const amountElement = document.getElementById('actualAmount');
      const orderElement = document.getElementById('orderNumber');
      
      if (!amountElement || !orderElement) {
        console.error('[支付页面] 找不到金额或订单号元素');
        return;
      }
      
      const amount = amountElement.value;
      const orderNumber = orderElement.textContent.trim().replace('# ', '');
      
      if (!amount || !orderNumber) {
        console.error('[支付页面] 金额或订单号为空');
        return;
      }
      
      console.log('[支付页面] 准备发送支付请求:', { amount, orderNumber });
      
      // 创建表单数据
      const formData = new FormData();
      formData.append('amount', amount);
      formData.append('orderNumber', orderNumber);
      
      // 发送请求到服务器
      fetch('code/process_payment.php', {
        method: 'POST',
        body: formData,
        credentials: 'same-origin'
      })
      .then(response => {
        if (!response.ok) {
          throw new Error(`HTTP error! status: ${response.status}`);
        }
        return response.text();
      })
      .then(text => {
        try {
          return JSON.parse(text);
        } catch (e) {
          console.error('[支付页面] JSON解析错误:', text);
          throw new Error('无法解析JSON响应');
        }
      })
      .then(data => {
        if (data.status === 'success') {
          console.log('[支付页面] 支付请求已记录，等待确认');
        } else {
          console.error('[支付页面] 支付记录失败:', data.message);
        }
      })
      .catch(error => {
        console.error('[支付页面] 支付请求发送失败:', error);
      });
    } catch (error) {
      console.error('[支付页面] 处理支付请求时发生错误:', error);
    }
  }
  
  // 关闭支付模态框
  function closePaymentModal() {
    const modal = document.getElementById('paymentModal');
    if (modal) {
      modal.style.display = 'none';
      document.body.style.overflow = 'auto'; // 恢复背景滚动
    }
  }
  
  // 复制钱包地址
  function copyAddress() {
    try {
      const addressElement = document.getElementById('walletAddress');
      if (!addressElement) {
        console.error('[支付页面] 找不到钱包地址元素');
        return;
      }
      
      const address = addressElement.textContent.trim();
      if (!address) {
        console.error('[支付页面] 钱包地址为空');
        return;
      }
      
      // 复制到剪贴板
      navigator.clipboard.writeText(address)
        .then(() => {
          // 显示复制成功反馈
          const btn = document.querySelector('.copy-btn');
          if (!btn) return;
          
          const originalIcon = btn.innerHTML;
          btn.innerHTML = '<i class="fas fa-check"></i>';
          btn.style.backgroundColor = '#4caf50';
          
          // 2秒后恢复按钮原始状态
          setTimeout(() => {
            btn.innerHTML = originalIcon;
            btn.style.backgroundColor = '';
          }, 2000);
        })
        .catch(err => {
          console.error('[支付页面] 复制失败:', err);
          alert('复制失败，请手动复制地址');
        });
    } catch (error) {
      console.error('[支付页面] 复制地址时发生错误:', error);
    }
  }
  
  // 确保在DOM加载完成后再次执行初始化
  if (document.readyState === 'loading') {
    document.addEventListener('DOMContentLoaded', initPaymentPage);
  } else {
    // 如果页面已经加载完成，立即执行初始化
    initPaymentPage();
  }
})();
