/**
 * 产品筛选功能脚本
 * 管理产品页面的筛选、排序和分页操作
 */

document.addEventListener('DOMContentLoaded', function() {
    // 当前筛选条件
    const currentFilters = {
        tag: typeof selectedTag !== 'undefined' ? selectedTag : 0,
        parent_region: typeof selectedParent !== 'undefined' ? selectedParent : 0,
        region: typeof selectedRegion !== 'undefined' ? selectedRegion : 0,
        min_price: typeof selectedMinPrice !== 'undefined' ? selectedMinPrice : null,
        max_price: typeof selectedMaxPrice !== 'undefined' ? selectedMaxPrice : null,
        sort: typeof sortBy !== 'undefined' ? sortBy : 'recommended',
        order: typeof sortOrder !== 'undefined' ? sortOrder : '',
        page: typeof currentPage !== 'undefined' ? currentPage : 1
    };

    // 显示或隐藏筛选结果统计
    updateFilterSummary();

    // 处理地区选择点击事件
    const countryOptions = document.querySelectorAll('.country-option');
    countryOptions.forEach(option => {
        option.addEventListener('click', function(e) {
            e.preventDefault();
            const parentId = this.getAttribute('data-value');
            
            // 更新选中状态
            countryOptions.forEach(opt => opt.classList.remove('active'));
            this.classList.add('active');
            
            // 更新筛选条件并重新加载
            currentFilters.parent_region = parentId;
            currentFilters.region = 0; // 重置子地区选择
            currentFilters.page = 1; // 重置页码
            applyFilters();
            
            // 显示相应的子地区选项
            updateRegionOptions(parentId);
        });
    });
    
    // 处理子地区选择点击事件
    document.querySelectorAll('[data-filter="region"]').forEach(option => {
        option.addEventListener('click', function(e) {
            e.preventDefault();
            const regionId = this.getAttribute('data-value');
            
            // 更新选中状态
            document.querySelectorAll('[data-filter="region"]').forEach(opt => opt.classList.remove('active'));
            this.classList.add('active');
            
            // 更新筛选条件并重新加载
            currentFilters.region = regionId;
            currentFilters.page = 1; // 重置页码
            applyFilters();
        });
    });
    
    // 处理标签选择点击事件
    document.querySelectorAll('[data-filter="tag"]').forEach(option => {
        option.addEventListener('click', function(e) {
            e.preventDefault();
            const tagId = this.getAttribute('data-value');
            
            // 更新选中状态，只在当前标签组内部修改
            const tagGroup = this.closest('.filter-options');
            tagGroup.querySelectorAll('.filter-option').forEach(opt => opt.classList.remove('active'));
            this.classList.add('active');
            
            // 更新筛选条件并重新加载
            currentFilters.tag = tagId;
            currentFilters.page = 1; // 重置页码
            applyFilters();
        });
    });
    
    // 处理价格范围选择点击事件
    document.querySelectorAll('[data-filter="price"]').forEach(option => {
        option.addEventListener('click', function(e) {
            e.preventDefault();
            const minPrice = this.getAttribute('data-min');
            const maxPrice = this.getAttribute('data-max');
            
            // 更新选中状态
            document.querySelectorAll('[data-filter="price"]').forEach(opt => opt.classList.remove('active'));
            this.classList.add('active');
            
            // 更新筛选条件并重新加载
            currentFilters.min_price = minPrice;
            currentFilters.max_price = maxPrice;
            currentFilters.page = 1; // 重置页码
            applyFilters();
        });
    });
    
    // 处理排序选项点击事件
    document.querySelectorAll('.sort-option').forEach(option => {
        option.addEventListener('click', function(e) {
            e.preventDefault();
            const sortType = this.getAttribute('data-sort');
            let sortOrder = '';
            
            if (sortType === 'price' || sortType === 'created') {
                // 对于价格和上架时间，可以切换排序方向
                const currentOrder = this.getAttribute('data-current-order') || '';
                sortOrder = currentOrder === 'asc' ? 'desc' : 'asc';
                this.setAttribute('data-current-order', sortOrder);
                
                // 更新排序图标
                const iconElement = this.querySelector('i');
                if (iconElement) {
                    if (sortOrder === 'asc') {
                        iconElement.className = 'fas fa-arrow-down';
                    } else {
                        iconElement.className = 'fas fa-arrow-up';
                    }
                }
            }
            
            // 更新选中状态
            document.querySelectorAll('.sort-option').forEach(opt => opt.classList.remove('active'));
            this.classList.add('active');
            
            // 更新筛选条件并重新加载
            currentFilters.sort = sortType;
            currentFilters.order = sortOrder;
            currentFilters.page = 1; // 重置页码
            applyFilters();
        });
    });
    
    // 处理分页点击事件
    document.addEventListener('click', function(e) {
        if (e.target.closest('.pagination a')) {
            e.preventDefault();
            const pageLink = e.target.closest('.pagination a');
            if (pageLink.classList.contains('disabled')) return;
            
            const page = pageLink.getAttribute('data-page');
            currentFilters.page = page;
            applyFilters();
            
            // 滚动到页面顶部
            window.scrollTo(0, 0);
        }
    });
    
    // 处理清除筛选按钮点击事件
    document.getElementById('clear-filters')?.addEventListener('click', function(e) {
        e.preventDefault();
        
        // 重置所有筛选条件
        currentFilters.tag = 0;
        currentFilters.parent_region = 0;
        currentFilters.region = 0;
        currentFilters.min_price = null;
        currentFilters.max_price = null;
        currentFilters.page = 1;
        
        // 应用筛选
        applyFilters();
    });

    /**
     * 应用当前筛选条件并重新加载页面
     */
    function applyFilters() {
        // 构建URL参数
        const params = new URLSearchParams();
        
        if (currentFilters.tag && currentFilters.tag != 0) {
            params.append('tag', currentFilters.tag);
        }
        
        if (currentFilters.parent_region && currentFilters.parent_region != 0) {
            params.append('parent_region', currentFilters.parent_region);
        }
        
        if (currentFilters.region && currentFilters.region != 0) {
            params.append('region', currentFilters.region);
        }
        
        if (currentFilters.min_price && currentFilters.max_price) {
            params.append('min_price', currentFilters.min_price);
            params.append('max_price', currentFilters.max_price);
        }
        
        if (currentFilters.sort && currentFilters.sort !== 'recommended') {
            params.append('sort', currentFilters.sort);
            if (currentFilters.order) {
                params.append('order', currentFilters.order);
            }
        }
        
        if (currentFilters.page && currentFilters.page > 1) {
            params.append('page', currentFilters.page);
        }
        
        // 重定向到包含筛选条件的URL
        const url = window.location.pathname + (params.toString() ? '?' + params.toString() : '');
        window.location.href = url;
    }
    
    /**
     * 更新筛选结果统计显示
     */
    function updateFilterSummary() {
        const filterSummary = document.getElementById('filter-summary');
        if (!filterSummary) return;
        
        // 判断是否有活跃的筛选条件
        const hasActiveFilters = 
            currentFilters.tag != 0 || 
            currentFilters.parent_region != 0 || 
            currentFilters.region != 0 || 
            (currentFilters.min_price && currentFilters.max_price);
            
        // 更新产品数量
        const productCount = document.getElementById('product-count');
        if (productCount) {
            const totalProducts = document.querySelectorAll('.server-table tbody tr').length;
            productCount.textContent = totalProducts;
        }
        
        // 显示或隐藏筛选结果统计
        if (hasActiveFilters) {
            filterSummary.style.display = 'flex';
            filterSummary.style.justifyContent = 'space-between';
            filterSummary.style.alignItems = 'center';
        } else {
            filterSummary.style.display = 'none';
        }
    }
    
    /**
     * 更新地区选项显示
     * @param {string} parentId 父地区ID
     */
    function updateRegionOptions(parentId) {
        const regionFilterSection = document.getElementById('region-filter-section');
        if (!regionFilterSection) return;
        
        // 获取所有地区组
        const regionGroups = document.querySelectorAll('.region-group');
        
        // 如果选择了特定父地区
        if (parentId && parentId != '0') {
            // 显示地区筛选部分
            regionFilterSection.style.display = 'block';
            
            // 隐藏所有地区组
            regionGroups.forEach(group => {
                group.style.display = 'none';
                group.classList.remove('active');
            });
            
            // 显示选中的父地区对应的子地区组
            const selectedGroup = document.querySelector(`.region-group[data-parent="${parentId}"]`);
            if (selectedGroup) {
                selectedGroup.style.display = 'flex';
                selectedGroup.classList.add('active');
                
                // 判断是否有子地区，如果没有则隐藏整个区域选择部分
                const hasChildren = selectedGroup.querySelectorAll('.filter-option').length > 0;
                if (!hasChildren) {
                    regionFilterSection.style.display = 'none';
                }
            }
        } else {
            // 如果选择了"全部"，隐藏地区筛选部分
            regionFilterSection.style.display = 'none';
        }
    }
}); 