/**
 * 提交工单页面相关功能脚本
 */
document.addEventListener('DOMContentLoaded', function() {
    // 初始化文件上传功能
    initFileUpload();
    
    // 初始化编辑器工具栏
    initEditorToolbar();
    
    // 表单提交处理
    initFormSubmit();
    
    // 取消按钮处理
    document.querySelector('.cancel-btn').addEventListener('click', function() {
        window.location.href = 'ticket.php';
    });
});

/**
 * 初始化文件上传功能
 */
function initFileUpload() {
    const fileInput = document.getElementById('attachments');
    const uploadBtn = document.querySelector('.upload-btn');
    const addMoreBtn = document.querySelector('.add-more-btn');
    const fileList = document.getElementById('fileList');
    const allowedTypes = ['.jpg', '.gif', '.jpeg', '.png'];
    const maxFileSize = 1024 * 1024; // 1MB
    
    // 点击"选择文件"按钮时触发文件选择
    uploadBtn.addEventListener('click', function() {
        fileInput.click();
    });
    
    // 点击"添加更多"按钮时触发文件选择
    addMoreBtn.addEventListener('click', function() {
        fileInput.click();
    });
    
    // 文件选择后的处理
    fileInput.addEventListener('change', function() {
        // 处理选中的文件
        const files = this.files;
        
        for (let i = 0; i < files.length; i++) {
            const file = files[i];
            
            // 检查文件类型
            let validType = false;
            for (let j = 0; j < allowedTypes.length; j++) {
                if (file.name.toLowerCase().endsWith(allowedTypes[j])) {
                    validType = true;
                    break;
                }
            }
            
            // 检查文件大小
            const validSize = file.size <= maxFileSize;
            
            // 检查文件名是否包含中文
            const hasChinese = /[\u4e00-\u9fa5]/.test(file.name);
            
            if (!validType) {
                showNotification('错误', `文件 ${file.name} 的类型不被支持。`, 'error');
                continue;
            }
            
            if (!validSize) {
                showNotification('错误', `文件 ${file.name} 超过了1MB的大小限制。`, 'error');
                continue;
            }
            
            if (hasChinese) {
                showNotification('错误', `文件 ${file.name} 包含中文字符，不支持。`, 'error');
                continue;
            }
            
            // 创建文件项
            const fileItem = document.createElement('div');
            fileItem.className = 'file-item';
            
            const fileName = document.createElement('span');
            fileName.className = 'file-name';
            fileName.textContent = file.name;
            
            const removeBtn = document.createElement('button');
            removeBtn.className = 'remove-file';
            removeBtn.innerHTML = '<i class="fas fa-times"></i>';
            removeBtn.dataset.filename = file.name;
            
            // 删除文件的点击事件
            removeBtn.addEventListener('click', function() {
                fileItem.remove();
            });
            
            fileItem.appendChild(fileName);
            fileItem.appendChild(removeBtn);
            fileList.appendChild(fileItem);
        }
    });
}

/**
 * 初始化编辑器工具栏
 */
function initEditorToolbar() {
    const textarea = document.getElementById('message');
    const buttons = document.querySelectorAll('.editor-toolbar button');
    
    buttons.forEach(button => {
        button.addEventListener('click', function() {
            const action = this.getAttribute('title');
            let startTag = '';
            let endTag = '';
            
            switch(action) {
                case '粗体':
                    startTag = '**';
                    endTag = '**';
                    break;
                case '斜体':
                    startTag = '*';
                    endTag = '*';
                    break;
                case '标题':
                    startTag = '## ';
                    endTag = '';
                    break;
                case '链接':
                    startTag = '[链接文本](';
                    endTag = ')';
                    break;
                case '无序列表':
                    startTag = '- ';
                    endTag = '';
                    break;
                case '有序列表':
                    startTag = '1. ';
                    endTag = '';
                    break;
                case '代码':
                    startTag = '```\n';
                    endTag = '\n```';
                    break;
                case '引用':
                    startTag = '> ';
                    endTag = '';
                    break;
                case '预览':
                    showPreview();
                    return;
                case '帮助':
                    showHelp();
                    return;
            }
            
            // 插入标记
            insertAtCursor(textarea, startTag, endTag);
        });
    });
}

/**
 * 在光标位置插入文本
 */
function insertAtCursor(textarea, startTag, endTag) {
    if (document.selection) {
        // IE
        textarea.focus();
        const sel = document.selection.createRange();
        const selectedText = sel.text;
        sel.text = startTag + selectedText + endTag;
        textarea.focus();
    } else if (textarea.selectionStart || textarea.selectionStart === 0) {
        // 其他浏览器
        const startPos = textarea.selectionStart;
        const endPos = textarea.selectionEnd;
        const selectedText = textarea.value.substring(startPos, endPos);
        
        textarea.value = textarea.value.substring(0, startPos) + 
                         startTag + selectedText + endTag + 
                         textarea.value.substring(endPos, textarea.value.length);
        
        // 重新定位光标
        textarea.focus();
        textarea.selectionStart = startPos + startTag.length + selectedText.length;
        textarea.selectionEnd = startPos + startTag.length + selectedText.length;
    } else {
        // 回退方案
        textarea.value += startTag + endTag;
        textarea.focus();
    }
}

/**
 * 显示预览
 */
function showPreview() {
    const content = document.getElementById('message').value;
    // 这里应该有一个转换Markdown到HTML的函数
    const convertedContent = simpleMdToHtml(content);
    
    // 创建预览模态框
    const modal = document.createElement('div');
    modal.className = 'modal';
    
    const modalContent = document.createElement('div');
    modalContent.className = 'modal-content';
    
    const modalHeader = document.createElement('div');
    modalHeader.className = 'modal-header';
    modalHeader.innerHTML = '<h3>预览</h3><span class="close">&times;</span>';
    
    const modalBody = document.createElement('div');
    modalBody.className = 'modal-body preview-content';
    modalBody.innerHTML = convertedContent;
    
    modalContent.appendChild(modalHeader);
    modalContent.appendChild(modalBody);
    modal.appendChild(modalContent);
    
    // 添加到页面
    document.body.appendChild(modal);
    
    // 关闭按钮功能
    const closeBtn = modal.querySelector('.close');
    closeBtn.addEventListener('click', function() {
        document.body.removeChild(modal);
    });
    
    // 点击模态框外部关闭
    modal.addEventListener('click', function(e) {
        if (e.target === modal) {
            document.body.removeChild(modal);
        }
    });
}

/**
 * 简单的Markdown到HTML转换
 */
function simpleMdToHtml(markdown) {
    // 这只是一个简单的实现，实际应用中应使用成熟的Markdown解析库
    let html = markdown
        // 标题转换
        .replace(/^## (.*$)/gm, '<h2>$1</h2>')
        .replace(/^# (.*$)/gm, '<h1>$1</h1>')
        // 加粗和斜体
        .replace(/\*\*(.*?)\*\*/g, '<strong>$1</strong>')
        .replace(/\*(.*?)\*/g, '<em>$1</em>')
        // 链接
        .replace(/\[(.*?)\]\((.*?)\)/g, '<a href="$2">$1</a>')
        // 列表
        .replace(/^\- (.*$)/gm, '<li>$1</li>')
        .replace(/^1\. (.*$)/gm, '<li>$1</li>')
        // 引用
        .replace(/^\> (.*$)/gm, '<blockquote>$1</blockquote>')
        // 代码块
        .replace(/```([\s\S]*?)```/g, '<pre><code>$1</code></pre>');
    
    // 段落处理
    html = html.replace(/^(?!<h|<li|<blockquote|<pre)(.*$)/gm, '<p>$1</p>');
    
    return html;
}

/**
 * 显示帮助
 */
function showHelp() {
    const helpContent = `
        <div class="help-section">
            <h2>编辑器使用帮助</h2>
            <ul>
                <li><strong>粗体</strong>: 使用 **文本** 来加粗文本</li>
                <li><em>斜体</em>: 使用 *文本* 来设置斜体</li>
                <li><h4>标题</h4>: 使用 ## 文本 来创建标题</li>
                <li><a href="#">链接</a>: 使用 [链接文本](链接地址) 来插入链接</li>
                <li>列表项: 使用 - 或 1. 来创建列表</li>
                <li>代码: 使用 \`\`\`代码内容\`\`\` 来插入代码块</li>
                <li>引用: 使用 > 文本 来创建引用</li>
            </ul>
        </div>
    `;
    
    // 创建帮助模态框
    const modal = document.createElement('div');
    modal.className = 'modal';
    
    const modalContent = document.createElement('div');
    modalContent.className = 'modal-content';
    
    const modalHeader = document.createElement('div');
    modalHeader.className = 'modal-header';
    modalHeader.innerHTML = '<h3>Markdown 编辑器帮助</h3><span class="close">&times;</span>';
    
    const modalBody = document.createElement('div');
    modalBody.className = 'modal-body';
    modalBody.innerHTML = helpContent;
    
    modalContent.appendChild(modalHeader);
    modalContent.appendChild(modalBody);
    modal.appendChild(modalContent);
    
    // 添加到页面
    document.body.appendChild(modal);
    
    // 关闭按钮功能
    const closeBtn = modal.querySelector('.close');
    closeBtn.addEventListener('click', function() {
        document.body.removeChild(modal);
    });
    
    // 点击模态框外部关闭
    modal.addEventListener('click', function(e) {
        if (e.target === modal) {
            document.body.removeChild(modal);
        }
    });
}

/**
 * 初始化表单提交
 */
function initFormSubmit() {
    const form = document.getElementById('ticketForm');
    
    form.addEventListener('submit', function(e) {
        e.preventDefault();
        
        // 验证表单
        if (!validateForm()) {
            return;
        }
        
        // 这里应该是AJAX提交表单的代码
        // 为演示，我们只显示成功消息
        showNotification('成功', '工单已成功提交，我们将尽快处理。', 'success');
        
        // 清空表单
        setTimeout(() => {
            window.location.href = 'ticket.php';
        }, 2000);
    });
}

/**
 * 验证表单
 */
function validateForm() {
    const requiredFields = document.querySelectorAll('[required]');
    let valid = true;
    
    requiredFields.forEach(field => {
        if (!field.value.trim()) {
            field.classList.add('error');
            valid = false;
            
            // 添加焦点事件来移除错误样式
            field.addEventListener('focus', function() {
                this.classList.remove('error');
            }, { once: true });
        }
    });
    
    if (!valid) {
        showNotification('错误', '请填写所有必填字段。', 'error');
    }
    
    return valid;
}

/**
 * 显示通知
 */
function showNotification(title, message, type) {
    // 创建通知元素
    const notification = document.createElement('div');
    notification.className = type === 'error' ? 'error-message' : 'success-message';
    notification.textContent = message;
    
    // 添加到页面
    document.body.appendChild(notification);
    
    // 设置自动移除
    setTimeout(() => {
        document.body.removeChild(notification);
    }, 3000);
} 