/**
 * 工单列表页面相关功能脚本
 */
document.addEventListener('DOMContentLoaded', function() {
    // 初始化排序功能
    initSorting();
    
    // 初始化分页
    initPagination();
    
    // 检查是否有工单记录
    checkNoResults();
    
    // 设置每页显示数量选择功能
    initPerPageSelect();
});

/**
 * 初始化表格排序功能
 */
function initSorting() {
    const sortableHeaders = document.querySelectorAll('#ticketTable th.sortable');
    
    sortableHeaders.forEach(header => {
        header.addEventListener('click', function() {
            const sortDirection = this.classList.contains('sort-asc') ? 'desc' : 'asc';
            
            // 移除所有排序类
            sortableHeaders.forEach(h => {
                h.classList.remove('sort-asc', 'sort-desc');
            });
            
            // 添加当前排序类
            this.classList.add(`sort-${sortDirection}`);
            
            // 更新图标
            updateSortIcons();
            
            // 执行排序
            sortTable(this.dataset.sort, sortDirection);
        });
    });
}

/**
 * 更新排序图标显示
 */
function updateSortIcons() {
    const headers = document.querySelectorAll('#ticketTable th.sortable');
    
    headers.forEach(header => {
        const icon = header.querySelector('i');
        
        // 重置所有图标
        icon.className = 'fas fa-sort';
        
        // 设置当前排序图标
        if (header.classList.contains('sort-asc')) {
            icon.className = 'fas fa-sort-up';
        } else if (header.classList.contains('sort-desc')) {
            icon.className = 'fas fa-sort-down';
        }
    });
}

/**
 * 排序表格
 */
function sortTable(column, direction) {
    const table = document.getElementById('ticketTable');
    const tbody = table.querySelector('tbody');
    const rows = Array.from(tbody.querySelectorAll('tr'));
    
    // 获取列索引
    let columnIndex;
    const headers = table.querySelectorAll('th');
    
    for (let i = 0; i < headers.length; i++) {
        if (headers[i].dataset.sort === column) {
            columnIndex = i;
            break;
        }
    }
    
    // 按指定列排序
    rows.sort((a, b) => {
        const aValue = a.cells[columnIndex].textContent.trim();
        const bValue = b.cells[columnIndex].textContent.trim();
        
        // 对日期列特殊处理
        if (column === 'date') {
            return compareDate(aValue, bValue, direction);
        }
        
        // 普通文本比较
        return direction === 'asc' ? 
            aValue.localeCompare(bValue) : 
            bValue.localeCompare(aValue);
    });
    
    // 重新排列行
    rows.forEach(row => {
        tbody.appendChild(row);
    });
}

/**
 * 比较日期格式
 */
function compareDate(a, b, direction) {
    // 解析日期格式，假设格式为 MM/DD/YYYY (HH:MM)
    const dateA = parseTicketDate(a);
    const dateB = parseTicketDate(b);
    
    return direction === 'asc' ? 
        dateA - dateB : 
        dateB - dateA;
}

/**
 * 解析工单日期字符串为Date对象
 */
function parseTicketDate(dateString) {
    // 格式假设为 MM/DD/YYYY (HH:MM)
    const regex = /(\d{2})\/(\d{2})\/(\d{4})\s*\((\d{2}):(\d{2})\)/;
    const match = dateString.match(regex);
    
    if (match) {
        const month = parseInt(match[1]) - 1; // 月份从0开始
        const day = parseInt(match[2]);
        const year = parseInt(match[3]);
        const hour = parseInt(match[4]);
        const minute = parseInt(match[5]);
        
        return new Date(year, month, day, hour, minute);
    }
    
    return new Date(0); // 无效日期返回1970年
}

/**
 * 初始化分页功能
 */
function initPagination() {
    const pageNumbers = document.querySelectorAll('.page-num');
    const prevButton = document.getElementById('prevPage');
    const nextButton = document.getElementById('nextPage');
    
    // 页码点击事件
    pageNumbers.forEach(page => {
        page.addEventListener('click', function(e) {
            e.preventDefault();
            
            // 移除当前活动页
            document.querySelector('.page-num.active').classList.remove('active');
            
            // 设置当前页为活动页
            this.classList.add('active');
            
            // 模拟加载新页面
            simulatePageLoad();
        });
    });
    
    // 上一页按钮
    prevButton.addEventListener('click', function(e) {
        e.preventDefault();
        
        const currentPage = document.querySelector('.page-num.active');
        const prevPage = currentPage.previousElementSibling;
        
        if (prevPage && prevPage.classList.contains('page-num')) {
            currentPage.classList.remove('active');
            prevPage.classList.add('active');
            
            // 模拟加载新页面
            simulatePageLoad();
        }
    });
    
    // 下一页按钮
    nextButton.addEventListener('click', function(e) {
        e.preventDefault();
        
        const currentPage = document.querySelector('.page-num.active');
        const nextPage = currentPage.nextElementSibling;
        
        if (nextPage && nextPage.classList.contains('page-num')) {
            currentPage.classList.remove('active');
            nextPage.classList.add('active');
            
            // 模拟加载新页面
            simulatePageLoad();
        }
    });
}

/**
 * 模拟页面加载
 */
function simulatePageLoad() {
    const tbody = document.querySelector('#ticketTable tbody');
    
    // 显示加载状态
    tbody.style.opacity = '0.5';
    
    // 模拟延迟
    setTimeout(() => {
        tbody.style.opacity = '1';
    }, 500);
}

/**
 * 检查是否有工单记录
 */
function checkNoResults() {
    const rows = document.querySelectorAll('#ticketTable tbody tr');
    const noResults = document.querySelector('.no-results');
    
    if (rows.length === 0) {
        noResults.classList.add('show');
    } else {
        noResults.classList.remove('show');
    }
}

/**
 * 初始化每页显示数量选择功能
 */
function initPerPageSelect() {
    const perPageSelect = document.getElementById('perPageSelect');
    
    perPageSelect.addEventListener('change', function() {
        // 模拟重新加载页面
        const tbody = document.querySelector('#ticketTable tbody');
        tbody.style.opacity = '0.5';
        
        setTimeout(() => {
            tbody.style.opacity = '1';
            
            // 重置为第一页
            const activePageBtn = document.querySelector('.page-num.active');
            if (activePageBtn) {
                activePageBtn.classList.remove('active');
            }
            
            const firstPageBtn = document.querySelector('.page-num');
            if (firstPageBtn) {
                firstPageBtn.classList.add('active');
            }
        }, 500);
    });
} 