<!DOCTYPE html>
<html lang="zh-CN">
  <?php
require_once 'code/auth.php';
require_once 'code/publi.php';
require_once '../config/database.php'; // 引入数据库配置文件

// 设置默认时区
date_default_timezone_set('Asia/Shanghai');

// 格式化日期时间的函数
function formatDateTime($dateTime, $format = 'Y-m-d H:i:s') {
    if (empty($dateTime)) {
        return '-';
    }
    
    // 处理已经是标准日期格式的情况
    if (preg_match('/^\d{4}-\d{2}-\d{2} \d{2}:\d{2}:\d{2}$/', $dateTime)) {
        return date($format, strtotime($dateTime));
    }
    
    // 尝试转换时间戳
    $timestamp = strtotime($dateTime);
    if ($timestamp === false) {
        // 如果转换失败，直接返回原始值
        return $dateTime;
    }
    
    return date($format, $timestamp);
}

// 检查用户是否已登录
if (!isset($_SESSION['user_id']) || empty($_SESSION['user_id'])) {
    header('Location: login.php');
    exit;
}

// 获取当前用户ID
$userId = $_SESSION['user_id'];

// 分页参数设置
$page = isset($_GET['page']) ? intval($_GET['page']) : 1;
$perPage = isset($_GET['per_page']) ? intval($_GET['per_page']) : 10;
if ($perPage <= 0) $perPage = 10;
if ($page <= 0) $page = 1;
$offset = ($page - 1) * $perPage;

try {
    // 获取数据库连接
    $db = getDbConnection();
    
    // 计算总工单数
    $countQuery = "SELECT COUNT(*) AS total FROM tickets WHERE user_id = :user_id";
    $countStmt = $db->prepare($countQuery);
    $countStmt->bindParam(':user_id', $userId, PDO::PARAM_INT);
    $countStmt->execute();
    $totalTickets = $countStmt->fetch(PDO::FETCH_ASSOC)['total'];
    
    // 计算总页数
    $totalPages = ceil($totalTickets / $perPage);
    
    // 获取工单列表
    $ticketsQuery = "SELECT t.*, 
                    DATE_FORMAT(t.created_at, '%Y-%m-%d %H:%i:%s') as formatted_created_at,
                    DATE_FORMAT(t.last_reply, '%Y-%m-%d %H:%i:%s') as formatted_last_reply
                    FROM tickets t 
                    WHERE t.user_id = :user_id
                    ORDER BY t.last_reply DESC, t.created_at DESC
                    LIMIT :offset, :limit";
    $ticketsStmt = $db->prepare($ticketsQuery);
    $ticketsStmt->bindParam(':user_id', $userId, PDO::PARAM_INT);
    $ticketsStmt->bindParam(':offset', $offset, PDO::PARAM_INT);
    $ticketsStmt->bindParam(':limit', $perPage, PDO::PARAM_INT);
    $ticketsStmt->execute();
    $tickets = $ticketsStmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    // 记录错误日志
    error_log("工单查询错误: " . $e->getMessage());
    $error = "获取工单数据时出错，请稍后再试。";
    $tickets = [];
    $totalPages = 0;
}

// 状态映射
$statusMap = [
    'open' => '未处理',
    'pending' => '处理中',
    'answered' => '已回复',
    'replied' => '已回复',
    'closed' => '已关闭'
];

// 状态CSS类映射
$statusClassMap = [
    'open' => 'open',
    'pending' => 'pending',
    'answered' => 'answered',
    'replied' => 'answered',
    'closed' => 'closed'
];
?>
  <head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>会员中心 - 我的工单</title>
    <?php include 'public/head.php'; ?>
  </head>
  <body class="ticket-page">
    <div class="container">
      <?php include 'public/left.php'; ?>
      <!-- 主要内容区 -->
      <div class="main">
        <?php include 'public/header.php'; ?>
        <!-- 面包屑导航 -->
        <div class="breadcrumb-container">
          <div class="breadcrumb">
            <a href="index.php" class="breadcrumb-link">
              <i class="fas fa-home"></i>
              会员中心
            </a>
            <span class="breadcrumb-separator"><i class="fas fa-angle-right"></i></span>
            <span class="breadcrumb-current">
              工单管理
            </span>
          </div>
        </div>
        <div class="content-wrapper">
          <div class="ticket-content">
            <div class="ticket-actions">
              <a href="ticket_add.php" class="btn btn-primary">提交新工单</a>
            </div>
            <?php if (isset($error)): ?>
            <div class="error-message">
              <?php echo $error; ?>
            </div>
            <?php endif; ?>
            <div class="ticket-list">
              <table>
                <thead>
                  <tr>
                    <th class="sortable" data-sort="subject">主题 <i class="fas fa-sort"></i></th>
                    <th class="sortable" data-sort="status">状态 <i class="fas fa-sort"></i></th>
                    <th class="sortable" data-sort="date">最后更新 <i class="fas fa-sort"></i></th>
                  </tr>
                </thead>
                <tbody>
                  <?php if (count($tickets) > 0): ?>
                  <?php foreach ($tickets as $ticket): ?>
                  <tr class="ticket-row" data-status="<?php echo $ticket['status']; ?>">
                    <td>
                      <a href="ticket_detail.php?id=<?php echo $ticket['id']; ?>">
                        #<?php echo $ticket['id']; ?> <?php echo htmlspecialchars($ticket['subject']); ?>
                      </a>
                    </td>
                    <td>
                      <span class="status-badge <?php echo $statusClassMap[$ticket['status']]; ?>">
                        <?php echo $statusMap[$ticket['status']]; ?>
                      </span>
                    </td>
                    <td>
                      <?php 
                                                    // 显示最后回复时间或创建时间
                                                    echo $ticket['last_reply'] ? formatDateTime($ticket['last_reply'], 'Y/m/d (H:i)') : formatDateTime($ticket['created_at'], 'Y/m/d (H:i)'); 
                                                    ?>
                    </td>
                  </tr>
                  <?php endforeach; ?>
                  <?php else: ?>
                  <tr>
                    <td colspan="3" class="no-tickets">目前没有工单记录</td>
                  </tr>
                  <?php endif; ?>
                </tbody>
              </table>
            </div>

            <?php if ($totalPages > 0): ?>
            <div class="pagination">
              <div class="per-page">
                <div style="width: 160px;">每页显示:</div>
                <select id="perPageSelect" onchange="changePerPage(this.value)">
                  <option value="10" <?php echo $perPage == 10 ? 'selected' : ''; ?>>10</option>
                  <option value="20" <?php echo $perPage == 20 ? 'selected' : ''; ?>>20</option>
                  <option value="50" <?php echo $perPage == 50 ? 'selected' : ''; ?>>50</option>
                  <option value="100" <?php echo $perPage == 100 ? 'selected' : ''; ?>>100</option>
                </select>
                条
              </div>
              <div class="page-numbers">
                <a href="?page=<?php echo max(1, $page-1); ?>&per_page=<?php echo $perPage; ?>" class="page-nav" id="prevPage" <?php echo $page <= 1 ? 'disabled' : ''; ?>>上一页</a>
                <div id="pageNumbersContainer">
                  <?php
                                    // 显示分页链接
                                    $startPage = max(1, min($page - 2, $totalPages - 4));
                                    $endPage = min($totalPages, max($page + 2, 5));
                                    
                                    // 确保总是显示至少5页（如果有）
                                    if ($endPage - $startPage < 4) {
                                        $startPage = max(1, $endPage - 4);
                                    }
                                    
                                    // 第一页
                                    if ($startPage > 1) {
                                        echo '<a href="?page=1&per_page='.$perPage.'" class="page-num">1</a>';
                                        if ($startPage > 2) {
                                            echo '<span>...</span>';
                                        }
                                    }
                                    
                                    // 页码链接
                                    for ($i = $startPage; $i <= $endPage; $i++) {
                                        $activeClass = $i == $page ? 'active' : '';
                                        echo '<a href="?page='.$i.'&per_page='.$perPage.'" class="page-num '.$activeClass.'">'.$i.'</a>';
                                    }
                                    
                                    // 最后一页
                                    if ($endPage < $totalPages) {
                                        if ($endPage < $totalPages - 1) {
                                            echo '<span>...</span>';
                                        }
                                        echo '<a href="?page='.$totalPages.'&per_page='.$perPage.'" class="page-num">'.$totalPages.'</a>';
                                    }
                                    ?>
                </div>
                <a href="?page=<?php echo min($totalPages, $page+1); ?>&per_page=<?php echo $perPage; ?>" class="page-nav" id="nextPage" <?php echo $page >= $totalPages ? 'disabled' : ''; ?>>下一页</a>
              </div>
            </div>
            <?php endif; ?>
          </div>
        </div>
      </div>
    </div>
    <script src="js/main.js"></script>
    <script src="js/tickets.js"></script>
    <script src="js/js.js"></script>
    <script>
    function changePerPage(value) {
      window.location.href = '?page=1&per_page=' + value;
    }
    </script>
  </body>
</html>
